/*
 * Blackfin testcase for testing illegal/legal 32-bit opcodes from userspace
 * we track all instructions which cause some sort of exception when run from
 * userspace, this is normally EXCAUSE :
 *  - 0x21 : illegal instruction
 *  - 0x22 : illegal instruction combination
 *  - 0x2e : use of supervisor resource from userspace
 * and walk every instruction from 0x00000000 to 0xffffffff (and have 0xc000 set)
 */

# Don't want to enable for normal `make check` as it takes way too long in
# the sim -- executes over 3 billion insns, and even at 10 MIPS, that's 10+
# minutes.  Useful for directed testing, but that's about it.
# mach: bfin
# sim: --environment operating
# xfail: "too many invalid insns are decoded as valid" *-*

#include "test.h"

#define SE_ALL_BITS 32
#include "se_allopcodes.h"
	.include "testutils.inc"

.macro se_all_load_insn
	R2 = [P5];
	R0 = R2 << 16;
	R1 = R2 >> 16;
	R0 = R0 | R1;
.endm

.macro se_all_next_insn
	/* increment, and go again. */
	R0 = R2;

	/* Is this the last insn we'll execute ? */
	imm32 R1, 0xfffff7ff;
	CC = R1 == R0;
	IF CC JUMP pass_lvl;

	/* cut across the opcode space in an efficient manner:
	 * increment the high 16bits first since the low 16bits encode
	 * the type of insn ... */
	imm32 R1, 0x10000;
	R0 = R1 + R0;
	CC = R1 < R0 (IU);
	IF CC jump 1f (bp);

	R0 += 1;
	/* skip any 16bit insn chunks */
	R1 = R0;
	R1.L = 0xC000;
	CC = R0 < R1 (IU);
	IF CC R0 = R1;
1:

	/* skip parallel insns */
	R1 = R0;
	R1.L = 0xe800;	/* allow linkage insns */
	CC = R0 == R1;
	IF CC jump 1f;
	CC = BITTST (R0, 11);
	IF !CC jump 1f (bp);
	R1 = 0x800;
	R0 = R0 + R1;
1:

.ifndef BFIN_JTAG
	/* Skip debug insns when running in the sim.  */
	R1.L = 0xff00;
	R1.H = 0x0000;
	R2 = R0 & R1;
	R1.L = 0xf000;
	CC = R1 == R2;
	IF !CC jump 1f (bp);
	R0.L = 0xf100;
	R0.H = 0x0000;
1:
.endif

	[P5] = R0;
.endm

.macro se_all_insn_init
	.dw 0xc000;
	.dw 0x0000;
.endm
.macro se_all_insn_table
	/* this table must be sorted, and end with zero */
	/* start		end			SEQSTAT */
	.dw 0x1a00, 0xc000,	0x1fff, 0xc000,		0x21, 0
	.dw 0x3a00, 0xc000,	0x3fff, 0xc000,		0x21, 0
	.dw 0x5a00, 0xc000,	0x5fff, 0xc000,		0x21, 0
	.dw 0x7a00, 0xc000,	0x7fff, 0xc000,		0x21, 0
	.dw 0x9a00, 0xc000,	0x9fff, 0xc000,		0x21, 0
	.dw 0xba00, 0xc000,	0xbfff, 0xc000,		0x21, 0
	.dw 0xda00, 0xc000,	0xdfff, 0xc000,		0x21, 0
	.dw 0xfa00, 0xc000,	0xffff, 0xc000,		0x21, 0
	.dw 0x1a00, 0xc001,	0x1fff, 0xc001,		0x21, 0
	.dw 0x3a00, 0xc001,	0x3fff, 0xc001,		0x21, 0
	.dw 0x5a00, 0xc001,	0x5fff, 0xc001,		0x21, 0
	.dw 0x7a00, 0xc001,	0x7fff, 0xc001,		0x21, 0
	.dw 0x9a00, 0xc001,	0x9fff, 0xc001,		0x21, 0
	.dw 0xba00, 0xc001,	0xbfff, 0xc001,		0x21, 0
	.dw 0xda00, 0xc001,	0xdfff, 0xc001,		0x21, 0
	.dw 0xfa00, 0xc001,	0xffff, 0xc001,		0x21, 0
	.dw 0x1a00, 0xc002,	0x1fff, 0xc002,		0x21, 0
	.dw 0x3a00, 0xc002,	0x3fff, 0xc002,		0x21, 0
	.dw 0x5a00, 0xc002,	0x5fff, 0xc002,		0x21, 0
	.dw 0x7a00, 0xc002,	0x7fff, 0xc002,		0x21, 0
	.dw 0x9a00, 0xc002,	0x9fff, 0xc002,		0x21, 0
	.dw 0xba00, 0xc002,	0xbfff, 0xc002,		0x21, 0
	.dw 0xda00, 0xc002,	0xdfff, 0xc002,		0x21, 0
	.dw 0xfa00, 0xc002,	0xffff, 0xc002,		0x21, 0
	.dw 0x1a00, 0xc003,	0x1fff, 0xc003,		0x21, 0
	.dw 0x3a00, 0xc003,	0xffff, 0xc003,		0x21, 0
	.dw 0x1a00, 0xc004,	0x1fff, 0xc004,		0x21, 0
	.dw 0x3a00, 0xc004,	0x3fff, 0xc004,		0x21, 0
	.dw 0x5a00, 0xc004,	0x5fff, 0xc004,		0x21, 0
	.dw 0x7a00, 0xc004,	0x7fff, 0xc004,		0x21, 0
	.dw 0x9a00, 0xc004,	0x9fff, 0xc004,		0x21, 0
	.dw 0xba00, 0xc004,	0xbfff, 0xc004,		0x21, 0
	.dw 0xda00, 0xc004,	0xdfff, 0xc004,		0x21, 0
	.dw 0xfa00, 0xc004,	0xffff, 0xc004,		0x21, 0
	.dw 0x1a00, 0xc005,	0x1fff, 0xc005,		0x21, 0
	.dw 0x3a00, 0xc005,	0x3fff, 0xc005,		0x21, 0
	.dw 0x5a00, 0xc005,	0x5fff, 0xc005,		0x21, 0
	.dw 0x7a00, 0xc005,	0x7fff, 0xc005,		0x21, 0
	.dw 0x9a00, 0xc005,	0x9fff, 0xc005,		0x21, 0
	.dw 0xba00, 0xc005,	0xbfff, 0xc005,		0x21, 0
	.dw 0xda00, 0xc005,	0xdfff, 0xc005,		0x21, 0
	.dw 0xfa00, 0xc005,	0xffff, 0xc005,		0x21, 0
	.dw 0x1a00, 0xc006,	0x1fff, 0xc006,		0x21, 0
	.dw 0x3a00, 0xc006,	0x3fff, 0xc006,		0x21, 0
	.dw 0x5a00, 0xc006,	0x5fff, 0xc006,		0x21, 0
	.dw 0x7a00, 0xc006,	0x7fff, 0xc006,		0x21, 0
	.dw 0x9a00, 0xc006,	0x9fff, 0xc006,		0x21, 0
	.dw 0xba00, 0xc006,	0xbfff, 0xc006,		0x21, 0
	.dw 0xda00, 0xc006,	0xdfff, 0xc006,		0x21, 0
	.dw 0xfa00, 0xc006,	0xffff, 0xc006,		0x21, 0
	.dw 0x1a00, 0xc007,	0x1fff, 0xc007,		0x21, 0
	.dw 0x3a00, 0xc007,	0x1fff, 0xc008,		0x21, 0
	.dw 0x2040, 0xc008,	0x207f, 0xc008,		0x21, 0
	.dw 0x20c0, 0xc008,	0x20ff, 0xc008,		0x21, 0
	.dw 0x2140, 0xc008,	0x217f, 0xc008,		0x21, 0
	.dw 0x21c0, 0xc008,	0x21ff, 0xc008,		0x21, 0
	.dw 0x2240, 0xc008,	0x227f, 0xc008,		0x21, 0
	.dw 0x22c0, 0xc008,	0x22ff, 0xc008,		0x21, 0
	.dw 0x2340, 0xc008,	0x237f, 0xc008,		0x21, 0
	.dw 0x23c0, 0xc008,	0x23ff, 0xc008,		0x21, 0
	.dw 0x2440, 0xc008,	0x247f, 0xc008,		0x21, 0
	.dw 0x24c0, 0xc008,	0x24ff, 0xc008,		0x21, 0
	.dw 0x2540, 0xc008,	0x257f, 0xc008,		0x21, 0
	.dw 0x25c0, 0xc008,	0x25ff, 0xc008,		0x21, 0
	.dw 0x2640, 0xc008,	0x267f, 0xc008,		0x21, 0
	.dw 0x26c0, 0xc008,	0x26ff, 0xc008,		0x21, 0
	.dw 0x2740, 0xc008,	0x277f, 0xc008,		0x21, 0
	.dw 0x27c0, 0xc008,	0x27ff, 0xc008,		0x21, 0
	.dw 0x2840, 0xc008,	0x287f, 0xc008,		0x21, 0
	.dw 0x28c0, 0xc008,	0x28ff, 0xc008,		0x21, 0
	.dw 0x2940, 0xc008,	0x297f, 0xc008,		0x21, 0
	.dw 0x29c0, 0xc008,	0x29ff, 0xc008,		0x21, 0
	.dw 0x2a40, 0xc008,	0x2a7f, 0xc008,		0x21, 0
	.dw 0x2ac0, 0xc008,	0x2aff, 0xc008,		0x21, 0
	.dw 0x2b40, 0xc008,	0x2b7f, 0xc008,		0x21, 0
	.dw 0x2bc0, 0xc008,	0x2bff, 0xc008,		0x21, 0
	.dw 0x2c40, 0xc008,	0x2c7f, 0xc008,		0x21, 0
	.dw 0x2cc0, 0xc008,	0x2cff, 0xc008,		0x21, 0
	.dw 0x2d40, 0xc008,	0x2d7f, 0xc008,		0x21, 0
	.dw 0x2dc0, 0xc008,	0x2dff, 0xc008,		0x21, 0
	.dw 0x2e40, 0xc008,	0x2e7f, 0xc008,		0x21, 0
	.dw 0x2ec0, 0xc008,	0x2eff, 0xc008,		0x21, 0
	.dw 0x2f40, 0xc008,	0x2f7f, 0xc008,		0x21, 0
	.dw 0x2fc0, 0xc008,	0x2fff, 0xc008,		0x21, 0
	.dw 0x3040, 0xc008,	0x307f, 0xc008,		0x21, 0
	.dw 0x30c0, 0xc008,	0x30ff, 0xc008,		0x21, 0
	.dw 0x3140, 0xc008,	0x317f, 0xc008,		0x21, 0
	.dw 0x31c0, 0xc008,	0x31ff, 0xc008,		0x21, 0
	.dw 0x3240, 0xc008,	0x327f, 0xc008,		0x21, 0
	.dw 0x32c0, 0xc008,	0x32ff, 0xc008,		0x21, 0
	.dw 0x3340, 0xc008,	0x337f, 0xc008,		0x21, 0
	.dw 0x33c0, 0xc008,	0x33ff, 0xc008,		0x21, 0
	.dw 0x3440, 0xc008,	0x347f, 0xc008,		0x21, 0
	.dw 0x34c0, 0xc008,	0x34ff, 0xc008,		0x21, 0
	.dw 0x3540, 0xc008,	0x357f, 0xc008,		0x21, 0
	.dw 0x35c0, 0xc008,	0x35ff, 0xc008,		0x21, 0
	.dw 0x3640, 0xc008,	0x367f, 0xc008,		0x21, 0
	.dw 0x36c0, 0xc008,	0x36ff, 0xc008,		0x21, 0
	.dw 0x3740, 0xc008,	0x377f, 0xc008,		0x21, 0
	.dw 0x37c0, 0xc008,	0x37ff, 0xc008,		0x21, 0
	.dw 0x3840, 0xc008,	0x387f, 0xc008,		0x21, 0
	.dw 0x38c0, 0xc008,	0x38ff, 0xc008,		0x21, 0
	.dw 0x3940, 0xc008,	0x397f, 0xc008,		0x21, 0
	.dw 0x39c0, 0xc008,	0x5fff, 0xc008,		0x21, 0
	.dw 0x6040, 0xc008,	0x607f, 0xc008,		0x21, 0
	.dw 0x60c0, 0xc008,	0x60ff, 0xc008,		0x21, 0
	.dw 0x6140, 0xc008,	0x617f, 0xc008,		0x21, 0
	.dw 0x61c0, 0xc008,	0x61ff, 0xc008,		0x21, 0
	.dw 0x6240, 0xc008,	0x627f, 0xc008,		0x21, 0
	.dw 0x62c0, 0xc008,	0x62ff, 0xc008,		0x21, 0
	.dw 0x6340, 0xc008,	0x637f, 0xc008,		0x21, 0
	.dw 0x63c0, 0xc008,	0x63ff, 0xc008,		0x21, 0
	.dw 0x6440, 0xc008,	0x647f, 0xc008,		0x21, 0
	.dw 0x64c0, 0xc008,	0x64ff, 0xc008,		0x21, 0
	.dw 0x6540, 0xc008,	0x657f, 0xc008,		0x21, 0
	.dw 0x65c0, 0xc008,	0x65ff, 0xc008,		0x21, 0
	.dw 0x6640, 0xc008,	0x667f, 0xc008,		0x21, 0
	.dw 0x66c0, 0xc008,	0x66ff, 0xc008,		0x21, 0
	.dw 0x6740, 0xc008,	0x677f, 0xc008,		0x21, 0
	.dw 0x67c0, 0xc008,	0x67ff, 0xc008,		0x21, 0
	.dw 0x6840, 0xc008,	0x687f, 0xc008,		0x21, 0
	.dw 0x68c0, 0xc008,	0x68ff, 0xc008,		0x21, 0
	.dw 0x6940, 0xc008,	0x697f, 0xc008,		0x21, 0
	.dw 0x69c0, 0xc008,	0x69ff, 0xc008,		0x21, 0
	.dw 0x6a40, 0xc008,	0x6a7f, 0xc008,		0x21, 0
	.dw 0x6ac0, 0xc008,	0x6aff, 0xc008,		0x21, 0
	.dw 0x6b40, 0xc008,	0x6b7f, 0xc008,		0x21, 0
	.dw 0x6bc0, 0xc008,	0x6bff, 0xc008,		0x21, 0
	.dw 0x6c40, 0xc008,	0x6c7f, 0xc008,		0x21, 0
	.dw 0x6cc0, 0xc008,	0x6cff, 0xc008,		0x21, 0
	.dw 0x6d40, 0xc008,	0x6d7f, 0xc008,		0x21, 0
	.dw 0x6dc0, 0xc008,	0x6dff, 0xc008,		0x21, 0
	.dw 0x6e40, 0xc008,	0x6e7f, 0xc008,		0x21, 0
	.dw 0x6ec0, 0xc008,	0x6eff, 0xc008,		0x21, 0
	.dw 0x6f40, 0xc008,	0x6f7f, 0xc008,		0x21, 0
	.dw 0x6fc0, 0xc008,	0x6fff, 0xc008,		0x21, 0
	.dw 0x7040, 0xc008,	0x707f, 0xc008,		0x21, 0
	.dw 0x70c0, 0xc008,	0x70ff, 0xc008,		0x21, 0
	.dw 0x7140, 0xc008,	0x717f, 0xc008,		0x21, 0
	.dw 0x71c0, 0xc008,	0x71ff, 0xc008,		0x21, 0
	.dw 0x7240, 0xc008,	0x727f, 0xc008,		0x21, 0
	.dw 0x72c0, 0xc008,	0x72ff, 0xc008,		0x21, 0
	.dw 0x7340, 0xc008,	0x737f, 0xc008,		0x21, 0
	.dw 0x73c0, 0xc008,	0x73ff, 0xc008,		0x21, 0
	.dw 0x7440, 0xc008,	0x747f, 0xc008,		0x21, 0
	.dw 0x74c0, 0xc008,	0x74ff, 0xc008,		0x21, 0
	.dw 0x7540, 0xc008,	0x757f, 0xc008,		0x21, 0
	.dw 0x75c0, 0xc008,	0x75ff, 0xc008,		0x21, 0
	.dw 0x7640, 0xc008,	0x767f, 0xc008,		0x21, 0
	.dw 0x76c0, 0xc008,	0x76ff, 0xc008,		0x21, 0
	.dw 0x7740, 0xc008,	0x777f, 0xc008,		0x21, 0
	.dw 0x77c0, 0xc008,	0x77ff, 0xc008,		0x21, 0
	.dw 0x7840, 0xc008,	0x787f, 0xc008,		0x21, 0
	.dw 0x78c0, 0xc008,	0x78ff, 0xc008,		0x21, 0
	.dw 0x7940, 0xc008,	0x797f, 0xc008,		0x21, 0
	.dw 0x79c0, 0xc008,	0x9fff, 0xc008,		0x21, 0
	.dw 0xa040, 0xc008,	0xa07f, 0xc008,		0x21, 0
	.dw 0xa0c0, 0xc008,	0xa0ff, 0xc008,		0x21, 0
	.dw 0xa140, 0xc008,	0xa17f, 0xc008,		0x21, 0
	.dw 0xa1c0, 0xc008,	0xa1ff, 0xc008,		0x21, 0
	.dw 0xa240, 0xc008,	0xa27f, 0xc008,		0x21, 0
	.dw 0xa2c0, 0xc008,	0xa2ff, 0xc008,		0x21, 0
	.dw 0xa340, 0xc008,	0xa37f, 0xc008,		0x21, 0
	.dw 0xa3c0, 0xc008,	0xa3ff, 0xc008,		0x21, 0
	.dw 0xa440, 0xc008,	0xa47f, 0xc008,		0x21, 0
	.dw 0xa4c0, 0xc008,	0xa4ff, 0xc008,		0x21, 0
	.dw 0xa540, 0xc008,	0xa57f, 0xc008,		0x21, 0
	.dw 0xa5c0, 0xc008,	0xa5ff, 0xc008,		0x21, 0
	.dw 0xa640, 0xc008,	0xa67f, 0xc008,		0x21, 0
	.dw 0xa6c0, 0xc008,	0xa6ff, 0xc008,		0x21, 0
	.dw 0xa740, 0xc008,	0xa77f, 0xc008,		0x21, 0
	.dw 0xa7c0, 0xc008,	0xa7ff, 0xc008,		0x21, 0
	.dw 0xa840, 0xc008,	0xa87f, 0xc008,		0x21, 0
	.dw 0xa8c0, 0xc008,	0xa8ff, 0xc008,		0x21, 0
	.dw 0xa940, 0xc008,	0xa97f, 0xc008,		0x21, 0
	.dw 0xa9c0, 0xc008,	0xa9ff, 0xc008,		0x21, 0
	.dw 0xaa40, 0xc008,	0xaa7f, 0xc008,		0x21, 0
	.dw 0xaac0, 0xc008,	0xaaff, 0xc008,		0x21, 0
	.dw 0xab40, 0xc008,	0xab7f, 0xc008,		0x21, 0
	.dw 0xabc0, 0xc008,	0xabff, 0xc008,		0x21, 0
	.dw 0xac40, 0xc008,	0xac7f, 0xc008,		0x21, 0
	.dw 0xacc0, 0xc008,	0xacff, 0xc008,		0x21, 0
	.dw 0xad40, 0xc008,	0xad7f, 0xc008,		0x21, 0
	.dw 0xadc0, 0xc008,	0xadff, 0xc008,		0x21, 0
	.dw 0xae40, 0xc008,	0xae7f, 0xc008,		0x21, 0
	.dw 0xaec0, 0xc008,	0xaeff, 0xc008,		0x21, 0
	.dw 0xaf40, 0xc008,	0xaf7f, 0xc008,		0x21, 0
	.dw 0xafc0, 0xc008,	0xafff, 0xc008,		0x21, 0
	.dw 0xb040, 0xc008,	0xb07f, 0xc008,		0x21, 0
	.dw 0xb0c0, 0xc008,	0xb0ff, 0xc008,		0x21, 0
	.dw 0xb140, 0xc008,	0xb17f, 0xc008,		0x21, 0
	.dw 0xb1c0, 0xc008,	0xb1ff, 0xc008,		0x21, 0
	.dw 0xb240, 0xc008,	0xb27f, 0xc008,		0x21, 0
	.dw 0xb2c0, 0xc008,	0xb2ff, 0xc008,		0x21, 0
	.dw 0xb340, 0xc008,	0xb37f, 0xc008,		0x21, 0
	.dw 0xb3c0, 0xc008,	0xb3ff, 0xc008,		0x21, 0
	.dw 0xb440, 0xc008,	0xb47f, 0xc008,		0x21, 0
	.dw 0xb4c0, 0xc008,	0xb4ff, 0xc008,		0x21, 0
	.dw 0xb540, 0xc008,	0xb57f, 0xc008,		0x21, 0
	.dw 0xb5c0, 0xc008,	0xb5ff, 0xc008,		0x21, 0
	.dw 0xb640, 0xc008,	0xb67f, 0xc008,		0x21, 0
	.dw 0xb6c0, 0xc008,	0xb6ff, 0xc008,		0x21, 0
	.dw 0xb740, 0xc008,	0xb77f, 0xc008,		0x21, 0
	.dw 0xb7c0, 0xc008,	0xb7ff, 0xc008,		0x21, 0
	.dw 0xb840, 0xc008,	0xb87f, 0xc008,		0x21, 0
	.dw 0xb8c0, 0xc008,	0xb8ff, 0xc008,		0x21, 0
	.dw 0xb940, 0xc008,	0xb97f, 0xc008,		0x21, 0
	.dw 0xb9c0, 0xc008,	0xdfff, 0xc008,		0x21, 0
	.dw 0xe040, 0xc008,	0xe07f, 0xc008,		0x21, 0
	.dw 0xe0c0, 0xc008,	0xe0ff, 0xc008,		0x21, 0
	.dw 0xe140, 0xc008,	0xe17f, 0xc008,		0x21, 0
	.dw 0xe1c0, 0xc008,	0xe1ff, 0xc008,		0x21, 0
	.dw 0xe240, 0xc008,	0xe27f, 0xc008,		0x21, 0
	.dw 0xe2c0, 0xc008,	0xe2ff, 0xc008,		0x21, 0
	.dw 0xe340, 0xc008,	0xe37f, 0xc008,		0x21, 0
	.dw 0xe3c0, 0xc008,	0xe3ff, 0xc008,		0x21, 0
	.dw 0xe440, 0xc008,	0xe47f, 0xc008,		0x21, 0
	.dw 0xe4c0, 0xc008,	0xe4ff, 0xc008,		0x21, 0
	.dw 0xe540, 0xc008,	0xe57f, 0xc008,		0x21, 0
	.dw 0xe5c0, 0xc008,	0xe5ff, 0xc008,		0x21, 0
	.dw 0xe640, 0xc008,	0xe67f, 0xc008,		0x21, 0
	.dw 0xe6c0, 0xc008,	0xe6ff, 0xc008,		0x21, 0
	.dw 0xe740, 0xc008,	0xe77f, 0xc008,		0x21, 0
	.dw 0xe7c0, 0xc008,	0xe7ff, 0xc008,		0x21, 0
	.dw 0xe840, 0xc008,	0xe87f, 0xc008,		0x21, 0
	.dw 0xe8c0, 0xc008,	0xe8ff, 0xc008,		0x21, 0
	.dw 0xe940, 0xc008,	0xe97f, 0xc008,		0x21, 0
	.dw 0xe9c0, 0xc008,	0xe9ff, 0xc008,		0x21, 0
	.dw 0xea40, 0xc008,	0xea7f, 0xc008,		0x21, 0
	.dw 0xeac0, 0xc008,	0xeaff, 0xc008,		0x21, 0
	.dw 0xeb40, 0xc008,	0xeb7f, 0xc008,		0x21, 0
	.dw 0xebc0, 0xc008,	0xebff, 0xc008,		0x21, 0
	.dw 0xec40, 0xc008,	0xec7f, 0xc008,		0x21, 0
	.dw 0xecc0, 0xc008,	0xecff, 0xc008,		0x21, 0
	.dw 0xed40, 0xc008,	0xed7f, 0xc008,		0x21, 0
	.dw 0xedc0, 0xc008,	0xedff, 0xc008,		0x21, 0
	.dw 0xee40, 0xc008,	0xee7f, 0xc008,		0x21, 0
	.dw 0xeec0, 0xc008,	0xeeff, 0xc008,		0x21, 0
	.dw 0xef40, 0xc008,	0xef7f, 0xc008,		0x21, 0
	.dw 0xefc0, 0xc008,	0xefff, 0xc008,		0x21, 0
	.dw 0xf040, 0xc008,	0xf07f, 0xc008,		0x21, 0
	.dw 0xf0c0, 0xc008,	0xf0ff, 0xc008,		0x21, 0
	.dw 0xf140, 0xc008,	0xf17f, 0xc008,		0x21, 0
	.dw 0xf1c0, 0xc008,	0xf1ff, 0xc008,		0x21, 0
	.dw 0xf240, 0xc008,	0xf27f, 0xc008,		0x21, 0
	.dw 0xf2c0, 0xc008,	0xf2ff, 0xc008,		0x21, 0
	.dw 0xf340, 0xc008,	0xf37f, 0xc008,		0x21, 0
	.dw 0xf3c0, 0xc008,	0xf3ff, 0xc008,		0x21, 0
	.dw 0xf440, 0xc008,	0xf47f, 0xc008,		0x21, 0
	.dw 0xf4c0, 0xc008,	0xf4ff, 0xc008,		0x21, 0
	.dw 0xf540, 0xc008,	0xf57f, 0xc008,		0x21, 0
	.dw 0xf5c0, 0xc008,	0xf5ff, 0xc008,		0x21, 0
	.dw 0xf640, 0xc008,	0xf67f, 0xc008,		0x21, 0
	.dw 0xf6c0, 0xc008,	0xf6ff, 0xc008,		0x21, 0
	.dw 0xf740, 0xc008,	0xf77f, 0xc008,		0x21, 0
	.dw 0xf7c0, 0xc008,	0xf7ff, 0xc008,		0x21, 0
	.dw 0xf840, 0xc008,	0xf87f, 0xc008,		0x21, 0
	.dw 0xf8c0, 0xc008,	0xf8ff, 0xc008,		0x21, 0
	.dw 0xf940, 0xc008,	0xf97f, 0xc008,		0x21, 0
	.dw 0xf9c0, 0xc008,	0x1fff, 0xc009,		0x21, 0
	.dw 0x2040, 0xc009,	0x207f, 0xc009,		0x21, 0
	.dw 0x20c0, 0xc009,	0x20ff, 0xc009,		0x21, 0
	.dw 0x2140, 0xc009,	0x217f, 0xc009,		0x21, 0
	.dw 0x21c0, 0xc009,	0x21ff, 0xc009,		0x21, 0
	.dw 0x2240, 0xc009,	0x227f, 0xc009,		0x21, 0
	.dw 0x22c0, 0xc009,	0x22ff, 0xc009,		0x21, 0
	.dw 0x2340, 0xc009,	0x237f, 0xc009,		0x21, 0
	.dw 0x23c0, 0xc009,	0x23ff, 0xc009,		0x21, 0
	.dw 0x2440, 0xc009,	0x247f, 0xc009,		0x21, 0
	.dw 0x24c0, 0xc009,	0x24ff, 0xc009,		0x21, 0
	.dw 0x2540, 0xc009,	0x257f, 0xc009,		0x21, 0
	.dw 0x25c0, 0xc009,	0x25ff, 0xc009,		0x21, 0
	.dw 0x2640, 0xc009,	0x267f, 0xc009,		0x21, 0
	.dw 0x26c0, 0xc009,	0x26ff, 0xc009,		0x21, 0
	.dw 0x2740, 0xc009,	0x277f, 0xc009,		0x21, 0
	.dw 0x27c0, 0xc009,	0x27ff, 0xc009,		0x21, 0
	.dw 0x2840, 0xc009,	0x287f, 0xc009,		0x21, 0
	.dw 0x28c0, 0xc009,	0x28ff, 0xc009,		0x21, 0
	.dw 0x2940, 0xc009,	0x297f, 0xc009,		0x21, 0
	.dw 0x29c0, 0xc009,	0x29ff, 0xc009,		0x21, 0
	.dw 0x2a40, 0xc009,	0x2a7f, 0xc009,		0x21, 0
	.dw 0x2ac0, 0xc009,	0x2aff, 0xc009,		0x21, 0
	.dw 0x2b40, 0xc009,	0x2b7f, 0xc009,		0x21, 0
	.dw 0x2bc0, 0xc009,	0x2bff, 0xc009,		0x21, 0
	.dw 0x2c40, 0xc009,	0x2c7f, 0xc009,		0x21, 0
	.dw 0x2cc0, 0xc009,	0x2cff, 0xc009,		0x21, 0
	.dw 0x2d40, 0xc009,	0x2d7f, 0xc009,		0x21, 0
	.dw 0x2dc0, 0xc009,	0x2dff, 0xc009,		0x21, 0
	.dw 0x2e40, 0xc009,	0x2e7f, 0xc009,		0x21, 0
	.dw 0x2ec0, 0xc009,	0x2eff, 0xc009,		0x21, 0
	.dw 0x2f40, 0xc009,	0x2f7f, 0xc009,		0x21, 0
	.dw 0x2fc0, 0xc009,	0x2fff, 0xc009,		0x21, 0
	.dw 0x3040, 0xc009,	0x307f, 0xc009,		0x21, 0
	.dw 0x30c0, 0xc009,	0x30ff, 0xc009,		0x21, 0
	.dw 0x3140, 0xc009,	0x317f, 0xc009,		0x21, 0
	.dw 0x31c0, 0xc009,	0x31ff, 0xc009,		0x21, 0
	.dw 0x3240, 0xc009,	0x327f, 0xc009,		0x21, 0
	.dw 0x32c0, 0xc009,	0x32ff, 0xc009,		0x21, 0
	.dw 0x3340, 0xc009,	0x337f, 0xc009,		0x21, 0
	.dw 0x33c0, 0xc009,	0x33ff, 0xc009,		0x21, 0
	.dw 0x3440, 0xc009,	0x347f, 0xc009,		0x21, 0
	.dw 0x34c0, 0xc009,	0x34ff, 0xc009,		0x21, 0
	.dw 0x3540, 0xc009,	0x357f, 0xc009,		0x21, 0
	.dw 0x35c0, 0xc009,	0x35ff, 0xc009,		0x21, 0
	.dw 0x3640, 0xc009,	0x367f, 0xc009,		0x21, 0
	.dw 0x36c0, 0xc009,	0x36ff, 0xc009,		0x21, 0
	.dw 0x3740, 0xc009,	0x377f, 0xc009,		0x21, 0
	.dw 0x37c0, 0xc009,	0x37ff, 0xc009,		0x21, 0
	.dw 0x3840, 0xc009,	0x387f, 0xc009,		0x21, 0
	.dw 0x38c0, 0xc009,	0x38ff, 0xc009,		0x21, 0
	.dw 0x3940, 0xc009,	0x397f, 0xc009,		0x21, 0
	.dw 0x39c0, 0xc009,	0x5fff, 0xc009,		0x21, 0
	.dw 0x6040, 0xc009,	0x607f, 0xc009,		0x21, 0
	.dw 0x60c0, 0xc009,	0x60ff, 0xc009,		0x21, 0
	.dw 0x6140, 0xc009,	0x617f, 0xc009,		0x21, 0
	.dw 0x61c0, 0xc009,	0x61ff, 0xc009,		0x21, 0
	.dw 0x6240, 0xc009,	0x627f, 0xc009,		0x21, 0
	.dw 0x62c0, 0xc009,	0x62ff, 0xc009,		0x21, 0
	.dw 0x6340, 0xc009,	0x637f, 0xc009,		0x21, 0
	.dw 0x63c0, 0xc009,	0x63ff, 0xc009,		0x21, 0
	.dw 0x6440, 0xc009,	0x647f, 0xc009,		0x21, 0
	.dw 0x64c0, 0xc009,	0x64ff, 0xc009,		0x21, 0
	.dw 0x6540, 0xc009,	0x657f, 0xc009,		0x21, 0
	.dw 0x65c0, 0xc009,	0x65ff, 0xc009,		0x21, 0
	.dw 0x6640, 0xc009,	0x667f, 0xc009,		0x21, 0
	.dw 0x66c0, 0xc009,	0x66ff, 0xc009,		0x21, 0
	.dw 0x6740, 0xc009,	0x677f, 0xc009,		0x21, 0
	.dw 0x67c0, 0xc009,	0x67ff, 0xc009,		0x21, 0
	.dw 0x6840, 0xc009,	0x687f, 0xc009,		0x21, 0
	.dw 0x68c0, 0xc009,	0x68ff, 0xc009,		0x21, 0
	.dw 0x6940, 0xc009,	0x697f, 0xc009,		0x21, 0
	.dw 0x69c0, 0xc009,	0x69ff, 0xc009,		0x21, 0
	.dw 0x6a40, 0xc009,	0x6a7f, 0xc009,		0x21, 0
	.dw 0x6ac0, 0xc009,	0x6aff, 0xc009,		0x21, 0
	.dw 0x6b40, 0xc009,	0x6b7f, 0xc009,		0x21, 0
	.dw 0x6bc0, 0xc009,	0x6bff, 0xc009,		0x21, 0
	.dw 0x6c40, 0xc009,	0x6c7f, 0xc009,		0x21, 0
	.dw 0x6cc0, 0xc009,	0x6cff, 0xc009,		0x21, 0
	.dw 0x6d40, 0xc009,	0x6d7f, 0xc009,		0x21, 0
	.dw 0x6dc0, 0xc009,	0x6dff, 0xc009,		0x21, 0
	.dw 0x6e40, 0xc009,	0x6e7f, 0xc009,		0x21, 0
	.dw 0x6ec0, 0xc009,	0x6eff, 0xc009,		0x21, 0
	.dw 0x6f40, 0xc009,	0x6f7f, 0xc009,		0x21, 0
	.dw 0x6fc0, 0xc009,	0x6fff, 0xc009,		0x21, 0
	.dw 0x7040, 0xc009,	0x707f, 0xc009,		0x21, 0
	.dw 0x70c0, 0xc009,	0x70ff, 0xc009,		0x21, 0
	.dw 0x7140, 0xc009,	0x717f, 0xc009,		0x21, 0
	.dw 0x71c0, 0xc009,	0x71ff, 0xc009,		0x21, 0
	.dw 0x7240, 0xc009,	0x727f, 0xc009,		0x21, 0
	.dw 0x72c0, 0xc009,	0x72ff, 0xc009,		0x21, 0
	.dw 0x7340, 0xc009,	0x737f, 0xc009,		0x21, 0
	.dw 0x73c0, 0xc009,	0x73ff, 0xc009,		0x21, 0
	.dw 0x7440, 0xc009,	0x747f, 0xc009,		0x21, 0
	.dw 0x74c0, 0xc009,	0x74ff, 0xc009,		0x21, 0
	.dw 0x7540, 0xc009,	0x757f, 0xc009,		0x21, 0
	.dw 0x75c0, 0xc009,	0x75ff, 0xc009,		0x21, 0
	.dw 0x7640, 0xc009,	0x767f, 0xc009,		0x21, 0
	.dw 0x76c0, 0xc009,	0x76ff, 0xc009,		0x21, 0
	.dw 0x7740, 0xc009,	0x777f, 0xc009,		0x21, 0
	.dw 0x77c0, 0xc009,	0x77ff, 0xc009,		0x21, 0
	.dw 0x7840, 0xc009,	0x787f, 0xc009,		0x21, 0
	.dw 0x78c0, 0xc009,	0x78ff, 0xc009,		0x21, 0
	.dw 0x7940, 0xc009,	0x797f, 0xc009,		0x21, 0
	.dw 0x79c0, 0xc009,	0x9fff, 0xc009,		0x21, 0
	.dw 0xa040, 0xc009,	0xa07f, 0xc009,		0x21, 0
	.dw 0xa0c0, 0xc009,	0xa0ff, 0xc009,		0x21, 0
	.dw 0xa140, 0xc009,	0xa17f, 0xc009,		0x21, 0
	.dw 0xa1c0, 0xc009,	0xa1ff, 0xc009,		0x21, 0
	.dw 0xa240, 0xc009,	0xa27f, 0xc009,		0x21, 0
	.dw 0xa2c0, 0xc009,	0xa2ff, 0xc009,		0x21, 0
	.dw 0xa340, 0xc009,	0xa37f, 0xc009,		0x21, 0
	.dw 0xa3c0, 0xc009,	0xa3ff, 0xc009,		0x21, 0
	.dw 0xa440, 0xc009,	0xa47f, 0xc009,		0x21, 0
	.dw 0xa4c0, 0xc009,	0xa4ff, 0xc009,		0x21, 0
	.dw 0xa540, 0xc009,	0xa57f, 0xc009,		0x21, 0
	.dw 0xa5c0, 0xc009,	0xa5ff, 0xc009,		0x21, 0
	.dw 0xa640, 0xc009,	0xa67f, 0xc009,		0x21, 0
	.dw 0xa6c0, 0xc009,	0xa6ff, 0xc009,		0x21, 0
	.dw 0xa740, 0xc009,	0xa77f, 0xc009,		0x21, 0
	.dw 0xa7c0, 0xc009,	0xa7ff, 0xc009,		0x21, 0
	.dw 0xa840, 0xc009,	0xa87f, 0xc009,		0x21, 0
	.dw 0xa8c0, 0xc009,	0xa8ff, 0xc009,		0x21, 0
	.dw 0xa940, 0xc009,	0xa97f, 0xc009,		0x21, 0
	.dw 0xa9c0, 0xc009,	0xa9ff, 0xc009,		0x21, 0
	.dw 0xaa40, 0xc009,	0xaa7f, 0xc009,		0x21, 0
	.dw 0xaac0, 0xc009,	0xaaff, 0xc009,		0x21, 0
	.dw 0xab40, 0xc009,	0xab7f, 0xc009,		0x21, 0
	.dw 0xabc0, 0xc009,	0xabff, 0xc009,		0x21, 0
	.dw 0xac40, 0xc009,	0xac7f, 0xc009,		0x21, 0
	.dw 0xacc0, 0xc009,	0xacff, 0xc009,		0x21, 0
	.dw 0xad40, 0xc009,	0xad7f, 0xc009,		0x21, 0
	.dw 0xadc0, 0xc009,	0xadff, 0xc009,		0x21, 0
	.dw 0xae40, 0xc009,	0xae7f, 0xc009,		0x21, 0
	.dw 0xaec0, 0xc009,	0xaeff, 0xc009,		0x21, 0
	.dw 0xaf40, 0xc009,	0xaf7f, 0xc009,		0x21, 0
	.dw 0xafc0, 0xc009,	0xafff, 0xc009,		0x21, 0
	.dw 0xb040, 0xc009,	0xb07f, 0xc009,		0x21, 0
	.dw 0xb0c0, 0xc009,	0xb0ff, 0xc009,		0x21, 0
	.dw 0xb140, 0xc009,	0xb17f, 0xc009,		0x21, 0
	.dw 0xb1c0, 0xc009,	0xb1ff, 0xc009,		0x21, 0
	.dw 0xb240, 0xc009,	0xb27f, 0xc009,		0x21, 0
	.dw 0xb2c0, 0xc009,	0xb2ff, 0xc009,		0x21, 0
	.dw 0xb340, 0xc009,	0xb37f, 0xc009,		0x21, 0
	.dw 0xb3c0, 0xc009,	0xb3ff, 0xc009,		0x21, 0
	.dw 0xb440, 0xc009,	0xb47f, 0xc009,		0x21, 0
	.dw 0xb4c0, 0xc009,	0xb4ff, 0xc009,		0x21, 0
	.dw 0xb540, 0xc009,	0xb57f, 0xc009,		0x21, 0
	.dw 0xb5c0, 0xc009,	0xb5ff, 0xc009,		0x21, 0
	.dw 0xb640, 0xc009,	0xb67f, 0xc009,		0x21, 0
	.dw 0xb6c0, 0xc009,	0xb6ff, 0xc009,		0x21, 0
	.dw 0xb740, 0xc009,	0xb77f, 0xc009,		0x21, 0
	.dw 0xb7c0, 0xc009,	0xb7ff, 0xc009,		0x21, 0
	.dw 0xb840, 0xc009,	0xb87f, 0xc009,		0x21, 0
	.dw 0xb8c0, 0xc009,	0xb8ff, 0xc009,		0x21, 0
	.dw 0xb940, 0xc009,	0xb97f, 0xc009,		0x21, 0
	.dw 0xb9c0, 0xc009,	0xdfff, 0xc009,		0x21, 0
	.dw 0xe040, 0xc009,	0xe07f, 0xc009,		0x21, 0
	.dw 0xe0c0, 0xc009,	0xe0ff, 0xc009,		0x21, 0
	.dw 0xe140, 0xc009,	0xe17f, 0xc009,		0x21, 0
	.dw 0xe1c0, 0xc009,	0xe1ff, 0xc009,		0x21, 0
	.dw 0xe240, 0xc009,	0xe27f, 0xc009,		0x21, 0
	.dw 0xe2c0, 0xc009,	0xe2ff, 0xc009,		0x21, 0
	.dw 0xe340, 0xc009,	0xe37f, 0xc009,		0x21, 0
	.dw 0xe3c0, 0xc009,	0xe3ff, 0xc009,		0x21, 0
	.dw 0xe440, 0xc009,	0xe47f, 0xc009,		0x21, 0
	.dw 0xe4c0, 0xc009,	0xe4ff, 0xc009,		0x21, 0
	.dw 0xe540, 0xc009,	0xe57f, 0xc009,		0x21, 0
	.dw 0xe5c0, 0xc009,	0xe5ff, 0xc009,		0x21, 0
	.dw 0xe640, 0xc009,	0xe67f, 0xc009,		0x21, 0
	.dw 0xe6c0, 0xc009,	0xe6ff, 0xc009,		0x21, 0
	.dw 0xe740, 0xc009,	0xe77f, 0xc009,		0x21, 0
	.dw 0xe7c0, 0xc009,	0xe7ff, 0xc009,		0x21, 0
	.dw 0xe840, 0xc009,	0xe87f, 0xc009,		0x21, 0
	.dw 0xe8c0, 0xc009,	0xe8ff, 0xc009,		0x21, 0
	.dw 0xe940, 0xc009,	0xe97f, 0xc009,		0x21, 0
	.dw 0xe9c0, 0xc009,	0xe9ff, 0xc009,		0x21, 0
	.dw 0xea40, 0xc009,	0xea7f, 0xc009,		0x21, 0
	.dw 0xeac0, 0xc009,	0xeaff, 0xc009,		0x21, 0
	.dw 0xeb40, 0xc009,	0xeb7f, 0xc009,		0x21, 0
	.dw 0xebc0, 0xc009,	0xebff, 0xc009,		0x21, 0
	.dw 0xec40, 0xc009,	0xec7f, 0xc009,		0x21, 0
	.dw 0xecc0, 0xc009,	0xecff, 0xc009,		0x21, 0
	.dw 0xed40, 0xc009,	0xed7f, 0xc009,		0x21, 0
	.dw 0xedc0, 0xc009,	0xedff, 0xc009,		0x21, 0
	.dw 0xee40, 0xc009,	0xee7f, 0xc009,		0x21, 0
	.dw 0xeec0, 0xc009,	0xeeff, 0xc009,		0x21, 0
	.dw 0xef40, 0xc009,	0xef7f, 0xc009,		0x21, 0
	.dw 0xefc0, 0xc009,	0xefff, 0xc009,		0x21, 0
	.dw 0xf040, 0xc009,	0xf07f, 0xc009,		0x21, 0
	.dw 0xf0c0, 0xc009,	0xf0ff, 0xc009,		0x21, 0
	.dw 0xf140, 0xc009,	0xf17f, 0xc009,		0x21, 0
	.dw 0xf1c0, 0xc009,	0xf1ff, 0xc009,		0x21, 0
	.dw 0xf240, 0xc009,	0xf27f, 0xc009,		0x21, 0
	.dw 0xf2c0, 0xc009,	0xf2ff, 0xc009,		0x21, 0
	.dw 0xf340, 0xc009,	0xf37f, 0xc009,		0x21, 0
	.dw 0xf3c0, 0xc009,	0xf3ff, 0xc009,		0x21, 0
	.dw 0xf440, 0xc009,	0xf47f, 0xc009,		0x21, 0
	.dw 0xf4c0, 0xc009,	0xf4ff, 0xc009,		0x21, 0
	.dw 0xf540, 0xc009,	0xf57f, 0xc009,		0x21, 0
	.dw 0xf5c0, 0xc009,	0xf5ff, 0xc009,		0x21, 0
	.dw 0xf640, 0xc009,	0xf67f, 0xc009,		0x21, 0
	.dw 0xf6c0, 0xc009,	0xf6ff, 0xc009,		0x21, 0
	.dw 0xf740, 0xc009,	0xf77f, 0xc009,		0x21, 0
	.dw 0xf7c0, 0xc009,	0xf7ff, 0xc009,		0x21, 0
	.dw 0xf840, 0xc009,	0xf87f, 0xc009,		0x21, 0
	.dw 0xf8c0, 0xc009,	0xf8ff, 0xc009,		0x21, 0
	.dw 0xf940, 0xc009,	0xf97f, 0xc009,		0x21, 0
	.dw 0xf9c0, 0xc009,	0x1fff, 0xc00a,		0x21, 0
	.dw 0x2040, 0xc00a,	0x207f, 0xc00a,		0x21, 0
	.dw 0x20c0, 0xc00a,	0x20ff, 0xc00a,		0x21, 0
	.dw 0x2140, 0xc00a,	0x217f, 0xc00a,		0x21, 0
	.dw 0x21c0, 0xc00a,	0x21ff, 0xc00a,		0x21, 0
	.dw 0x2240, 0xc00a,	0x227f, 0xc00a,		0x21, 0
	.dw 0x22c0, 0xc00a,	0x22ff, 0xc00a,		0x21, 0
	.dw 0x2340, 0xc00a,	0x237f, 0xc00a,		0x21, 0
	.dw 0x23c0, 0xc00a,	0x23ff, 0xc00a,		0x21, 0
	.dw 0x2440, 0xc00a,	0x247f, 0xc00a,		0x21, 0
	.dw 0x24c0, 0xc00a,	0x24ff, 0xc00a,		0x21, 0
	.dw 0x2540, 0xc00a,	0x257f, 0xc00a,		0x21, 0
	.dw 0x25c0, 0xc00a,	0x25ff, 0xc00a,		0x21, 0
	.dw 0x2640, 0xc00a,	0x267f, 0xc00a,		0x21, 0
	.dw 0x26c0, 0xc00a,	0x26ff, 0xc00a,		0x21, 0
	.dw 0x2740, 0xc00a,	0x277f, 0xc00a,		0x21, 0
	.dw 0x27c0, 0xc00a,	0x27ff, 0xc00a,		0x21, 0
	.dw 0x2840, 0xc00a,	0x287f, 0xc00a,		0x21, 0
	.dw 0x28c0, 0xc00a,	0x28ff, 0xc00a,		0x21, 0
	.dw 0x2940, 0xc00a,	0x297f, 0xc00a,		0x21, 0
	.dw 0x29c0, 0xc00a,	0x29ff, 0xc00a,		0x21, 0
	.dw 0x2a40, 0xc00a,	0x2a7f, 0xc00a,		0x21, 0
	.dw 0x2ac0, 0xc00a,	0x2aff, 0xc00a,		0x21, 0
	.dw 0x2b40, 0xc00a,	0x2b7f, 0xc00a,		0x21, 0
	.dw 0x2bc0, 0xc00a,	0x2bff, 0xc00a,		0x21, 0
	.dw 0x2c40, 0xc00a,	0x2c7f, 0xc00a,		0x21, 0
	.dw 0x2cc0, 0xc00a,	0x2cff, 0xc00a,		0x21, 0
	.dw 0x2d40, 0xc00a,	0x2d7f, 0xc00a,		0x21, 0
	.dw 0x2dc0, 0xc00a,	0x2dff, 0xc00a,		0x21, 0
	.dw 0x2e40, 0xc00a,	0x2e7f, 0xc00a,		0x21, 0
	.dw 0x2ec0, 0xc00a,	0x2eff, 0xc00a,		0x21, 0
	.dw 0x2f40, 0xc00a,	0x2f7f, 0xc00a,		0x21, 0
	.dw 0x2fc0, 0xc00a,	0x2fff, 0xc00a,		0x21, 0
	.dw 0x3040, 0xc00a,	0x307f, 0xc00a,		0x21, 0
	.dw 0x30c0, 0xc00a,	0x30ff, 0xc00a,		0x21, 0
	.dw 0x3140, 0xc00a,	0x317f, 0xc00a,		0x21, 0
	.dw 0x31c0, 0xc00a,	0x31ff, 0xc00a,		0x21, 0
	.dw 0x3240, 0xc00a,	0x327f, 0xc00a,		0x21, 0
	.dw 0x32c0, 0xc00a,	0x32ff, 0xc00a,		0x21, 0
	.dw 0x3340, 0xc00a,	0x337f, 0xc00a,		0x21, 0
	.dw 0x33c0, 0xc00a,	0x33ff, 0xc00a,		0x21, 0
	.dw 0x3440, 0xc00a,	0x347f, 0xc00a,		0x21, 0
	.dw 0x34c0, 0xc00a,	0x34ff, 0xc00a,		0x21, 0
	.dw 0x3540, 0xc00a,	0x357f, 0xc00a,		0x21, 0
	.dw 0x35c0, 0xc00a,	0x35ff, 0xc00a,		0x21, 0
	.dw 0x3640, 0xc00a,	0x367f, 0xc00a,		0x21, 0
	.dw 0x36c0, 0xc00a,	0x36ff, 0xc00a,		0x21, 0
	.dw 0x3740, 0xc00a,	0x377f, 0xc00a,		0x21, 0
	.dw 0x37c0, 0xc00a,	0x37ff, 0xc00a,		0x21, 0
	.dw 0x3840, 0xc00a,	0x387f, 0xc00a,		0x21, 0
	.dw 0x38c0, 0xc00a,	0x38ff, 0xc00a,		0x21, 0
	.dw 0x3940, 0xc00a,	0x397f, 0xc00a,		0x21, 0
	.dw 0x39c0, 0xc00a,	0x5fff, 0xc00a,		0x21, 0
	.dw 0x6040, 0xc00a,	0x607f, 0xc00a,		0x21, 0
	.dw 0x60c0, 0xc00a,	0x60ff, 0xc00a,		0x21, 0
	.dw 0x6140, 0xc00a,	0x617f, 0xc00a,		0x21, 0
	.dw 0x61c0, 0xc00a,	0x61ff, 0xc00a,		0x21, 0
	.dw 0x6240, 0xc00a,	0x627f, 0xc00a,		0x21, 0
	.dw 0x62c0, 0xc00a,	0x62ff, 0xc00a,		0x21, 0
	.dw 0x6340, 0xc00a,	0x637f, 0xc00a,		0x21, 0
	.dw 0x63c0, 0xc00a,	0x63ff, 0xc00a,		0x21, 0
	.dw 0x6440, 0xc00a,	0x647f, 0xc00a,		0x21, 0
	.dw 0x64c0, 0xc00a,	0x64ff, 0xc00a,		0x21, 0
	.dw 0x6540, 0xc00a,	0x657f, 0xc00a,		0x21, 0
	.dw 0x65c0, 0xc00a,	0x65ff, 0xc00a,		0x21, 0
	.dw 0x6640, 0xc00a,	0x667f, 0xc00a,		0x21, 0
	.dw 0x66c0, 0xc00a,	0x66ff, 0xc00a,		0x21, 0
	.dw 0x6740, 0xc00a,	0x677f, 0xc00a,		0x21, 0
	.dw 0x67c0, 0xc00a,	0x67ff, 0xc00a,		0x21, 0
	.dw 0x6840, 0xc00a,	0x687f, 0xc00a,		0x21, 0
	.dw 0x68c0, 0xc00a,	0x68ff, 0xc00a,		0x21, 0
	.dw 0x6940, 0xc00a,	0x697f, 0xc00a,		0x21, 0
	.dw 0x69c0, 0xc00a,	0x69ff, 0xc00a,		0x21, 0
	.dw 0x6a40, 0xc00a,	0x6a7f, 0xc00a,		0x21, 0
	.dw 0x6ac0, 0xc00a,	0x6aff, 0xc00a,		0x21, 0
	.dw 0x6b40, 0xc00a,	0x6b7f, 0xc00a,		0x21, 0
	.dw 0x6bc0, 0xc00a,	0x6bff, 0xc00a,		0x21, 0
	.dw 0x6c40, 0xc00a,	0x6c7f, 0xc00a,		0x21, 0
	.dw 0x6cc0, 0xc00a,	0x6cff, 0xc00a,		0x21, 0
	.dw 0x6d40, 0xc00a,	0x6d7f, 0xc00a,		0x21, 0
	.dw 0x6dc0, 0xc00a,	0x6dff, 0xc00a,		0x21, 0
	.dw 0x6e40, 0xc00a,	0x6e7f, 0xc00a,		0x21, 0
	.dw 0x6ec0, 0xc00a,	0x6eff, 0xc00a,		0x21, 0
	.dw 0x6f40, 0xc00a,	0x6f7f, 0xc00a,		0x21, 0
	.dw 0x6fc0, 0xc00a,	0x6fff, 0xc00a,		0x21, 0
	.dw 0x7040, 0xc00a,	0x707f, 0xc00a,		0x21, 0
	.dw 0x70c0, 0xc00a,	0x70ff, 0xc00a,		0x21, 0
	.dw 0x7140, 0xc00a,	0x717f, 0xc00a,		0x21, 0
	.dw 0x71c0, 0xc00a,	0x71ff, 0xc00a,		0x21, 0
	.dw 0x7240, 0xc00a,	0x727f, 0xc00a,		0x21, 0
	.dw 0x72c0, 0xc00a,	0x72ff, 0xc00a,		0x21, 0
	.dw 0x7340, 0xc00a,	0x737f, 0xc00a,		0x21, 0
	.dw 0x73c0, 0xc00a,	0x73ff, 0xc00a,		0x21, 0
	.dw 0x7440, 0xc00a,	0x747f, 0xc00a,		0x21, 0
	.dw 0x74c0, 0xc00a,	0x74ff, 0xc00a,		0x21, 0
	.dw 0x7540, 0xc00a,	0x757f, 0xc00a,		0x21, 0
	.dw 0x75c0, 0xc00a,	0x75ff, 0xc00a,		0x21, 0
	.dw 0x7640, 0xc00a,	0x767f, 0xc00a,		0x21, 0
	.dw 0x76c0, 0xc00a,	0x76ff, 0xc00a,		0x21, 0
	.dw 0x7740, 0xc00a,	0x777f, 0xc00a,		0x21, 0
	.dw 0x77c0, 0xc00a,	0x77ff, 0xc00a,		0x21, 0
	.dw 0x7840, 0xc00a,	0x787f, 0xc00a,		0x21, 0
	.dw 0x78c0, 0xc00a,	0x78ff, 0xc00a,		0x21, 0
	.dw 0x7940, 0xc00a,	0x797f, 0xc00a,		0x21, 0
	.dw 0x79c0, 0xc00a,	0x9fff, 0xc00a,		0x21, 0
	.dw 0xa040, 0xc00a,	0xa07f, 0xc00a,		0x21, 0
	.dw 0xa0c0, 0xc00a,	0xa0ff, 0xc00a,		0x21, 0
	.dw 0xa140, 0xc00a,	0xa17f, 0xc00a,		0x21, 0
	.dw 0xa1c0, 0xc00a,	0xa1ff, 0xc00a,		0x21, 0
	.dw 0xa240, 0xc00a,	0xa27f, 0xc00a,		0x21, 0
	.dw 0xa2c0, 0xc00a,	0xa2ff, 0xc00a,		0x21, 0
	.dw 0xa340, 0xc00a,	0xa37f, 0xc00a,		0x21, 0
	.dw 0xa3c0, 0xc00a,	0xa3ff, 0xc00a,		0x21, 0
	.dw 0xa440, 0xc00a,	0xa47f, 0xc00a,		0x21, 0
	.dw 0xa4c0, 0xc00a,	0xa4ff, 0xc00a,		0x21, 0
	.dw 0xa540, 0xc00a,	0xa57f, 0xc00a,		0x21, 0
	.dw 0xa5c0, 0xc00a,	0xa5ff, 0xc00a,		0x21, 0
	.dw 0xa640, 0xc00a,	0xa67f, 0xc00a,		0x21, 0
	.dw 0xa6c0, 0xc00a,	0xa6ff, 0xc00a,		0x21, 0
	.dw 0xa740, 0xc00a,	0xa77f, 0xc00a,		0x21, 0
	.dw 0xa7c0, 0xc00a,	0xa7ff, 0xc00a,		0x21, 0
	.dw 0xa840, 0xc00a,	0xa87f, 0xc00a,		0x21, 0
	.dw 0xa8c0, 0xc00a,	0xa8ff, 0xc00a,		0x21, 0
	.dw 0xa940, 0xc00a,	0xa97f, 0xc00a,		0x21, 0
	.dw 0xa9c0, 0xc00a,	0xa9ff, 0xc00a,		0x21, 0
	.dw 0xaa40, 0xc00a,	0xaa7f, 0xc00a,		0x21, 0
	.dw 0xaac0, 0xc00a,	0xaaff, 0xc00a,		0x21, 0
	.dw 0xab40, 0xc00a,	0xab7f, 0xc00a,		0x21, 0
	.dw 0xabc0, 0xc00a,	0xabff, 0xc00a,		0x21, 0
	.dw 0xac40, 0xc00a,	0xac7f, 0xc00a,		0x21, 0
	.dw 0xacc0, 0xc00a,	0xacff, 0xc00a,		0x21, 0
	.dw 0xad40, 0xc00a,	0xad7f, 0xc00a,		0x21, 0
	.dw 0xadc0, 0xc00a,	0xadff, 0xc00a,		0x21, 0
	.dw 0xae40, 0xc00a,	0xae7f, 0xc00a,		0x21, 0
	.dw 0xaec0, 0xc00a,	0xaeff, 0xc00a,		0x21, 0
	.dw 0xaf40, 0xc00a,	0xaf7f, 0xc00a,		0x21, 0
	.dw 0xafc0, 0xc00a,	0xafff, 0xc00a,		0x21, 0
	.dw 0xb040, 0xc00a,	0xb07f, 0xc00a,		0x21, 0
	.dw 0xb0c0, 0xc00a,	0xb0ff, 0xc00a,		0x21, 0
	.dw 0xb140, 0xc00a,	0xb17f, 0xc00a,		0x21, 0
	.dw 0xb1c0, 0xc00a,	0xb1ff, 0xc00a,		0x21, 0
	.dw 0xb240, 0xc00a,	0xb27f, 0xc00a,		0x21, 0
	.dw 0xb2c0, 0xc00a,	0xb2ff, 0xc00a,		0x21, 0
	.dw 0xb340, 0xc00a,	0xb37f, 0xc00a,		0x21, 0
	.dw 0xb3c0, 0xc00a,	0xb3ff, 0xc00a,		0x21, 0
	.dw 0xb440, 0xc00a,	0xb47f, 0xc00a,		0x21, 0
	.dw 0xb4c0, 0xc00a,	0xb4ff, 0xc00a,		0x21, 0
	.dw 0xb540, 0xc00a,	0xb57f, 0xc00a,		0x21, 0
	.dw 0xb5c0, 0xc00a,	0xb5ff, 0xc00a,		0x21, 0
	.dw 0xb640, 0xc00a,	0xb67f, 0xc00a,		0x21, 0
	.dw 0xb6c0, 0xc00a,	0xb6ff, 0xc00a,		0x21, 0
	.dw 0xb740, 0xc00a,	0xb77f, 0xc00a,		0x21, 0
	.dw 0xb7c0, 0xc00a,	0xb7ff, 0xc00a,		0x21, 0
	.dw 0xb840, 0xc00a,	0xb87f, 0xc00a,		0x21, 0
	.dw 0xb8c0, 0xc00a,	0xb8ff, 0xc00a,		0x21, 0
	.dw 0xb940, 0xc00a,	0xb97f, 0xc00a,		0x21, 0
	.dw 0xb9c0, 0xc00a,	0xdfff, 0xc00a,		0x21, 0
	.dw 0xe040, 0xc00a,	0xe07f, 0xc00a,		0x21, 0
	.dw 0xe0c0, 0xc00a,	0xe0ff, 0xc00a,		0x21, 0
	.dw 0xe140, 0xc00a,	0xe17f, 0xc00a,		0x21, 0
	.dw 0xe1c0, 0xc00a,	0xe1ff, 0xc00a,		0x21, 0
	.dw 0xe240, 0xc00a,	0xe27f, 0xc00a,		0x21, 0
	.dw 0xe2c0, 0xc00a,	0xe2ff, 0xc00a,		0x21, 0
	.dw 0xe340, 0xc00a,	0xe37f, 0xc00a,		0x21, 0
	.dw 0xe3c0, 0xc00a,	0xe3ff, 0xc00a,		0x21, 0
	.dw 0xe440, 0xc00a,	0xe47f, 0xc00a,		0x21, 0
	.dw 0xe4c0, 0xc00a,	0xe4ff, 0xc00a,		0x21, 0
	.dw 0xe540, 0xc00a,	0xe57f, 0xc00a,		0x21, 0
	.dw 0xe5c0, 0xc00a,	0xe5ff, 0xc00a,		0x21, 0
	.dw 0xe640, 0xc00a,	0xe67f, 0xc00a,		0x21, 0
	.dw 0xe6c0, 0xc00a,	0xe6ff, 0xc00a,		0x21, 0
	.dw 0xe740, 0xc00a,	0xe77f, 0xc00a,		0x21, 0
	.dw 0xe7c0, 0xc00a,	0xe7ff, 0xc00a,		0x21, 0
	.dw 0xe840, 0xc00a,	0xe87f, 0xc00a,		0x21, 0
	.dw 0xe8c0, 0xc00a,	0xe8ff, 0xc00a,		0x21, 0
	.dw 0xe940, 0xc00a,	0xe97f, 0xc00a,		0x21, 0
	.dw 0xe9c0, 0xc00a,	0xe9ff, 0xc00a,		0x21, 0
	.dw 0xea40, 0xc00a,	0xea7f, 0xc00a,		0x21, 0
	.dw 0xeac0, 0xc00a,	0xeaff, 0xc00a,		0x21, 0
	.dw 0xeb40, 0xc00a,	0xeb7f, 0xc00a,		0x21, 0
	.dw 0xebc0, 0xc00a,	0xebff, 0xc00a,		0x21, 0
	.dw 0xec40, 0xc00a,	0xec7f, 0xc00a,		0x21, 0
	.dw 0xecc0, 0xc00a,	0xecff, 0xc00a,		0x21, 0
	.dw 0xed40, 0xc00a,	0xed7f, 0xc00a,		0x21, 0
	.dw 0xedc0, 0xc00a,	0xedff, 0xc00a,		0x21, 0
	.dw 0xee40, 0xc00a,	0xee7f, 0xc00a,		0x21, 0
	.dw 0xeec0, 0xc00a,	0xeeff, 0xc00a,		0x21, 0
	.dw 0xef40, 0xc00a,	0xef7f, 0xc00a,		0x21, 0
	.dw 0xefc0, 0xc00a,	0xefff, 0xc00a,		0x21, 0
	.dw 0xf040, 0xc00a,	0xf07f, 0xc00a,		0x21, 0
	.dw 0xf0c0, 0xc00a,	0xf0ff, 0xc00a,		0x21, 0
	.dw 0xf140, 0xc00a,	0xf17f, 0xc00a,		0x21, 0
	.dw 0xf1c0, 0xc00a,	0xf1ff, 0xc00a,		0x21, 0
	.dw 0xf240, 0xc00a,	0xf27f, 0xc00a,		0x21, 0
	.dw 0xf2c0, 0xc00a,	0xf2ff, 0xc00a,		0x21, 0
	.dw 0xf340, 0xc00a,	0xf37f, 0xc00a,		0x21, 0
	.dw 0xf3c0, 0xc00a,	0xf3ff, 0xc00a,		0x21, 0
	.dw 0xf440, 0xc00a,	0xf47f, 0xc00a,		0x21, 0
	.dw 0xf4c0, 0xc00a,	0xf4ff, 0xc00a,		0x21, 0
	.dw 0xf540, 0xc00a,	0xf57f, 0xc00a,		0x21, 0
	.dw 0xf5c0, 0xc00a,	0xf5ff, 0xc00a,		0x21, 0
	.dw 0xf640, 0xc00a,	0xf67f, 0xc00a,		0x21, 0
	.dw 0xf6c0, 0xc00a,	0xf6ff, 0xc00a,		0x21, 0
	.dw 0xf740, 0xc00a,	0xf77f, 0xc00a,		0x21, 0
	.dw 0xf7c0, 0xc00a,	0xf7ff, 0xc00a,		0x21, 0
	.dw 0xf840, 0xc00a,	0xf87f, 0xc00a,		0x21, 0
	.dw 0xf8c0, 0xc00a,	0xf8ff, 0xc00a,		0x21, 0
	.dw 0xf940, 0xc00a,	0xf97f, 0xc00a,		0x21, 0
	.dw 0xf9c0, 0xc00a,	0x1fff, 0xc00b,		0x21, 0
	.dw 0x2040, 0xc00b,	0x207f, 0xc00b,		0x21, 0
	.dw 0x20c0, 0xc00b,	0x20ff, 0xc00b,		0x21, 0
	.dw 0x2140, 0xc00b,	0x217f, 0xc00b,		0x21, 0
	.dw 0x21c0, 0xc00b,	0x21ff, 0xc00b,		0x21, 0
	.dw 0x2240, 0xc00b,	0x227f, 0xc00b,		0x21, 0
	.dw 0x22c0, 0xc00b,	0x22ff, 0xc00b,		0x21, 0
	.dw 0x2340, 0xc00b,	0x237f, 0xc00b,		0x21, 0
	.dw 0x23c0, 0xc00b,	0x23ff, 0xc00b,		0x21, 0
	.dw 0x2440, 0xc00b,	0x247f, 0xc00b,		0x21, 0
	.dw 0x24c0, 0xc00b,	0x24ff, 0xc00b,		0x21, 0
	.dw 0x2540, 0xc00b,	0x257f, 0xc00b,		0x21, 0
	.dw 0x25c0, 0xc00b,	0x25ff, 0xc00b,		0x21, 0
	.dw 0x2640, 0xc00b,	0x267f, 0xc00b,		0x21, 0
	.dw 0x26c0, 0xc00b,	0x26ff, 0xc00b,		0x21, 0
	.dw 0x2740, 0xc00b,	0x277f, 0xc00b,		0x21, 0
	.dw 0x27c0, 0xc00b,	0x27ff, 0xc00b,		0x21, 0
	.dw 0x2840, 0xc00b,	0x287f, 0xc00b,		0x21, 0
	.dw 0x28c0, 0xc00b,	0x28ff, 0xc00b,		0x21, 0
	.dw 0x2940, 0xc00b,	0x297f, 0xc00b,		0x21, 0
	.dw 0x29c0, 0xc00b,	0x29ff, 0xc00b,		0x21, 0
	.dw 0x2a40, 0xc00b,	0x2a7f, 0xc00b,		0x21, 0
	.dw 0x2ac0, 0xc00b,	0x2aff, 0xc00b,		0x21, 0
	.dw 0x2b40, 0xc00b,	0x2b7f, 0xc00b,		0x21, 0
	.dw 0x2bc0, 0xc00b,	0x2bff, 0xc00b,		0x21, 0
	.dw 0x2c40, 0xc00b,	0x2c7f, 0xc00b,		0x21, 0
	.dw 0x2cc0, 0xc00b,	0x2cff, 0xc00b,		0x21, 0
	.dw 0x2d40, 0xc00b,	0x2d7f, 0xc00b,		0x21, 0
	.dw 0x2dc0, 0xc00b,	0x2dff, 0xc00b,		0x21, 0
	.dw 0x2e40, 0xc00b,	0x2e7f, 0xc00b,		0x21, 0
	.dw 0x2ec0, 0xc00b,	0x2eff, 0xc00b,		0x21, 0
	.dw 0x2f40, 0xc00b,	0x2f7f, 0xc00b,		0x21, 0
	.dw 0x2fc0, 0xc00b,	0x2fff, 0xc00b,		0x21, 0
	.dw 0x3040, 0xc00b,	0x307f, 0xc00b,		0x21, 0
	.dw 0x30c0, 0xc00b,	0x30ff, 0xc00b,		0x21, 0
	.dw 0x3140, 0xc00b,	0x317f, 0xc00b,		0x21, 0
	.dw 0x31c0, 0xc00b,	0x31ff, 0xc00b,		0x21, 0
	.dw 0x3240, 0xc00b,	0x327f, 0xc00b,		0x21, 0
	.dw 0x32c0, 0xc00b,	0x32ff, 0xc00b,		0x21, 0
	.dw 0x3340, 0xc00b,	0x337f, 0xc00b,		0x21, 0
	.dw 0x33c0, 0xc00b,	0x33ff, 0xc00b,		0x21, 0
	.dw 0x3440, 0xc00b,	0x347f, 0xc00b,		0x21, 0
	.dw 0x34c0, 0xc00b,	0x34ff, 0xc00b,		0x21, 0
	.dw 0x3540, 0xc00b,	0x357f, 0xc00b,		0x21, 0
	.dw 0x35c0, 0xc00b,	0x35ff, 0xc00b,		0x21, 0
	.dw 0x3640, 0xc00b,	0x367f, 0xc00b,		0x21, 0
	.dw 0x36c0, 0xc00b,	0x36ff, 0xc00b,		0x21, 0
	.dw 0x3740, 0xc00b,	0x377f, 0xc00b,		0x21, 0
	.dw 0x37c0, 0xc00b,	0x37ff, 0xc00b,		0x21, 0
	.dw 0x3840, 0xc00b,	0x387f, 0xc00b,		0x21, 0
	.dw 0x38c0, 0xc00b,	0x38ff, 0xc00b,		0x21, 0
	.dw 0x3940, 0xc00b,	0x397f, 0xc00b,		0x21, 0
	.dw 0x39c0, 0xc00b,	0xffff, 0xc00b,		0x21, 0
	.dw 0x0040, 0xc00c,	0x007f, 0xc00c,		0x21, 0
	.dw 0x00c0, 0xc00c,	0x00ff, 0xc00c,		0x21, 0
	.dw 0x0140, 0xc00c,	0x017f, 0xc00c,		0x21, 0
	.dw 0x01c0, 0xc00c,	0x01ff, 0xc00c,		0x21, 0
	.dw 0x0240, 0xc00c,	0x027f, 0xc00c,		0x21, 0
	.dw 0x02c0, 0xc00c,	0x02ff, 0xc00c,		0x21, 0
	.dw 0x0340, 0xc00c,	0x037f, 0xc00c,		0x21, 0
	.dw 0x03c0, 0xc00c,	0x03ff, 0xc00c,		0x21, 0
	.dw 0x0440, 0xc00c,	0x047f, 0xc00c,		0x21, 0
	.dw 0x04c0, 0xc00c,	0x04ff, 0xc00c,		0x21, 0
	.dw 0x0540, 0xc00c,	0x057f, 0xc00c,		0x21, 0
	.dw 0x05c0, 0xc00c,	0x05ff, 0xc00c,		0x21, 0
	.dw 0x0640, 0xc00c,	0x067f, 0xc00c,		0x21, 0
	.dw 0x06c0, 0xc00c,	0x06ff, 0xc00c,		0x21, 0
	.dw 0x0740, 0xc00c,	0x077f, 0xc00c,		0x21, 0
	.dw 0x07c0, 0xc00c,	0x07ff, 0xc00c,		0x21, 0
	.dw 0x0840, 0xc00c,	0x087f, 0xc00c,		0x21, 0
	.dw 0x08c0, 0xc00c,	0x08ff, 0xc00c,		0x21, 0
	.dw 0x0940, 0xc00c,	0x097f, 0xc00c,		0x21, 0
	.dw 0x09c0, 0xc00c,	0x09ff, 0xc00c,		0x21, 0
	.dw 0x0a40, 0xc00c,	0x0a7f, 0xc00c,		0x21, 0
	.dw 0x0ac0, 0xc00c,	0x0aff, 0xc00c,		0x21, 0
	.dw 0x0b40, 0xc00c,	0x0b7f, 0xc00c,		0x21, 0
	.dw 0x0bc0, 0xc00c,	0x0bff, 0xc00c,		0x21, 0
	.dw 0x0c40, 0xc00c,	0x0c7f, 0xc00c,		0x21, 0
	.dw 0x0cc0, 0xc00c,	0x0cff, 0xc00c,		0x21, 0
	.dw 0x0d40, 0xc00c,	0x0d7f, 0xc00c,		0x21, 0
	.dw 0x0dc0, 0xc00c,	0x0dff, 0xc00c,		0x21, 0
	.dw 0x0e40, 0xc00c,	0x0e7f, 0xc00c,		0x21, 0
	.dw 0x0ec0, 0xc00c,	0x0eff, 0xc00c,		0x21, 0
	.dw 0x0f40, 0xc00c,	0x0f7f, 0xc00c,		0x21, 0
	.dw 0x0fc0, 0xc00c,	0x0fff, 0xc00c,		0x21, 0
	.dw 0x1040, 0xc00c,	0x107f, 0xc00c,		0x21, 0
	.dw 0x10c0, 0xc00c,	0x10ff, 0xc00c,		0x21, 0
	.dw 0x1140, 0xc00c,	0x117f, 0xc00c,		0x21, 0
	.dw 0x11c0, 0xc00c,	0x11ff, 0xc00c,		0x21, 0
	.dw 0x1240, 0xc00c,	0x127f, 0xc00c,		0x21, 0
	.dw 0x12c0, 0xc00c,	0x12ff, 0xc00c,		0x21, 0
	.dw 0x1340, 0xc00c,	0x137f, 0xc00c,		0x21, 0
	.dw 0x13c0, 0xc00c,	0x13ff, 0xc00c,		0x21, 0
	.dw 0x1440, 0xc00c,	0x147f, 0xc00c,		0x21, 0
	.dw 0x14c0, 0xc00c,	0x14ff, 0xc00c,		0x21, 0
	.dw 0x1540, 0xc00c,	0x157f, 0xc00c,		0x21, 0
	.dw 0x15c0, 0xc00c,	0x15ff, 0xc00c,		0x21, 0
	.dw 0x1640, 0xc00c,	0x167f, 0xc00c,		0x21, 0
	.dw 0x16c0, 0xc00c,	0x16ff, 0xc00c,		0x21, 0
	.dw 0x1740, 0xc00c,	0x177f, 0xc00c,		0x21, 0
	.dw 0x17c0, 0xc00c,	0x17ff, 0xc00c,		0x21, 0
	.dw 0x1840, 0xc00c,	0x187f, 0xc00c,		0x21, 0
	.dw 0x18c0, 0xc00c,	0x18ff, 0xc00c,		0x21, 0
	.dw 0x1940, 0xc00c,	0x197f, 0xc00c,		0x21, 0
	.dw 0x19c0, 0xc00c,	0x1fff, 0xc00c,		0x21, 0
	.dw 0x2040, 0xc00c,	0x207f, 0xc00c,		0x21, 0
	.dw 0x20c0, 0xc00c,	0x20ff, 0xc00c,		0x21, 0
	.dw 0x2140, 0xc00c,	0x217f, 0xc00c,		0x21, 0
	.dw 0x21c0, 0xc00c,	0x21ff, 0xc00c,		0x21, 0
	.dw 0x2240, 0xc00c,	0x227f, 0xc00c,		0x21, 0
	.dw 0x22c0, 0xc00c,	0x22ff, 0xc00c,		0x21, 0
	.dw 0x2340, 0xc00c,	0x237f, 0xc00c,		0x21, 0
	.dw 0x23c0, 0xc00c,	0x23ff, 0xc00c,		0x21, 0
	.dw 0x2440, 0xc00c,	0x247f, 0xc00c,		0x21, 0
	.dw 0x24c0, 0xc00c,	0x24ff, 0xc00c,		0x21, 0
	.dw 0x2540, 0xc00c,	0x257f, 0xc00c,		0x21, 0
	.dw 0x25c0, 0xc00c,	0x25ff, 0xc00c,		0x21, 0
	.dw 0x2640, 0xc00c,	0x267f, 0xc00c,		0x21, 0
	.dw 0x26c0, 0xc00c,	0x26ff, 0xc00c,		0x21, 0
	.dw 0x2740, 0xc00c,	0x277f, 0xc00c,		0x21, 0
	.dw 0x27c0, 0xc00c,	0x27ff, 0xc00c,		0x21, 0
	.dw 0x2840, 0xc00c,	0x287f, 0xc00c,		0x21, 0
	.dw 0x28c0, 0xc00c,	0x28ff, 0xc00c,		0x21, 0
	.dw 0x2940, 0xc00c,	0x297f, 0xc00c,		0x21, 0
	.dw 0x29c0, 0xc00c,	0x29ff, 0xc00c,		0x21, 0
	.dw 0x2a40, 0xc00c,	0x2a7f, 0xc00c,		0x21, 0
	.dw 0x2ac0, 0xc00c,	0x2aff, 0xc00c,		0x21, 0
	.dw 0x2b40, 0xc00c,	0x2b7f, 0xc00c,		0x21, 0
	.dw 0x2bc0, 0xc00c,	0x2bff, 0xc00c,		0x21, 0
	.dw 0x2c40, 0xc00c,	0x2c7f, 0xc00c,		0x21, 0
	.dw 0x2cc0, 0xc00c,	0x2cff, 0xc00c,		0x21, 0
	.dw 0x2d40, 0xc00c,	0x2d7f, 0xc00c,		0x21, 0
	.dw 0x2dc0, 0xc00c,	0x2dff, 0xc00c,		0x21, 0
	.dw 0x2e40, 0xc00c,	0x2e7f, 0xc00c,		0x21, 0
	.dw 0x2ec0, 0xc00c,	0x2eff, 0xc00c,		0x21, 0
	.dw 0x2f40, 0xc00c,	0x2f7f, 0xc00c,		0x21, 0
	.dw 0x2fc0, 0xc00c,	0x2fff, 0xc00c,		0x21, 0
	.dw 0x3040, 0xc00c,	0x307f, 0xc00c,		0x21, 0
	.dw 0x30c0, 0xc00c,	0x30ff, 0xc00c,		0x21, 0
	.dw 0x3140, 0xc00c,	0x317f, 0xc00c,		0x21, 0
	.dw 0x31c0, 0xc00c,	0x31ff, 0xc00c,		0x21, 0
	.dw 0x3240, 0xc00c,	0x327f, 0xc00c,		0x21, 0
	.dw 0x32c0, 0xc00c,	0x32ff, 0xc00c,		0x21, 0
	.dw 0x3340, 0xc00c,	0x337f, 0xc00c,		0x21, 0
	.dw 0x33c0, 0xc00c,	0x33ff, 0xc00c,		0x21, 0
	.dw 0x3440, 0xc00c,	0x347f, 0xc00c,		0x21, 0
	.dw 0x34c0, 0xc00c,	0x34ff, 0xc00c,		0x21, 0
	.dw 0x3540, 0xc00c,	0x357f, 0xc00c,		0x21, 0
	.dw 0x35c0, 0xc00c,	0x35ff, 0xc00c,		0x21, 0
	.dw 0x3640, 0xc00c,	0x367f, 0xc00c,		0x21, 0
	.dw 0x36c0, 0xc00c,	0x36ff, 0xc00c,		0x21, 0
	.dw 0x3740, 0xc00c,	0x377f, 0xc00c,		0x21, 0
	.dw 0x37c0, 0xc00c,	0x37ff, 0xc00c,		0x21, 0
	.dw 0x3840, 0xc00c,	0x387f, 0xc00c,		0x21, 0
	.dw 0x38c0, 0xc00c,	0x38ff, 0xc00c,		0x21, 0
	.dw 0x3940, 0xc00c,	0x397f, 0xc00c,		0x21, 0
	.dw 0x39c0, 0xc00c,	0x3fff, 0xc00c,		0x21, 0
	.dw 0x4040, 0xc00c,	0x407f, 0xc00c,		0x21, 0
	.dw 0x40c0, 0xc00c,	0x40ff, 0xc00c,		0x21, 0
	.dw 0x4140, 0xc00c,	0x417f, 0xc00c,		0x21, 0
	.dw 0x41c0, 0xc00c,	0x41ff, 0xc00c,		0x21, 0
	.dw 0x4240, 0xc00c,	0x427f, 0xc00c,		0x21, 0
	.dw 0x42c0, 0xc00c,	0x42ff, 0xc00c,		0x21, 0
	.dw 0x4340, 0xc00c,	0x437f, 0xc00c,		0x21, 0
	.dw 0x43c0, 0xc00c,	0x43ff, 0xc00c,		0x21, 0
	.dw 0x4440, 0xc00c,	0x447f, 0xc00c,		0x21, 0
	.dw 0x44c0, 0xc00c,	0x44ff, 0xc00c,		0x21, 0
	.dw 0x4540, 0xc00c,	0x457f, 0xc00c,		0x21, 0
	.dw 0x45c0, 0xc00c,	0x45ff, 0xc00c,		0x21, 0
	.dw 0x4640, 0xc00c,	0x467f, 0xc00c,		0x21, 0
	.dw 0x46c0, 0xc00c,	0x46ff, 0xc00c,		0x21, 0
	.dw 0x4740, 0xc00c,	0x477f, 0xc00c,		0x21, 0
	.dw 0x47c0, 0xc00c,	0x47ff, 0xc00c,		0x21, 0
	.dw 0x4840, 0xc00c,	0x487f, 0xc00c,		0x21, 0
	.dw 0x48c0, 0xc00c,	0x48ff, 0xc00c,		0x21, 0
	.dw 0x4940, 0xc00c,	0x497f, 0xc00c,		0x21, 0
	.dw 0x49c0, 0xc00c,	0x49ff, 0xc00c,		0x21, 0
	.dw 0x4a40, 0xc00c,	0x4a7f, 0xc00c,		0x21, 0
	.dw 0x4ac0, 0xc00c,	0x4aff, 0xc00c,		0x21, 0
	.dw 0x4b40, 0xc00c,	0x4b7f, 0xc00c,		0x21, 0
	.dw 0x4bc0, 0xc00c,	0x4bff, 0xc00c,		0x21, 0
	.dw 0x4c40, 0xc00c,	0x4c7f, 0xc00c,		0x21, 0
	.dw 0x4cc0, 0xc00c,	0x4cff, 0xc00c,		0x21, 0
	.dw 0x4d40, 0xc00c,	0x4d7f, 0xc00c,		0x21, 0
	.dw 0x4dc0, 0xc00c,	0x4dff, 0xc00c,		0x21, 0
	.dw 0x4e40, 0xc00c,	0x4e7f, 0xc00c,		0x21, 0
	.dw 0x4ec0, 0xc00c,	0x4eff, 0xc00c,		0x21, 0
	.dw 0x4f40, 0xc00c,	0x4f7f, 0xc00c,		0x21, 0
	.dw 0x4fc0, 0xc00c,	0x4fff, 0xc00c,		0x21, 0
	.dw 0x5040, 0xc00c,	0x507f, 0xc00c,		0x21, 0
	.dw 0x50c0, 0xc00c,	0x50ff, 0xc00c,		0x21, 0
	.dw 0x5140, 0xc00c,	0x517f, 0xc00c,		0x21, 0
	.dw 0x51c0, 0xc00c,	0x51ff, 0xc00c,		0x21, 0
	.dw 0x5240, 0xc00c,	0x527f, 0xc00c,		0x21, 0
	.dw 0x52c0, 0xc00c,	0x52ff, 0xc00c,		0x21, 0
	.dw 0x5340, 0xc00c,	0x537f, 0xc00c,		0x21, 0
	.dw 0x53c0, 0xc00c,	0x53ff, 0xc00c,		0x21, 0
	.dw 0x5440, 0xc00c,	0x547f, 0xc00c,		0x21, 0
	.dw 0x54c0, 0xc00c,	0x54ff, 0xc00c,		0x21, 0
	.dw 0x5540, 0xc00c,	0x557f, 0xc00c,		0x21, 0
	.dw 0x55c0, 0xc00c,	0x55ff, 0xc00c,		0x21, 0
	.dw 0x5640, 0xc00c,	0x567f, 0xc00c,		0x21, 0
	.dw 0x56c0, 0xc00c,	0x56ff, 0xc00c,		0x21, 0
	.dw 0x5740, 0xc00c,	0x577f, 0xc00c,		0x21, 0
	.dw 0x57c0, 0xc00c,	0x57ff, 0xc00c,		0x21, 0
	.dw 0x5840, 0xc00c,	0x587f, 0xc00c,		0x21, 0
	.dw 0x58c0, 0xc00c,	0x58ff, 0xc00c,		0x21, 0
	.dw 0x5940, 0xc00c,	0x597f, 0xc00c,		0x21, 0
	.dw 0x59c0, 0xc00c,	0x5fff, 0xc00c,		0x21, 0
	.dw 0x6040, 0xc00c,	0x607f, 0xc00c,		0x21, 0
	.dw 0x60c0, 0xc00c,	0x60ff, 0xc00c,		0x21, 0
	.dw 0x6140, 0xc00c,	0x617f, 0xc00c,		0x21, 0
	.dw 0x61c0, 0xc00c,	0x61ff, 0xc00c,		0x21, 0
	.dw 0x6240, 0xc00c,	0x627f, 0xc00c,		0x21, 0
	.dw 0x62c0, 0xc00c,	0x62ff, 0xc00c,		0x21, 0
	.dw 0x6340, 0xc00c,	0x637f, 0xc00c,		0x21, 0
	.dw 0x63c0, 0xc00c,	0x63ff, 0xc00c,		0x21, 0
	.dw 0x6440, 0xc00c,	0x647f, 0xc00c,		0x21, 0
	.dw 0x64c0, 0xc00c,	0x64ff, 0xc00c,		0x21, 0
	.dw 0x6540, 0xc00c,	0x657f, 0xc00c,		0x21, 0
	.dw 0x65c0, 0xc00c,	0x65ff, 0xc00c,		0x21, 0
	.dw 0x6640, 0xc00c,	0x667f, 0xc00c,		0x21, 0
	.dw 0x66c0, 0xc00c,	0x66ff, 0xc00c,		0x21, 0
	.dw 0x6740, 0xc00c,	0x677f, 0xc00c,		0x21, 0
	.dw 0x67c0, 0xc00c,	0x67ff, 0xc00c,		0x21, 0
	.dw 0x6840, 0xc00c,	0x687f, 0xc00c,		0x21, 0
	.dw 0x68c0, 0xc00c,	0x68ff, 0xc00c,		0x21, 0
	.dw 0x6940, 0xc00c,	0x697f, 0xc00c,		0x21, 0
	.dw 0x69c0, 0xc00c,	0x69ff, 0xc00c,		0x21, 0
	.dw 0x6a40, 0xc00c,	0x6a7f, 0xc00c,		0x21, 0
	.dw 0x6ac0, 0xc00c,	0x6aff, 0xc00c,		0x21, 0
	.dw 0x6b40, 0xc00c,	0x6b7f, 0xc00c,		0x21, 0
	.dw 0x6bc0, 0xc00c,	0x6bff, 0xc00c,		0x21, 0
	.dw 0x6c40, 0xc00c,	0x6c7f, 0xc00c,		0x21, 0
	.dw 0x6cc0, 0xc00c,	0x6cff, 0xc00c,		0x21, 0
	.dw 0x6d40, 0xc00c,	0x6d7f, 0xc00c,		0x21, 0
	.dw 0x6dc0, 0xc00c,	0x6dff, 0xc00c,		0x21, 0
	.dw 0x6e40, 0xc00c,	0x6e7f, 0xc00c,		0x21, 0
	.dw 0x6ec0, 0xc00c,	0x6eff, 0xc00c,		0x21, 0
	.dw 0x6f40, 0xc00c,	0x6f7f, 0xc00c,		0x21, 0
	.dw 0x6fc0, 0xc00c,	0x6fff, 0xc00c,		0x21, 0
	.dw 0x7040, 0xc00c,	0x707f, 0xc00c,		0x21, 0
	.dw 0x70c0, 0xc00c,	0x70ff, 0xc00c,		0x21, 0
	.dw 0x7140, 0xc00c,	0x717f, 0xc00c,		0x21, 0
	.dw 0x71c0, 0xc00c,	0x71ff, 0xc00c,		0x21, 0
	.dw 0x7240, 0xc00c,	0x727f, 0xc00c,		0x21, 0
	.dw 0x72c0, 0xc00c,	0x72ff, 0xc00c,		0x21, 0
	.dw 0x7340, 0xc00c,	0x737f, 0xc00c,		0x21, 0
	.dw 0x73c0, 0xc00c,	0x73ff, 0xc00c,		0x21, 0
	.dw 0x7440, 0xc00c,	0x747f, 0xc00c,		0x21, 0
	.dw 0x74c0, 0xc00c,	0x74ff, 0xc00c,		0x21, 0
	.dw 0x7540, 0xc00c,	0x757f, 0xc00c,		0x21, 0
	.dw 0x75c0, 0xc00c,	0x75ff, 0xc00c,		0x21, 0
	.dw 0x7640, 0xc00c,	0x767f, 0xc00c,		0x21, 0
	.dw 0x76c0, 0xc00c,	0x76ff, 0xc00c,		0x21, 0
	.dw 0x7740, 0xc00c,	0x777f, 0xc00c,		0x21, 0
	.dw 0x77c0, 0xc00c,	0x77ff, 0xc00c,		0x21, 0
	.dw 0x7840, 0xc00c,	0x787f, 0xc00c,		0x21, 0
	.dw 0x78c0, 0xc00c,	0x78ff, 0xc00c,		0x21, 0
	.dw 0x7940, 0xc00c,	0x797f, 0xc00c,		0x21, 0
	.dw 0x79c0, 0xc00c,	0x7fff, 0xc00c,		0x21, 0
	.dw 0x8040, 0xc00c,	0x807f, 0xc00c,		0x21, 0
	.dw 0x80c0, 0xc00c,	0x80ff, 0xc00c,		0x21, 0
	.dw 0x8140, 0xc00c,	0x817f, 0xc00c,		0x21, 0
	.dw 0x81c0, 0xc00c,	0x81ff, 0xc00c,		0x21, 0
	.dw 0x8240, 0xc00c,	0x827f, 0xc00c,		0x21, 0
	.dw 0x82c0, 0xc00c,	0x82ff, 0xc00c,		0x21, 0
	.dw 0x8340, 0xc00c,	0x837f, 0xc00c,		0x21, 0
	.dw 0x83c0, 0xc00c,	0x83ff, 0xc00c,		0x21, 0
	.dw 0x8440, 0xc00c,	0x847f, 0xc00c,		0x21, 0
	.dw 0x84c0, 0xc00c,	0x84ff, 0xc00c,		0x21, 0
	.dw 0x8540, 0xc00c,	0x857f, 0xc00c,		0x21, 0
	.dw 0x85c0, 0xc00c,	0x85ff, 0xc00c,		0x21, 0
	.dw 0x8640, 0xc00c,	0x867f, 0xc00c,		0x21, 0
	.dw 0x86c0, 0xc00c,	0x86ff, 0xc00c,		0x21, 0
	.dw 0x8740, 0xc00c,	0x877f, 0xc00c,		0x21, 0
	.dw 0x87c0, 0xc00c,	0x87ff, 0xc00c,		0x21, 0
	.dw 0x8840, 0xc00c,	0x887f, 0xc00c,		0x21, 0
	.dw 0x88c0, 0xc00c,	0x88ff, 0xc00c,		0x21, 0
	.dw 0x8940, 0xc00c,	0x897f, 0xc00c,		0x21, 0
	.dw 0x89c0, 0xc00c,	0x89ff, 0xc00c,		0x21, 0
	.dw 0x8a40, 0xc00c,	0x8a7f, 0xc00c,		0x21, 0
	.dw 0x8ac0, 0xc00c,	0x8aff, 0xc00c,		0x21, 0
	.dw 0x8b40, 0xc00c,	0x8b7f, 0xc00c,		0x21, 0
	.dw 0x8bc0, 0xc00c,	0x8bff, 0xc00c,		0x21, 0
	.dw 0x8c40, 0xc00c,	0x8c7f, 0xc00c,		0x21, 0
	.dw 0x8cc0, 0xc00c,	0x8cff, 0xc00c,		0x21, 0
	.dw 0x8d40, 0xc00c,	0x8d7f, 0xc00c,		0x21, 0
	.dw 0x8dc0, 0xc00c,	0x8dff, 0xc00c,		0x21, 0
	.dw 0x8e40, 0xc00c,	0x8e7f, 0xc00c,		0x21, 0
	.dw 0x8ec0, 0xc00c,	0x8eff, 0xc00c,		0x21, 0
	.dw 0x8f40, 0xc00c,	0x8f7f, 0xc00c,		0x21, 0
	.dw 0x8fc0, 0xc00c,	0x8fff, 0xc00c,		0x21, 0
	.dw 0x9040, 0xc00c,	0x907f, 0xc00c,		0x21, 0
	.dw 0x90c0, 0xc00c,	0x90ff, 0xc00c,		0x21, 0
	.dw 0x9140, 0xc00c,	0x917f, 0xc00c,		0x21, 0
	.dw 0x91c0, 0xc00c,	0x91ff, 0xc00c,		0x21, 0
	.dw 0x9240, 0xc00c,	0x927f, 0xc00c,		0x21, 0
	.dw 0x92c0, 0xc00c,	0x92ff, 0xc00c,		0x21, 0
	.dw 0x9340, 0xc00c,	0x937f, 0xc00c,		0x21, 0
	.dw 0x93c0, 0xc00c,	0x93ff, 0xc00c,		0x21, 0
	.dw 0x9440, 0xc00c,	0x947f, 0xc00c,		0x21, 0
	.dw 0x94c0, 0xc00c,	0x94ff, 0xc00c,		0x21, 0
	.dw 0x9540, 0xc00c,	0x957f, 0xc00c,		0x21, 0
	.dw 0x95c0, 0xc00c,	0x95ff, 0xc00c,		0x21, 0
	.dw 0x9640, 0xc00c,	0x967f, 0xc00c,		0x21, 0
	.dw 0x96c0, 0xc00c,	0x96ff, 0xc00c,		0x21, 0
	.dw 0x9740, 0xc00c,	0x977f, 0xc00c,		0x21, 0
	.dw 0x97c0, 0xc00c,	0x97ff, 0xc00c,		0x21, 0
	.dw 0x9840, 0xc00c,	0x987f, 0xc00c,		0x21, 0
	.dw 0x98c0, 0xc00c,	0x98ff, 0xc00c,		0x21, 0
	.dw 0x9940, 0xc00c,	0x997f, 0xc00c,		0x21, 0
	.dw 0x99c0, 0xc00c,	0x9fff, 0xc00c,		0x21, 0
	.dw 0xa040, 0xc00c,	0xa07f, 0xc00c,		0x21, 0
	.dw 0xa0c0, 0xc00c,	0xa0ff, 0xc00c,		0x21, 0
	.dw 0xa140, 0xc00c,	0xa17f, 0xc00c,		0x21, 0
	.dw 0xa1c0, 0xc00c,	0xa1ff, 0xc00c,		0x21, 0
	.dw 0xa240, 0xc00c,	0xa27f, 0xc00c,		0x21, 0
	.dw 0xa2c0, 0xc00c,	0xa2ff, 0xc00c,		0x21, 0
	.dw 0xa340, 0xc00c,	0xa37f, 0xc00c,		0x21, 0
	.dw 0xa3c0, 0xc00c,	0xa3ff, 0xc00c,		0x21, 0
	.dw 0xa440, 0xc00c,	0xa47f, 0xc00c,		0x21, 0
	.dw 0xa4c0, 0xc00c,	0xa4ff, 0xc00c,		0x21, 0
	.dw 0xa540, 0xc00c,	0xa57f, 0xc00c,		0x21, 0
	.dw 0xa5c0, 0xc00c,	0xa5ff, 0xc00c,		0x21, 0
	.dw 0xa640, 0xc00c,	0xa67f, 0xc00c,		0x21, 0
	.dw 0xa6c0, 0xc00c,	0xa6ff, 0xc00c,		0x21, 0
	.dw 0xa740, 0xc00c,	0xa77f, 0xc00c,		0x21, 0
	.dw 0xa7c0, 0xc00c,	0xa7ff, 0xc00c,		0x21, 0
	.dw 0xa840, 0xc00c,	0xa87f, 0xc00c,		0x21, 0
	.dw 0xa8c0, 0xc00c,	0xa8ff, 0xc00c,		0x21, 0
	.dw 0xa940, 0xc00c,	0xa97f, 0xc00c,		0x21, 0
	.dw 0xa9c0, 0xc00c,	0xa9ff, 0xc00c,		0x21, 0
	.dw 0xaa40, 0xc00c,	0xaa7f, 0xc00c,		0x21, 0
	.dw 0xaac0, 0xc00c,	0xaaff, 0xc00c,		0x21, 0
	.dw 0xab40, 0xc00c,	0xab7f, 0xc00c,		0x21, 0
	.dw 0xabc0, 0xc00c,	0xabff, 0xc00c,		0x21, 0
	.dw 0xac40, 0xc00c,	0xac7f, 0xc00c,		0x21, 0
	.dw 0xacc0, 0xc00c,	0xacff, 0xc00c,		0x21, 0
	.dw 0xad40, 0xc00c,	0xad7f, 0xc00c,		0x21, 0
	.dw 0xadc0, 0xc00c,	0xadff, 0xc00c,		0x21, 0
	.dw 0xae40, 0xc00c,	0xae7f, 0xc00c,		0x21, 0
	.dw 0xaec0, 0xc00c,	0xaeff, 0xc00c,		0x21, 0
	.dw 0xaf40, 0xc00c,	0xaf7f, 0xc00c,		0x21, 0
	.dw 0xafc0, 0xc00c,	0xafff, 0xc00c,		0x21, 0
	.dw 0xb040, 0xc00c,	0xb07f, 0xc00c,		0x21, 0
	.dw 0xb0c0, 0xc00c,	0xb0ff, 0xc00c,		0x21, 0
	.dw 0xb140, 0xc00c,	0xb17f, 0xc00c,		0x21, 0
	.dw 0xb1c0, 0xc00c,	0xb1ff, 0xc00c,		0x21, 0
	.dw 0xb240, 0xc00c,	0xb27f, 0xc00c,		0x21, 0
	.dw 0xb2c0, 0xc00c,	0xb2ff, 0xc00c,		0x21, 0
	.dw 0xb340, 0xc00c,	0xb37f, 0xc00c,		0x21, 0
	.dw 0xb3c0, 0xc00c,	0xb3ff, 0xc00c,		0x21, 0
	.dw 0xb440, 0xc00c,	0xb47f, 0xc00c,		0x21, 0
	.dw 0xb4c0, 0xc00c,	0xb4ff, 0xc00c,		0x21, 0
	.dw 0xb540, 0xc00c,	0xb57f, 0xc00c,		0x21, 0
	.dw 0xb5c0, 0xc00c,	0xb5ff, 0xc00c,		0x21, 0
	.dw 0xb640, 0xc00c,	0xb67f, 0xc00c,		0x21, 0
	.dw 0xb6c0, 0xc00c,	0xb6ff, 0xc00c,		0x21, 0
	.dw 0xb740, 0xc00c,	0xb77f, 0xc00c,		0x21, 0
	.dw 0xb7c0, 0xc00c,	0xb7ff, 0xc00c,		0x21, 0
	.dw 0xb840, 0xc00c,	0xb87f, 0xc00c,		0x21, 0
	.dw 0xb8c0, 0xc00c,	0xb8ff, 0xc00c,		0x21, 0
	.dw 0xb940, 0xc00c,	0xb97f, 0xc00c,		0x21, 0
	.dw 0xb9c0, 0xc00c,	0xbfff, 0xc00c,		0x21, 0
	.dw 0xc040, 0xc00c,	0xc07f, 0xc00c,		0x21, 0
	.dw 0xc0c0, 0xc00c,	0xc0ff, 0xc00c,		0x21, 0
	.dw 0xc140, 0xc00c,	0xc17f, 0xc00c,		0x21, 0
	.dw 0xc1c0, 0xc00c,	0xc1ff, 0xc00c,		0x21, 0
	.dw 0xc240, 0xc00c,	0xc27f, 0xc00c,		0x21, 0
	.dw 0xc2c0, 0xc00c,	0xc2ff, 0xc00c,		0x21, 0
	.dw 0xc340, 0xc00c,	0xc37f, 0xc00c,		0x21, 0
	.dw 0xc3c0, 0xc00c,	0xc3ff, 0xc00c,		0x21, 0
	.dw 0xc440, 0xc00c,	0xc47f, 0xc00c,		0x21, 0
	.dw 0xc4c0, 0xc00c,	0xc4ff, 0xc00c,		0x21, 0
	.dw 0xc540, 0xc00c,	0xc57f, 0xc00c,		0x21, 0
	.dw 0xc5c0, 0xc00c,	0xc5ff, 0xc00c,		0x21, 0
	.dw 0xc640, 0xc00c,	0xc67f, 0xc00c,		0x21, 0
	.dw 0xc6c0, 0xc00c,	0xc6ff, 0xc00c,		0x21, 0
	.dw 0xc740, 0xc00c,	0xc77f, 0xc00c,		0x21, 0
	.dw 0xc7c0, 0xc00c,	0xc7ff, 0xc00c,		0x21, 0
	.dw 0xc840, 0xc00c,	0xc87f, 0xc00c,		0x21, 0
	.dw 0xc8c0, 0xc00c,	0xc8ff, 0xc00c,		0x21, 0
	.dw 0xc940, 0xc00c,	0xc97f, 0xc00c,		0x21, 0
	.dw 0xc9c0, 0xc00c,	0xc9ff, 0xc00c,		0x21, 0
	.dw 0xca40, 0xc00c,	0xca7f, 0xc00c,		0x21, 0
	.dw 0xcac0, 0xc00c,	0xcaff, 0xc00c,		0x21, 0
	.dw 0xcb40, 0xc00c,	0xcb7f, 0xc00c,		0x21, 0
	.dw 0xcbc0, 0xc00c,	0xcbff, 0xc00c,		0x21, 0
	.dw 0xcc40, 0xc00c,	0xcc7f, 0xc00c,		0x21, 0
	.dw 0xccc0, 0xc00c,	0xccff, 0xc00c,		0x21, 0
	.dw 0xcd40, 0xc00c,	0xcd7f, 0xc00c,		0x21, 0
	.dw 0xcdc0, 0xc00c,	0xcdff, 0xc00c,		0x21, 0
	.dw 0xce40, 0xc00c,	0xce7f, 0xc00c,		0x21, 0
	.dw 0xcec0, 0xc00c,	0xceff, 0xc00c,		0x21, 0
	.dw 0xcf40, 0xc00c,	0xcf7f, 0xc00c,		0x21, 0
	.dw 0xcfc0, 0xc00c,	0xcfff, 0xc00c,		0x21, 0
	.dw 0xd040, 0xc00c,	0xd07f, 0xc00c,		0x21, 0
	.dw 0xd0c0, 0xc00c,	0xd0ff, 0xc00c,		0x21, 0
	.dw 0xd140, 0xc00c,	0xd17f, 0xc00c,		0x21, 0
	.dw 0xd1c0, 0xc00c,	0xd1ff, 0xc00c,		0x21, 0
	.dw 0xd240, 0xc00c,	0xd27f, 0xc00c,		0x21, 0
	.dw 0xd2c0, 0xc00c,	0xd2ff, 0xc00c,		0x21, 0
	.dw 0xd340, 0xc00c,	0xd37f, 0xc00c,		0x21, 0
	.dw 0xd3c0, 0xc00c,	0xd3ff, 0xc00c,		0x21, 0
	.dw 0xd440, 0xc00c,	0xd47f, 0xc00c,		0x21, 0
	.dw 0xd4c0, 0xc00c,	0xd4ff, 0xc00c,		0x21, 0
	.dw 0xd540, 0xc00c,	0xd57f, 0xc00c,		0x21, 0
	.dw 0xd5c0, 0xc00c,	0xd5ff, 0xc00c,		0x21, 0
	.dw 0xd640, 0xc00c,	0xd67f, 0xc00c,		0x21, 0
	.dw 0xd6c0, 0xc00c,	0xd6ff, 0xc00c,		0x21, 0
	.dw 0xd740, 0xc00c,	0xd77f, 0xc00c,		0x21, 0
	.dw 0xd7c0, 0xc00c,	0xd7ff, 0xc00c,		0x21, 0
	.dw 0xd840, 0xc00c,	0xd87f, 0xc00c,		0x21, 0
	.dw 0xd8c0, 0xc00c,	0xd8ff, 0xc00c,		0x21, 0
	.dw 0xd940, 0xc00c,	0xd97f, 0xc00c,		0x21, 0
	.dw 0xd9c0, 0xc00c,	0xdfff, 0xc00c,		0x21, 0
	.dw 0xe040, 0xc00c,	0xe07f, 0xc00c,		0x21, 0
	.dw 0xe0c0, 0xc00c,	0xe0ff, 0xc00c,		0x21, 0
	.dw 0xe140, 0xc00c,	0xe17f, 0xc00c,		0x21, 0
	.dw 0xe1c0, 0xc00c,	0xe1ff, 0xc00c,		0x21, 0
	.dw 0xe240, 0xc00c,	0xe27f, 0xc00c,		0x21, 0
	.dw 0xe2c0, 0xc00c,	0xe2ff, 0xc00c,		0x21, 0
	.dw 0xe340, 0xc00c,	0xe37f, 0xc00c,		0x21, 0
	.dw 0xe3c0, 0xc00c,	0xe3ff, 0xc00c,		0x21, 0
	.dw 0xe440, 0xc00c,	0xe47f, 0xc00c,		0x21, 0
	.dw 0xe4c0, 0xc00c,	0xe4ff, 0xc00c,		0x21, 0
	.dw 0xe540, 0xc00c,	0xe57f, 0xc00c,		0x21, 0
	.dw 0xe5c0, 0xc00c,	0xe5ff, 0xc00c,		0x21, 0
	.dw 0xe640, 0xc00c,	0xe67f, 0xc00c,		0x21, 0
	.dw 0xe6c0, 0xc00c,	0xe6ff, 0xc00c,		0x21, 0
	.dw 0xe740, 0xc00c,	0xe77f, 0xc00c,		0x21, 0
	.dw 0xe7c0, 0xc00c,	0xe7ff, 0xc00c,		0x21, 0
	.dw 0xe840, 0xc00c,	0xe87f, 0xc00c,		0x21, 0
	.dw 0xe8c0, 0xc00c,	0xe8ff, 0xc00c,		0x21, 0
	.dw 0xe940, 0xc00c,	0xe97f, 0xc00c,		0x21, 0
	.dw 0xe9c0, 0xc00c,	0xe9ff, 0xc00c,		0x21, 0
	.dw 0xea40, 0xc00c,	0xea7f, 0xc00c,		0x21, 0
	.dw 0xeac0, 0xc00c,	0xeaff, 0xc00c,		0x21, 0
	.dw 0xeb40, 0xc00c,	0xeb7f, 0xc00c,		0x21, 0
	.dw 0xebc0, 0xc00c,	0xebff, 0xc00c,		0x21, 0
	.dw 0xec40, 0xc00c,	0xec7f, 0xc00c,		0x21, 0
	.dw 0xecc0, 0xc00c,	0xecff, 0xc00c,		0x21, 0
	.dw 0xed40, 0xc00c,	0xed7f, 0xc00c,		0x21, 0
	.dw 0xedc0, 0xc00c,	0xedff, 0xc00c,		0x21, 0
	.dw 0xee40, 0xc00c,	0xee7f, 0xc00c,		0x21, 0
	.dw 0xeec0, 0xc00c,	0xeeff, 0xc00c,		0x21, 0
	.dw 0xef40, 0xc00c,	0xef7f, 0xc00c,		0x21, 0
	.dw 0xefc0, 0xc00c,	0xefff, 0xc00c,		0x21, 0
	.dw 0xf040, 0xc00c,	0xf07f, 0xc00c,		0x21, 0
	.dw 0xf0c0, 0xc00c,	0xf0ff, 0xc00c,		0x21, 0
	.dw 0xf140, 0xc00c,	0xf17f, 0xc00c,		0x21, 0
	.dw 0xf1c0, 0xc00c,	0xf1ff, 0xc00c,		0x21, 0
	.dw 0xf240, 0xc00c,	0xf27f, 0xc00c,		0x21, 0
	.dw 0xf2c0, 0xc00c,	0xf2ff, 0xc00c,		0x21, 0
	.dw 0xf340, 0xc00c,	0xf37f, 0xc00c,		0x21, 0
	.dw 0xf3c0, 0xc00c,	0xf3ff, 0xc00c,		0x21, 0
	.dw 0xf440, 0xc00c,	0xf47f, 0xc00c,		0x21, 0
	.dw 0xf4c0, 0xc00c,	0xf4ff, 0xc00c,		0x21, 0
	.dw 0xf540, 0xc00c,	0xf57f, 0xc00c,		0x21, 0
	.dw 0xf5c0, 0xc00c,	0xf5ff, 0xc00c,		0x21, 0
	.dw 0xf640, 0xc00c,	0xf67f, 0xc00c,		0x21, 0
	.dw 0xf6c0, 0xc00c,	0xf6ff, 0xc00c,		0x21, 0
	.dw 0xf740, 0xc00c,	0xf77f, 0xc00c,		0x21, 0
	.dw 0xf7c0, 0xc00c,	0xf7ff, 0xc00c,		0x21, 0
	.dw 0xf840, 0xc00c,	0xf87f, 0xc00c,		0x21, 0
	.dw 0xf8c0, 0xc00c,	0xf8ff, 0xc00c,		0x21, 0
	.dw 0xf940, 0xc00c,	0xf97f, 0xc00c,		0x21, 0
	.dw 0xf9c0, 0xc00c,	0xffff, 0xc00c,		0x21, 0
	.dw 0x0040, 0xc00d,	0x007f, 0xc00d,		0x21, 0
	.dw 0x00c0, 0xc00d,	0x00ff, 0xc00d,		0x21, 0
	.dw 0x0140, 0xc00d,	0x017f, 0xc00d,		0x21, 0
	.dw 0x01c0, 0xc00d,	0x01ff, 0xc00d,		0x21, 0
	.dw 0x0240, 0xc00d,	0x027f, 0xc00d,		0x21, 0
	.dw 0x02c0, 0xc00d,	0x02ff, 0xc00d,		0x21, 0
	.dw 0x0340, 0xc00d,	0x037f, 0xc00d,		0x21, 0
	.dw 0x03c0, 0xc00d,	0x03ff, 0xc00d,		0x21, 0
	.dw 0x0440, 0xc00d,	0x047f, 0xc00d,		0x21, 0
	.dw 0x04c0, 0xc00d,	0x04ff, 0xc00d,		0x21, 0
	.dw 0x0540, 0xc00d,	0x057f, 0xc00d,		0x21, 0
	.dw 0x05c0, 0xc00d,	0x05ff, 0xc00d,		0x21, 0
	.dw 0x0640, 0xc00d,	0x067f, 0xc00d,		0x21, 0
	.dw 0x06c0, 0xc00d,	0x06ff, 0xc00d,		0x21, 0
	.dw 0x0740, 0xc00d,	0x077f, 0xc00d,		0x21, 0
	.dw 0x07c0, 0xc00d,	0x07ff, 0xc00d,		0x21, 0
	.dw 0x0840, 0xc00d,	0x087f, 0xc00d,		0x21, 0
	.dw 0x08c0, 0xc00d,	0x08ff, 0xc00d,		0x21, 0
	.dw 0x0940, 0xc00d,	0x097f, 0xc00d,		0x21, 0
	.dw 0x09c0, 0xc00d,	0x09ff, 0xc00d,		0x21, 0
	.dw 0x0a40, 0xc00d,	0x0a7f, 0xc00d,		0x21, 0
	.dw 0x0ac0, 0xc00d,	0x0aff, 0xc00d,		0x21, 0
	.dw 0x0b40, 0xc00d,	0x0b7f, 0xc00d,		0x21, 0
	.dw 0x0bc0, 0xc00d,	0x0bff, 0xc00d,		0x21, 0
	.dw 0x0c40, 0xc00d,	0x0c7f, 0xc00d,		0x21, 0
	.dw 0x0cc0, 0xc00d,	0x0cff, 0xc00d,		0x21, 0
	.dw 0x0d40, 0xc00d,	0x0d7f, 0xc00d,		0x21, 0
	.dw 0x0dc0, 0xc00d,	0x0dff, 0xc00d,		0x21, 0
	.dw 0x0e40, 0xc00d,	0x0e7f, 0xc00d,		0x21, 0
	.dw 0x0ec0, 0xc00d,	0x0eff, 0xc00d,		0x21, 0
	.dw 0x0f40, 0xc00d,	0x0f7f, 0xc00d,		0x21, 0
	.dw 0x0fc0, 0xc00d,	0x0fff, 0xc00d,		0x21, 0
	.dw 0x1040, 0xc00d,	0x107f, 0xc00d,		0x21, 0
	.dw 0x10c0, 0xc00d,	0x10ff, 0xc00d,		0x21, 0
	.dw 0x1140, 0xc00d,	0x117f, 0xc00d,		0x21, 0
	.dw 0x11c0, 0xc00d,	0x11ff, 0xc00d,		0x21, 0
	.dw 0x1240, 0xc00d,	0x127f, 0xc00d,		0x21, 0
	.dw 0x12c0, 0xc00d,	0x12ff, 0xc00d,		0x21, 0
	.dw 0x1340, 0xc00d,	0x137f, 0xc00d,		0x21, 0
	.dw 0x13c0, 0xc00d,	0x13ff, 0xc00d,		0x21, 0
	.dw 0x1440, 0xc00d,	0x147f, 0xc00d,		0x21, 0
	.dw 0x14c0, 0xc00d,	0x14ff, 0xc00d,		0x21, 0
	.dw 0x1540, 0xc00d,	0x157f, 0xc00d,		0x21, 0
	.dw 0x15c0, 0xc00d,	0x15ff, 0xc00d,		0x21, 0
	.dw 0x1640, 0xc00d,	0x167f, 0xc00d,		0x21, 0
	.dw 0x16c0, 0xc00d,	0x16ff, 0xc00d,		0x21, 0
	.dw 0x1740, 0xc00d,	0x177f, 0xc00d,		0x21, 0
	.dw 0x17c0, 0xc00d,	0x17ff, 0xc00d,		0x21, 0
	.dw 0x1840, 0xc00d,	0x187f, 0xc00d,		0x21, 0
	.dw 0x18c0, 0xc00d,	0x18ff, 0xc00d,		0x21, 0
	.dw 0x1940, 0xc00d,	0x197f, 0xc00d,		0x21, 0
	.dw 0x19c0, 0xc00d,	0x1fff, 0xc00d,		0x21, 0
	.dw 0x2040, 0xc00d,	0x207f, 0xc00d,		0x21, 0
	.dw 0x20c0, 0xc00d,	0x20ff, 0xc00d,		0x21, 0
	.dw 0x2140, 0xc00d,	0x217f, 0xc00d,		0x21, 0
	.dw 0x21c0, 0xc00d,	0x21ff, 0xc00d,		0x21, 0
	.dw 0x2240, 0xc00d,	0x227f, 0xc00d,		0x21, 0
	.dw 0x22c0, 0xc00d,	0x22ff, 0xc00d,		0x21, 0
	.dw 0x2340, 0xc00d,	0x237f, 0xc00d,		0x21, 0
	.dw 0x23c0, 0xc00d,	0x23ff, 0xc00d,		0x21, 0
	.dw 0x2440, 0xc00d,	0x247f, 0xc00d,		0x21, 0
	.dw 0x24c0, 0xc00d,	0x24ff, 0xc00d,		0x21, 0
	.dw 0x2540, 0xc00d,	0x257f, 0xc00d,		0x21, 0
	.dw 0x25c0, 0xc00d,	0x25ff, 0xc00d,		0x21, 0
	.dw 0x2640, 0xc00d,	0x267f, 0xc00d,		0x21, 0
	.dw 0x26c0, 0xc00d,	0x26ff, 0xc00d,		0x21, 0
	.dw 0x2740, 0xc00d,	0x277f, 0xc00d,		0x21, 0
	.dw 0x27c0, 0xc00d,	0x27ff, 0xc00d,		0x21, 0
	.dw 0x2840, 0xc00d,	0x287f, 0xc00d,		0x21, 0
	.dw 0x28c0, 0xc00d,	0x28ff, 0xc00d,		0x21, 0
	.dw 0x2940, 0xc00d,	0x297f, 0xc00d,		0x21, 0
	.dw 0x29c0, 0xc00d,	0x29ff, 0xc00d,		0x21, 0
	.dw 0x2a40, 0xc00d,	0x2a7f, 0xc00d,		0x21, 0
	.dw 0x2ac0, 0xc00d,	0x2aff, 0xc00d,		0x21, 0
	.dw 0x2b40, 0xc00d,	0x2b7f, 0xc00d,		0x21, 0
	.dw 0x2bc0, 0xc00d,	0x2bff, 0xc00d,		0x21, 0
	.dw 0x2c40, 0xc00d,	0x2c7f, 0xc00d,		0x21, 0
	.dw 0x2cc0, 0xc00d,	0x2cff, 0xc00d,		0x21, 0
	.dw 0x2d40, 0xc00d,	0x2d7f, 0xc00d,		0x21, 0
	.dw 0x2dc0, 0xc00d,	0x2dff, 0xc00d,		0x21, 0
	.dw 0x2e40, 0xc00d,	0x2e7f, 0xc00d,		0x21, 0
	.dw 0x2ec0, 0xc00d,	0x2eff, 0xc00d,		0x21, 0
	.dw 0x2f40, 0xc00d,	0x2f7f, 0xc00d,		0x21, 0
	.dw 0x2fc0, 0xc00d,	0x2fff, 0xc00d,		0x21, 0
	.dw 0x3040, 0xc00d,	0x307f, 0xc00d,		0x21, 0
	.dw 0x30c0, 0xc00d,	0x30ff, 0xc00d,		0x21, 0
	.dw 0x3140, 0xc00d,	0x317f, 0xc00d,		0x21, 0
	.dw 0x31c0, 0xc00d,	0x31ff, 0xc00d,		0x21, 0
	.dw 0x3240, 0xc00d,	0x327f, 0xc00d,		0x21, 0
	.dw 0x32c0, 0xc00d,	0x32ff, 0xc00d,		0x21, 0
	.dw 0x3340, 0xc00d,	0x337f, 0xc00d,		0x21, 0
	.dw 0x33c0, 0xc00d,	0x33ff, 0xc00d,		0x21, 0
	.dw 0x3440, 0xc00d,	0x347f, 0xc00d,		0x21, 0
	.dw 0x34c0, 0xc00d,	0x34ff, 0xc00d,		0x21, 0
	.dw 0x3540, 0xc00d,	0x357f, 0xc00d,		0x21, 0
	.dw 0x35c0, 0xc00d,	0x35ff, 0xc00d,		0x21, 0
	.dw 0x3640, 0xc00d,	0x367f, 0xc00d,		0x21, 0
	.dw 0x36c0, 0xc00d,	0x36ff, 0xc00d,		0x21, 0
	.dw 0x3740, 0xc00d,	0x377f, 0xc00d,		0x21, 0
	.dw 0x37c0, 0xc00d,	0x37ff, 0xc00d,		0x21, 0
	.dw 0x3840, 0xc00d,	0x387f, 0xc00d,		0x21, 0
	.dw 0x38c0, 0xc00d,	0x38ff, 0xc00d,		0x21, 0
	.dw 0x3940, 0xc00d,	0x397f, 0xc00d,		0x21, 0
	.dw 0x39c0, 0xc00d,	0x3fff, 0xc00d,		0x21, 0
	.dw 0x4040, 0xc00d,	0x407f, 0xc00d,		0x21, 0
	.dw 0x40c0, 0xc00d,	0x40ff, 0xc00d,		0x21, 0
	.dw 0x4140, 0xc00d,	0x417f, 0xc00d,		0x21, 0
	.dw 0x41c0, 0xc00d,	0x41ff, 0xc00d,		0x21, 0
	.dw 0x4240, 0xc00d,	0x427f, 0xc00d,		0x21, 0
	.dw 0x42c0, 0xc00d,	0x42ff, 0xc00d,		0x21, 0
	.dw 0x4340, 0xc00d,	0x437f, 0xc00d,		0x21, 0
	.dw 0x43c0, 0xc00d,	0x43ff, 0xc00d,		0x21, 0
	.dw 0x4440, 0xc00d,	0x447f, 0xc00d,		0x21, 0
	.dw 0x44c0, 0xc00d,	0x44ff, 0xc00d,		0x21, 0
	.dw 0x4540, 0xc00d,	0x457f, 0xc00d,		0x21, 0
	.dw 0x45c0, 0xc00d,	0x45ff, 0xc00d,		0x21, 0
	.dw 0x4640, 0xc00d,	0x467f, 0xc00d,		0x21, 0
	.dw 0x46c0, 0xc00d,	0x46ff, 0xc00d,		0x21, 0
	.dw 0x4740, 0xc00d,	0x477f, 0xc00d,		0x21, 0
	.dw 0x47c0, 0xc00d,	0x47ff, 0xc00d,		0x21, 0
	.dw 0x4840, 0xc00d,	0x487f, 0xc00d,		0x21, 0
	.dw 0x48c0, 0xc00d,	0x48ff, 0xc00d,		0x21, 0
	.dw 0x4940, 0xc00d,	0x497f, 0xc00d,		0x21, 0
	.dw 0x49c0, 0xc00d,	0x49ff, 0xc00d,		0x21, 0
	.dw 0x4a40, 0xc00d,	0x4a7f, 0xc00d,		0x21, 0
	.dw 0x4ac0, 0xc00d,	0x4aff, 0xc00d,		0x21, 0
	.dw 0x4b40, 0xc00d,	0x4b7f, 0xc00d,		0x21, 0
	.dw 0x4bc0, 0xc00d,	0x4bff, 0xc00d,		0x21, 0
	.dw 0x4c40, 0xc00d,	0x4c7f, 0xc00d,		0x21, 0
	.dw 0x4cc0, 0xc00d,	0x4cff, 0xc00d,		0x21, 0
	.dw 0x4d40, 0xc00d,	0x4d7f, 0xc00d,		0x21, 0
	.dw 0x4dc0, 0xc00d,	0x4dff, 0xc00d,		0x21, 0
	.dw 0x4e40, 0xc00d,	0x4e7f, 0xc00d,		0x21, 0
	.dw 0x4ec0, 0xc00d,	0x4eff, 0xc00d,		0x21, 0
	.dw 0x4f40, 0xc00d,	0x4f7f, 0xc00d,		0x21, 0
	.dw 0x4fc0, 0xc00d,	0x4fff, 0xc00d,		0x21, 0
	.dw 0x5040, 0xc00d,	0x507f, 0xc00d,		0x21, 0
	.dw 0x50c0, 0xc00d,	0x50ff, 0xc00d,		0x21, 0
	.dw 0x5140, 0xc00d,	0x517f, 0xc00d,		0x21, 0
	.dw 0x51c0, 0xc00d,	0x51ff, 0xc00d,		0x21, 0
	.dw 0x5240, 0xc00d,	0x527f, 0xc00d,		0x21, 0
	.dw 0x52c0, 0xc00d,	0x52ff, 0xc00d,		0x21, 0
	.dw 0x5340, 0xc00d,	0x537f, 0xc00d,		0x21, 0
	.dw 0x53c0, 0xc00d,	0x53ff, 0xc00d,		0x21, 0
	.dw 0x5440, 0xc00d,	0x547f, 0xc00d,		0x21, 0
	.dw 0x54c0, 0xc00d,	0x54ff, 0xc00d,		0x21, 0
	.dw 0x5540, 0xc00d,	0x557f, 0xc00d,		0x21, 0
	.dw 0x55c0, 0xc00d,	0x55ff, 0xc00d,		0x21, 0
	.dw 0x5640, 0xc00d,	0x567f, 0xc00d,		0x21, 0
	.dw 0x56c0, 0xc00d,	0x56ff, 0xc00d,		0x21, 0
	.dw 0x5740, 0xc00d,	0x577f, 0xc00d,		0x21, 0
	.dw 0x57c0, 0xc00d,	0x57ff, 0xc00d,		0x21, 0
	.dw 0x5840, 0xc00d,	0x587f, 0xc00d,		0x21, 0
	.dw 0x58c0, 0xc00d,	0x58ff, 0xc00d,		0x21, 0
	.dw 0x5940, 0xc00d,	0x597f, 0xc00d,		0x21, 0
	.dw 0x59c0, 0xc00d,	0x5fff, 0xc00d,		0x21, 0
	.dw 0x6040, 0xc00d,	0x607f, 0xc00d,		0x21, 0
	.dw 0x60c0, 0xc00d,	0x60ff, 0xc00d,		0x21, 0
	.dw 0x6140, 0xc00d,	0x617f, 0xc00d,		0x21, 0
	.dw 0x61c0, 0xc00d,	0x61ff, 0xc00d,		0x21, 0
	.dw 0x6240, 0xc00d,	0x627f, 0xc00d,		0x21, 0
	.dw 0x62c0, 0xc00d,	0x62ff, 0xc00d,		0x21, 0
	.dw 0x6340, 0xc00d,	0x637f, 0xc00d,		0x21, 0
	.dw 0x63c0, 0xc00d,	0x63ff, 0xc00d,		0x21, 0
	.dw 0x6440, 0xc00d,	0x647f, 0xc00d,		0x21, 0
	.dw 0x64c0, 0xc00d,	0x64ff, 0xc00d,		0x21, 0
	.dw 0x6540, 0xc00d,	0x657f, 0xc00d,		0x21, 0
	.dw 0x65c0, 0xc00d,	0x65ff, 0xc00d,		0x21, 0
	.dw 0x6640, 0xc00d,	0x667f, 0xc00d,		0x21, 0
	.dw 0x66c0, 0xc00d,	0x66ff, 0xc00d,		0x21, 0
	.dw 0x6740, 0xc00d,	0x677f, 0xc00d,		0x21, 0
	.dw 0x67c0, 0xc00d,	0x67ff, 0xc00d,		0x21, 0
	.dw 0x6840, 0xc00d,	0x687f, 0xc00d,		0x21, 0
	.dw 0x68c0, 0xc00d,	0x68ff, 0xc00d,		0x21, 0
	.dw 0x6940, 0xc00d,	0x697f, 0xc00d,		0x21, 0
	.dw 0x69c0, 0xc00d,	0x69ff, 0xc00d,		0x21, 0
	.dw 0x6a40, 0xc00d,	0x6a7f, 0xc00d,		0x21, 0
	.dw 0x6ac0, 0xc00d,	0x6aff, 0xc00d,		0x21, 0
	.dw 0x6b40, 0xc00d,	0x6b7f, 0xc00d,		0x21, 0
	.dw 0x6bc0, 0xc00d,	0x6bff, 0xc00d,		0x21, 0
	.dw 0x6c40, 0xc00d,	0x6c7f, 0xc00d,		0x21, 0
	.dw 0x6cc0, 0xc00d,	0x6cff, 0xc00d,		0x21, 0
	.dw 0x6d40, 0xc00d,	0x6d7f, 0xc00d,		0x21, 0
	.dw 0x6dc0, 0xc00d,	0x6dff, 0xc00d,		0x21, 0
	.dw 0x6e40, 0xc00d,	0x6e7f, 0xc00d,		0x21, 0
	.dw 0x6ec0, 0xc00d,	0x6eff, 0xc00d,		0x21, 0
	.dw 0x6f40, 0xc00d,	0x6f7f, 0xc00d,		0x21, 0
	.dw 0x6fc0, 0xc00d,	0x6fff, 0xc00d,		0x21, 0
	.dw 0x7040, 0xc00d,	0x707f, 0xc00d,		0x21, 0
	.dw 0x70c0, 0xc00d,	0x70ff, 0xc00d,		0x21, 0
	.dw 0x7140, 0xc00d,	0x717f, 0xc00d,		0x21, 0
	.dw 0x71c0, 0xc00d,	0x71ff, 0xc00d,		0x21, 0
	.dw 0x7240, 0xc00d,	0x727f, 0xc00d,		0x21, 0
	.dw 0x72c0, 0xc00d,	0x72ff, 0xc00d,		0x21, 0
	.dw 0x7340, 0xc00d,	0x737f, 0xc00d,		0x21, 0
	.dw 0x73c0, 0xc00d,	0x73ff, 0xc00d,		0x21, 0
	.dw 0x7440, 0xc00d,	0x747f, 0xc00d,		0x21, 0
	.dw 0x74c0, 0xc00d,	0x74ff, 0xc00d,		0x21, 0
	.dw 0x7540, 0xc00d,	0x757f, 0xc00d,		0x21, 0
	.dw 0x75c0, 0xc00d,	0x75ff, 0xc00d,		0x21, 0
	.dw 0x7640, 0xc00d,	0x767f, 0xc00d,		0x21, 0
	.dw 0x76c0, 0xc00d,	0x76ff, 0xc00d,		0x21, 0
	.dw 0x7740, 0xc00d,	0x777f, 0xc00d,		0x21, 0
	.dw 0x77c0, 0xc00d,	0x77ff, 0xc00d,		0x21, 0
	.dw 0x7840, 0xc00d,	0x787f, 0xc00d,		0x21, 0
	.dw 0x78c0, 0xc00d,	0x78ff, 0xc00d,		0x21, 0
	.dw 0x7940, 0xc00d,	0x797f, 0xc00d,		0x21, 0
	.dw 0x79c0, 0xc00d,	0x7fff, 0xc00d,		0x21, 0
	.dw 0x8040, 0xc00d,	0x807f, 0xc00d,		0x21, 0
	.dw 0x80c0, 0xc00d,	0x80ff, 0xc00d,		0x21, 0
	.dw 0x8140, 0xc00d,	0x817f, 0xc00d,		0x21, 0
	.dw 0x81c0, 0xc00d,	0x81ff, 0xc00d,		0x21, 0
	.dw 0x8240, 0xc00d,	0x827f, 0xc00d,		0x21, 0
	.dw 0x82c0, 0xc00d,	0x82ff, 0xc00d,		0x21, 0
	.dw 0x8340, 0xc00d,	0x837f, 0xc00d,		0x21, 0
	.dw 0x83c0, 0xc00d,	0x83ff, 0xc00d,		0x21, 0
	.dw 0x8440, 0xc00d,	0x847f, 0xc00d,		0x21, 0
	.dw 0x84c0, 0xc00d,	0x84ff, 0xc00d,		0x21, 0
	.dw 0x8540, 0xc00d,	0x857f, 0xc00d,		0x21, 0
	.dw 0x85c0, 0xc00d,	0x85ff, 0xc00d,		0x21, 0
	.dw 0x8640, 0xc00d,	0x867f, 0xc00d,		0x21, 0
	.dw 0x86c0, 0xc00d,	0x86ff, 0xc00d,		0x21, 0
	.dw 0x8740, 0xc00d,	0x877f, 0xc00d,		0x21, 0
	.dw 0x87c0, 0xc00d,	0x87ff, 0xc00d,		0x21, 0
	.dw 0x8840, 0xc00d,	0x887f, 0xc00d,		0x21, 0
	.dw 0x88c0, 0xc00d,	0x88ff, 0xc00d,		0x21, 0
	.dw 0x8940, 0xc00d,	0x897f, 0xc00d,		0x21, 0
	.dw 0x89c0, 0xc00d,	0x89ff, 0xc00d,		0x21, 0
	.dw 0x8a40, 0xc00d,	0x8a7f, 0xc00d,		0x21, 0
	.dw 0x8ac0, 0xc00d,	0x8aff, 0xc00d,		0x21, 0
	.dw 0x8b40, 0xc00d,	0x8b7f, 0xc00d,		0x21, 0
	.dw 0x8bc0, 0xc00d,	0x8bff, 0xc00d,		0x21, 0
	.dw 0x8c40, 0xc00d,	0x8c7f, 0xc00d,		0x21, 0
	.dw 0x8cc0, 0xc00d,	0x8cff, 0xc00d,		0x21, 0
	.dw 0x8d40, 0xc00d,	0x8d7f, 0xc00d,		0x21, 0
	.dw 0x8dc0, 0xc00d,	0x8dff, 0xc00d,		0x21, 0
	.dw 0x8e40, 0xc00d,	0x8e7f, 0xc00d,		0x21, 0
	.dw 0x8ec0, 0xc00d,	0x8eff, 0xc00d,		0x21, 0
	.dw 0x8f40, 0xc00d,	0x8f7f, 0xc00d,		0x21, 0
	.dw 0x8fc0, 0xc00d,	0x8fff, 0xc00d,		0x21, 0
	.dw 0x9040, 0xc00d,	0x907f, 0xc00d,		0x21, 0
	.dw 0x90c0, 0xc00d,	0x90ff, 0xc00d,		0x21, 0
	.dw 0x9140, 0xc00d,	0x917f, 0xc00d,		0x21, 0
	.dw 0x91c0, 0xc00d,	0x91ff, 0xc00d,		0x21, 0
	.dw 0x9240, 0xc00d,	0x927f, 0xc00d,		0x21, 0
	.dw 0x92c0, 0xc00d,	0x92ff, 0xc00d,		0x21, 0
	.dw 0x9340, 0xc00d,	0x937f, 0xc00d,		0x21, 0
	.dw 0x93c0, 0xc00d,	0x93ff, 0xc00d,		0x21, 0
	.dw 0x9440, 0xc00d,	0x947f, 0xc00d,		0x21, 0
	.dw 0x94c0, 0xc00d,	0x94ff, 0xc00d,		0x21, 0
	.dw 0x9540, 0xc00d,	0x957f, 0xc00d,		0x21, 0
	.dw 0x95c0, 0xc00d,	0x95ff, 0xc00d,		0x21, 0
	.dw 0x9640, 0xc00d,	0x967f, 0xc00d,		0x21, 0
	.dw 0x96c0, 0xc00d,	0x96ff, 0xc00d,		0x21, 0
	.dw 0x9740, 0xc00d,	0x977f, 0xc00d,		0x21, 0
	.dw 0x97c0, 0xc00d,	0x97ff, 0xc00d,		0x21, 0
	.dw 0x9840, 0xc00d,	0x987f, 0xc00d,		0x21, 0
	.dw 0x98c0, 0xc00d,	0x98ff, 0xc00d,		0x21, 0
	.dw 0x9940, 0xc00d,	0x997f, 0xc00d,		0x21, 0
	.dw 0x99c0, 0xc00d,	0x9fff, 0xc00d,		0x21, 0
	.dw 0xa040, 0xc00d,	0xa07f, 0xc00d,		0x21, 0
	.dw 0xa0c0, 0xc00d,	0xa0ff, 0xc00d,		0x21, 0
	.dw 0xa140, 0xc00d,	0xa17f, 0xc00d,		0x21, 0
	.dw 0xa1c0, 0xc00d,	0xa1ff, 0xc00d,		0x21, 0
	.dw 0xa240, 0xc00d,	0xa27f, 0xc00d,		0x21, 0
	.dw 0xa2c0, 0xc00d,	0xa2ff, 0xc00d,		0x21, 0
	.dw 0xa340, 0xc00d,	0xa37f, 0xc00d,		0x21, 0
	.dw 0xa3c0, 0xc00d,	0xa3ff, 0xc00d,		0x21, 0
	.dw 0xa440, 0xc00d,	0xa47f, 0xc00d,		0x21, 0
	.dw 0xa4c0, 0xc00d,	0xa4ff, 0xc00d,		0x21, 0
	.dw 0xa540, 0xc00d,	0xa57f, 0xc00d,		0x21, 0
	.dw 0xa5c0, 0xc00d,	0xa5ff, 0xc00d,		0x21, 0
	.dw 0xa640, 0xc00d,	0xa67f, 0xc00d,		0x21, 0
	.dw 0xa6c0, 0xc00d,	0xa6ff, 0xc00d,		0x21, 0
	.dw 0xa740, 0xc00d,	0xa77f, 0xc00d,		0x21, 0
	.dw 0xa7c0, 0xc00d,	0xa7ff, 0xc00d,		0x21, 0
	.dw 0xa840, 0xc00d,	0xa87f, 0xc00d,		0x21, 0
	.dw 0xa8c0, 0xc00d,	0xa8ff, 0xc00d,		0x21, 0
	.dw 0xa940, 0xc00d,	0xa97f, 0xc00d,		0x21, 0
	.dw 0xa9c0, 0xc00d,	0xa9ff, 0xc00d,		0x21, 0
	.dw 0xaa40, 0xc00d,	0xaa7f, 0xc00d,		0x21, 0
	.dw 0xaac0, 0xc00d,	0xaaff, 0xc00d,		0x21, 0
	.dw 0xab40, 0xc00d,	0xab7f, 0xc00d,		0x21, 0
	.dw 0xabc0, 0xc00d,	0xabff, 0xc00d,		0x21, 0
	.dw 0xac40, 0xc00d,	0xac7f, 0xc00d,		0x21, 0
	.dw 0xacc0, 0xc00d,	0xacff, 0xc00d,		0x21, 0
	.dw 0xad40, 0xc00d,	0xad7f, 0xc00d,		0x21, 0
	.dw 0xadc0, 0xc00d,	0xadff, 0xc00d,		0x21, 0
	.dw 0xae40, 0xc00d,	0xae7f, 0xc00d,		0x21, 0
	.dw 0xaec0, 0xc00d,	0xaeff, 0xc00d,		0x21, 0
	.dw 0xaf40, 0xc00d,	0xaf7f, 0xc00d,		0x21, 0
	.dw 0xafc0, 0xc00d,	0xafff, 0xc00d,		0x21, 0
	.dw 0xb040, 0xc00d,	0xb07f, 0xc00d,		0x21, 0
	.dw 0xb0c0, 0xc00d,	0xb0ff, 0xc00d,		0x21, 0
	.dw 0xb140, 0xc00d,	0xb17f, 0xc00d,		0x21, 0
	.dw 0xb1c0, 0xc00d,	0xb1ff, 0xc00d,		0x21, 0
	.dw 0xb240, 0xc00d,	0xb27f, 0xc00d,		0x21, 0
	.dw 0xb2c0, 0xc00d,	0xb2ff, 0xc00d,		0x21, 0
	.dw 0xb340, 0xc00d,	0xb37f, 0xc00d,		0x21, 0
	.dw 0xb3c0, 0xc00d,	0xb3ff, 0xc00d,		0x21, 0
	.dw 0xb440, 0xc00d,	0xb47f, 0xc00d,		0x21, 0
	.dw 0xb4c0, 0xc00d,	0xb4ff, 0xc00d,		0x21, 0
	.dw 0xb540, 0xc00d,	0xb57f, 0xc00d,		0x21, 0
	.dw 0xb5c0, 0xc00d,	0xb5ff, 0xc00d,		0x21, 0
	.dw 0xb640, 0xc00d,	0xb67f, 0xc00d,		0x21, 0
	.dw 0xb6c0, 0xc00d,	0xb6ff, 0xc00d,		0x21, 0
	.dw 0xb740, 0xc00d,	0xb77f, 0xc00d,		0x21, 0
	.dw 0xb7c0, 0xc00d,	0xb7ff, 0xc00d,		0x21, 0
	.dw 0xb840, 0xc00d,	0xb87f, 0xc00d,		0x21, 0
	.dw 0xb8c0, 0xc00d,	0xb8ff, 0xc00d,		0x21, 0
	.dw 0xb940, 0xc00d,	0xb97f, 0xc00d,		0x21, 0
	.dw 0xb9c0, 0xc00d,	0xbfff, 0xc00d,		0x21, 0
	.dw 0xc040, 0xc00d,	0xc07f, 0xc00d,		0x21, 0
	.dw 0xc0c0, 0xc00d,	0xc0ff, 0xc00d,		0x21, 0
	.dw 0xc140, 0xc00d,	0xc17f, 0xc00d,		0x21, 0
	.dw 0xc1c0, 0xc00d,	0xc1ff, 0xc00d,		0x21, 0
	.dw 0xc240, 0xc00d,	0xc27f, 0xc00d,		0x21, 0
	.dw 0xc2c0, 0xc00d,	0xc2ff, 0xc00d,		0x21, 0
	.dw 0xc340, 0xc00d,	0xc37f, 0xc00d,		0x21, 0
	.dw 0xc3c0, 0xc00d,	0xc3ff, 0xc00d,		0x21, 0
	.dw 0xc440, 0xc00d,	0xc47f, 0xc00d,		0x21, 0
	.dw 0xc4c0, 0xc00d,	0xc4ff, 0xc00d,		0x21, 0
	.dw 0xc540, 0xc00d,	0xc57f, 0xc00d,		0x21, 0
	.dw 0xc5c0, 0xc00d,	0xc5ff, 0xc00d,		0x21, 0
	.dw 0xc640, 0xc00d,	0xc67f, 0xc00d,		0x21, 0
	.dw 0xc6c0, 0xc00d,	0xc6ff, 0xc00d,		0x21, 0
	.dw 0xc740, 0xc00d,	0xc77f, 0xc00d,		0x21, 0
	.dw 0xc7c0, 0xc00d,	0xc7ff, 0xc00d,		0x21, 0
	.dw 0xc840, 0xc00d,	0xc87f, 0xc00d,		0x21, 0
	.dw 0xc8c0, 0xc00d,	0xc8ff, 0xc00d,		0x21, 0
	.dw 0xc940, 0xc00d,	0xc97f, 0xc00d,		0x21, 0
	.dw 0xc9c0, 0xc00d,	0xc9ff, 0xc00d,		0x21, 0
	.dw 0xca40, 0xc00d,	0xca7f, 0xc00d,		0x21, 0
	.dw 0xcac0, 0xc00d,	0xcaff, 0xc00d,		0x21, 0
	.dw 0xcb40, 0xc00d,	0xcb7f, 0xc00d,		0x21, 0
	.dw 0xcbc0, 0xc00d,	0xcbff, 0xc00d,		0x21, 0
	.dw 0xcc40, 0xc00d,	0xcc7f, 0xc00d,		0x21, 0
	.dw 0xccc0, 0xc00d,	0xccff, 0xc00d,		0x21, 0
	.dw 0xcd40, 0xc00d,	0xcd7f, 0xc00d,		0x21, 0
	.dw 0xcdc0, 0xc00d,	0xcdff, 0xc00d,		0x21, 0
	.dw 0xce40, 0xc00d,	0xce7f, 0xc00d,		0x21, 0
	.dw 0xcec0, 0xc00d,	0xceff, 0xc00d,		0x21, 0
	.dw 0xcf40, 0xc00d,	0xcf7f, 0xc00d,		0x21, 0
	.dw 0xcfc0, 0xc00d,	0xcfff, 0xc00d,		0x21, 0
	.dw 0xd040, 0xc00d,	0xd07f, 0xc00d,		0x21, 0
	.dw 0xd0c0, 0xc00d,	0xd0ff, 0xc00d,		0x21, 0
	.dw 0xd140, 0xc00d,	0xd17f, 0xc00d,		0x21, 0
	.dw 0xd1c0, 0xc00d,	0xd1ff, 0xc00d,		0x21, 0
	.dw 0xd240, 0xc00d,	0xd27f, 0xc00d,		0x21, 0
	.dw 0xd2c0, 0xc00d,	0xd2ff, 0xc00d,		0x21, 0
	.dw 0xd340, 0xc00d,	0xd37f, 0xc00d,		0x21, 0
	.dw 0xd3c0, 0xc00d,	0xd3ff, 0xc00d,		0x21, 0
	.dw 0xd440, 0xc00d,	0xd47f, 0xc00d,		0x21, 0
	.dw 0xd4c0, 0xc00d,	0xd4ff, 0xc00d,		0x21, 0
	.dw 0xd540, 0xc00d,	0xd57f, 0xc00d,		0x21, 0
	.dw 0xd5c0, 0xc00d,	0xd5ff, 0xc00d,		0x21, 0
	.dw 0xd640, 0xc00d,	0xd67f, 0xc00d,		0x21, 0
	.dw 0xd6c0, 0xc00d,	0xd6ff, 0xc00d,		0x21, 0
	.dw 0xd740, 0xc00d,	0xd77f, 0xc00d,		0x21, 0
	.dw 0xd7c0, 0xc00d,	0xd7ff, 0xc00d,		0x21, 0
	.dw 0xd840, 0xc00d,	0xd87f, 0xc00d,		0x21, 0
	.dw 0xd8c0, 0xc00d,	0xd8ff, 0xc00d,		0x21, 0
	.dw 0xd940, 0xc00d,	0xd97f, 0xc00d,		0x21, 0
	.dw 0xd9c0, 0xc00d,	0xdfff, 0xc00d,		0x21, 0
	.dw 0xe040, 0xc00d,	0xe07f, 0xc00d,		0x21, 0
	.dw 0xe0c0, 0xc00d,	0xe0ff, 0xc00d,		0x21, 0
	.dw 0xe140, 0xc00d,	0xe17f, 0xc00d,		0x21, 0
	.dw 0xe1c0, 0xc00d,	0xe1ff, 0xc00d,		0x21, 0
	.dw 0xe240, 0xc00d,	0xe27f, 0xc00d,		0x21, 0
	.dw 0xe2c0, 0xc00d,	0xe2ff, 0xc00d,		0x21, 0
	.dw 0xe340, 0xc00d,	0xe37f, 0xc00d,		0x21, 0
	.dw 0xe3c0, 0xc00d,	0xe3ff, 0xc00d,		0x21, 0
	.dw 0xe440, 0xc00d,	0xe47f, 0xc00d,		0x21, 0
	.dw 0xe4c0, 0xc00d,	0xe4ff, 0xc00d,		0x21, 0
	.dw 0xe540, 0xc00d,	0xe57f, 0xc00d,		0x21, 0
	.dw 0xe5c0, 0xc00d,	0xe5ff, 0xc00d,		0x21, 0
	.dw 0xe640, 0xc00d,	0xe67f, 0xc00d,		0x21, 0
	.dw 0xe6c0, 0xc00d,	0xe6ff, 0xc00d,		0x21, 0
	.dw 0xe740, 0xc00d,	0xe77f, 0xc00d,		0x21, 0
	.dw 0xe7c0, 0xc00d,	0xe7ff, 0xc00d,		0x21, 0
	.dw 0xe840, 0xc00d,	0xe87f, 0xc00d,		0x21, 0
	.dw 0xe8c0, 0xc00d,	0xe8ff, 0xc00d,		0x21, 0
	.dw 0xe940, 0xc00d,	0xe97f, 0xc00d,		0x21, 0
	.dw 0xe9c0, 0xc00d,	0xe9ff, 0xc00d,		0x21, 0
	.dw 0xea40, 0xc00d,	0xea7f, 0xc00d,		0x21, 0
	.dw 0xeac0, 0xc00d,	0xeaff, 0xc00d,		0x21, 0
	.dw 0xeb40, 0xc00d,	0xeb7f, 0xc00d,		0x21, 0
	.dw 0xebc0, 0xc00d,	0xebff, 0xc00d,		0x21, 0
	.dw 0xec40, 0xc00d,	0xec7f, 0xc00d,		0x21, 0
	.dw 0xecc0, 0xc00d,	0xecff, 0xc00d,		0x21, 0
	.dw 0xed40, 0xc00d,	0xed7f, 0xc00d,		0x21, 0
	.dw 0xedc0, 0xc00d,	0xedff, 0xc00d,		0x21, 0
	.dw 0xee40, 0xc00d,	0xee7f, 0xc00d,		0x21, 0
	.dw 0xeec0, 0xc00d,	0xeeff, 0xc00d,		0x21, 0
	.dw 0xef40, 0xc00d,	0xef7f, 0xc00d,		0x21, 0
	.dw 0xefc0, 0xc00d,	0xefff, 0xc00d,		0x21, 0
	.dw 0xf040, 0xc00d,	0xf07f, 0xc00d,		0x21, 0
	.dw 0xf0c0, 0xc00d,	0xf0ff, 0xc00d,		0x21, 0
	.dw 0xf140, 0xc00d,	0xf17f, 0xc00d,		0x21, 0
	.dw 0xf1c0, 0xc00d,	0xf1ff, 0xc00d,		0x21, 0
	.dw 0xf240, 0xc00d,	0xf27f, 0xc00d,		0x21, 0
	.dw 0xf2c0, 0xc00d,	0xf2ff, 0xc00d,		0x21, 0
	.dw 0xf340, 0xc00d,	0xf37f, 0xc00d,		0x21, 0
	.dw 0xf3c0, 0xc00d,	0xf3ff, 0xc00d,		0x21, 0
	.dw 0xf440, 0xc00d,	0xf47f, 0xc00d,		0x21, 0
	.dw 0xf4c0, 0xc00d,	0xf4ff, 0xc00d,		0x21, 0
	.dw 0xf540, 0xc00d,	0xf57f, 0xc00d,		0x21, 0
	.dw 0xf5c0, 0xc00d,	0xf5ff, 0xc00d,		0x21, 0
	.dw 0xf640, 0xc00d,	0xf67f, 0xc00d,		0x21, 0
	.dw 0xf6c0, 0xc00d,	0xf6ff, 0xc00d,		0x21, 0
	.dw 0xf740, 0xc00d,	0xf77f, 0xc00d,		0x21, 0
	.dw 0xf7c0, 0xc00d,	0xf7ff, 0xc00d,		0x21, 0
	.dw 0xf840, 0xc00d,	0xf87f, 0xc00d,		0x21, 0
	.dw 0xf8c0, 0xc00d,	0xf8ff, 0xc00d,		0x21, 0
	.dw 0xf940, 0xc00d,	0xf97f, 0xc00d,		0x21, 0
	.dw 0xf9c0, 0xc00d,	0xffff, 0xc00d,		0x21, 0
	.dw 0x0040, 0xc00e,	0x007f, 0xc00e,		0x21, 0
	.dw 0x00c0, 0xc00e,	0x00ff, 0xc00e,		0x21, 0
	.dw 0x0140, 0xc00e,	0x017f, 0xc00e,		0x21, 0
	.dw 0x01c0, 0xc00e,	0x01ff, 0xc00e,		0x21, 0
	.dw 0x0240, 0xc00e,	0x027f, 0xc00e,		0x21, 0
	.dw 0x02c0, 0xc00e,	0x02ff, 0xc00e,		0x21, 0
	.dw 0x0340, 0xc00e,	0x037f, 0xc00e,		0x21, 0
	.dw 0x03c0, 0xc00e,	0x03ff, 0xc00e,		0x21, 0
	.dw 0x0440, 0xc00e,	0x047f, 0xc00e,		0x21, 0
	.dw 0x04c0, 0xc00e,	0x04ff, 0xc00e,		0x21, 0
	.dw 0x0540, 0xc00e,	0x057f, 0xc00e,		0x21, 0
	.dw 0x05c0, 0xc00e,	0x05ff, 0xc00e,		0x21, 0
	.dw 0x0640, 0xc00e,	0x067f, 0xc00e,		0x21, 0
	.dw 0x06c0, 0xc00e,	0x06ff, 0xc00e,		0x21, 0
	.dw 0x0740, 0xc00e,	0x077f, 0xc00e,		0x21, 0
	.dw 0x07c0, 0xc00e,	0x07ff, 0xc00e,		0x21, 0
	.dw 0x0840, 0xc00e,	0x087f, 0xc00e,		0x21, 0
	.dw 0x08c0, 0xc00e,	0x08ff, 0xc00e,		0x21, 0
	.dw 0x0940, 0xc00e,	0x097f, 0xc00e,		0x21, 0
	.dw 0x09c0, 0xc00e,	0x09ff, 0xc00e,		0x21, 0
	.dw 0x0a40, 0xc00e,	0x0a7f, 0xc00e,		0x21, 0
	.dw 0x0ac0, 0xc00e,	0x0aff, 0xc00e,		0x21, 0
	.dw 0x0b40, 0xc00e,	0x0b7f, 0xc00e,		0x21, 0
	.dw 0x0bc0, 0xc00e,	0x0bff, 0xc00e,		0x21, 0
	.dw 0x0c40, 0xc00e,	0x0c7f, 0xc00e,		0x21, 0
	.dw 0x0cc0, 0xc00e,	0x0cff, 0xc00e,		0x21, 0
	.dw 0x0d40, 0xc00e,	0x0d7f, 0xc00e,		0x21, 0
	.dw 0x0dc0, 0xc00e,	0x0dff, 0xc00e,		0x21, 0
	.dw 0x0e40, 0xc00e,	0x0e7f, 0xc00e,		0x21, 0
	.dw 0x0ec0, 0xc00e,	0x0eff, 0xc00e,		0x21, 0
	.dw 0x0f40, 0xc00e,	0x0f7f, 0xc00e,		0x21, 0
	.dw 0x0fc0, 0xc00e,	0x0fff, 0xc00e,		0x21, 0
	.dw 0x1040, 0xc00e,	0x107f, 0xc00e,		0x21, 0
	.dw 0x10c0, 0xc00e,	0x10ff, 0xc00e,		0x21, 0
	.dw 0x1140, 0xc00e,	0x117f, 0xc00e,		0x21, 0
	.dw 0x11c0, 0xc00e,	0x11ff, 0xc00e,		0x21, 0
	.dw 0x1240, 0xc00e,	0x127f, 0xc00e,		0x21, 0
	.dw 0x12c0, 0xc00e,	0x12ff, 0xc00e,		0x21, 0
	.dw 0x1340, 0xc00e,	0x137f, 0xc00e,		0x21, 0
	.dw 0x13c0, 0xc00e,	0x13ff, 0xc00e,		0x21, 0
	.dw 0x1440, 0xc00e,	0x147f, 0xc00e,		0x21, 0
	.dw 0x14c0, 0xc00e,	0x14ff, 0xc00e,		0x21, 0
	.dw 0x1540, 0xc00e,	0x157f, 0xc00e,		0x21, 0
	.dw 0x15c0, 0xc00e,	0x15ff, 0xc00e,		0x21, 0
	.dw 0x1640, 0xc00e,	0x167f, 0xc00e,		0x21, 0
	.dw 0x16c0, 0xc00e,	0x16ff, 0xc00e,		0x21, 0
	.dw 0x1740, 0xc00e,	0x177f, 0xc00e,		0x21, 0
	.dw 0x17c0, 0xc00e,	0x17ff, 0xc00e,		0x21, 0
	.dw 0x1840, 0xc00e,	0x187f, 0xc00e,		0x21, 0
	.dw 0x18c0, 0xc00e,	0x18ff, 0xc00e,		0x21, 0
	.dw 0x1940, 0xc00e,	0x197f, 0xc00e,		0x21, 0
	.dw 0x19c0, 0xc00e,	0x1fff, 0xc00e,		0x21, 0
	.dw 0x2040, 0xc00e,	0x207f, 0xc00e,		0x21, 0
	.dw 0x20c0, 0xc00e,	0x20ff, 0xc00e,		0x21, 0
	.dw 0x2140, 0xc00e,	0x217f, 0xc00e,		0x21, 0
	.dw 0x21c0, 0xc00e,	0x21ff, 0xc00e,		0x21, 0
	.dw 0x2240, 0xc00e,	0x227f, 0xc00e,		0x21, 0
	.dw 0x22c0, 0xc00e,	0x22ff, 0xc00e,		0x21, 0
	.dw 0x2340, 0xc00e,	0x237f, 0xc00e,		0x21, 0
	.dw 0x23c0, 0xc00e,	0x23ff, 0xc00e,		0x21, 0
	.dw 0x2440, 0xc00e,	0x247f, 0xc00e,		0x21, 0
	.dw 0x24c0, 0xc00e,	0x24ff, 0xc00e,		0x21, 0
	.dw 0x2540, 0xc00e,	0x257f, 0xc00e,		0x21, 0
	.dw 0x25c0, 0xc00e,	0x25ff, 0xc00e,		0x21, 0
	.dw 0x2640, 0xc00e,	0x267f, 0xc00e,		0x21, 0
	.dw 0x26c0, 0xc00e,	0x26ff, 0xc00e,		0x21, 0
	.dw 0x2740, 0xc00e,	0x277f, 0xc00e,		0x21, 0
	.dw 0x27c0, 0xc00e,	0x27ff, 0xc00e,		0x21, 0
	.dw 0x2840, 0xc00e,	0x287f, 0xc00e,		0x21, 0
	.dw 0x28c0, 0xc00e,	0x28ff, 0xc00e,		0x21, 0
	.dw 0x2940, 0xc00e,	0x297f, 0xc00e,		0x21, 0
	.dw 0x29c0, 0xc00e,	0x29ff, 0xc00e,		0x21, 0
	.dw 0x2a40, 0xc00e,	0x2a7f, 0xc00e,		0x21, 0
	.dw 0x2ac0, 0xc00e,	0x2aff, 0xc00e,		0x21, 0
	.dw 0x2b40, 0xc00e,	0x2b7f, 0xc00e,		0x21, 0
	.dw 0x2bc0, 0xc00e,	0x2bff, 0xc00e,		0x21, 0
	.dw 0x2c40, 0xc00e,	0x2c7f, 0xc00e,		0x21, 0
	.dw 0x2cc0, 0xc00e,	0x2cff, 0xc00e,		0x21, 0
	.dw 0x2d40, 0xc00e,	0x2d7f, 0xc00e,		0x21, 0
	.dw 0x2dc0, 0xc00e,	0x2dff, 0xc00e,		0x21, 0
	.dw 0x2e40, 0xc00e,	0x2e7f, 0xc00e,		0x21, 0
	.dw 0x2ec0, 0xc00e,	0x2eff, 0xc00e,		0x21, 0
	.dw 0x2f40, 0xc00e,	0x2f7f, 0xc00e,		0x21, 0
	.dw 0x2fc0, 0xc00e,	0x2fff, 0xc00e,		0x21, 0
	.dw 0x3040, 0xc00e,	0x307f, 0xc00e,		0x21, 0
	.dw 0x30c0, 0xc00e,	0x30ff, 0xc00e,		0x21, 0
	.dw 0x3140, 0xc00e,	0x317f, 0xc00e,		0x21, 0
	.dw 0x31c0, 0xc00e,	0x31ff, 0xc00e,		0x21, 0
	.dw 0x3240, 0xc00e,	0x327f, 0xc00e,		0x21, 0
	.dw 0x32c0, 0xc00e,	0x32ff, 0xc00e,		0x21, 0
	.dw 0x3340, 0xc00e,	0x337f, 0xc00e,		0x21, 0
	.dw 0x33c0, 0xc00e,	0x33ff, 0xc00e,		0x21, 0
	.dw 0x3440, 0xc00e,	0x347f, 0xc00e,		0x21, 0
	.dw 0x34c0, 0xc00e,	0x34ff, 0xc00e,		0x21, 0
	.dw 0x3540, 0xc00e,	0x357f, 0xc00e,		0x21, 0
	.dw 0x35c0, 0xc00e,	0x35ff, 0xc00e,		0x21, 0
	.dw 0x3640, 0xc00e,	0x367f, 0xc00e,		0x21, 0
	.dw 0x36c0, 0xc00e,	0x36ff, 0xc00e,		0x21, 0
	.dw 0x3740, 0xc00e,	0x377f, 0xc00e,		0x21, 0
	.dw 0x37c0, 0xc00e,	0x37ff, 0xc00e,		0x21, 0
	.dw 0x3840, 0xc00e,	0x387f, 0xc00e,		0x21, 0
	.dw 0x38c0, 0xc00e,	0x38ff, 0xc00e,		0x21, 0
	.dw 0x3940, 0xc00e,	0x397f, 0xc00e,		0x21, 0
	.dw 0x39c0, 0xc00e,	0x3fff, 0xc00e,		0x21, 0
	.dw 0x4040, 0xc00e,	0x407f, 0xc00e,		0x21, 0
	.dw 0x40c0, 0xc00e,	0x40ff, 0xc00e,		0x21, 0
	.dw 0x4140, 0xc00e,	0x417f, 0xc00e,		0x21, 0
	.dw 0x41c0, 0xc00e,	0x41ff, 0xc00e,		0x21, 0
	.dw 0x4240, 0xc00e,	0x427f, 0xc00e,		0x21, 0
	.dw 0x42c0, 0xc00e,	0x42ff, 0xc00e,		0x21, 0
	.dw 0x4340, 0xc00e,	0x437f, 0xc00e,		0x21, 0
	.dw 0x43c0, 0xc00e,	0x43ff, 0xc00e,		0x21, 0
	.dw 0x4440, 0xc00e,	0x447f, 0xc00e,		0x21, 0
	.dw 0x44c0, 0xc00e,	0x44ff, 0xc00e,		0x21, 0
	.dw 0x4540, 0xc00e,	0x457f, 0xc00e,		0x21, 0
	.dw 0x45c0, 0xc00e,	0x45ff, 0xc00e,		0x21, 0
	.dw 0x4640, 0xc00e,	0x467f, 0xc00e,		0x21, 0
	.dw 0x46c0, 0xc00e,	0x46ff, 0xc00e,		0x21, 0
	.dw 0x4740, 0xc00e,	0x477f, 0xc00e,		0x21, 0
	.dw 0x47c0, 0xc00e,	0x47ff, 0xc00e,		0x21, 0
	.dw 0x4840, 0xc00e,	0x487f, 0xc00e,		0x21, 0
	.dw 0x48c0, 0xc00e,	0x48ff, 0xc00e,		0x21, 0
	.dw 0x4940, 0xc00e,	0x497f, 0xc00e,		0x21, 0
	.dw 0x49c0, 0xc00e,	0x49ff, 0xc00e,		0x21, 0
	.dw 0x4a40, 0xc00e,	0x4a7f, 0xc00e,		0x21, 0
	.dw 0x4ac0, 0xc00e,	0x4aff, 0xc00e,		0x21, 0
	.dw 0x4b40, 0xc00e,	0x4b7f, 0xc00e,		0x21, 0
	.dw 0x4bc0, 0xc00e,	0x4bff, 0xc00e,		0x21, 0
	.dw 0x4c40, 0xc00e,	0x4c7f, 0xc00e,		0x21, 0
	.dw 0x4cc0, 0xc00e,	0x4cff, 0xc00e,		0x21, 0
	.dw 0x4d40, 0xc00e,	0x4d7f, 0xc00e,		0x21, 0
	.dw 0x4dc0, 0xc00e,	0x4dff, 0xc00e,		0x21, 0
	.dw 0x4e40, 0xc00e,	0x4e7f, 0xc00e,		0x21, 0
	.dw 0x4ec0, 0xc00e,	0x4eff, 0xc00e,		0x21, 0
	.dw 0x4f40, 0xc00e,	0x4f7f, 0xc00e,		0x21, 0
	.dw 0x4fc0, 0xc00e,	0x4fff, 0xc00e,		0x21, 0
	.dw 0x5040, 0xc00e,	0x507f, 0xc00e,		0x21, 0
	.dw 0x50c0, 0xc00e,	0x50ff, 0xc00e,		0x21, 0
	.dw 0x5140, 0xc00e,	0x517f, 0xc00e,		0x21, 0
	.dw 0x51c0, 0xc00e,	0x51ff, 0xc00e,		0x21, 0
	.dw 0x5240, 0xc00e,	0x527f, 0xc00e,		0x21, 0
	.dw 0x52c0, 0xc00e,	0x52ff, 0xc00e,		0x21, 0
	.dw 0x5340, 0xc00e,	0x537f, 0xc00e,		0x21, 0
	.dw 0x53c0, 0xc00e,	0x53ff, 0xc00e,		0x21, 0
	.dw 0x5440, 0xc00e,	0x547f, 0xc00e,		0x21, 0
	.dw 0x54c0, 0xc00e,	0x54ff, 0xc00e,		0x21, 0
	.dw 0x5540, 0xc00e,	0x557f, 0xc00e,		0x21, 0
	.dw 0x55c0, 0xc00e,	0x55ff, 0xc00e,		0x21, 0
	.dw 0x5640, 0xc00e,	0x567f, 0xc00e,		0x21, 0
	.dw 0x56c0, 0xc00e,	0x56ff, 0xc00e,		0x21, 0
	.dw 0x5740, 0xc00e,	0x577f, 0xc00e,		0x21, 0
	.dw 0x57c0, 0xc00e,	0x57ff, 0xc00e,		0x21, 0
	.dw 0x5840, 0xc00e,	0x587f, 0xc00e,		0x21, 0
	.dw 0x58c0, 0xc00e,	0x58ff, 0xc00e,		0x21, 0
	.dw 0x5940, 0xc00e,	0x597f, 0xc00e,		0x21, 0
	.dw 0x59c0, 0xc00e,	0x5fff, 0xc00e,		0x21, 0
	.dw 0x6040, 0xc00e,	0x607f, 0xc00e,		0x21, 0
	.dw 0x60c0, 0xc00e,	0x60ff, 0xc00e,		0x21, 0
	.dw 0x6140, 0xc00e,	0x617f, 0xc00e,		0x21, 0
	.dw 0x61c0, 0xc00e,	0x61ff, 0xc00e,		0x21, 0
	.dw 0x6240, 0xc00e,	0x627f, 0xc00e,		0x21, 0
	.dw 0x62c0, 0xc00e,	0x62ff, 0xc00e,		0x21, 0
	.dw 0x6340, 0xc00e,	0x637f, 0xc00e,		0x21, 0
	.dw 0x63c0, 0xc00e,	0x63ff, 0xc00e,		0x21, 0
	.dw 0x6440, 0xc00e,	0x647f, 0xc00e,		0x21, 0
	.dw 0x64c0, 0xc00e,	0x64ff, 0xc00e,		0x21, 0
	.dw 0x6540, 0xc00e,	0x657f, 0xc00e,		0x21, 0
	.dw 0x65c0, 0xc00e,	0x65ff, 0xc00e,		0x21, 0
	.dw 0x6640, 0xc00e,	0x667f, 0xc00e,		0x21, 0
	.dw 0x66c0, 0xc00e,	0x66ff, 0xc00e,		0x21, 0
	.dw 0x6740, 0xc00e,	0x677f, 0xc00e,		0x21, 0
	.dw 0x67c0, 0xc00e,	0x67ff, 0xc00e,		0x21, 0
	.dw 0x6840, 0xc00e,	0x687f, 0xc00e,		0x21, 0
	.dw 0x68c0, 0xc00e,	0x68ff, 0xc00e,		0x21, 0
	.dw 0x6940, 0xc00e,	0x697f, 0xc00e,		0x21, 0
	.dw 0x69c0, 0xc00e,	0x69ff, 0xc00e,		0x21, 0
	.dw 0x6a40, 0xc00e,	0x6a7f, 0xc00e,		0x21, 0
	.dw 0x6ac0, 0xc00e,	0x6aff, 0xc00e,		0x21, 0
	.dw 0x6b40, 0xc00e,	0x6b7f, 0xc00e,		0x21, 0
	.dw 0x6bc0, 0xc00e,	0x6bff, 0xc00e,		0x21, 0
	.dw 0x6c40, 0xc00e,	0x6c7f, 0xc00e,		0x21, 0
	.dw 0x6cc0, 0xc00e,	0x6cff, 0xc00e,		0x21, 0
	.dw 0x6d40, 0xc00e,	0x6d7f, 0xc00e,		0x21, 0
	.dw 0x6dc0, 0xc00e,	0x6dff, 0xc00e,		0x21, 0
	.dw 0x6e40, 0xc00e,	0x6e7f, 0xc00e,		0x21, 0
	.dw 0x6ec0, 0xc00e,	0x6eff, 0xc00e,		0x21, 0
	.dw 0x6f40, 0xc00e,	0x6f7f, 0xc00e,		0x21, 0
	.dw 0x6fc0, 0xc00e,	0x6fff, 0xc00e,		0x21, 0
	.dw 0x7040, 0xc00e,	0x707f, 0xc00e,		0x21, 0
	.dw 0x70c0, 0xc00e,	0x70ff, 0xc00e,		0x21, 0
	.dw 0x7140, 0xc00e,	0x717f, 0xc00e,		0x21, 0
	.dw 0x71c0, 0xc00e,	0x71ff, 0xc00e,		0x21, 0
	.dw 0x7240, 0xc00e,	0x727f, 0xc00e,		0x21, 0
	.dw 0x72c0, 0xc00e,	0x72ff, 0xc00e,		0x21, 0
	.dw 0x7340, 0xc00e,	0x737f, 0xc00e,		0x21, 0
	.dw 0x73c0, 0xc00e,	0x73ff, 0xc00e,		0x21, 0
	.dw 0x7440, 0xc00e,	0x747f, 0xc00e,		0x21, 0
	.dw 0x74c0, 0xc00e,	0x74ff, 0xc00e,		0x21, 0
	.dw 0x7540, 0xc00e,	0x757f, 0xc00e,		0x21, 0
	.dw 0x75c0, 0xc00e,	0x75ff, 0xc00e,		0x21, 0
	.dw 0x7640, 0xc00e,	0x767f, 0xc00e,		0x21, 0
	.dw 0x76c0, 0xc00e,	0x76ff, 0xc00e,		0x21, 0
	.dw 0x7740, 0xc00e,	0x777f, 0xc00e,		0x21, 0
	.dw 0x77c0, 0xc00e,	0x77ff, 0xc00e,		0x21, 0
	.dw 0x7840, 0xc00e,	0x787f, 0xc00e,		0x21, 0
	.dw 0x78c0, 0xc00e,	0x78ff, 0xc00e,		0x21, 0
	.dw 0x7940, 0xc00e,	0x797f, 0xc00e,		0x21, 0
	.dw 0x79c0, 0xc00e,	0x7fff, 0xc00e,		0x21, 0
	.dw 0x8040, 0xc00e,	0x807f, 0xc00e,		0x21, 0
	.dw 0x80c0, 0xc00e,	0x80ff, 0xc00e,		0x21, 0
	.dw 0x8140, 0xc00e,	0x817f, 0xc00e,		0x21, 0
	.dw 0x81c0, 0xc00e,	0x81ff, 0xc00e,		0x21, 0
	.dw 0x8240, 0xc00e,	0x827f, 0xc00e,		0x21, 0
	.dw 0x82c0, 0xc00e,	0x82ff, 0xc00e,		0x21, 0
	.dw 0x8340, 0xc00e,	0x837f, 0xc00e,		0x21, 0
	.dw 0x83c0, 0xc00e,	0x83ff, 0xc00e,		0x21, 0
	.dw 0x8440, 0xc00e,	0x847f, 0xc00e,		0x21, 0
	.dw 0x84c0, 0xc00e,	0x84ff, 0xc00e,		0x21, 0
	.dw 0x8540, 0xc00e,	0x857f, 0xc00e,		0x21, 0
	.dw 0x85c0, 0xc00e,	0x85ff, 0xc00e,		0x21, 0
	.dw 0x8640, 0xc00e,	0x867f, 0xc00e,		0x21, 0
	.dw 0x86c0, 0xc00e,	0x86ff, 0xc00e,		0x21, 0
	.dw 0x8740, 0xc00e,	0x877f, 0xc00e,		0x21, 0
	.dw 0x87c0, 0xc00e,	0x87ff, 0xc00e,		0x21, 0
	.dw 0x8840, 0xc00e,	0x887f, 0xc00e,		0x21, 0
	.dw 0x88c0, 0xc00e,	0x88ff, 0xc00e,		0x21, 0
	.dw 0x8940, 0xc00e,	0x897f, 0xc00e,		0x21, 0
	.dw 0x89c0, 0xc00e,	0x89ff, 0xc00e,		0x21, 0
	.dw 0x8a40, 0xc00e,	0x8a7f, 0xc00e,		0x21, 0
	.dw 0x8ac0, 0xc00e,	0x8aff, 0xc00e,		0x21, 0
	.dw 0x8b40, 0xc00e,	0x8b7f, 0xc00e,		0x21, 0
	.dw 0x8bc0, 0xc00e,	0x8bff, 0xc00e,		0x21, 0
	.dw 0x8c40, 0xc00e,	0x8c7f, 0xc00e,		0x21, 0
	.dw 0x8cc0, 0xc00e,	0x8cff, 0xc00e,		0x21, 0
	.dw 0x8d40, 0xc00e,	0x8d7f, 0xc00e,		0x21, 0
	.dw 0x8dc0, 0xc00e,	0x8dff, 0xc00e,		0x21, 0
	.dw 0x8e40, 0xc00e,	0x8e7f, 0xc00e,		0x21, 0
	.dw 0x8ec0, 0xc00e,	0x8eff, 0xc00e,		0x21, 0
	.dw 0x8f40, 0xc00e,	0x8f7f, 0xc00e,		0x21, 0
	.dw 0x8fc0, 0xc00e,	0x8fff, 0xc00e,		0x21, 0
	.dw 0x9040, 0xc00e,	0x907f, 0xc00e,		0x21, 0
	.dw 0x90c0, 0xc00e,	0x90ff, 0xc00e,		0x21, 0
	.dw 0x9140, 0xc00e,	0x917f, 0xc00e,		0x21, 0
	.dw 0x91c0, 0xc00e,	0x91ff, 0xc00e,		0x21, 0
	.dw 0x9240, 0xc00e,	0x927f, 0xc00e,		0x21, 0
	.dw 0x92c0, 0xc00e,	0x92ff, 0xc00e,		0x21, 0
	.dw 0x9340, 0xc00e,	0x937f, 0xc00e,		0x21, 0
	.dw 0x93c0, 0xc00e,	0x93ff, 0xc00e,		0x21, 0
	.dw 0x9440, 0xc00e,	0x947f, 0xc00e,		0x21, 0
	.dw 0x94c0, 0xc00e,	0x94ff, 0xc00e,		0x21, 0
	.dw 0x9540, 0xc00e,	0x957f, 0xc00e,		0x21, 0
	.dw 0x95c0, 0xc00e,	0x95ff, 0xc00e,		0x21, 0
	.dw 0x9640, 0xc00e,	0x967f, 0xc00e,		0x21, 0
	.dw 0x96c0, 0xc00e,	0x96ff, 0xc00e,		0x21, 0
	.dw 0x9740, 0xc00e,	0x977f, 0xc00e,		0x21, 0
	.dw 0x97c0, 0xc00e,	0x97ff, 0xc00e,		0x21, 0
	.dw 0x9840, 0xc00e,	0x987f, 0xc00e,		0x21, 0
	.dw 0x98c0, 0xc00e,	0x98ff, 0xc00e,		0x21, 0
	.dw 0x9940, 0xc00e,	0x997f, 0xc00e,		0x21, 0
	.dw 0x99c0, 0xc00e,	0x9fff, 0xc00e,		0x21, 0
	.dw 0xa040, 0xc00e,	0xa07f, 0xc00e,		0x21, 0
	.dw 0xa0c0, 0xc00e,	0xa0ff, 0xc00e,		0x21, 0
	.dw 0xa140, 0xc00e,	0xa17f, 0xc00e,		0x21, 0
	.dw 0xa1c0, 0xc00e,	0xa1ff, 0xc00e,		0x21, 0
	.dw 0xa240, 0xc00e,	0xa27f, 0xc00e,		0x21, 0
	.dw 0xa2c0, 0xc00e,	0xa2ff, 0xc00e,		0x21, 0
	.dw 0xa340, 0xc00e,	0xa37f, 0xc00e,		0x21, 0
	.dw 0xa3c0, 0xc00e,	0xa3ff, 0xc00e,		0x21, 0
	.dw 0xa440, 0xc00e,	0xa47f, 0xc00e,		0x21, 0
	.dw 0xa4c0, 0xc00e,	0xa4ff, 0xc00e,		0x21, 0
	.dw 0xa540, 0xc00e,	0xa57f, 0xc00e,		0x21, 0
	.dw 0xa5c0, 0xc00e,	0xa5ff, 0xc00e,		0x21, 0
	.dw 0xa640, 0xc00e,	0xa67f, 0xc00e,		0x21, 0
	.dw 0xa6c0, 0xc00e,	0xa6ff, 0xc00e,		0x21, 0
	.dw 0xa740, 0xc00e,	0xa77f, 0xc00e,		0x21, 0
	.dw 0xa7c0, 0xc00e,	0xa7ff, 0xc00e,		0x21, 0
	.dw 0xa840, 0xc00e,	0xa87f, 0xc00e,		0x21, 0
	.dw 0xa8c0, 0xc00e,	0xa8ff, 0xc00e,		0x21, 0
	.dw 0xa940, 0xc00e,	0xa97f, 0xc00e,		0x21, 0
	.dw 0xa9c0, 0xc00e,	0xa9ff, 0xc00e,		0x21, 0
	.dw 0xaa40, 0xc00e,	0xaa7f, 0xc00e,		0x21, 0
	.dw 0xaac0, 0xc00e,	0xaaff, 0xc00e,		0x21, 0
	.dw 0xab40, 0xc00e,	0xab7f, 0xc00e,		0x21, 0
	.dw 0xabc0, 0xc00e,	0xabff, 0xc00e,		0x21, 0
	.dw 0xac40, 0xc00e,	0xac7f, 0xc00e,		0x21, 0
	.dw 0xacc0, 0xc00e,	0xacff, 0xc00e,		0x21, 0
	.dw 0xad40, 0xc00e,	0xad7f, 0xc00e,		0x21, 0
	.dw 0xadc0, 0xc00e,	0xadff, 0xc00e,		0x21, 0
	.dw 0xae40, 0xc00e,	0xae7f, 0xc00e,		0x21, 0
	.dw 0xaec0, 0xc00e,	0xaeff, 0xc00e,		0x21, 0
	.dw 0xaf40, 0xc00e,	0xaf7f, 0xc00e,		0x21, 0
	.dw 0xafc0, 0xc00e,	0xafff, 0xc00e,		0x21, 0
	.dw 0xb040, 0xc00e,	0xb07f, 0xc00e,		0x21, 0
	.dw 0xb0c0, 0xc00e,	0xb0ff, 0xc00e,		0x21, 0
	.dw 0xb140, 0xc00e,	0xb17f, 0xc00e,		0x21, 0
	.dw 0xb1c0, 0xc00e,	0xb1ff, 0xc00e,		0x21, 0
	.dw 0xb240, 0xc00e,	0xb27f, 0xc00e,		0x21, 0
	.dw 0xb2c0, 0xc00e,	0xb2ff, 0xc00e,		0x21, 0
	.dw 0xb340, 0xc00e,	0xb37f, 0xc00e,		0x21, 0
	.dw 0xb3c0, 0xc00e,	0xb3ff, 0xc00e,		0x21, 0
	.dw 0xb440, 0xc00e,	0xb47f, 0xc00e,		0x21, 0
	.dw 0xb4c0, 0xc00e,	0xb4ff, 0xc00e,		0x21, 0
	.dw 0xb540, 0xc00e,	0xb57f, 0xc00e,		0x21, 0
	.dw 0xb5c0, 0xc00e,	0xb5ff, 0xc00e,		0x21, 0
	.dw 0xb640, 0xc00e,	0xb67f, 0xc00e,		0x21, 0
	.dw 0xb6c0, 0xc00e,	0xb6ff, 0xc00e,		0x21, 0
	.dw 0xb740, 0xc00e,	0xb77f, 0xc00e,		0x21, 0
	.dw 0xb7c0, 0xc00e,	0xb7ff, 0xc00e,		0x21, 0
	.dw 0xb840, 0xc00e,	0xb87f, 0xc00e,		0x21, 0
	.dw 0xb8c0, 0xc00e,	0xb8ff, 0xc00e,		0x21, 0
	.dw 0xb940, 0xc00e,	0xb97f, 0xc00e,		0x21, 0
	.dw 0xb9c0, 0xc00e,	0xbfff, 0xc00e,		0x21, 0
	.dw 0xc040, 0xc00e,	0xc07f, 0xc00e,		0x21, 0
	.dw 0xc0c0, 0xc00e,	0xc0ff, 0xc00e,		0x21, 0
	.dw 0xc140, 0xc00e,	0xc17f, 0xc00e,		0x21, 0
	.dw 0xc1c0, 0xc00e,	0xc1ff, 0xc00e,		0x21, 0
	.dw 0xc240, 0xc00e,	0xc27f, 0xc00e,		0x21, 0
	.dw 0xc2c0, 0xc00e,	0xc2ff, 0xc00e,		0x21, 0
	.dw 0xc340, 0xc00e,	0xc37f, 0xc00e,		0x21, 0
	.dw 0xc3c0, 0xc00e,	0xc3ff, 0xc00e,		0x21, 0
	.dw 0xc440, 0xc00e,	0xc47f, 0xc00e,		0x21, 0
	.dw 0xc4c0, 0xc00e,	0xc4ff, 0xc00e,		0x21, 0
	.dw 0xc540, 0xc00e,	0xc57f, 0xc00e,		0x21, 0
	.dw 0xc5c0, 0xc00e,	0xc5ff, 0xc00e,		0x21, 0
	.dw 0xc640, 0xc00e,	0xc67f, 0xc00e,		0x21, 0
	.dw 0xc6c0, 0xc00e,	0xc6ff, 0xc00e,		0x21, 0
	.dw 0xc740, 0xc00e,	0xc77f, 0xc00e,		0x21, 0
	.dw 0xc7c0, 0xc00e,	0xc7ff, 0xc00e,		0x21, 0
	.dw 0xc840, 0xc00e,	0xc87f, 0xc00e,		0x21, 0
	.dw 0xc8c0, 0xc00e,	0xc8ff, 0xc00e,		0x21, 0
	.dw 0xc940, 0xc00e,	0xc97f, 0xc00e,		0x21, 0
	.dw 0xc9c0, 0xc00e,	0xc9ff, 0xc00e,		0x21, 0
	.dw 0xca40, 0xc00e,	0xca7f, 0xc00e,		0x21, 0
	.dw 0xcac0, 0xc00e,	0xcaff, 0xc00e,		0x21, 0
	.dw 0xcb40, 0xc00e,	0xcb7f, 0xc00e,		0x21, 0
	.dw 0xcbc0, 0xc00e,	0xcbff, 0xc00e,		0x21, 0
	.dw 0xcc40, 0xc00e,	0xcc7f, 0xc00e,		0x21, 0
	.dw 0xccc0, 0xc00e,	0xccff, 0xc00e,		0x21, 0
	.dw 0xcd40, 0xc00e,	0xcd7f, 0xc00e,		0x21, 0
	.dw 0xcdc0, 0xc00e,	0xcdff, 0xc00e,		0x21, 0
	.dw 0xce40, 0xc00e,	0xce7f, 0xc00e,		0x21, 0
	.dw 0xcec0, 0xc00e,	0xceff, 0xc00e,		0x21, 0
	.dw 0xcf40, 0xc00e,	0xcf7f, 0xc00e,		0x21, 0
	.dw 0xcfc0, 0xc00e,	0xcfff, 0xc00e,		0x21, 0
	.dw 0xd040, 0xc00e,	0xd07f, 0xc00e,		0x21, 0
	.dw 0xd0c0, 0xc00e,	0xd0ff, 0xc00e,		0x21, 0
	.dw 0xd140, 0xc00e,	0xd17f, 0xc00e,		0x21, 0
	.dw 0xd1c0, 0xc00e,	0xd1ff, 0xc00e,		0x21, 0
	.dw 0xd240, 0xc00e,	0xd27f, 0xc00e,		0x21, 0
	.dw 0xd2c0, 0xc00e,	0xd2ff, 0xc00e,		0x21, 0
	.dw 0xd340, 0xc00e,	0xd37f, 0xc00e,		0x21, 0
	.dw 0xd3c0, 0xc00e,	0xd3ff, 0xc00e,		0x21, 0
	.dw 0xd440, 0xc00e,	0xd47f, 0xc00e,		0x21, 0
	.dw 0xd4c0, 0xc00e,	0xd4ff, 0xc00e,		0x21, 0
	.dw 0xd540, 0xc00e,	0xd57f, 0xc00e,		0x21, 0
	.dw 0xd5c0, 0xc00e,	0xd5ff, 0xc00e,		0x21, 0
	.dw 0xd640, 0xc00e,	0xd67f, 0xc00e,		0x21, 0
	.dw 0xd6c0, 0xc00e,	0xd6ff, 0xc00e,		0x21, 0
	.dw 0xd740, 0xc00e,	0xd77f, 0xc00e,		0x21, 0
	.dw 0xd7c0, 0xc00e,	0xd7ff, 0xc00e,		0x21, 0
	.dw 0xd840, 0xc00e,	0xd87f, 0xc00e,		0x21, 0
	.dw 0xd8c0, 0xc00e,	0xd8ff, 0xc00e,		0x21, 0
	.dw 0xd940, 0xc00e,	0xd97f, 0xc00e,		0x21, 0
	.dw 0xd9c0, 0xc00e,	0xdfff, 0xc00e,		0x21, 0
	.dw 0xe040, 0xc00e,	0xe07f, 0xc00e,		0x21, 0
	.dw 0xe0c0, 0xc00e,	0xe0ff, 0xc00e,		0x21, 0
	.dw 0xe140, 0xc00e,	0xe17f, 0xc00e,		0x21, 0
	.dw 0xe1c0, 0xc00e,	0xe1ff, 0xc00e,		0x21, 0
	.dw 0xe240, 0xc00e,	0xe27f, 0xc00e,		0x21, 0
	.dw 0xe2c0, 0xc00e,	0xe2ff, 0xc00e,		0x21, 0
	.dw 0xe340, 0xc00e,	0xe37f, 0xc00e,		0x21, 0
	.dw 0xe3c0, 0xc00e,	0xe3ff, 0xc00e,		0x21, 0
	.dw 0xe440, 0xc00e,	0xe47f, 0xc00e,		0x21, 0
	.dw 0xe4c0, 0xc00e,	0xe4ff, 0xc00e,		0x21, 0
	.dw 0xe540, 0xc00e,	0xe57f, 0xc00e,		0x21, 0
	.dw 0xe5c0, 0xc00e,	0xe5ff, 0xc00e,		0x21, 0
	.dw 0xe640, 0xc00e,	0xe67f, 0xc00e,		0x21, 0
	.dw 0xe6c0, 0xc00e,	0xe6ff, 0xc00e,		0x21, 0
	.dw 0xe740, 0xc00e,	0xe77f, 0xc00e,		0x21, 0
	.dw 0xe7c0, 0xc00e,	0xe7ff, 0xc00e,		0x21, 0
	.dw 0xe840, 0xc00e,	0xe87f, 0xc00e,		0x21, 0
	.dw 0xe8c0, 0xc00e,	0xe8ff, 0xc00e,		0x21, 0
	.dw 0xe940, 0xc00e,	0xe97f, 0xc00e,		0x21, 0
	.dw 0xe9c0, 0xc00e,	0xe9ff, 0xc00e,		0x21, 0
	.dw 0xea40, 0xc00e,	0xea7f, 0xc00e,		0x21, 0
	.dw 0xeac0, 0xc00e,	0xeaff, 0xc00e,		0x21, 0
	.dw 0xeb40, 0xc00e,	0xeb7f, 0xc00e,		0x21, 0
	.dw 0xebc0, 0xc00e,	0xebff, 0xc00e,		0x21, 0
	.dw 0xec40, 0xc00e,	0xec7f, 0xc00e,		0x21, 0
	.dw 0xecc0, 0xc00e,	0xecff, 0xc00e,		0x21, 0
	.dw 0xed40, 0xc00e,	0xed7f, 0xc00e,		0x21, 0
	.dw 0xedc0, 0xc00e,	0xedff, 0xc00e,		0x21, 0
	.dw 0xee40, 0xc00e,	0xee7f, 0xc00e,		0x21, 0
	.dw 0xeec0, 0xc00e,	0xeeff, 0xc00e,		0x21, 0
	.dw 0xef40, 0xc00e,	0xef7f, 0xc00e,		0x21, 0
	.dw 0xefc0, 0xc00e,	0xefff, 0xc00e,		0x21, 0
	.dw 0xf040, 0xc00e,	0xf07f, 0xc00e,		0x21, 0
	.dw 0xf0c0, 0xc00e,	0xf0ff, 0xc00e,		0x21, 0
	.dw 0xf140, 0xc00e,	0xf17f, 0xc00e,		0x21, 0
	.dw 0xf1c0, 0xc00e,	0xf1ff, 0xc00e,		0x21, 0
	.dw 0xf240, 0xc00e,	0xf27f, 0xc00e,		0x21, 0
	.dw 0xf2c0, 0xc00e,	0xf2ff, 0xc00e,		0x21, 0
	.dw 0xf340, 0xc00e,	0xf37f, 0xc00e,		0x21, 0
	.dw 0xf3c0, 0xc00e,	0xf3ff, 0xc00e,		0x21, 0
	.dw 0xf440, 0xc00e,	0xf47f, 0xc00e,		0x21, 0
	.dw 0xf4c0, 0xc00e,	0xf4ff, 0xc00e,		0x21, 0
	.dw 0xf540, 0xc00e,	0xf57f, 0xc00e,		0x21, 0
	.dw 0xf5c0, 0xc00e,	0xf5ff, 0xc00e,		0x21, 0
	.dw 0xf640, 0xc00e,	0xf67f, 0xc00e,		0x21, 0
	.dw 0xf6c0, 0xc00e,	0xf6ff, 0xc00e,		0x21, 0
	.dw 0xf740, 0xc00e,	0xf77f, 0xc00e,		0x21, 0
	.dw 0xf7c0, 0xc00e,	0xf7ff, 0xc00e,		0x21, 0
	.dw 0xf840, 0xc00e,	0xf87f, 0xc00e,		0x21, 0
	.dw 0xf8c0, 0xc00e,	0xf8ff, 0xc00e,		0x21, 0
	.dw 0xf940, 0xc00e,	0xf97f, 0xc00e,		0x21, 0
	.dw 0xf9c0, 0xc00e,	0xffff, 0xc00e,		0x21, 0
	.dw 0x0040, 0xc00f,	0x007f, 0xc00f,		0x21, 0
	.dw 0x00c0, 0xc00f,	0x00ff, 0xc00f,		0x21, 0
	.dw 0x0140, 0xc00f,	0x017f, 0xc00f,		0x21, 0
	.dw 0x01c0, 0xc00f,	0x01ff, 0xc00f,		0x21, 0
	.dw 0x0240, 0xc00f,	0x027f, 0xc00f,		0x21, 0
	.dw 0x02c0, 0xc00f,	0x02ff, 0xc00f,		0x21, 0
	.dw 0x0340, 0xc00f,	0x037f, 0xc00f,		0x21, 0
	.dw 0x03c0, 0xc00f,	0x03ff, 0xc00f,		0x21, 0
	.dw 0x0440, 0xc00f,	0x047f, 0xc00f,		0x21, 0
	.dw 0x04c0, 0xc00f,	0x04ff, 0xc00f,		0x21, 0
	.dw 0x0540, 0xc00f,	0x057f, 0xc00f,		0x21, 0
	.dw 0x05c0, 0xc00f,	0x05ff, 0xc00f,		0x21, 0
	.dw 0x0640, 0xc00f,	0x067f, 0xc00f,		0x21, 0
	.dw 0x06c0, 0xc00f,	0x06ff, 0xc00f,		0x21, 0
	.dw 0x0740, 0xc00f,	0x077f, 0xc00f,		0x21, 0
	.dw 0x07c0, 0xc00f,	0x07ff, 0xc00f,		0x21, 0
	.dw 0x0840, 0xc00f,	0x087f, 0xc00f,		0x21, 0
	.dw 0x08c0, 0xc00f,	0x08ff, 0xc00f,		0x21, 0
	.dw 0x0940, 0xc00f,	0x097f, 0xc00f,		0x21, 0
	.dw 0x09c0, 0xc00f,	0x09ff, 0xc00f,		0x21, 0
	.dw 0x0a40, 0xc00f,	0x0a7f, 0xc00f,		0x21, 0
	.dw 0x0ac0, 0xc00f,	0x0aff, 0xc00f,		0x21, 0
	.dw 0x0b40, 0xc00f,	0x0b7f, 0xc00f,		0x21, 0
	.dw 0x0bc0, 0xc00f,	0x0bff, 0xc00f,		0x21, 0
	.dw 0x0c40, 0xc00f,	0x0c7f, 0xc00f,		0x21, 0
	.dw 0x0cc0, 0xc00f,	0x0cff, 0xc00f,		0x21, 0
	.dw 0x0d40, 0xc00f,	0x0d7f, 0xc00f,		0x21, 0
	.dw 0x0dc0, 0xc00f,	0x0dff, 0xc00f,		0x21, 0
	.dw 0x0e40, 0xc00f,	0x0e7f, 0xc00f,		0x21, 0
	.dw 0x0ec0, 0xc00f,	0x0eff, 0xc00f,		0x21, 0
	.dw 0x0f40, 0xc00f,	0x0f7f, 0xc00f,		0x21, 0
	.dw 0x0fc0, 0xc00f,	0x0fff, 0xc00f,		0x21, 0
	.dw 0x1040, 0xc00f,	0x107f, 0xc00f,		0x21, 0
	.dw 0x10c0, 0xc00f,	0x10ff, 0xc00f,		0x21, 0
	.dw 0x1140, 0xc00f,	0x117f, 0xc00f,		0x21, 0
	.dw 0x11c0, 0xc00f,	0x11ff, 0xc00f,		0x21, 0
	.dw 0x1240, 0xc00f,	0x127f, 0xc00f,		0x21, 0
	.dw 0x12c0, 0xc00f,	0x12ff, 0xc00f,		0x21, 0
	.dw 0x1340, 0xc00f,	0x137f, 0xc00f,		0x21, 0
	.dw 0x13c0, 0xc00f,	0x13ff, 0xc00f,		0x21, 0
	.dw 0x1440, 0xc00f,	0x147f, 0xc00f,		0x21, 0
	.dw 0x14c0, 0xc00f,	0x14ff, 0xc00f,		0x21, 0
	.dw 0x1540, 0xc00f,	0x157f, 0xc00f,		0x21, 0
	.dw 0x15c0, 0xc00f,	0x15ff, 0xc00f,		0x21, 0
	.dw 0x1640, 0xc00f,	0x167f, 0xc00f,		0x21, 0
	.dw 0x16c0, 0xc00f,	0x16ff, 0xc00f,		0x21, 0
	.dw 0x1740, 0xc00f,	0x177f, 0xc00f,		0x21, 0
	.dw 0x17c0, 0xc00f,	0x17ff, 0xc00f,		0x21, 0
	.dw 0x1840, 0xc00f,	0x187f, 0xc00f,		0x21, 0
	.dw 0x18c0, 0xc00f,	0x18ff, 0xc00f,		0x21, 0
	.dw 0x1940, 0xc00f,	0x197f, 0xc00f,		0x21, 0
	.dw 0x19c0, 0xc00f,	0x1fff, 0xc00f,		0x21, 0
	.dw 0x2040, 0xc00f,	0x207f, 0xc00f,		0x21, 0
	.dw 0x20c0, 0xc00f,	0x20ff, 0xc00f,		0x21, 0
	.dw 0x2140, 0xc00f,	0x217f, 0xc00f,		0x21, 0
	.dw 0x21c0, 0xc00f,	0x21ff, 0xc00f,		0x21, 0
	.dw 0x2240, 0xc00f,	0x227f, 0xc00f,		0x21, 0
	.dw 0x22c0, 0xc00f,	0x22ff, 0xc00f,		0x21, 0
	.dw 0x2340, 0xc00f,	0x237f, 0xc00f,		0x21, 0
	.dw 0x23c0, 0xc00f,	0x23ff, 0xc00f,		0x21, 0
	.dw 0x2440, 0xc00f,	0x247f, 0xc00f,		0x21, 0
	.dw 0x24c0, 0xc00f,	0x24ff, 0xc00f,		0x21, 0
	.dw 0x2540, 0xc00f,	0x257f, 0xc00f,		0x21, 0
	.dw 0x25c0, 0xc00f,	0x25ff, 0xc00f,		0x21, 0
	.dw 0x2640, 0xc00f,	0x267f, 0xc00f,		0x21, 0
	.dw 0x26c0, 0xc00f,	0x26ff, 0xc00f,		0x21, 0
	.dw 0x2740, 0xc00f,	0x277f, 0xc00f,		0x21, 0
	.dw 0x27c0, 0xc00f,	0x27ff, 0xc00f,		0x21, 0
	.dw 0x2840, 0xc00f,	0x287f, 0xc00f,		0x21, 0
	.dw 0x28c0, 0xc00f,	0x28ff, 0xc00f,		0x21, 0
	.dw 0x2940, 0xc00f,	0x297f, 0xc00f,		0x21, 0
	.dw 0x29c0, 0xc00f,	0x29ff, 0xc00f,		0x21, 0
	.dw 0x2a40, 0xc00f,	0x2a7f, 0xc00f,		0x21, 0
	.dw 0x2ac0, 0xc00f,	0x2aff, 0xc00f,		0x21, 0
	.dw 0x2b40, 0xc00f,	0x2b7f, 0xc00f,		0x21, 0
	.dw 0x2bc0, 0xc00f,	0x2bff, 0xc00f,		0x21, 0
	.dw 0x2c40, 0xc00f,	0x2c7f, 0xc00f,		0x21, 0
	.dw 0x2cc0, 0xc00f,	0x2cff, 0xc00f,		0x21, 0
	.dw 0x2d40, 0xc00f,	0x2d7f, 0xc00f,		0x21, 0
	.dw 0x2dc0, 0xc00f,	0x2dff, 0xc00f,		0x21, 0
	.dw 0x2e40, 0xc00f,	0x2e7f, 0xc00f,		0x21, 0
	.dw 0x2ec0, 0xc00f,	0x2eff, 0xc00f,		0x21, 0
	.dw 0x2f40, 0xc00f,	0x2f7f, 0xc00f,		0x21, 0
	.dw 0x2fc0, 0xc00f,	0x2fff, 0xc00f,		0x21, 0
	.dw 0x3040, 0xc00f,	0x307f, 0xc00f,		0x21, 0
	.dw 0x30c0, 0xc00f,	0x30ff, 0xc00f,		0x21, 0
	.dw 0x3140, 0xc00f,	0x317f, 0xc00f,		0x21, 0
	.dw 0x31c0, 0xc00f,	0x31ff, 0xc00f,		0x21, 0
	.dw 0x3240, 0xc00f,	0x327f, 0xc00f,		0x21, 0
	.dw 0x32c0, 0xc00f,	0x32ff, 0xc00f,		0x21, 0
	.dw 0x3340, 0xc00f,	0x337f, 0xc00f,		0x21, 0
	.dw 0x33c0, 0xc00f,	0x33ff, 0xc00f,		0x21, 0
	.dw 0x3440, 0xc00f,	0x347f, 0xc00f,		0x21, 0
	.dw 0x34c0, 0xc00f,	0x34ff, 0xc00f,		0x21, 0
	.dw 0x3540, 0xc00f,	0x357f, 0xc00f,		0x21, 0
	.dw 0x35c0, 0xc00f,	0x35ff, 0xc00f,		0x21, 0
	.dw 0x3640, 0xc00f,	0x367f, 0xc00f,		0x21, 0
	.dw 0x36c0, 0xc00f,	0x36ff, 0xc00f,		0x21, 0
	.dw 0x3740, 0xc00f,	0x377f, 0xc00f,		0x21, 0
	.dw 0x37c0, 0xc00f,	0x37ff, 0xc00f,		0x21, 0
	.dw 0x3840, 0xc00f,	0x387f, 0xc00f,		0x21, 0
	.dw 0x38c0, 0xc00f,	0x38ff, 0xc00f,		0x21, 0
	.dw 0x3940, 0xc00f,	0x397f, 0xc00f,		0x21, 0
	.dw 0x39c0, 0xc00f,	0xffff, 0xc00f,		0x21, 0
	.dw 0x1a00, 0xc010,	0x1fff, 0xc010,		0x21, 0
	.dw 0x3a00, 0xc010,	0x3fff, 0xc010,		0x21, 0
	.dw 0x5a00, 0xc010,	0x5fff, 0xc010,		0x21, 0
	.dw 0x7a00, 0xc010,	0x7fff, 0xc010,		0x21, 0
	.dw 0x9a00, 0xc010,	0x9fff, 0xc010,		0x21, 0
	.dw 0xba00, 0xc010,	0xbfff, 0xc010,		0x21, 0
	.dw 0xda00, 0xc010,	0xdfff, 0xc010,		0x21, 0
	.dw 0xfa00, 0xc010,	0xffff, 0xc010,		0x21, 0
	.dw 0x1a00, 0xc011,	0x1fff, 0xc011,		0x21, 0
	.dw 0x3a00, 0xc011,	0x3fff, 0xc011,		0x21, 0
	.dw 0x5a00, 0xc011,	0x5fff, 0xc011,		0x21, 0
	.dw 0x7a00, 0xc011,	0x7fff, 0xc011,		0x21, 0
	.dw 0x9a00, 0xc011,	0x9fff, 0xc011,		0x21, 0
	.dw 0xba00, 0xc011,	0xbfff, 0xc011,		0x21, 0
	.dw 0xda00, 0xc011,	0xdfff, 0xc011,		0x21, 0
	.dw 0xfa00, 0xc011,	0xffff, 0xc011,		0x21, 0
	.dw 0x1a00, 0xc012,	0x1fff, 0xc012,		0x21, 0
	.dw 0x3a00, 0xc012,	0x3fff, 0xc012,		0x21, 0
	.dw 0x5a00, 0xc012,	0x5fff, 0xc012,		0x21, 0
	.dw 0x7a00, 0xc012,	0x7fff, 0xc012,		0x21, 0
	.dw 0x9a00, 0xc012,	0x9fff, 0xc012,		0x21, 0
	.dw 0xba00, 0xc012,	0xbfff, 0xc012,		0x21, 0
	.dw 0xda00, 0xc012,	0xdfff, 0xc012,		0x21, 0
	.dw 0xfa00, 0xc012,	0xffff, 0xc013,		0x21, 0
	.dw 0x1a00, 0xc014,	0x1fff, 0xc014,		0x21, 0
	.dw 0x3a00, 0xc014,	0x3fff, 0xc014,		0x21, 0
	.dw 0x5a00, 0xc014,	0x5fff, 0xc014,		0x21, 0
	.dw 0x7a00, 0xc014,	0x7fff, 0xc014,		0x21, 0
	.dw 0x9a00, 0xc014,	0x9fff, 0xc014,		0x21, 0
	.dw 0xba00, 0xc014,	0xbfff, 0xc014,		0x21, 0
	.dw 0xda00, 0xc014,	0xdfff, 0xc014,		0x21, 0
	.dw 0xfa00, 0xc014,	0xffff, 0xc014,		0x21, 0
	.dw 0x1a00, 0xc015,	0x1fff, 0xc015,		0x21, 0
	.dw 0x3a00, 0xc015,	0x3fff, 0xc015,		0x21, 0
	.dw 0x5a00, 0xc015,	0x5fff, 0xc015,		0x21, 0
	.dw 0x7a00, 0xc015,	0x7fff, 0xc015,		0x21, 0
	.dw 0x9a00, 0xc015,	0x9fff, 0xc015,		0x21, 0
	.dw 0xba00, 0xc015,	0xbfff, 0xc015,		0x21, 0
	.dw 0xda00, 0xc015,	0xdfff, 0xc015,		0x21, 0
	.dw 0xfa00, 0xc015,	0xffff, 0xc015,		0x21, 0
	.dw 0x1a00, 0xc016,	0x1fff, 0xc016,		0x21, 0
	.dw 0x3a00, 0xc016,	0x3fff, 0xc016,		0x21, 0
	.dw 0x5a00, 0xc016,	0x5fff, 0xc016,		0x21, 0
	.dw 0x7a00, 0xc016,	0x7fff, 0xc016,		0x21, 0
	.dw 0x9a00, 0xc016,	0x9fff, 0xc016,		0x21, 0
	.dw 0xba00, 0xc016,	0xbfff, 0xc016,		0x21, 0
	.dw 0xda00, 0xc016,	0xdfff, 0xc016,		0x21, 0
	.dw 0xfa00, 0xc016,	0xffff, 0xc016,		0x21, 0
	.dw 0x1a00, 0xc017,	0x1fff, 0xc017,		0x21, 0
	.dw 0x3a00, 0xc017,	0x1fff, 0xc018,		0x21, 0
	.dw 0x2040, 0xc018,	0x207f, 0xc018,		0x21, 0
	.dw 0x20c0, 0xc018,	0x20ff, 0xc018,		0x21, 0
	.dw 0x2140, 0xc018,	0x217f, 0xc018,		0x21, 0
	.dw 0x21c0, 0xc018,	0x21ff, 0xc018,		0x21, 0
	.dw 0x2240, 0xc018,	0x227f, 0xc018,		0x21, 0
	.dw 0x22c0, 0xc018,	0x22ff, 0xc018,		0x21, 0
	.dw 0x2340, 0xc018,	0x237f, 0xc018,		0x21, 0
	.dw 0x23c0, 0xc018,	0x23ff, 0xc018,		0x21, 0
	.dw 0x2440, 0xc018,	0x247f, 0xc018,		0x21, 0
	.dw 0x24c0, 0xc018,	0x24ff, 0xc018,		0x21, 0
	.dw 0x2540, 0xc018,	0x257f, 0xc018,		0x21, 0
	.dw 0x25c0, 0xc018,	0x25ff, 0xc018,		0x21, 0
	.dw 0x2640, 0xc018,	0x267f, 0xc018,		0x21, 0
	.dw 0x26c0, 0xc018,	0x26ff, 0xc018,		0x21, 0
	.dw 0x2740, 0xc018,	0x277f, 0xc018,		0x21, 0
	.dw 0x27c0, 0xc018,	0x27ff, 0xc018,		0x21, 0
	.dw 0x2840, 0xc018,	0x287f, 0xc018,		0x21, 0
	.dw 0x28c0, 0xc018,	0x28ff, 0xc018,		0x21, 0
	.dw 0x2940, 0xc018,	0x297f, 0xc018,		0x21, 0
	.dw 0x29c0, 0xc018,	0x29ff, 0xc018,		0x21, 0
	.dw 0x2a40, 0xc018,	0x2a7f, 0xc018,		0x21, 0
	.dw 0x2ac0, 0xc018,	0x2aff, 0xc018,		0x21, 0
	.dw 0x2b40, 0xc018,	0x2b7f, 0xc018,		0x21, 0
	.dw 0x2bc0, 0xc018,	0x2bff, 0xc018,		0x21, 0
	.dw 0x2c40, 0xc018,	0x2c7f, 0xc018,		0x21, 0
	.dw 0x2cc0, 0xc018,	0x2cff, 0xc018,		0x21, 0
	.dw 0x2d40, 0xc018,	0x2d7f, 0xc018,		0x21, 0
	.dw 0x2dc0, 0xc018,	0x2dff, 0xc018,		0x21, 0
	.dw 0x2e40, 0xc018,	0x2e7f, 0xc018,		0x21, 0
	.dw 0x2ec0, 0xc018,	0x2eff, 0xc018,		0x21, 0
	.dw 0x2f40, 0xc018,	0x2f7f, 0xc018,		0x21, 0
	.dw 0x2fc0, 0xc018,	0x2fff, 0xc018,		0x21, 0
	.dw 0x3040, 0xc018,	0x307f, 0xc018,		0x21, 0
	.dw 0x30c0, 0xc018,	0x30ff, 0xc018,		0x21, 0
	.dw 0x3140, 0xc018,	0x317f, 0xc018,		0x21, 0
	.dw 0x31c0, 0xc018,	0x31ff, 0xc018,		0x21, 0
	.dw 0x3240, 0xc018,	0x327f, 0xc018,		0x21, 0
	.dw 0x32c0, 0xc018,	0x32ff, 0xc018,		0x21, 0
	.dw 0x3340, 0xc018,	0x337f, 0xc018,		0x21, 0
	.dw 0x33c0, 0xc018,	0x33ff, 0xc018,		0x21, 0
	.dw 0x3440, 0xc018,	0x347f, 0xc018,		0x21, 0
	.dw 0x34c0, 0xc018,	0x34ff, 0xc018,		0x21, 0
	.dw 0x3540, 0xc018,	0x357f, 0xc018,		0x21, 0
	.dw 0x35c0, 0xc018,	0x35ff, 0xc018,		0x21, 0
	.dw 0x3640, 0xc018,	0x367f, 0xc018,		0x21, 0
	.dw 0x36c0, 0xc018,	0x36ff, 0xc018,		0x21, 0
	.dw 0x3740, 0xc018,	0x377f, 0xc018,		0x21, 0
	.dw 0x37c0, 0xc018,	0x37ff, 0xc018,		0x21, 0
	.dw 0x3840, 0xc018,	0x387f, 0xc018,		0x21, 0
	.dw 0x38c0, 0xc018,	0x38ff, 0xc018,		0x21, 0
	.dw 0x3940, 0xc018,	0x397f, 0xc018,		0x21, 0
	.dw 0x39c0, 0xc018,	0x5fff, 0xc018,		0x21, 0
	.dw 0x6040, 0xc018,	0x607f, 0xc018,		0x21, 0
	.dw 0x60c0, 0xc018,	0x60ff, 0xc018,		0x21, 0
	.dw 0x6140, 0xc018,	0x617f, 0xc018,		0x21, 0
	.dw 0x61c0, 0xc018,	0x61ff, 0xc018,		0x21, 0
	.dw 0x6240, 0xc018,	0x627f, 0xc018,		0x21, 0
	.dw 0x62c0, 0xc018,	0x62ff, 0xc018,		0x21, 0
	.dw 0x6340, 0xc018,	0x637f, 0xc018,		0x21, 0
	.dw 0x63c0, 0xc018,	0x63ff, 0xc018,		0x21, 0
	.dw 0x6440, 0xc018,	0x647f, 0xc018,		0x21, 0
	.dw 0x64c0, 0xc018,	0x64ff, 0xc018,		0x21, 0
	.dw 0x6540, 0xc018,	0x657f, 0xc018,		0x21, 0
	.dw 0x65c0, 0xc018,	0x65ff, 0xc018,		0x21, 0
	.dw 0x6640, 0xc018,	0x667f, 0xc018,		0x21, 0
	.dw 0x66c0, 0xc018,	0x66ff, 0xc018,		0x21, 0
	.dw 0x6740, 0xc018,	0x677f, 0xc018,		0x21, 0
	.dw 0x67c0, 0xc018,	0x67ff, 0xc018,		0x21, 0
	.dw 0x6840, 0xc018,	0x687f, 0xc018,		0x21, 0
	.dw 0x68c0, 0xc018,	0x68ff, 0xc018,		0x21, 0
	.dw 0x6940, 0xc018,	0x697f, 0xc018,		0x21, 0
	.dw 0x69c0, 0xc018,	0x69ff, 0xc018,		0x21, 0
	.dw 0x6a40, 0xc018,	0x6a7f, 0xc018,		0x21, 0
	.dw 0x6ac0, 0xc018,	0x6aff, 0xc018,		0x21, 0
	.dw 0x6b40, 0xc018,	0x6b7f, 0xc018,		0x21, 0
	.dw 0x6bc0, 0xc018,	0x6bff, 0xc018,		0x21, 0
	.dw 0x6c40, 0xc018,	0x6c7f, 0xc018,		0x21, 0
	.dw 0x6cc0, 0xc018,	0x6cff, 0xc018,		0x21, 0
	.dw 0x6d40, 0xc018,	0x6d7f, 0xc018,		0x21, 0
	.dw 0x6dc0, 0xc018,	0x6dff, 0xc018,		0x21, 0
	.dw 0x6e40, 0xc018,	0x6e7f, 0xc018,		0x21, 0
	.dw 0x6ec0, 0xc018,	0x6eff, 0xc018,		0x21, 0
	.dw 0x6f40, 0xc018,	0x6f7f, 0xc018,		0x21, 0
	.dw 0x6fc0, 0xc018,	0x6fff, 0xc018,		0x21, 0
	.dw 0x7040, 0xc018,	0x707f, 0xc018,		0x21, 0
	.dw 0x70c0, 0xc018,	0x70ff, 0xc018,		0x21, 0
	.dw 0x7140, 0xc018,	0x717f, 0xc018,		0x21, 0
	.dw 0x71c0, 0xc018,	0x71ff, 0xc018,		0x21, 0
	.dw 0x7240, 0xc018,	0x727f, 0xc018,		0x21, 0
	.dw 0x72c0, 0xc018,	0x72ff, 0xc018,		0x21, 0
	.dw 0x7340, 0xc018,	0x737f, 0xc018,		0x21, 0
	.dw 0x73c0, 0xc018,	0x73ff, 0xc018,		0x21, 0
	.dw 0x7440, 0xc018,	0x747f, 0xc018,		0x21, 0
	.dw 0x74c0, 0xc018,	0x74ff, 0xc018,		0x21, 0
	.dw 0x7540, 0xc018,	0x757f, 0xc018,		0x21, 0
	.dw 0x75c0, 0xc018,	0x75ff, 0xc018,		0x21, 0
	.dw 0x7640, 0xc018,	0x767f, 0xc018,		0x21, 0
	.dw 0x76c0, 0xc018,	0x76ff, 0xc018,		0x21, 0
	.dw 0x7740, 0xc018,	0x777f, 0xc018,		0x21, 0
	.dw 0x77c0, 0xc018,	0x77ff, 0xc018,		0x21, 0
	.dw 0x7840, 0xc018,	0x787f, 0xc018,		0x21, 0
	.dw 0x78c0, 0xc018,	0x78ff, 0xc018,		0x21, 0
	.dw 0x7940, 0xc018,	0x797f, 0xc018,		0x21, 0
	.dw 0x79c0, 0xc018,	0x9fff, 0xc018,		0x21, 0
	.dw 0xa040, 0xc018,	0xa07f, 0xc018,		0x21, 0
	.dw 0xa0c0, 0xc018,	0xa0ff, 0xc018,		0x21, 0
	.dw 0xa140, 0xc018,	0xa17f, 0xc018,		0x21, 0
	.dw 0xa1c0, 0xc018,	0xa1ff, 0xc018,		0x21, 0
	.dw 0xa240, 0xc018,	0xa27f, 0xc018,		0x21, 0
	.dw 0xa2c0, 0xc018,	0xa2ff, 0xc018,		0x21, 0
	.dw 0xa340, 0xc018,	0xa37f, 0xc018,		0x21, 0
	.dw 0xa3c0, 0xc018,	0xa3ff, 0xc018,		0x21, 0
	.dw 0xa440, 0xc018,	0xa47f, 0xc018,		0x21, 0
	.dw 0xa4c0, 0xc018,	0xa4ff, 0xc018,		0x21, 0
	.dw 0xa540, 0xc018,	0xa57f, 0xc018,		0x21, 0
	.dw 0xa5c0, 0xc018,	0xa5ff, 0xc018,		0x21, 0
	.dw 0xa640, 0xc018,	0xa67f, 0xc018,		0x21, 0
	.dw 0xa6c0, 0xc018,	0xa6ff, 0xc018,		0x21, 0
	.dw 0xa740, 0xc018,	0xa77f, 0xc018,		0x21, 0
	.dw 0xa7c0, 0xc018,	0xa7ff, 0xc018,		0x21, 0
	.dw 0xa840, 0xc018,	0xa87f, 0xc018,		0x21, 0
	.dw 0xa8c0, 0xc018,	0xa8ff, 0xc018,		0x21, 0
	.dw 0xa940, 0xc018,	0xa97f, 0xc018,		0x21, 0
	.dw 0xa9c0, 0xc018,	0xa9ff, 0xc018,		0x21, 0
	.dw 0xaa40, 0xc018,	0xaa7f, 0xc018,		0x21, 0
	.dw 0xaac0, 0xc018,	0xaaff, 0xc018,		0x21, 0
	.dw 0xab40, 0xc018,	0xab7f, 0xc018,		0x21, 0
	.dw 0xabc0, 0xc018,	0xabff, 0xc018,		0x21, 0
	.dw 0xac40, 0xc018,	0xac7f, 0xc018,		0x21, 0
	.dw 0xacc0, 0xc018,	0xacff, 0xc018,		0x21, 0
	.dw 0xad40, 0xc018,	0xad7f, 0xc018,		0x21, 0
	.dw 0xadc0, 0xc018,	0xadff, 0xc018,		0x21, 0
	.dw 0xae40, 0xc018,	0xae7f, 0xc018,		0x21, 0
	.dw 0xaec0, 0xc018,	0xaeff, 0xc018,		0x21, 0
	.dw 0xaf40, 0xc018,	0xaf7f, 0xc018,		0x21, 0
	.dw 0xafc0, 0xc018,	0xafff, 0xc018,		0x21, 0
	.dw 0xb040, 0xc018,	0xb07f, 0xc018,		0x21, 0
	.dw 0xb0c0, 0xc018,	0xb0ff, 0xc018,		0x21, 0
	.dw 0xb140, 0xc018,	0xb17f, 0xc018,		0x21, 0
	.dw 0xb1c0, 0xc018,	0xb1ff, 0xc018,		0x21, 0
	.dw 0xb240, 0xc018,	0xb27f, 0xc018,		0x21, 0
	.dw 0xb2c0, 0xc018,	0xb2ff, 0xc018,		0x21, 0
	.dw 0xb340, 0xc018,	0xb37f, 0xc018,		0x21, 0
	.dw 0xb3c0, 0xc018,	0xb3ff, 0xc018,		0x21, 0
	.dw 0xb440, 0xc018,	0xb47f, 0xc018,		0x21, 0
	.dw 0xb4c0, 0xc018,	0xb4ff, 0xc018,		0x21, 0
	.dw 0xb540, 0xc018,	0xb57f, 0xc018,		0x21, 0
	.dw 0xb5c0, 0xc018,	0xb5ff, 0xc018,		0x21, 0
	.dw 0xb640, 0xc018,	0xb67f, 0xc018,		0x21, 0
	.dw 0xb6c0, 0xc018,	0xb6ff, 0xc018,		0x21, 0
	.dw 0xb740, 0xc018,	0xb77f, 0xc018,		0x21, 0
	.dw 0xb7c0, 0xc018,	0xb7ff, 0xc018,		0x21, 0
	.dw 0xb840, 0xc018,	0xb87f, 0xc018,		0x21, 0
	.dw 0xb8c0, 0xc018,	0xb8ff, 0xc018,		0x21, 0
	.dw 0xb940, 0xc018,	0xb97f, 0xc018,		0x21, 0
	.dw 0xb9c0, 0xc018,	0xdfff, 0xc018,		0x21, 0
	.dw 0xe040, 0xc018,	0xe07f, 0xc018,		0x21, 0
	.dw 0xe0c0, 0xc018,	0xe0ff, 0xc018,		0x21, 0
	.dw 0xe140, 0xc018,	0xe17f, 0xc018,		0x21, 0
	.dw 0xe1c0, 0xc018,	0xe1ff, 0xc018,		0x21, 0
	.dw 0xe240, 0xc018,	0xe27f, 0xc018,		0x21, 0
	.dw 0xe2c0, 0xc018,	0xe2ff, 0xc018,		0x21, 0
	.dw 0xe340, 0xc018,	0xe37f, 0xc018,		0x21, 0
	.dw 0xe3c0, 0xc018,	0xe3ff, 0xc018,		0x21, 0
	.dw 0xe440, 0xc018,	0xe47f, 0xc018,		0x21, 0
	.dw 0xe4c0, 0xc018,	0xe4ff, 0xc018,		0x21, 0
	.dw 0xe540, 0xc018,	0xe57f, 0xc018,		0x21, 0
	.dw 0xe5c0, 0xc018,	0xe5ff, 0xc018,		0x21, 0
	.dw 0xe640, 0xc018,	0xe67f, 0xc018,		0x21, 0
	.dw 0xe6c0, 0xc018,	0xe6ff, 0xc018,		0x21, 0
	.dw 0xe740, 0xc018,	0xe77f, 0xc018,		0x21, 0
	.dw 0xe7c0, 0xc018,	0xe7ff, 0xc018,		0x21, 0
	.dw 0xe840, 0xc018,	0xe87f, 0xc018,		0x21, 0
	.dw 0xe8c0, 0xc018,	0xe8ff, 0xc018,		0x21, 0
	.dw 0xe940, 0xc018,	0xe97f, 0xc018,		0x21, 0
	.dw 0xe9c0, 0xc018,	0xe9ff, 0xc018,		0x21, 0
	.dw 0xea40, 0xc018,	0xea7f, 0xc018,		0x21, 0
	.dw 0xeac0, 0xc018,	0xeaff, 0xc018,		0x21, 0
	.dw 0xeb40, 0xc018,	0xeb7f, 0xc018,		0x21, 0
	.dw 0xebc0, 0xc018,	0xebff, 0xc018,		0x21, 0
	.dw 0xec40, 0xc018,	0xec7f, 0xc018,		0x21, 0
	.dw 0xecc0, 0xc018,	0xecff, 0xc018,		0x21, 0
	.dw 0xed40, 0xc018,	0xed7f, 0xc018,		0x21, 0
	.dw 0xedc0, 0xc018,	0xedff, 0xc018,		0x21, 0
	.dw 0xee40, 0xc018,	0xee7f, 0xc018,		0x21, 0
	.dw 0xeec0, 0xc018,	0xeeff, 0xc018,		0x21, 0
	.dw 0xef40, 0xc018,	0xef7f, 0xc018,		0x21, 0
	.dw 0xefc0, 0xc018,	0xefff, 0xc018,		0x21, 0
	.dw 0xf040, 0xc018,	0xf07f, 0xc018,		0x21, 0
	.dw 0xf0c0, 0xc018,	0xf0ff, 0xc018,		0x21, 0
	.dw 0xf140, 0xc018,	0xf17f, 0xc018,		0x21, 0
	.dw 0xf1c0, 0xc018,	0xf1ff, 0xc018,		0x21, 0
	.dw 0xf240, 0xc018,	0xf27f, 0xc018,		0x21, 0
	.dw 0xf2c0, 0xc018,	0xf2ff, 0xc018,		0x21, 0
	.dw 0xf340, 0xc018,	0xf37f, 0xc018,		0x21, 0
	.dw 0xf3c0, 0xc018,	0xf3ff, 0xc018,		0x21, 0
	.dw 0xf440, 0xc018,	0xf47f, 0xc018,		0x21, 0
	.dw 0xf4c0, 0xc018,	0xf4ff, 0xc018,		0x21, 0
	.dw 0xf540, 0xc018,	0xf57f, 0xc018,		0x21, 0
	.dw 0xf5c0, 0xc018,	0xf5ff, 0xc018,		0x21, 0
	.dw 0xf640, 0xc018,	0xf67f, 0xc018,		0x21, 0
	.dw 0xf6c0, 0xc018,	0xf6ff, 0xc018,		0x21, 0
	.dw 0xf740, 0xc018,	0xf77f, 0xc018,		0x21, 0
	.dw 0xf7c0, 0xc018,	0xf7ff, 0xc018,		0x21, 0
	.dw 0xf840, 0xc018,	0xf87f, 0xc018,		0x21, 0
	.dw 0xf8c0, 0xc018,	0xf8ff, 0xc018,		0x21, 0
	.dw 0xf940, 0xc018,	0xf97f, 0xc018,		0x21, 0
	.dw 0xf9c0, 0xc018,	0x1fff, 0xc019,		0x21, 0
	.dw 0x2040, 0xc019,	0x207f, 0xc019,		0x21, 0
	.dw 0x20c0, 0xc019,	0x20ff, 0xc019,		0x21, 0
	.dw 0x2140, 0xc019,	0x217f, 0xc019,		0x21, 0
	.dw 0x21c0, 0xc019,	0x21ff, 0xc019,		0x21, 0
	.dw 0x2240, 0xc019,	0x227f, 0xc019,		0x21, 0
	.dw 0x22c0, 0xc019,	0x22ff, 0xc019,		0x21, 0
	.dw 0x2340, 0xc019,	0x237f, 0xc019,		0x21, 0
	.dw 0x23c0, 0xc019,	0x23ff, 0xc019,		0x21, 0
	.dw 0x2440, 0xc019,	0x247f, 0xc019,		0x21, 0
	.dw 0x24c0, 0xc019,	0x24ff, 0xc019,		0x21, 0
	.dw 0x2540, 0xc019,	0x257f, 0xc019,		0x21, 0
	.dw 0x25c0, 0xc019,	0x25ff, 0xc019,		0x21, 0
	.dw 0x2640, 0xc019,	0x267f, 0xc019,		0x21, 0
	.dw 0x26c0, 0xc019,	0x26ff, 0xc019,		0x21, 0
	.dw 0x2740, 0xc019,	0x277f, 0xc019,		0x21, 0
	.dw 0x27c0, 0xc019,	0x27ff, 0xc019,		0x21, 0
	.dw 0x2840, 0xc019,	0x287f, 0xc019,		0x21, 0
	.dw 0x28c0, 0xc019,	0x28ff, 0xc019,		0x21, 0
	.dw 0x2940, 0xc019,	0x297f, 0xc019,		0x21, 0
	.dw 0x29c0, 0xc019,	0x29ff, 0xc019,		0x21, 0
	.dw 0x2a40, 0xc019,	0x2a7f, 0xc019,		0x21, 0
	.dw 0x2ac0, 0xc019,	0x2aff, 0xc019,		0x21, 0
	.dw 0x2b40, 0xc019,	0x2b7f, 0xc019,		0x21, 0
	.dw 0x2bc0, 0xc019,	0x2bff, 0xc019,		0x21, 0
	.dw 0x2c40, 0xc019,	0x2c7f, 0xc019,		0x21, 0
	.dw 0x2cc0, 0xc019,	0x2cff, 0xc019,		0x21, 0
	.dw 0x2d40, 0xc019,	0x2d7f, 0xc019,		0x21, 0
	.dw 0x2dc0, 0xc019,	0x2dff, 0xc019,		0x21, 0
	.dw 0x2e40, 0xc019,	0x2e7f, 0xc019,		0x21, 0
	.dw 0x2ec0, 0xc019,	0x2eff, 0xc019,		0x21, 0
	.dw 0x2f40, 0xc019,	0x2f7f, 0xc019,		0x21, 0
	.dw 0x2fc0, 0xc019,	0x2fff, 0xc019,		0x21, 0
	.dw 0x3040, 0xc019,	0x307f, 0xc019,		0x21, 0
	.dw 0x30c0, 0xc019,	0x30ff, 0xc019,		0x21, 0
	.dw 0x3140, 0xc019,	0x317f, 0xc019,		0x21, 0
	.dw 0x31c0, 0xc019,	0x31ff, 0xc019,		0x21, 0
	.dw 0x3240, 0xc019,	0x327f, 0xc019,		0x21, 0
	.dw 0x32c0, 0xc019,	0x32ff, 0xc019,		0x21, 0
	.dw 0x3340, 0xc019,	0x337f, 0xc019,		0x21, 0
	.dw 0x33c0, 0xc019,	0x33ff, 0xc019,		0x21, 0
	.dw 0x3440, 0xc019,	0x347f, 0xc019,		0x21, 0
	.dw 0x34c0, 0xc019,	0x34ff, 0xc019,		0x21, 0
	.dw 0x3540, 0xc019,	0x357f, 0xc019,		0x21, 0
	.dw 0x35c0, 0xc019,	0x35ff, 0xc019,		0x21, 0
	.dw 0x3640, 0xc019,	0x367f, 0xc019,		0x21, 0
	.dw 0x36c0, 0xc019,	0x36ff, 0xc019,		0x21, 0
	.dw 0x3740, 0xc019,	0x377f, 0xc019,		0x21, 0
	.dw 0x37c0, 0xc019,	0x37ff, 0xc019,		0x21, 0
	.dw 0x3840, 0xc019,	0x387f, 0xc019,		0x21, 0
	.dw 0x38c0, 0xc019,	0x38ff, 0xc019,		0x21, 0
	.dw 0x3940, 0xc019,	0x397f, 0xc019,		0x21, 0
	.dw 0x39c0, 0xc019,	0x5fff, 0xc019,		0x21, 0
	.dw 0x6040, 0xc019,	0x607f, 0xc019,		0x21, 0
	.dw 0x60c0, 0xc019,	0x60ff, 0xc019,		0x21, 0
	.dw 0x6140, 0xc019,	0x617f, 0xc019,		0x21, 0
	.dw 0x61c0, 0xc019,	0x61ff, 0xc019,		0x21, 0
	.dw 0x6240, 0xc019,	0x627f, 0xc019,		0x21, 0
	.dw 0x62c0, 0xc019,	0x62ff, 0xc019,		0x21, 0
	.dw 0x6340, 0xc019,	0x637f, 0xc019,		0x21, 0
	.dw 0x63c0, 0xc019,	0x63ff, 0xc019,		0x21, 0
	.dw 0x6440, 0xc019,	0x647f, 0xc019,		0x21, 0
	.dw 0x64c0, 0xc019,	0x64ff, 0xc019,		0x21, 0
	.dw 0x6540, 0xc019,	0x657f, 0xc019,		0x21, 0
	.dw 0x65c0, 0xc019,	0x65ff, 0xc019,		0x21, 0
	.dw 0x6640, 0xc019,	0x667f, 0xc019,		0x21, 0
	.dw 0x66c0, 0xc019,	0x66ff, 0xc019,		0x21, 0
	.dw 0x6740, 0xc019,	0x677f, 0xc019,		0x21, 0
	.dw 0x67c0, 0xc019,	0x67ff, 0xc019,		0x21, 0
	.dw 0x6840, 0xc019,	0x687f, 0xc019,		0x21, 0
	.dw 0x68c0, 0xc019,	0x68ff, 0xc019,		0x21, 0
	.dw 0x6940, 0xc019,	0x697f, 0xc019,		0x21, 0
	.dw 0x69c0, 0xc019,	0x69ff, 0xc019,		0x21, 0
	.dw 0x6a40, 0xc019,	0x6a7f, 0xc019,		0x21, 0
	.dw 0x6ac0, 0xc019,	0x6aff, 0xc019,		0x21, 0
	.dw 0x6b40, 0xc019,	0x6b7f, 0xc019,		0x21, 0
	.dw 0x6bc0, 0xc019,	0x6bff, 0xc019,		0x21, 0
	.dw 0x6c40, 0xc019,	0x6c7f, 0xc019,		0x21, 0
	.dw 0x6cc0, 0xc019,	0x6cff, 0xc019,		0x21, 0
	.dw 0x6d40, 0xc019,	0x6d7f, 0xc019,		0x21, 0
	.dw 0x6dc0, 0xc019,	0x6dff, 0xc019,		0x21, 0
	.dw 0x6e40, 0xc019,	0x6e7f, 0xc019,		0x21, 0
	.dw 0x6ec0, 0xc019,	0x6eff, 0xc019,		0x21, 0
	.dw 0x6f40, 0xc019,	0x6f7f, 0xc019,		0x21, 0
	.dw 0x6fc0, 0xc019,	0x6fff, 0xc019,		0x21, 0
	.dw 0x7040, 0xc019,	0x707f, 0xc019,		0x21, 0
	.dw 0x70c0, 0xc019,	0x70ff, 0xc019,		0x21, 0
	.dw 0x7140, 0xc019,	0x717f, 0xc019,		0x21, 0
	.dw 0x71c0, 0xc019,	0x71ff, 0xc019,		0x21, 0
	.dw 0x7240, 0xc019,	0x727f, 0xc019,		0x21, 0
	.dw 0x72c0, 0xc019,	0x72ff, 0xc019,		0x21, 0
	.dw 0x7340, 0xc019,	0x737f, 0xc019,		0x21, 0
	.dw 0x73c0, 0xc019,	0x73ff, 0xc019,		0x21, 0
	.dw 0x7440, 0xc019,	0x747f, 0xc019,		0x21, 0
	.dw 0x74c0, 0xc019,	0x74ff, 0xc019,		0x21, 0
	.dw 0x7540, 0xc019,	0x757f, 0xc019,		0x21, 0
	.dw 0x75c0, 0xc019,	0x75ff, 0xc019,		0x21, 0
	.dw 0x7640, 0xc019,	0x767f, 0xc019,		0x21, 0
	.dw 0x76c0, 0xc019,	0x76ff, 0xc019,		0x21, 0
	.dw 0x7740, 0xc019,	0x777f, 0xc019,		0x21, 0
	.dw 0x77c0, 0xc019,	0x77ff, 0xc019,		0x21, 0
	.dw 0x7840, 0xc019,	0x787f, 0xc019,		0x21, 0
	.dw 0x78c0, 0xc019,	0x78ff, 0xc019,		0x21, 0
	.dw 0x7940, 0xc019,	0x797f, 0xc019,		0x21, 0
	.dw 0x79c0, 0xc019,	0x9fff, 0xc019,		0x21, 0
	.dw 0xa040, 0xc019,	0xa07f, 0xc019,		0x21, 0
	.dw 0xa0c0, 0xc019,	0xa0ff, 0xc019,		0x21, 0
	.dw 0xa140, 0xc019,	0xa17f, 0xc019,		0x21, 0
	.dw 0xa1c0, 0xc019,	0xa1ff, 0xc019,		0x21, 0
	.dw 0xa240, 0xc019,	0xa27f, 0xc019,		0x21, 0
	.dw 0xa2c0, 0xc019,	0xa2ff, 0xc019,		0x21, 0
	.dw 0xa340, 0xc019,	0xa37f, 0xc019,		0x21, 0
	.dw 0xa3c0, 0xc019,	0xa3ff, 0xc019,		0x21, 0
	.dw 0xa440, 0xc019,	0xa47f, 0xc019,		0x21, 0
	.dw 0xa4c0, 0xc019,	0xa4ff, 0xc019,		0x21, 0
	.dw 0xa540, 0xc019,	0xa57f, 0xc019,		0x21, 0
	.dw 0xa5c0, 0xc019,	0xa5ff, 0xc019,		0x21, 0
	.dw 0xa640, 0xc019,	0xa67f, 0xc019,		0x21, 0
	.dw 0xa6c0, 0xc019,	0xa6ff, 0xc019,		0x21, 0
	.dw 0xa740, 0xc019,	0xa77f, 0xc019,		0x21, 0
	.dw 0xa7c0, 0xc019,	0xa7ff, 0xc019,		0x21, 0
	.dw 0xa840, 0xc019,	0xa87f, 0xc019,		0x21, 0
	.dw 0xa8c0, 0xc019,	0xa8ff, 0xc019,		0x21, 0
	.dw 0xa940, 0xc019,	0xa97f, 0xc019,		0x21, 0
	.dw 0xa9c0, 0xc019,	0xa9ff, 0xc019,		0x21, 0
	.dw 0xaa40, 0xc019,	0xaa7f, 0xc019,		0x21, 0
	.dw 0xaac0, 0xc019,	0xaaff, 0xc019,		0x21, 0
	.dw 0xab40, 0xc019,	0xab7f, 0xc019,		0x21, 0
	.dw 0xabc0, 0xc019,	0xabff, 0xc019,		0x21, 0
	.dw 0xac40, 0xc019,	0xac7f, 0xc019,		0x21, 0
	.dw 0xacc0, 0xc019,	0xacff, 0xc019,		0x21, 0
	.dw 0xad40, 0xc019,	0xad7f, 0xc019,		0x21, 0
	.dw 0xadc0, 0xc019,	0xadff, 0xc019,		0x21, 0
	.dw 0xae40, 0xc019,	0xae7f, 0xc019,		0x21, 0
	.dw 0xaec0, 0xc019,	0xaeff, 0xc019,		0x21, 0
	.dw 0xaf40, 0xc019,	0xaf7f, 0xc019,		0x21, 0
	.dw 0xafc0, 0xc019,	0xafff, 0xc019,		0x21, 0
	.dw 0xb040, 0xc019,	0xb07f, 0xc019,		0x21, 0
	.dw 0xb0c0, 0xc019,	0xb0ff, 0xc019,		0x21, 0
	.dw 0xb140, 0xc019,	0xb17f, 0xc019,		0x21, 0
	.dw 0xb1c0, 0xc019,	0xb1ff, 0xc019,		0x21, 0
	.dw 0xb240, 0xc019,	0xb27f, 0xc019,		0x21, 0
	.dw 0xb2c0, 0xc019,	0xb2ff, 0xc019,		0x21, 0
	.dw 0xb340, 0xc019,	0xb37f, 0xc019,		0x21, 0
	.dw 0xb3c0, 0xc019,	0xb3ff, 0xc019,		0x21, 0
	.dw 0xb440, 0xc019,	0xb47f, 0xc019,		0x21, 0
	.dw 0xb4c0, 0xc019,	0xb4ff, 0xc019,		0x21, 0
	.dw 0xb540, 0xc019,	0xb57f, 0xc019,		0x21, 0
	.dw 0xb5c0, 0xc019,	0xb5ff, 0xc019,		0x21, 0
	.dw 0xb640, 0xc019,	0xb67f, 0xc019,		0x21, 0
	.dw 0xb6c0, 0xc019,	0xb6ff, 0xc019,		0x21, 0
	.dw 0xb740, 0xc019,	0xb77f, 0xc019,		0x21, 0
	.dw 0xb7c0, 0xc019,	0xb7ff, 0xc019,		0x21, 0
	.dw 0xb840, 0xc019,	0xb87f, 0xc019,		0x21, 0
	.dw 0xb8c0, 0xc019,	0xb8ff, 0xc019,		0x21, 0
	.dw 0xb940, 0xc019,	0xb97f, 0xc019,		0x21, 0
	.dw 0xb9c0, 0xc019,	0xdfff, 0xc019,		0x21, 0
	.dw 0xe040, 0xc019,	0xe07f, 0xc019,		0x21, 0
	.dw 0xe0c0, 0xc019,	0xe0ff, 0xc019,		0x21, 0
	.dw 0xe140, 0xc019,	0xe17f, 0xc019,		0x21, 0
	.dw 0xe1c0, 0xc019,	0xe1ff, 0xc019,		0x21, 0
	.dw 0xe240, 0xc019,	0xe27f, 0xc019,		0x21, 0
	.dw 0xe2c0, 0xc019,	0xe2ff, 0xc019,		0x21, 0
	.dw 0xe340, 0xc019,	0xe37f, 0xc019,		0x21, 0
	.dw 0xe3c0, 0xc019,	0xe3ff, 0xc019,		0x21, 0
	.dw 0xe440, 0xc019,	0xe47f, 0xc019,		0x21, 0
	.dw 0xe4c0, 0xc019,	0xe4ff, 0xc019,		0x21, 0
	.dw 0xe540, 0xc019,	0xe57f, 0xc019,		0x21, 0
	.dw 0xe5c0, 0xc019,	0xe5ff, 0xc019,		0x21, 0
	.dw 0xe640, 0xc019,	0xe67f, 0xc019,		0x21, 0
	.dw 0xe6c0, 0xc019,	0xe6ff, 0xc019,		0x21, 0
	.dw 0xe740, 0xc019,	0xe77f, 0xc019,		0x21, 0
	.dw 0xe7c0, 0xc019,	0xe7ff, 0xc019,		0x21, 0
	.dw 0xe840, 0xc019,	0xe87f, 0xc019,		0x21, 0
	.dw 0xe8c0, 0xc019,	0xe8ff, 0xc019,		0x21, 0
	.dw 0xe940, 0xc019,	0xe97f, 0xc019,		0x21, 0
	.dw 0xe9c0, 0xc019,	0xe9ff, 0xc019,		0x21, 0
	.dw 0xea40, 0xc019,	0xea7f, 0xc019,		0x21, 0
	.dw 0xeac0, 0xc019,	0xeaff, 0xc019,		0x21, 0
	.dw 0xeb40, 0xc019,	0xeb7f, 0xc019,		0x21, 0
	.dw 0xebc0, 0xc019,	0xebff, 0xc019,		0x21, 0
	.dw 0xec40, 0xc019,	0xec7f, 0xc019,		0x21, 0
	.dw 0xecc0, 0xc019,	0xecff, 0xc019,		0x21, 0
	.dw 0xed40, 0xc019,	0xed7f, 0xc019,		0x21, 0
	.dw 0xedc0, 0xc019,	0xedff, 0xc019,		0x21, 0
	.dw 0xee40, 0xc019,	0xee7f, 0xc019,		0x21, 0
	.dw 0xeec0, 0xc019,	0xeeff, 0xc019,		0x21, 0
	.dw 0xef40, 0xc019,	0xef7f, 0xc019,		0x21, 0
	.dw 0xefc0, 0xc019,	0xefff, 0xc019,		0x21, 0
	.dw 0xf040, 0xc019,	0xf07f, 0xc019,		0x21, 0
	.dw 0xf0c0, 0xc019,	0xf0ff, 0xc019,		0x21, 0
	.dw 0xf140, 0xc019,	0xf17f, 0xc019,		0x21, 0
	.dw 0xf1c0, 0xc019,	0xf1ff, 0xc019,		0x21, 0
	.dw 0xf240, 0xc019,	0xf27f, 0xc019,		0x21, 0
	.dw 0xf2c0, 0xc019,	0xf2ff, 0xc019,		0x21, 0
	.dw 0xf340, 0xc019,	0xf37f, 0xc019,		0x21, 0
	.dw 0xf3c0, 0xc019,	0xf3ff, 0xc019,		0x21, 0
	.dw 0xf440, 0xc019,	0xf47f, 0xc019,		0x21, 0
	.dw 0xf4c0, 0xc019,	0xf4ff, 0xc019,		0x21, 0
	.dw 0xf540, 0xc019,	0xf57f, 0xc019,		0x21, 0
	.dw 0xf5c0, 0xc019,	0xf5ff, 0xc019,		0x21, 0
	.dw 0xf640, 0xc019,	0xf67f, 0xc019,		0x21, 0
	.dw 0xf6c0, 0xc019,	0xf6ff, 0xc019,		0x21, 0
	.dw 0xf740, 0xc019,	0xf77f, 0xc019,		0x21, 0
	.dw 0xf7c0, 0xc019,	0xf7ff, 0xc019,		0x21, 0
	.dw 0xf840, 0xc019,	0xf87f, 0xc019,		0x21, 0
	.dw 0xf8c0, 0xc019,	0xf8ff, 0xc019,		0x21, 0
	.dw 0xf940, 0xc019,	0xf97f, 0xc019,		0x21, 0
	.dw 0xf9c0, 0xc019,	0x1fff, 0xc01a,		0x21, 0
	.dw 0x2040, 0xc01a,	0x207f, 0xc01a,		0x21, 0
	.dw 0x20c0, 0xc01a,	0x20ff, 0xc01a,		0x21, 0
	.dw 0x2140, 0xc01a,	0x217f, 0xc01a,		0x21, 0
	.dw 0x21c0, 0xc01a,	0x21ff, 0xc01a,		0x21, 0
	.dw 0x2240, 0xc01a,	0x227f, 0xc01a,		0x21, 0
	.dw 0x22c0, 0xc01a,	0x22ff, 0xc01a,		0x21, 0
	.dw 0x2340, 0xc01a,	0x237f, 0xc01a,		0x21, 0
	.dw 0x23c0, 0xc01a,	0x23ff, 0xc01a,		0x21, 0
	.dw 0x2440, 0xc01a,	0x247f, 0xc01a,		0x21, 0
	.dw 0x24c0, 0xc01a,	0x24ff, 0xc01a,		0x21, 0
	.dw 0x2540, 0xc01a,	0x257f, 0xc01a,		0x21, 0
	.dw 0x25c0, 0xc01a,	0x25ff, 0xc01a,		0x21, 0
	.dw 0x2640, 0xc01a,	0x267f, 0xc01a,		0x21, 0
	.dw 0x26c0, 0xc01a,	0x26ff, 0xc01a,		0x21, 0
	.dw 0x2740, 0xc01a,	0x277f, 0xc01a,		0x21, 0
	.dw 0x27c0, 0xc01a,	0x27ff, 0xc01a,		0x21, 0
	.dw 0x2840, 0xc01a,	0x287f, 0xc01a,		0x21, 0
	.dw 0x28c0, 0xc01a,	0x28ff, 0xc01a,		0x21, 0
	.dw 0x2940, 0xc01a,	0x297f, 0xc01a,		0x21, 0
	.dw 0x29c0, 0xc01a,	0x29ff, 0xc01a,		0x21, 0
	.dw 0x2a40, 0xc01a,	0x2a7f, 0xc01a,		0x21, 0
	.dw 0x2ac0, 0xc01a,	0x2aff, 0xc01a,		0x21, 0
	.dw 0x2b40, 0xc01a,	0x2b7f, 0xc01a,		0x21, 0
	.dw 0x2bc0, 0xc01a,	0x2bff, 0xc01a,		0x21, 0
	.dw 0x2c40, 0xc01a,	0x2c7f, 0xc01a,		0x21, 0
	.dw 0x2cc0, 0xc01a,	0x2cff, 0xc01a,		0x21, 0
	.dw 0x2d40, 0xc01a,	0x2d7f, 0xc01a,		0x21, 0
	.dw 0x2dc0, 0xc01a,	0x2dff, 0xc01a,		0x21, 0
	.dw 0x2e40, 0xc01a,	0x2e7f, 0xc01a,		0x21, 0
	.dw 0x2ec0, 0xc01a,	0x2eff, 0xc01a,		0x21, 0
	.dw 0x2f40, 0xc01a,	0x2f7f, 0xc01a,		0x21, 0
	.dw 0x2fc0, 0xc01a,	0x2fff, 0xc01a,		0x21, 0
	.dw 0x3040, 0xc01a,	0x307f, 0xc01a,		0x21, 0
	.dw 0x30c0, 0xc01a,	0x30ff, 0xc01a,		0x21, 0
	.dw 0x3140, 0xc01a,	0x317f, 0xc01a,		0x21, 0
	.dw 0x31c0, 0xc01a,	0x31ff, 0xc01a,		0x21, 0
	.dw 0x3240, 0xc01a,	0x327f, 0xc01a,		0x21, 0
	.dw 0x32c0, 0xc01a,	0x32ff, 0xc01a,		0x21, 0
	.dw 0x3340, 0xc01a,	0x337f, 0xc01a,		0x21, 0
	.dw 0x33c0, 0xc01a,	0x33ff, 0xc01a,		0x21, 0
	.dw 0x3440, 0xc01a,	0x347f, 0xc01a,		0x21, 0
	.dw 0x34c0, 0xc01a,	0x34ff, 0xc01a,		0x21, 0
	.dw 0x3540, 0xc01a,	0x357f, 0xc01a,		0x21, 0
	.dw 0x35c0, 0xc01a,	0x35ff, 0xc01a,		0x21, 0
	.dw 0x3640, 0xc01a,	0x367f, 0xc01a,		0x21, 0
	.dw 0x36c0, 0xc01a,	0x36ff, 0xc01a,		0x21, 0
	.dw 0x3740, 0xc01a,	0x377f, 0xc01a,		0x21, 0
	.dw 0x37c0, 0xc01a,	0x37ff, 0xc01a,		0x21, 0
	.dw 0x3840, 0xc01a,	0x387f, 0xc01a,		0x21, 0
	.dw 0x38c0, 0xc01a,	0x38ff, 0xc01a,		0x21, 0
	.dw 0x3940, 0xc01a,	0x397f, 0xc01a,		0x21, 0
	.dw 0x39c0, 0xc01a,	0x5fff, 0xc01a,		0x21, 0
	.dw 0x6040, 0xc01a,	0x607f, 0xc01a,		0x21, 0
	.dw 0x60c0, 0xc01a,	0x60ff, 0xc01a,		0x21, 0
	.dw 0x6140, 0xc01a,	0x617f, 0xc01a,		0x21, 0
	.dw 0x61c0, 0xc01a,	0x61ff, 0xc01a,		0x21, 0
	.dw 0x6240, 0xc01a,	0x627f, 0xc01a,		0x21, 0
	.dw 0x62c0, 0xc01a,	0x62ff, 0xc01a,		0x21, 0
	.dw 0x6340, 0xc01a,	0x637f, 0xc01a,		0x21, 0
	.dw 0x63c0, 0xc01a,	0x63ff, 0xc01a,		0x21, 0
	.dw 0x6440, 0xc01a,	0x647f, 0xc01a,		0x21, 0
	.dw 0x64c0, 0xc01a,	0x64ff, 0xc01a,		0x21, 0
	.dw 0x6540, 0xc01a,	0x657f, 0xc01a,		0x21, 0
	.dw 0x65c0, 0xc01a,	0x65ff, 0xc01a,		0x21, 0
	.dw 0x6640, 0xc01a,	0x667f, 0xc01a,		0x21, 0
	.dw 0x66c0, 0xc01a,	0x66ff, 0xc01a,		0x21, 0
	.dw 0x6740, 0xc01a,	0x677f, 0xc01a,		0x21, 0
	.dw 0x67c0, 0xc01a,	0x67ff, 0xc01a,		0x21, 0
	.dw 0x6840, 0xc01a,	0x687f, 0xc01a,		0x21, 0
	.dw 0x68c0, 0xc01a,	0x68ff, 0xc01a,		0x21, 0
	.dw 0x6940, 0xc01a,	0x697f, 0xc01a,		0x21, 0
	.dw 0x69c0, 0xc01a,	0x69ff, 0xc01a,		0x21, 0
	.dw 0x6a40, 0xc01a,	0x6a7f, 0xc01a,		0x21, 0
	.dw 0x6ac0, 0xc01a,	0x6aff, 0xc01a,		0x21, 0
	.dw 0x6b40, 0xc01a,	0x6b7f, 0xc01a,		0x21, 0
	.dw 0x6bc0, 0xc01a,	0x6bff, 0xc01a,		0x21, 0
	.dw 0x6c40, 0xc01a,	0x6c7f, 0xc01a,		0x21, 0
	.dw 0x6cc0, 0xc01a,	0x6cff, 0xc01a,		0x21, 0
	.dw 0x6d40, 0xc01a,	0x6d7f, 0xc01a,		0x21, 0
	.dw 0x6dc0, 0xc01a,	0x6dff, 0xc01a,		0x21, 0
	.dw 0x6e40, 0xc01a,	0x6e7f, 0xc01a,		0x21, 0
	.dw 0x6ec0, 0xc01a,	0x6eff, 0xc01a,		0x21, 0
	.dw 0x6f40, 0xc01a,	0x6f7f, 0xc01a,		0x21, 0
	.dw 0x6fc0, 0xc01a,	0x6fff, 0xc01a,		0x21, 0
	.dw 0x7040, 0xc01a,	0x707f, 0xc01a,		0x21, 0
	.dw 0x70c0, 0xc01a,	0x70ff, 0xc01a,		0x21, 0
	.dw 0x7140, 0xc01a,	0x717f, 0xc01a,		0x21, 0
	.dw 0x71c0, 0xc01a,	0x71ff, 0xc01a,		0x21, 0
	.dw 0x7240, 0xc01a,	0x727f, 0xc01a,		0x21, 0
	.dw 0x72c0, 0xc01a,	0x72ff, 0xc01a,		0x21, 0
	.dw 0x7340, 0xc01a,	0x737f, 0xc01a,		0x21, 0
	.dw 0x73c0, 0xc01a,	0x73ff, 0xc01a,		0x21, 0
	.dw 0x7440, 0xc01a,	0x747f, 0xc01a,		0x21, 0
	.dw 0x74c0, 0xc01a,	0x74ff, 0xc01a,		0x21, 0
	.dw 0x7540, 0xc01a,	0x757f, 0xc01a,		0x21, 0
	.dw 0x75c0, 0xc01a,	0x75ff, 0xc01a,		0x21, 0
	.dw 0x7640, 0xc01a,	0x767f, 0xc01a,		0x21, 0
	.dw 0x76c0, 0xc01a,	0x76ff, 0xc01a,		0x21, 0
	.dw 0x7740, 0xc01a,	0x777f, 0xc01a,		0x21, 0
	.dw 0x77c0, 0xc01a,	0x77ff, 0xc01a,		0x21, 0
	.dw 0x7840, 0xc01a,	0x787f, 0xc01a,		0x21, 0
	.dw 0x78c0, 0xc01a,	0x78ff, 0xc01a,		0x21, 0
	.dw 0x7940, 0xc01a,	0x797f, 0xc01a,		0x21, 0
	.dw 0x79c0, 0xc01a,	0x9fff, 0xc01a,		0x21, 0
	.dw 0xa040, 0xc01a,	0xa07f, 0xc01a,		0x21, 0
	.dw 0xa0c0, 0xc01a,	0xa0ff, 0xc01a,		0x21, 0
	.dw 0xa140, 0xc01a,	0xa17f, 0xc01a,		0x21, 0
	.dw 0xa1c0, 0xc01a,	0xa1ff, 0xc01a,		0x21, 0
	.dw 0xa240, 0xc01a,	0xa27f, 0xc01a,		0x21, 0
	.dw 0xa2c0, 0xc01a,	0xa2ff, 0xc01a,		0x21, 0
	.dw 0xa340, 0xc01a,	0xa37f, 0xc01a,		0x21, 0
	.dw 0xa3c0, 0xc01a,	0xa3ff, 0xc01a,		0x21, 0
	.dw 0xa440, 0xc01a,	0xa47f, 0xc01a,		0x21, 0
	.dw 0xa4c0, 0xc01a,	0xa4ff, 0xc01a,		0x21, 0
	.dw 0xa540, 0xc01a,	0xa57f, 0xc01a,		0x21, 0
	.dw 0xa5c0, 0xc01a,	0xa5ff, 0xc01a,		0x21, 0
	.dw 0xa640, 0xc01a,	0xa67f, 0xc01a,		0x21, 0
	.dw 0xa6c0, 0xc01a,	0xa6ff, 0xc01a,		0x21, 0
	.dw 0xa740, 0xc01a,	0xa77f, 0xc01a,		0x21, 0
	.dw 0xa7c0, 0xc01a,	0xa7ff, 0xc01a,		0x21, 0
	.dw 0xa840, 0xc01a,	0xa87f, 0xc01a,		0x21, 0
	.dw 0xa8c0, 0xc01a,	0xa8ff, 0xc01a,		0x21, 0
	.dw 0xa940, 0xc01a,	0xa97f, 0xc01a,		0x21, 0
	.dw 0xa9c0, 0xc01a,	0xa9ff, 0xc01a,		0x21, 0
	.dw 0xaa40, 0xc01a,	0xaa7f, 0xc01a,		0x21, 0
	.dw 0xaac0, 0xc01a,	0xaaff, 0xc01a,		0x21, 0
	.dw 0xab40, 0xc01a,	0xab7f, 0xc01a,		0x21, 0
	.dw 0xabc0, 0xc01a,	0xabff, 0xc01a,		0x21, 0
	.dw 0xac40, 0xc01a,	0xac7f, 0xc01a,		0x21, 0
	.dw 0xacc0, 0xc01a,	0xacff, 0xc01a,		0x21, 0
	.dw 0xad40, 0xc01a,	0xad7f, 0xc01a,		0x21, 0
	.dw 0xadc0, 0xc01a,	0xadff, 0xc01a,		0x21, 0
	.dw 0xae40, 0xc01a,	0xae7f, 0xc01a,		0x21, 0
	.dw 0xaec0, 0xc01a,	0xaeff, 0xc01a,		0x21, 0
	.dw 0xaf40, 0xc01a,	0xaf7f, 0xc01a,		0x21, 0
	.dw 0xafc0, 0xc01a,	0xafff, 0xc01a,		0x21, 0
	.dw 0xb040, 0xc01a,	0xb07f, 0xc01a,		0x21, 0
	.dw 0xb0c0, 0xc01a,	0xb0ff, 0xc01a,		0x21, 0
	.dw 0xb140, 0xc01a,	0xb17f, 0xc01a,		0x21, 0
	.dw 0xb1c0, 0xc01a,	0xb1ff, 0xc01a,		0x21, 0
	.dw 0xb240, 0xc01a,	0xb27f, 0xc01a,		0x21, 0
	.dw 0xb2c0, 0xc01a,	0xb2ff, 0xc01a,		0x21, 0
	.dw 0xb340, 0xc01a,	0xb37f, 0xc01a,		0x21, 0
	.dw 0xb3c0, 0xc01a,	0xb3ff, 0xc01a,		0x21, 0
	.dw 0xb440, 0xc01a,	0xb47f, 0xc01a,		0x21, 0
	.dw 0xb4c0, 0xc01a,	0xb4ff, 0xc01a,		0x21, 0
	.dw 0xb540, 0xc01a,	0xb57f, 0xc01a,		0x21, 0
	.dw 0xb5c0, 0xc01a,	0xb5ff, 0xc01a,		0x21, 0
	.dw 0xb640, 0xc01a,	0xb67f, 0xc01a,		0x21, 0
	.dw 0xb6c0, 0xc01a,	0xb6ff, 0xc01a,		0x21, 0
	.dw 0xb740, 0xc01a,	0xb77f, 0xc01a,		0x21, 0
	.dw 0xb7c0, 0xc01a,	0xb7ff, 0xc01a,		0x21, 0
	.dw 0xb840, 0xc01a,	0xb87f, 0xc01a,		0x21, 0
	.dw 0xb8c0, 0xc01a,	0xb8ff, 0xc01a,		0x21, 0
	.dw 0xb940, 0xc01a,	0xb97f, 0xc01a,		0x21, 0
	.dw 0xb9c0, 0xc01a,	0xdfff, 0xc01a,		0x21, 0
	.dw 0xe040, 0xc01a,	0xe07f, 0xc01a,		0x21, 0
	.dw 0xe0c0, 0xc01a,	0xe0ff, 0xc01a,		0x21, 0
	.dw 0xe140, 0xc01a,	0xe17f, 0xc01a,		0x21, 0
	.dw 0xe1c0, 0xc01a,	0xe1ff, 0xc01a,		0x21, 0
	.dw 0xe240, 0xc01a,	0xe27f, 0xc01a,		0x21, 0
	.dw 0xe2c0, 0xc01a,	0xe2ff, 0xc01a,		0x21, 0
	.dw 0xe340, 0xc01a,	0xe37f, 0xc01a,		0x21, 0
	.dw 0xe3c0, 0xc01a,	0xe3ff, 0xc01a,		0x21, 0
	.dw 0xe440, 0xc01a,	0xe47f, 0xc01a,		0x21, 0
	.dw 0xe4c0, 0xc01a,	0xe4ff, 0xc01a,		0x21, 0
	.dw 0xe540, 0xc01a,	0xe57f, 0xc01a,		0x21, 0
	.dw 0xe5c0, 0xc01a,	0xe5ff, 0xc01a,		0x21, 0
	.dw 0xe640, 0xc01a,	0xe67f, 0xc01a,		0x21, 0
	.dw 0xe6c0, 0xc01a,	0xe6ff, 0xc01a,		0x21, 0
	.dw 0xe740, 0xc01a,	0xe77f, 0xc01a,		0x21, 0
	.dw 0xe7c0, 0xc01a,	0xe7ff, 0xc01a,		0x21, 0
	.dw 0xe840, 0xc01a,	0xe87f, 0xc01a,		0x21, 0
	.dw 0xe8c0, 0xc01a,	0xe8ff, 0xc01a,		0x21, 0
	.dw 0xe940, 0xc01a,	0xe97f, 0xc01a,		0x21, 0
	.dw 0xe9c0, 0xc01a,	0xe9ff, 0xc01a,		0x21, 0
	.dw 0xea40, 0xc01a,	0xea7f, 0xc01a,		0x21, 0
	.dw 0xeac0, 0xc01a,	0xeaff, 0xc01a,		0x21, 0
	.dw 0xeb40, 0xc01a,	0xeb7f, 0xc01a,		0x21, 0
	.dw 0xebc0, 0xc01a,	0xebff, 0xc01a,		0x21, 0
	.dw 0xec40, 0xc01a,	0xec7f, 0xc01a,		0x21, 0
	.dw 0xecc0, 0xc01a,	0xecff, 0xc01a,		0x21, 0
	.dw 0xed40, 0xc01a,	0xed7f, 0xc01a,		0x21, 0
	.dw 0xedc0, 0xc01a,	0xedff, 0xc01a,		0x21, 0
	.dw 0xee40, 0xc01a,	0xee7f, 0xc01a,		0x21, 0
	.dw 0xeec0, 0xc01a,	0xeeff, 0xc01a,		0x21, 0
	.dw 0xef40, 0xc01a,	0xef7f, 0xc01a,		0x21, 0
	.dw 0xefc0, 0xc01a,	0xefff, 0xc01a,		0x21, 0
	.dw 0xf040, 0xc01a,	0xf07f, 0xc01a,		0x21, 0
	.dw 0xf0c0, 0xc01a,	0xf0ff, 0xc01a,		0x21, 0
	.dw 0xf140, 0xc01a,	0xf17f, 0xc01a,		0x21, 0
	.dw 0xf1c0, 0xc01a,	0xf1ff, 0xc01a,		0x21, 0
	.dw 0xf240, 0xc01a,	0xf27f, 0xc01a,		0x21, 0
	.dw 0xf2c0, 0xc01a,	0xf2ff, 0xc01a,		0x21, 0
	.dw 0xf340, 0xc01a,	0xf37f, 0xc01a,		0x21, 0
	.dw 0xf3c0, 0xc01a,	0xf3ff, 0xc01a,		0x21, 0
	.dw 0xf440, 0xc01a,	0xf47f, 0xc01a,		0x21, 0
	.dw 0xf4c0, 0xc01a,	0xf4ff, 0xc01a,		0x21, 0
	.dw 0xf540, 0xc01a,	0xf57f, 0xc01a,		0x21, 0
	.dw 0xf5c0, 0xc01a,	0xf5ff, 0xc01a,		0x21, 0
	.dw 0xf640, 0xc01a,	0xf67f, 0xc01a,		0x21, 0
	.dw 0xf6c0, 0xc01a,	0xf6ff, 0xc01a,		0x21, 0
	.dw 0xf740, 0xc01a,	0xf77f, 0xc01a,		0x21, 0
	.dw 0xf7c0, 0xc01a,	0xf7ff, 0xc01a,		0x21, 0
	.dw 0xf840, 0xc01a,	0xf87f, 0xc01a,		0x21, 0
	.dw 0xf8c0, 0xc01a,	0xf8ff, 0xc01a,		0x21, 0
	.dw 0xf940, 0xc01a,	0xf97f, 0xc01a,		0x21, 0
	.dw 0xf9c0, 0xc01a,	0xffff, 0xc01b,		0x21, 0
	.dw 0x0040, 0xc01c,	0x007f, 0xc01c,		0x21, 0
	.dw 0x00c0, 0xc01c,	0x00ff, 0xc01c,		0x21, 0
	.dw 0x0140, 0xc01c,	0x017f, 0xc01c,		0x21, 0
	.dw 0x01c0, 0xc01c,	0x01ff, 0xc01c,		0x21, 0
	.dw 0x0240, 0xc01c,	0x027f, 0xc01c,		0x21, 0
	.dw 0x02c0, 0xc01c,	0x02ff, 0xc01c,		0x21, 0
	.dw 0x0340, 0xc01c,	0x037f, 0xc01c,		0x21, 0
	.dw 0x03c0, 0xc01c,	0x03ff, 0xc01c,		0x21, 0
	.dw 0x0440, 0xc01c,	0x047f, 0xc01c,		0x21, 0
	.dw 0x04c0, 0xc01c,	0x04ff, 0xc01c,		0x21, 0
	.dw 0x0540, 0xc01c,	0x057f, 0xc01c,		0x21, 0
	.dw 0x05c0, 0xc01c,	0x05ff, 0xc01c,		0x21, 0
	.dw 0x0640, 0xc01c,	0x067f, 0xc01c,		0x21, 0
	.dw 0x06c0, 0xc01c,	0x06ff, 0xc01c,		0x21, 0
	.dw 0x0740, 0xc01c,	0x077f, 0xc01c,		0x21, 0
	.dw 0x07c0, 0xc01c,	0x07ff, 0xc01c,		0x21, 0
	.dw 0x0840, 0xc01c,	0x087f, 0xc01c,		0x21, 0
	.dw 0x08c0, 0xc01c,	0x08ff, 0xc01c,		0x21, 0
	.dw 0x0940, 0xc01c,	0x097f, 0xc01c,		0x21, 0
	.dw 0x09c0, 0xc01c,	0x09ff, 0xc01c,		0x21, 0
	.dw 0x0a40, 0xc01c,	0x0a7f, 0xc01c,		0x21, 0
	.dw 0x0ac0, 0xc01c,	0x0aff, 0xc01c,		0x21, 0
	.dw 0x0b40, 0xc01c,	0x0b7f, 0xc01c,		0x21, 0
	.dw 0x0bc0, 0xc01c,	0x0bff, 0xc01c,		0x21, 0
	.dw 0x0c40, 0xc01c,	0x0c7f, 0xc01c,		0x21, 0
	.dw 0x0cc0, 0xc01c,	0x0cff, 0xc01c,		0x21, 0
	.dw 0x0d40, 0xc01c,	0x0d7f, 0xc01c,		0x21, 0
	.dw 0x0dc0, 0xc01c,	0x0dff, 0xc01c,		0x21, 0
	.dw 0x0e40, 0xc01c,	0x0e7f, 0xc01c,		0x21, 0
	.dw 0x0ec0, 0xc01c,	0x0eff, 0xc01c,		0x21, 0
	.dw 0x0f40, 0xc01c,	0x0f7f, 0xc01c,		0x21, 0
	.dw 0x0fc0, 0xc01c,	0x0fff, 0xc01c,		0x21, 0
	.dw 0x1040, 0xc01c,	0x107f, 0xc01c,		0x21, 0
	.dw 0x10c0, 0xc01c,	0x10ff, 0xc01c,		0x21, 0
	.dw 0x1140, 0xc01c,	0x117f, 0xc01c,		0x21, 0
	.dw 0x11c0, 0xc01c,	0x11ff, 0xc01c,		0x21, 0
	.dw 0x1240, 0xc01c,	0x127f, 0xc01c,		0x21, 0
	.dw 0x12c0, 0xc01c,	0x12ff, 0xc01c,		0x21, 0
	.dw 0x1340, 0xc01c,	0x137f, 0xc01c,		0x21, 0
	.dw 0x13c0, 0xc01c,	0x13ff, 0xc01c,		0x21, 0
	.dw 0x1440, 0xc01c,	0x147f, 0xc01c,		0x21, 0
	.dw 0x14c0, 0xc01c,	0x14ff, 0xc01c,		0x21, 0
	.dw 0x1540, 0xc01c,	0x157f, 0xc01c,		0x21, 0
	.dw 0x15c0, 0xc01c,	0x15ff, 0xc01c,		0x21, 0
	.dw 0x1640, 0xc01c,	0x167f, 0xc01c,		0x21, 0
	.dw 0x16c0, 0xc01c,	0x16ff, 0xc01c,		0x21, 0
	.dw 0x1740, 0xc01c,	0x177f, 0xc01c,		0x21, 0
	.dw 0x17c0, 0xc01c,	0x17ff, 0xc01c,		0x21, 0
	.dw 0x1840, 0xc01c,	0x187f, 0xc01c,		0x21, 0
	.dw 0x18c0, 0xc01c,	0x18ff, 0xc01c,		0x21, 0
	.dw 0x1940, 0xc01c,	0x197f, 0xc01c,		0x21, 0
	.dw 0x19c0, 0xc01c,	0x1fff, 0xc01c,		0x21, 0
	.dw 0x2040, 0xc01c,	0x207f, 0xc01c,		0x21, 0
	.dw 0x20c0, 0xc01c,	0x20ff, 0xc01c,		0x21, 0
	.dw 0x2140, 0xc01c,	0x217f, 0xc01c,		0x21, 0
	.dw 0x21c0, 0xc01c,	0x21ff, 0xc01c,		0x21, 0
	.dw 0x2240, 0xc01c,	0x227f, 0xc01c,		0x21, 0
	.dw 0x22c0, 0xc01c,	0x22ff, 0xc01c,		0x21, 0
	.dw 0x2340, 0xc01c,	0x237f, 0xc01c,		0x21, 0
	.dw 0x23c0, 0xc01c,	0x23ff, 0xc01c,		0x21, 0
	.dw 0x2440, 0xc01c,	0x247f, 0xc01c,		0x21, 0
	.dw 0x24c0, 0xc01c,	0x24ff, 0xc01c,		0x21, 0
	.dw 0x2540, 0xc01c,	0x257f, 0xc01c,		0x21, 0
	.dw 0x25c0, 0xc01c,	0x25ff, 0xc01c,		0x21, 0
	.dw 0x2640, 0xc01c,	0x267f, 0xc01c,		0x21, 0
	.dw 0x26c0, 0xc01c,	0x26ff, 0xc01c,		0x21, 0
	.dw 0x2740, 0xc01c,	0x277f, 0xc01c,		0x21, 0
	.dw 0x27c0, 0xc01c,	0x27ff, 0xc01c,		0x21, 0
	.dw 0x2840, 0xc01c,	0x287f, 0xc01c,		0x21, 0
	.dw 0x28c0, 0xc01c,	0x28ff, 0xc01c,		0x21, 0
	.dw 0x2940, 0xc01c,	0x297f, 0xc01c,		0x21, 0
	.dw 0x29c0, 0xc01c,	0x29ff, 0xc01c,		0x21, 0
	.dw 0x2a40, 0xc01c,	0x2a7f, 0xc01c,		0x21, 0
	.dw 0x2ac0, 0xc01c,	0x2aff, 0xc01c,		0x21, 0
	.dw 0x2b40, 0xc01c,	0x2b7f, 0xc01c,		0x21, 0
	.dw 0x2bc0, 0xc01c,	0x2bff, 0xc01c,		0x21, 0
	.dw 0x2c40, 0xc01c,	0x2c7f, 0xc01c,		0x21, 0
	.dw 0x2cc0, 0xc01c,	0x2cff, 0xc01c,		0x21, 0
	.dw 0x2d40, 0xc01c,	0x2d7f, 0xc01c,		0x21, 0
	.dw 0x2dc0, 0xc01c,	0x2dff, 0xc01c,		0x21, 0
	.dw 0x2e40, 0xc01c,	0x2e7f, 0xc01c,		0x21, 0
	.dw 0x2ec0, 0xc01c,	0x2eff, 0xc01c,		0x21, 0
	.dw 0x2f40, 0xc01c,	0x2f7f, 0xc01c,		0x21, 0
	.dw 0x2fc0, 0xc01c,	0x2fff, 0xc01c,		0x21, 0
	.dw 0x3040, 0xc01c,	0x307f, 0xc01c,		0x21, 0
	.dw 0x30c0, 0xc01c,	0x30ff, 0xc01c,		0x21, 0
	.dw 0x3140, 0xc01c,	0x317f, 0xc01c,		0x21, 0
	.dw 0x31c0, 0xc01c,	0x31ff, 0xc01c,		0x21, 0
	.dw 0x3240, 0xc01c,	0x327f, 0xc01c,		0x21, 0
	.dw 0x32c0, 0xc01c,	0x32ff, 0xc01c,		0x21, 0
	.dw 0x3340, 0xc01c,	0x337f, 0xc01c,		0x21, 0
	.dw 0x33c0, 0xc01c,	0x33ff, 0xc01c,		0x21, 0
	.dw 0x3440, 0xc01c,	0x347f, 0xc01c,		0x21, 0
	.dw 0x34c0, 0xc01c,	0x34ff, 0xc01c,		0x21, 0
	.dw 0x3540, 0xc01c,	0x357f, 0xc01c,		0x21, 0
	.dw 0x35c0, 0xc01c,	0x35ff, 0xc01c,		0x21, 0
	.dw 0x3640, 0xc01c,	0x367f, 0xc01c,		0x21, 0
	.dw 0x36c0, 0xc01c,	0x36ff, 0xc01c,		0x21, 0
	.dw 0x3740, 0xc01c,	0x377f, 0xc01c,		0x21, 0
	.dw 0x37c0, 0xc01c,	0x37ff, 0xc01c,		0x21, 0
	.dw 0x3840, 0xc01c,	0x387f, 0xc01c,		0x21, 0
	.dw 0x38c0, 0xc01c,	0x38ff, 0xc01c,		0x21, 0
	.dw 0x3940, 0xc01c,	0x397f, 0xc01c,		0x21, 0
	.dw 0x39c0, 0xc01c,	0x3fff, 0xc01c,		0x21, 0
	.dw 0x4040, 0xc01c,	0x407f, 0xc01c,		0x21, 0
	.dw 0x40c0, 0xc01c,	0x40ff, 0xc01c,		0x21, 0
	.dw 0x4140, 0xc01c,	0x417f, 0xc01c,		0x21, 0
	.dw 0x41c0, 0xc01c,	0x41ff, 0xc01c,		0x21, 0
	.dw 0x4240, 0xc01c,	0x427f, 0xc01c,		0x21, 0
	.dw 0x42c0, 0xc01c,	0x42ff, 0xc01c,		0x21, 0
	.dw 0x4340, 0xc01c,	0x437f, 0xc01c,		0x21, 0
	.dw 0x43c0, 0xc01c,	0x43ff, 0xc01c,		0x21, 0
	.dw 0x4440, 0xc01c,	0x447f, 0xc01c,		0x21, 0
	.dw 0x44c0, 0xc01c,	0x44ff, 0xc01c,		0x21, 0
	.dw 0x4540, 0xc01c,	0x457f, 0xc01c,		0x21, 0
	.dw 0x45c0, 0xc01c,	0x45ff, 0xc01c,		0x21, 0
	.dw 0x4640, 0xc01c,	0x467f, 0xc01c,		0x21, 0
	.dw 0x46c0, 0xc01c,	0x46ff, 0xc01c,		0x21, 0
	.dw 0x4740, 0xc01c,	0x477f, 0xc01c,		0x21, 0
	.dw 0x47c0, 0xc01c,	0x47ff, 0xc01c,		0x21, 0
	.dw 0x4840, 0xc01c,	0x487f, 0xc01c,		0x21, 0
	.dw 0x48c0, 0xc01c,	0x48ff, 0xc01c,		0x21, 0
	.dw 0x4940, 0xc01c,	0x497f, 0xc01c,		0x21, 0
	.dw 0x49c0, 0xc01c,	0x49ff, 0xc01c,		0x21, 0
	.dw 0x4a40, 0xc01c,	0x4a7f, 0xc01c,		0x21, 0
	.dw 0x4ac0, 0xc01c,	0x4aff, 0xc01c,		0x21, 0
	.dw 0x4b40, 0xc01c,	0x4b7f, 0xc01c,		0x21, 0
	.dw 0x4bc0, 0xc01c,	0x4bff, 0xc01c,		0x21, 0
	.dw 0x4c40, 0xc01c,	0x4c7f, 0xc01c,		0x21, 0
	.dw 0x4cc0, 0xc01c,	0x4cff, 0xc01c,		0x21, 0
	.dw 0x4d40, 0xc01c,	0x4d7f, 0xc01c,		0x21, 0
	.dw 0x4dc0, 0xc01c,	0x4dff, 0xc01c,		0x21, 0
	.dw 0x4e40, 0xc01c,	0x4e7f, 0xc01c,		0x21, 0
	.dw 0x4ec0, 0xc01c,	0x4eff, 0xc01c,		0x21, 0
	.dw 0x4f40, 0xc01c,	0x4f7f, 0xc01c,		0x21, 0
	.dw 0x4fc0, 0xc01c,	0x4fff, 0xc01c,		0x21, 0
	.dw 0x5040, 0xc01c,	0x507f, 0xc01c,		0x21, 0
	.dw 0x50c0, 0xc01c,	0x50ff, 0xc01c,		0x21, 0
	.dw 0x5140, 0xc01c,	0x517f, 0xc01c,		0x21, 0
	.dw 0x51c0, 0xc01c,	0x51ff, 0xc01c,		0x21, 0
	.dw 0x5240, 0xc01c,	0x527f, 0xc01c,		0x21, 0
	.dw 0x52c0, 0xc01c,	0x52ff, 0xc01c,		0x21, 0
	.dw 0x5340, 0xc01c,	0x537f, 0xc01c,		0x21, 0
	.dw 0x53c0, 0xc01c,	0x53ff, 0xc01c,		0x21, 0
	.dw 0x5440, 0xc01c,	0x547f, 0xc01c,		0x21, 0
	.dw 0x54c0, 0xc01c,	0x54ff, 0xc01c,		0x21, 0
	.dw 0x5540, 0xc01c,	0x557f, 0xc01c,		0x21, 0
	.dw 0x55c0, 0xc01c,	0x55ff, 0xc01c,		0x21, 0
	.dw 0x5640, 0xc01c,	0x567f, 0xc01c,		0x21, 0
	.dw 0x56c0, 0xc01c,	0x56ff, 0xc01c,		0x21, 0
	.dw 0x5740, 0xc01c,	0x577f, 0xc01c,		0x21, 0
	.dw 0x57c0, 0xc01c,	0x57ff, 0xc01c,		0x21, 0
	.dw 0x5840, 0xc01c,	0x587f, 0xc01c,		0x21, 0
	.dw 0x58c0, 0xc01c,	0x58ff, 0xc01c,		0x21, 0
	.dw 0x5940, 0xc01c,	0x597f, 0xc01c,		0x21, 0
	.dw 0x59c0, 0xc01c,	0x5fff, 0xc01c,		0x21, 0
	.dw 0x6040, 0xc01c,	0x607f, 0xc01c,		0x21, 0
	.dw 0x60c0, 0xc01c,	0x60ff, 0xc01c,		0x21, 0
	.dw 0x6140, 0xc01c,	0x617f, 0xc01c,		0x21, 0
	.dw 0x61c0, 0xc01c,	0x61ff, 0xc01c,		0x21, 0
	.dw 0x6240, 0xc01c,	0x627f, 0xc01c,		0x21, 0
	.dw 0x62c0, 0xc01c,	0x62ff, 0xc01c,		0x21, 0
	.dw 0x6340, 0xc01c,	0x637f, 0xc01c,		0x21, 0
	.dw 0x63c0, 0xc01c,	0x63ff, 0xc01c,		0x21, 0
	.dw 0x6440, 0xc01c,	0x647f, 0xc01c,		0x21, 0
	.dw 0x64c0, 0xc01c,	0x64ff, 0xc01c,		0x21, 0
	.dw 0x6540, 0xc01c,	0x657f, 0xc01c,		0x21, 0
	.dw 0x65c0, 0xc01c,	0x65ff, 0xc01c,		0x21, 0
	.dw 0x6640, 0xc01c,	0x667f, 0xc01c,		0x21, 0
	.dw 0x66c0, 0xc01c,	0x66ff, 0xc01c,		0x21, 0
	.dw 0x6740, 0xc01c,	0x677f, 0xc01c,		0x21, 0
	.dw 0x67c0, 0xc01c,	0x67ff, 0xc01c,		0x21, 0
	.dw 0x6840, 0xc01c,	0x687f, 0xc01c,		0x21, 0
	.dw 0x68c0, 0xc01c,	0x68ff, 0xc01c,		0x21, 0
	.dw 0x6940, 0xc01c,	0x697f, 0xc01c,		0x21, 0
	.dw 0x69c0, 0xc01c,	0x69ff, 0xc01c,		0x21, 0
	.dw 0x6a40, 0xc01c,	0x6a7f, 0xc01c,		0x21, 0
	.dw 0x6ac0, 0xc01c,	0x6aff, 0xc01c,		0x21, 0
	.dw 0x6b40, 0xc01c,	0x6b7f, 0xc01c,		0x21, 0
	.dw 0x6bc0, 0xc01c,	0x6bff, 0xc01c,		0x21, 0
	.dw 0x6c40, 0xc01c,	0x6c7f, 0xc01c,		0x21, 0
	.dw 0x6cc0, 0xc01c,	0x6cff, 0xc01c,		0x21, 0
	.dw 0x6d40, 0xc01c,	0x6d7f, 0xc01c,		0x21, 0
	.dw 0x6dc0, 0xc01c,	0x6dff, 0xc01c,		0x21, 0
	.dw 0x6e40, 0xc01c,	0x6e7f, 0xc01c,		0x21, 0
	.dw 0x6ec0, 0xc01c,	0x6eff, 0xc01c,		0x21, 0
	.dw 0x6f40, 0xc01c,	0x6f7f, 0xc01c,		0x21, 0
	.dw 0x6fc0, 0xc01c,	0x6fff, 0xc01c,		0x21, 0
	.dw 0x7040, 0xc01c,	0x707f, 0xc01c,		0x21, 0
	.dw 0x70c0, 0xc01c,	0x70ff, 0xc01c,		0x21, 0
	.dw 0x7140, 0xc01c,	0x717f, 0xc01c,		0x21, 0
	.dw 0x71c0, 0xc01c,	0x71ff, 0xc01c,		0x21, 0
	.dw 0x7240, 0xc01c,	0x727f, 0xc01c,		0x21, 0
	.dw 0x72c0, 0xc01c,	0x72ff, 0xc01c,		0x21, 0
	.dw 0x7340, 0xc01c,	0x737f, 0xc01c,		0x21, 0
	.dw 0x73c0, 0xc01c,	0x73ff, 0xc01c,		0x21, 0
	.dw 0x7440, 0xc01c,	0x747f, 0xc01c,		0x21, 0
	.dw 0x74c0, 0xc01c,	0x74ff, 0xc01c,		0x21, 0
	.dw 0x7540, 0xc01c,	0x757f, 0xc01c,		0x21, 0
	.dw 0x75c0, 0xc01c,	0x75ff, 0xc01c,		0x21, 0
	.dw 0x7640, 0xc01c,	0x767f, 0xc01c,		0x21, 0
	.dw 0x76c0, 0xc01c,	0x76ff, 0xc01c,		0x21, 0
	.dw 0x7740, 0xc01c,	0x777f, 0xc01c,		0x21, 0
	.dw 0x77c0, 0xc01c,	0x77ff, 0xc01c,		0x21, 0
	.dw 0x7840, 0xc01c,	0x787f, 0xc01c,		0x21, 0
	.dw 0x78c0, 0xc01c,	0x78ff, 0xc01c,		0x21, 0
	.dw 0x7940, 0xc01c,	0x797f, 0xc01c,		0x21, 0
	.dw 0x79c0, 0xc01c,	0x7fff, 0xc01c,		0x21, 0
	.dw 0x8040, 0xc01c,	0x807f, 0xc01c,		0x21, 0
	.dw 0x80c0, 0xc01c,	0x80ff, 0xc01c,		0x21, 0
	.dw 0x8140, 0xc01c,	0x817f, 0xc01c,		0x21, 0
	.dw 0x81c0, 0xc01c,	0x81ff, 0xc01c,		0x21, 0
	.dw 0x8240, 0xc01c,	0x827f, 0xc01c,		0x21, 0
	.dw 0x82c0, 0xc01c,	0x82ff, 0xc01c,		0x21, 0
	.dw 0x8340, 0xc01c,	0x837f, 0xc01c,		0x21, 0
	.dw 0x83c0, 0xc01c,	0x83ff, 0xc01c,		0x21, 0
	.dw 0x8440, 0xc01c,	0x847f, 0xc01c,		0x21, 0
	.dw 0x84c0, 0xc01c,	0x84ff, 0xc01c,		0x21, 0
	.dw 0x8540, 0xc01c,	0x857f, 0xc01c,		0x21, 0
	.dw 0x85c0, 0xc01c,	0x85ff, 0xc01c,		0x21, 0
	.dw 0x8640, 0xc01c,	0x867f, 0xc01c,		0x21, 0
	.dw 0x86c0, 0xc01c,	0x86ff, 0xc01c,		0x21, 0
	.dw 0x8740, 0xc01c,	0x877f, 0xc01c,		0x21, 0
	.dw 0x87c0, 0xc01c,	0x87ff, 0xc01c,		0x21, 0
	.dw 0x8840, 0xc01c,	0x887f, 0xc01c,		0x21, 0
	.dw 0x88c0, 0xc01c,	0x88ff, 0xc01c,		0x21, 0
	.dw 0x8940, 0xc01c,	0x897f, 0xc01c,		0x21, 0
	.dw 0x89c0, 0xc01c,	0x89ff, 0xc01c,		0x21, 0
	.dw 0x8a40, 0xc01c,	0x8a7f, 0xc01c,		0x21, 0
	.dw 0x8ac0, 0xc01c,	0x8aff, 0xc01c,		0x21, 0
	.dw 0x8b40, 0xc01c,	0x8b7f, 0xc01c,		0x21, 0
	.dw 0x8bc0, 0xc01c,	0x8bff, 0xc01c,		0x21, 0
	.dw 0x8c40, 0xc01c,	0x8c7f, 0xc01c,		0x21, 0
	.dw 0x8cc0, 0xc01c,	0x8cff, 0xc01c,		0x21, 0
	.dw 0x8d40, 0xc01c,	0x8d7f, 0xc01c,		0x21, 0
	.dw 0x8dc0, 0xc01c,	0x8dff, 0xc01c,		0x21, 0
	.dw 0x8e40, 0xc01c,	0x8e7f, 0xc01c,		0x21, 0
	.dw 0x8ec0, 0xc01c,	0x8eff, 0xc01c,		0x21, 0
	.dw 0x8f40, 0xc01c,	0x8f7f, 0xc01c,		0x21, 0
	.dw 0x8fc0, 0xc01c,	0x8fff, 0xc01c,		0x21, 0
	.dw 0x9040, 0xc01c,	0x907f, 0xc01c,		0x21, 0
	.dw 0x90c0, 0xc01c,	0x90ff, 0xc01c,		0x21, 0
	.dw 0x9140, 0xc01c,	0x917f, 0xc01c,		0x21, 0
	.dw 0x91c0, 0xc01c,	0x91ff, 0xc01c,		0x21, 0
	.dw 0x9240, 0xc01c,	0x927f, 0xc01c,		0x21, 0
	.dw 0x92c0, 0xc01c,	0x92ff, 0xc01c,		0x21, 0
	.dw 0x9340, 0xc01c,	0x937f, 0xc01c,		0x21, 0
	.dw 0x93c0, 0xc01c,	0x93ff, 0xc01c,		0x21, 0
	.dw 0x9440, 0xc01c,	0x947f, 0xc01c,		0x21, 0
	.dw 0x94c0, 0xc01c,	0x94ff, 0xc01c,		0x21, 0
	.dw 0x9540, 0xc01c,	0x957f, 0xc01c,		0x21, 0
	.dw 0x95c0, 0xc01c,	0x95ff, 0xc01c,		0x21, 0
	.dw 0x9640, 0xc01c,	0x967f, 0xc01c,		0x21, 0
	.dw 0x96c0, 0xc01c,	0x96ff, 0xc01c,		0x21, 0
	.dw 0x9740, 0xc01c,	0x977f, 0xc01c,		0x21, 0
	.dw 0x97c0, 0xc01c,	0x97ff, 0xc01c,		0x21, 0
	.dw 0x9840, 0xc01c,	0x987f, 0xc01c,		0x21, 0
	.dw 0x98c0, 0xc01c,	0x98ff, 0xc01c,		0x21, 0
	.dw 0x9940, 0xc01c,	0x997f, 0xc01c,		0x21, 0
	.dw 0x99c0, 0xc01c,	0x9fff, 0xc01c,		0x21, 0
	.dw 0xa040, 0xc01c,	0xa07f, 0xc01c,		0x21, 0
	.dw 0xa0c0, 0xc01c,	0xa0ff, 0xc01c,		0x21, 0
	.dw 0xa140, 0xc01c,	0xa17f, 0xc01c,		0x21, 0
	.dw 0xa1c0, 0xc01c,	0xa1ff, 0xc01c,		0x21, 0
	.dw 0xa240, 0xc01c,	0xa27f, 0xc01c,		0x21, 0
	.dw 0xa2c0, 0xc01c,	0xa2ff, 0xc01c,		0x21, 0
	.dw 0xa340, 0xc01c,	0xa37f, 0xc01c,		0x21, 0
	.dw 0xa3c0, 0xc01c,	0xa3ff, 0xc01c,		0x21, 0
	.dw 0xa440, 0xc01c,	0xa47f, 0xc01c,		0x21, 0
	.dw 0xa4c0, 0xc01c,	0xa4ff, 0xc01c,		0x21, 0
	.dw 0xa540, 0xc01c,	0xa57f, 0xc01c,		0x21, 0
	.dw 0xa5c0, 0xc01c,	0xa5ff, 0xc01c,		0x21, 0
	.dw 0xa640, 0xc01c,	0xa67f, 0xc01c,		0x21, 0
	.dw 0xa6c0, 0xc01c,	0xa6ff, 0xc01c,		0x21, 0
	.dw 0xa740, 0xc01c,	0xa77f, 0xc01c,		0x21, 0
	.dw 0xa7c0, 0xc01c,	0xa7ff, 0xc01c,		0x21, 0
	.dw 0xa840, 0xc01c,	0xa87f, 0xc01c,		0x21, 0
	.dw 0xa8c0, 0xc01c,	0xa8ff, 0xc01c,		0x21, 0
	.dw 0xa940, 0xc01c,	0xa97f, 0xc01c,		0x21, 0
	.dw 0xa9c0, 0xc01c,	0xa9ff, 0xc01c,		0x21, 0
	.dw 0xaa40, 0xc01c,	0xaa7f, 0xc01c,		0x21, 0
	.dw 0xaac0, 0xc01c,	0xaaff, 0xc01c,		0x21, 0
	.dw 0xab40, 0xc01c,	0xab7f, 0xc01c,		0x21, 0
	.dw 0xabc0, 0xc01c,	0xabff, 0xc01c,		0x21, 0
	.dw 0xac40, 0xc01c,	0xac7f, 0xc01c,		0x21, 0
	.dw 0xacc0, 0xc01c,	0xacff, 0xc01c,		0x21, 0
	.dw 0xad40, 0xc01c,	0xad7f, 0xc01c,		0x21, 0
	.dw 0xadc0, 0xc01c,	0xadff, 0xc01c,		0x21, 0
	.dw 0xae40, 0xc01c,	0xae7f, 0xc01c,		0x21, 0
	.dw 0xaec0, 0xc01c,	0xaeff, 0xc01c,		0x21, 0
	.dw 0xaf40, 0xc01c,	0xaf7f, 0xc01c,		0x21, 0
	.dw 0xafc0, 0xc01c,	0xafff, 0xc01c,		0x21, 0
	.dw 0xb040, 0xc01c,	0xb07f, 0xc01c,		0x21, 0
	.dw 0xb0c0, 0xc01c,	0xb0ff, 0xc01c,		0x21, 0
	.dw 0xb140, 0xc01c,	0xb17f, 0xc01c,		0x21, 0
	.dw 0xb1c0, 0xc01c,	0xb1ff, 0xc01c,		0x21, 0
	.dw 0xb240, 0xc01c,	0xb27f, 0xc01c,		0x21, 0
	.dw 0xb2c0, 0xc01c,	0xb2ff, 0xc01c,		0x21, 0
	.dw 0xb340, 0xc01c,	0xb37f, 0xc01c,		0x21, 0
	.dw 0xb3c0, 0xc01c,	0xb3ff, 0xc01c,		0x21, 0
	.dw 0xb440, 0xc01c,	0xb47f, 0xc01c,		0x21, 0
	.dw 0xb4c0, 0xc01c,	0xb4ff, 0xc01c,		0x21, 0
	.dw 0xb540, 0xc01c,	0xb57f, 0xc01c,		0x21, 0
	.dw 0xb5c0, 0xc01c,	0xb5ff, 0xc01c,		0x21, 0
	.dw 0xb640, 0xc01c,	0xb67f, 0xc01c,		0x21, 0
	.dw 0xb6c0, 0xc01c,	0xb6ff, 0xc01c,		0x21, 0
	.dw 0xb740, 0xc01c,	0xb77f, 0xc01c,		0x21, 0
	.dw 0xb7c0, 0xc01c,	0xb7ff, 0xc01c,		0x21, 0
	.dw 0xb840, 0xc01c,	0xb87f, 0xc01c,		0x21, 0
	.dw 0xb8c0, 0xc01c,	0xb8ff, 0xc01c,		0x21, 0
	.dw 0xb940, 0xc01c,	0xb97f, 0xc01c,		0x21, 0
	.dw 0xb9c0, 0xc01c,	0xbfff, 0xc01c,		0x21, 0
	.dw 0xc040, 0xc01c,	0xc07f, 0xc01c,		0x21, 0
	.dw 0xc0c0, 0xc01c,	0xc0ff, 0xc01c,		0x21, 0
	.dw 0xc140, 0xc01c,	0xc17f, 0xc01c,		0x21, 0
	.dw 0xc1c0, 0xc01c,	0xc1ff, 0xc01c,		0x21, 0
	.dw 0xc240, 0xc01c,	0xc27f, 0xc01c,		0x21, 0
	.dw 0xc2c0, 0xc01c,	0xc2ff, 0xc01c,		0x21, 0
	.dw 0xc340, 0xc01c,	0xc37f, 0xc01c,		0x21, 0
	.dw 0xc3c0, 0xc01c,	0xc3ff, 0xc01c,		0x21, 0
	.dw 0xc440, 0xc01c,	0xc47f, 0xc01c,		0x21, 0
	.dw 0xc4c0, 0xc01c,	0xc4ff, 0xc01c,		0x21, 0
	.dw 0xc540, 0xc01c,	0xc57f, 0xc01c,		0x21, 0
	.dw 0xc5c0, 0xc01c,	0xc5ff, 0xc01c,		0x21, 0
	.dw 0xc640, 0xc01c,	0xc67f, 0xc01c,		0x21, 0
	.dw 0xc6c0, 0xc01c,	0xc6ff, 0xc01c,		0x21, 0
	.dw 0xc740, 0xc01c,	0xc77f, 0xc01c,		0x21, 0
	.dw 0xc7c0, 0xc01c,	0xc7ff, 0xc01c,		0x21, 0
	.dw 0xc840, 0xc01c,	0xc87f, 0xc01c,		0x21, 0
	.dw 0xc8c0, 0xc01c,	0xc8ff, 0xc01c,		0x21, 0
	.dw 0xc940, 0xc01c,	0xc97f, 0xc01c,		0x21, 0
	.dw 0xc9c0, 0xc01c,	0xc9ff, 0xc01c,		0x21, 0
	.dw 0xca40, 0xc01c,	0xca7f, 0xc01c,		0x21, 0
	.dw 0xcac0, 0xc01c,	0xcaff, 0xc01c,		0x21, 0
	.dw 0xcb40, 0xc01c,	0xcb7f, 0xc01c,		0x21, 0
	.dw 0xcbc0, 0xc01c,	0xcbff, 0xc01c,		0x21, 0
	.dw 0xcc40, 0xc01c,	0xcc7f, 0xc01c,		0x21, 0
	.dw 0xccc0, 0xc01c,	0xccff, 0xc01c,		0x21, 0
	.dw 0xcd40, 0xc01c,	0xcd7f, 0xc01c,		0x21, 0
	.dw 0xcdc0, 0xc01c,	0xcdff, 0xc01c,		0x21, 0
	.dw 0xce40, 0xc01c,	0xce7f, 0xc01c,		0x21, 0
	.dw 0xcec0, 0xc01c,	0xceff, 0xc01c,		0x21, 0
	.dw 0xcf40, 0xc01c,	0xcf7f, 0xc01c,		0x21, 0
	.dw 0xcfc0, 0xc01c,	0xcfff, 0xc01c,		0x21, 0
	.dw 0xd040, 0xc01c,	0xd07f, 0xc01c,		0x21, 0
	.dw 0xd0c0, 0xc01c,	0xd0ff, 0xc01c,		0x21, 0
	.dw 0xd140, 0xc01c,	0xd17f, 0xc01c,		0x21, 0
	.dw 0xd1c0, 0xc01c,	0xd1ff, 0xc01c,		0x21, 0
	.dw 0xd240, 0xc01c,	0xd27f, 0xc01c,		0x21, 0
	.dw 0xd2c0, 0xc01c,	0xd2ff, 0xc01c,		0x21, 0
	.dw 0xd340, 0xc01c,	0xd37f, 0xc01c,		0x21, 0
	.dw 0xd3c0, 0xc01c,	0xd3ff, 0xc01c,		0x21, 0
	.dw 0xd440, 0xc01c,	0xd47f, 0xc01c,		0x21, 0
	.dw 0xd4c0, 0xc01c,	0xd4ff, 0xc01c,		0x21, 0
	.dw 0xd540, 0xc01c,	0xd57f, 0xc01c,		0x21, 0
	.dw 0xd5c0, 0xc01c,	0xd5ff, 0xc01c,		0x21, 0
	.dw 0xd640, 0xc01c,	0xd67f, 0xc01c,		0x21, 0
	.dw 0xd6c0, 0xc01c,	0xd6ff, 0xc01c,		0x21, 0
	.dw 0xd740, 0xc01c,	0xd77f, 0xc01c,		0x21, 0
	.dw 0xd7c0, 0xc01c,	0xd7ff, 0xc01c,		0x21, 0
	.dw 0xd840, 0xc01c,	0xd87f, 0xc01c,		0x21, 0
	.dw 0xd8c0, 0xc01c,	0xd8ff, 0xc01c,		0x21, 0
	.dw 0xd940, 0xc01c,	0xd97f, 0xc01c,		0x21, 0
	.dw 0xd9c0, 0xc01c,	0xdfff, 0xc01c,		0x21, 0
	.dw 0xe040, 0xc01c,	0xe07f, 0xc01c,		0x21, 0
	.dw 0xe0c0, 0xc01c,	0xe0ff, 0xc01c,		0x21, 0
	.dw 0xe140, 0xc01c,	0xe17f, 0xc01c,		0x21, 0
	.dw 0xe1c0, 0xc01c,	0xe1ff, 0xc01c,		0x21, 0
	.dw 0xe240, 0xc01c,	0xe27f, 0xc01c,		0x21, 0
	.dw 0xe2c0, 0xc01c,	0xe2ff, 0xc01c,		0x21, 0
	.dw 0xe340, 0xc01c,	0xe37f, 0xc01c,		0x21, 0
	.dw 0xe3c0, 0xc01c,	0xe3ff, 0xc01c,		0x21, 0
	.dw 0xe440, 0xc01c,	0xe47f, 0xc01c,		0x21, 0
	.dw 0xe4c0, 0xc01c,	0xe4ff, 0xc01c,		0x21, 0
	.dw 0xe540, 0xc01c,	0xe57f, 0xc01c,		0x21, 0
	.dw 0xe5c0, 0xc01c,	0xe5ff, 0xc01c,		0x21, 0
	.dw 0xe640, 0xc01c,	0xe67f, 0xc01c,		0x21, 0
	.dw 0xe6c0, 0xc01c,	0xe6ff, 0xc01c,		0x21, 0
	.dw 0xe740, 0xc01c,	0xe77f, 0xc01c,		0x21, 0
	.dw 0xe7c0, 0xc01c,	0xe7ff, 0xc01c,		0x21, 0
	.dw 0xe840, 0xc01c,	0xe87f, 0xc01c,		0x21, 0
	.dw 0xe8c0, 0xc01c,	0xe8ff, 0xc01c,		0x21, 0
	.dw 0xe940, 0xc01c,	0xe97f, 0xc01c,		0x21, 0
	.dw 0xe9c0, 0xc01c,	0xe9ff, 0xc01c,		0x21, 0
	.dw 0xea40, 0xc01c,	0xea7f, 0xc01c,		0x21, 0
	.dw 0xeac0, 0xc01c,	0xeaff, 0xc01c,		0x21, 0
	.dw 0xeb40, 0xc01c,	0xeb7f, 0xc01c,		0x21, 0
	.dw 0xebc0, 0xc01c,	0xebff, 0xc01c,		0x21, 0
	.dw 0xec40, 0xc01c,	0xec7f, 0xc01c,		0x21, 0
	.dw 0xecc0, 0xc01c,	0xecff, 0xc01c,		0x21, 0
	.dw 0xed40, 0xc01c,	0xed7f, 0xc01c,		0x21, 0
	.dw 0xedc0, 0xc01c,	0xedff, 0xc01c,		0x21, 0
	.dw 0xee40, 0xc01c,	0xee7f, 0xc01c,		0x21, 0
	.dw 0xeec0, 0xc01c,	0xeeff, 0xc01c,		0x21, 0
	.dw 0xef40, 0xc01c,	0xef7f, 0xc01c,		0x21, 0
	.dw 0xefc0, 0xc01c,	0xefff, 0xc01c,		0x21, 0
	.dw 0xf040, 0xc01c,	0xf07f, 0xc01c,		0x21, 0
	.dw 0xf0c0, 0xc01c,	0xf0ff, 0xc01c,		0x21, 0
	.dw 0xf140, 0xc01c,	0xf17f, 0xc01c,		0x21, 0
	.dw 0xf1c0, 0xc01c,	0xf1ff, 0xc01c,		0x21, 0
	.dw 0xf240, 0xc01c,	0xf27f, 0xc01c,		0x21, 0
	.dw 0xf2c0, 0xc01c,	0xf2ff, 0xc01c,		0x21, 0
	.dw 0xf340, 0xc01c,	0xf37f, 0xc01c,		0x21, 0
	.dw 0xf3c0, 0xc01c,	0xf3ff, 0xc01c,		0x21, 0
	.dw 0xf440, 0xc01c,	0xf47f, 0xc01c,		0x21, 0
	.dw 0xf4c0, 0xc01c,	0xf4ff, 0xc01c,		0x21, 0
	.dw 0xf540, 0xc01c,	0xf57f, 0xc01c,		0x21, 0
	.dw 0xf5c0, 0xc01c,	0xf5ff, 0xc01c,		0x21, 0
	.dw 0xf640, 0xc01c,	0xf67f, 0xc01c,		0x21, 0
	.dw 0xf6c0, 0xc01c,	0xf6ff, 0xc01c,		0x21, 0
	.dw 0xf740, 0xc01c,	0xf77f, 0xc01c,		0x21, 0
	.dw 0xf7c0, 0xc01c,	0xf7ff, 0xc01c,		0x21, 0
	.dw 0xf840, 0xc01c,	0xf87f, 0xc01c,		0x21, 0
	.dw 0xf8c0, 0xc01c,	0xf8ff, 0xc01c,		0x21, 0
	.dw 0xf940, 0xc01c,	0xf97f, 0xc01c,		0x21, 0
	.dw 0xf9c0, 0xc01c,	0xffff, 0xc01c,		0x21, 0
	.dw 0x0040, 0xc01d,	0x007f, 0xc01d,		0x21, 0
	.dw 0x00c0, 0xc01d,	0x00ff, 0xc01d,		0x21, 0
	.dw 0x0140, 0xc01d,	0x017f, 0xc01d,		0x21, 0
	.dw 0x01c0, 0xc01d,	0x01ff, 0xc01d,		0x21, 0
	.dw 0x0240, 0xc01d,	0x027f, 0xc01d,		0x21, 0
	.dw 0x02c0, 0xc01d,	0x02ff, 0xc01d,		0x21, 0
	.dw 0x0340, 0xc01d,	0x037f, 0xc01d,		0x21, 0
	.dw 0x03c0, 0xc01d,	0x03ff, 0xc01d,		0x21, 0
	.dw 0x0440, 0xc01d,	0x047f, 0xc01d,		0x21, 0
	.dw 0x04c0, 0xc01d,	0x04ff, 0xc01d,		0x21, 0
	.dw 0x0540, 0xc01d,	0x057f, 0xc01d,		0x21, 0
	.dw 0x05c0, 0xc01d,	0x05ff, 0xc01d,		0x21, 0
	.dw 0x0640, 0xc01d,	0x067f, 0xc01d,		0x21, 0
	.dw 0x06c0, 0xc01d,	0x06ff, 0xc01d,		0x21, 0
	.dw 0x0740, 0xc01d,	0x077f, 0xc01d,		0x21, 0
	.dw 0x07c0, 0xc01d,	0x07ff, 0xc01d,		0x21, 0
	.dw 0x0840, 0xc01d,	0x087f, 0xc01d,		0x21, 0
	.dw 0x08c0, 0xc01d,	0x08ff, 0xc01d,		0x21, 0
	.dw 0x0940, 0xc01d,	0x097f, 0xc01d,		0x21, 0
	.dw 0x09c0, 0xc01d,	0x09ff, 0xc01d,		0x21, 0
	.dw 0x0a40, 0xc01d,	0x0a7f, 0xc01d,		0x21, 0
	.dw 0x0ac0, 0xc01d,	0x0aff, 0xc01d,		0x21, 0
	.dw 0x0b40, 0xc01d,	0x0b7f, 0xc01d,		0x21, 0
	.dw 0x0bc0, 0xc01d,	0x0bff, 0xc01d,		0x21, 0
	.dw 0x0c40, 0xc01d,	0x0c7f, 0xc01d,		0x21, 0
	.dw 0x0cc0, 0xc01d,	0x0cff, 0xc01d,		0x21, 0
	.dw 0x0d40, 0xc01d,	0x0d7f, 0xc01d,		0x21, 0
	.dw 0x0dc0, 0xc01d,	0x0dff, 0xc01d,		0x21, 0
	.dw 0x0e40, 0xc01d,	0x0e7f, 0xc01d,		0x21, 0
	.dw 0x0ec0, 0xc01d,	0x0eff, 0xc01d,		0x21, 0
	.dw 0x0f40, 0xc01d,	0x0f7f, 0xc01d,		0x21, 0
	.dw 0x0fc0, 0xc01d,	0x0fff, 0xc01d,		0x21, 0
	.dw 0x1040, 0xc01d,	0x107f, 0xc01d,		0x21, 0
	.dw 0x10c0, 0xc01d,	0x10ff, 0xc01d,		0x21, 0
	.dw 0x1140, 0xc01d,	0x117f, 0xc01d,		0x21, 0
	.dw 0x11c0, 0xc01d,	0x11ff, 0xc01d,		0x21, 0
	.dw 0x1240, 0xc01d,	0x127f, 0xc01d,		0x21, 0
	.dw 0x12c0, 0xc01d,	0x12ff, 0xc01d,		0x21, 0
	.dw 0x1340, 0xc01d,	0x137f, 0xc01d,		0x21, 0
	.dw 0x13c0, 0xc01d,	0x13ff, 0xc01d,		0x21, 0
	.dw 0x1440, 0xc01d,	0x147f, 0xc01d,		0x21, 0
	.dw 0x14c0, 0xc01d,	0x14ff, 0xc01d,		0x21, 0
	.dw 0x1540, 0xc01d,	0x157f, 0xc01d,		0x21, 0
	.dw 0x15c0, 0xc01d,	0x15ff, 0xc01d,		0x21, 0
	.dw 0x1640, 0xc01d,	0x167f, 0xc01d,		0x21, 0
	.dw 0x16c0, 0xc01d,	0x16ff, 0xc01d,		0x21, 0
	.dw 0x1740, 0xc01d,	0x177f, 0xc01d,		0x21, 0
	.dw 0x17c0, 0xc01d,	0x17ff, 0xc01d,		0x21, 0
	.dw 0x1840, 0xc01d,	0x187f, 0xc01d,		0x21, 0
	.dw 0x18c0, 0xc01d,	0x18ff, 0xc01d,		0x21, 0
	.dw 0x1940, 0xc01d,	0x197f, 0xc01d,		0x21, 0
	.dw 0x19c0, 0xc01d,	0x1fff, 0xc01d,		0x21, 0
	.dw 0x2040, 0xc01d,	0x207f, 0xc01d,		0x21, 0
	.dw 0x20c0, 0xc01d,	0x20ff, 0xc01d,		0x21, 0
	.dw 0x2140, 0xc01d,	0x217f, 0xc01d,		0x21, 0
	.dw 0x21c0, 0xc01d,	0x21ff, 0xc01d,		0x21, 0
	.dw 0x2240, 0xc01d,	0x227f, 0xc01d,		0x21, 0
	.dw 0x22c0, 0xc01d,	0x22ff, 0xc01d,		0x21, 0
	.dw 0x2340, 0xc01d,	0x237f, 0xc01d,		0x21, 0
	.dw 0x23c0, 0xc01d,	0x23ff, 0xc01d,		0x21, 0
	.dw 0x2440, 0xc01d,	0x247f, 0xc01d,		0x21, 0
	.dw 0x24c0, 0xc01d,	0x24ff, 0xc01d,		0x21, 0
	.dw 0x2540, 0xc01d,	0x257f, 0xc01d,		0x21, 0
	.dw 0x25c0, 0xc01d,	0x25ff, 0xc01d,		0x21, 0
	.dw 0x2640, 0xc01d,	0x267f, 0xc01d,		0x21, 0
	.dw 0x26c0, 0xc01d,	0x26ff, 0xc01d,		0x21, 0
	.dw 0x2740, 0xc01d,	0x277f, 0xc01d,		0x21, 0
	.dw 0x27c0, 0xc01d,	0x27ff, 0xc01d,		0x21, 0
	.dw 0x2840, 0xc01d,	0x287f, 0xc01d,		0x21, 0
	.dw 0x28c0, 0xc01d,	0x28ff, 0xc01d,		0x21, 0
	.dw 0x2940, 0xc01d,	0x297f, 0xc01d,		0x21, 0
	.dw 0x29c0, 0xc01d,	0x29ff, 0xc01d,		0x21, 0
	.dw 0x2a40, 0xc01d,	0x2a7f, 0xc01d,		0x21, 0
	.dw 0x2ac0, 0xc01d,	0x2aff, 0xc01d,		0x21, 0
	.dw 0x2b40, 0xc01d,	0x2b7f, 0xc01d,		0x21, 0
	.dw 0x2bc0, 0xc01d,	0x2bff, 0xc01d,		0x21, 0
	.dw 0x2c40, 0xc01d,	0x2c7f, 0xc01d,		0x21, 0
	.dw 0x2cc0, 0xc01d,	0x2cff, 0xc01d,		0x21, 0
	.dw 0x2d40, 0xc01d,	0x2d7f, 0xc01d,		0x21, 0
	.dw 0x2dc0, 0xc01d,	0x2dff, 0xc01d,		0x21, 0
	.dw 0x2e40, 0xc01d,	0x2e7f, 0xc01d,		0x21, 0
	.dw 0x2ec0, 0xc01d,	0x2eff, 0xc01d,		0x21, 0
	.dw 0x2f40, 0xc01d,	0x2f7f, 0xc01d,		0x21, 0
	.dw 0x2fc0, 0xc01d,	0x2fff, 0xc01d,		0x21, 0
	.dw 0x3040, 0xc01d,	0x307f, 0xc01d,		0x21, 0
	.dw 0x30c0, 0xc01d,	0x30ff, 0xc01d,		0x21, 0
	.dw 0x3140, 0xc01d,	0x317f, 0xc01d,		0x21, 0
	.dw 0x31c0, 0xc01d,	0x31ff, 0xc01d,		0x21, 0
	.dw 0x3240, 0xc01d,	0x327f, 0xc01d,		0x21, 0
	.dw 0x32c0, 0xc01d,	0x32ff, 0xc01d,		0x21, 0
	.dw 0x3340, 0xc01d,	0x337f, 0xc01d,		0x21, 0
	.dw 0x33c0, 0xc01d,	0x33ff, 0xc01d,		0x21, 0
	.dw 0x3440, 0xc01d,	0x347f, 0xc01d,		0x21, 0
	.dw 0x34c0, 0xc01d,	0x34ff, 0xc01d,		0x21, 0
	.dw 0x3540, 0xc01d,	0x357f, 0xc01d,		0x21, 0
	.dw 0x35c0, 0xc01d,	0x35ff, 0xc01d,		0x21, 0
	.dw 0x3640, 0xc01d,	0x367f, 0xc01d,		0x21, 0
	.dw 0x36c0, 0xc01d,	0x36ff, 0xc01d,		0x21, 0
	.dw 0x3740, 0xc01d,	0x377f, 0xc01d,		0x21, 0
	.dw 0x37c0, 0xc01d,	0x37ff, 0xc01d,		0x21, 0
	.dw 0x3840, 0xc01d,	0x387f, 0xc01d,		0x21, 0
	.dw 0x38c0, 0xc01d,	0x38ff, 0xc01d,		0x21, 0
	.dw 0x3940, 0xc01d,	0x397f, 0xc01d,		0x21, 0
	.dw 0x39c0, 0xc01d,	0x3fff, 0xc01d,		0x21, 0
	.dw 0x4040, 0xc01d,	0x407f, 0xc01d,		0x21, 0
	.dw 0x40c0, 0xc01d,	0x40ff, 0xc01d,		0x21, 0
	.dw 0x4140, 0xc01d,	0x417f, 0xc01d,		0x21, 0
	.dw 0x41c0, 0xc01d,	0x41ff, 0xc01d,		0x21, 0
	.dw 0x4240, 0xc01d,	0x427f, 0xc01d,		0x21, 0
	.dw 0x42c0, 0xc01d,	0x42ff, 0xc01d,		0x21, 0
	.dw 0x4340, 0xc01d,	0x437f, 0xc01d,		0x21, 0
	.dw 0x43c0, 0xc01d,	0x43ff, 0xc01d,		0x21, 0
	.dw 0x4440, 0xc01d,	0x447f, 0xc01d,		0x21, 0
	.dw 0x44c0, 0xc01d,	0x44ff, 0xc01d,		0x21, 0
	.dw 0x4540, 0xc01d,	0x457f, 0xc01d,		0x21, 0
	.dw 0x45c0, 0xc01d,	0x45ff, 0xc01d,		0x21, 0
	.dw 0x4640, 0xc01d,	0x467f, 0xc01d,		0x21, 0
	.dw 0x46c0, 0xc01d,	0x46ff, 0xc01d,		0x21, 0
	.dw 0x4740, 0xc01d,	0x477f, 0xc01d,		0x21, 0
	.dw 0x47c0, 0xc01d,	0x47ff, 0xc01d,		0x21, 0
	.dw 0x4840, 0xc01d,	0x487f, 0xc01d,		0x21, 0
	.dw 0x48c0, 0xc01d,	0x48ff, 0xc01d,		0x21, 0
	.dw 0x4940, 0xc01d,	0x497f, 0xc01d,		0x21, 0
	.dw 0x49c0, 0xc01d,	0x49ff, 0xc01d,		0x21, 0
	.dw 0x4a40, 0xc01d,	0x4a7f, 0xc01d,		0x21, 0
	.dw 0x4ac0, 0xc01d,	0x4aff, 0xc01d,		0x21, 0
	.dw 0x4b40, 0xc01d,	0x4b7f, 0xc01d,		0x21, 0
	.dw 0x4bc0, 0xc01d,	0x4bff, 0xc01d,		0x21, 0
	.dw 0x4c40, 0xc01d,	0x4c7f, 0xc01d,		0x21, 0
	.dw 0x4cc0, 0xc01d,	0x4cff, 0xc01d,		0x21, 0
	.dw 0x4d40, 0xc01d,	0x4d7f, 0xc01d,		0x21, 0
	.dw 0x4dc0, 0xc01d,	0x4dff, 0xc01d,		0x21, 0
	.dw 0x4e40, 0xc01d,	0x4e7f, 0xc01d,		0x21, 0
	.dw 0x4ec0, 0xc01d,	0x4eff, 0xc01d,		0x21, 0
	.dw 0x4f40, 0xc01d,	0x4f7f, 0xc01d,		0x21, 0
	.dw 0x4fc0, 0xc01d,	0x4fff, 0xc01d,		0x21, 0
	.dw 0x5040, 0xc01d,	0x507f, 0xc01d,		0x21, 0
	.dw 0x50c0, 0xc01d,	0x50ff, 0xc01d,		0x21, 0
	.dw 0x5140, 0xc01d,	0x517f, 0xc01d,		0x21, 0
	.dw 0x51c0, 0xc01d,	0x51ff, 0xc01d,		0x21, 0
	.dw 0x5240, 0xc01d,	0x527f, 0xc01d,		0x21, 0
	.dw 0x52c0, 0xc01d,	0x52ff, 0xc01d,		0x21, 0
	.dw 0x5340, 0xc01d,	0x537f, 0xc01d,		0x21, 0
	.dw 0x53c0, 0xc01d,	0x53ff, 0xc01d,		0x21, 0
	.dw 0x5440, 0xc01d,	0x547f, 0xc01d,		0x21, 0
	.dw 0x54c0, 0xc01d,	0x54ff, 0xc01d,		0x21, 0
	.dw 0x5540, 0xc01d,	0x557f, 0xc01d,		0x21, 0
	.dw 0x55c0, 0xc01d,	0x55ff, 0xc01d,		0x21, 0
	.dw 0x5640, 0xc01d,	0x567f, 0xc01d,		0x21, 0
	.dw 0x56c0, 0xc01d,	0x56ff, 0xc01d,		0x21, 0
	.dw 0x5740, 0xc01d,	0x577f, 0xc01d,		0x21, 0
	.dw 0x57c0, 0xc01d,	0x57ff, 0xc01d,		0x21, 0
	.dw 0x5840, 0xc01d,	0x587f, 0xc01d,		0x21, 0
	.dw 0x58c0, 0xc01d,	0x58ff, 0xc01d,		0x21, 0
	.dw 0x5940, 0xc01d,	0x597f, 0xc01d,		0x21, 0
	.dw 0x59c0, 0xc01d,	0x5fff, 0xc01d,		0x21, 0
	.dw 0x6040, 0xc01d,	0x607f, 0xc01d,		0x21, 0
	.dw 0x60c0, 0xc01d,	0x60ff, 0xc01d,		0x21, 0
	.dw 0x6140, 0xc01d,	0x617f, 0xc01d,		0x21, 0
	.dw 0x61c0, 0xc01d,	0x61ff, 0xc01d,		0x21, 0
	.dw 0x6240, 0xc01d,	0x627f, 0xc01d,		0x21, 0
	.dw 0x62c0, 0xc01d,	0x62ff, 0xc01d,		0x21, 0
	.dw 0x6340, 0xc01d,	0x637f, 0xc01d,		0x21, 0
	.dw 0x63c0, 0xc01d,	0x63ff, 0xc01d,		0x21, 0
	.dw 0x6440, 0xc01d,	0x647f, 0xc01d,		0x21, 0
	.dw 0x64c0, 0xc01d,	0x64ff, 0xc01d,		0x21, 0
	.dw 0x6540, 0xc01d,	0x657f, 0xc01d,		0x21, 0
	.dw 0x65c0, 0xc01d,	0x65ff, 0xc01d,		0x21, 0
	.dw 0x6640, 0xc01d,	0x667f, 0xc01d,		0x21, 0
	.dw 0x66c0, 0xc01d,	0x66ff, 0xc01d,		0x21, 0
	.dw 0x6740, 0xc01d,	0x677f, 0xc01d,		0x21, 0
	.dw 0x67c0, 0xc01d,	0x67ff, 0xc01d,		0x21, 0
	.dw 0x6840, 0xc01d,	0x687f, 0xc01d,		0x21, 0
	.dw 0x68c0, 0xc01d,	0x68ff, 0xc01d,		0x21, 0
	.dw 0x6940, 0xc01d,	0x697f, 0xc01d,		0x21, 0
	.dw 0x69c0, 0xc01d,	0x69ff, 0xc01d,		0x21, 0
	.dw 0x6a40, 0xc01d,	0x6a7f, 0xc01d,		0x21, 0
	.dw 0x6ac0, 0xc01d,	0x6aff, 0xc01d,		0x21, 0
	.dw 0x6b40, 0xc01d,	0x6b7f, 0xc01d,		0x21, 0
	.dw 0x6bc0, 0xc01d,	0x6bff, 0xc01d,		0x21, 0
	.dw 0x6c40, 0xc01d,	0x6c7f, 0xc01d,		0x21, 0
	.dw 0x6cc0, 0xc01d,	0x6cff, 0xc01d,		0x21, 0
	.dw 0x6d40, 0xc01d,	0x6d7f, 0xc01d,		0x21, 0
	.dw 0x6dc0, 0xc01d,	0x6dff, 0xc01d,		0x21, 0
	.dw 0x6e40, 0xc01d,	0x6e7f, 0xc01d,		0x21, 0
	.dw 0x6ec0, 0xc01d,	0x6eff, 0xc01d,		0x21, 0
	.dw 0x6f40, 0xc01d,	0x6f7f, 0xc01d,		0x21, 0
	.dw 0x6fc0, 0xc01d,	0x6fff, 0xc01d,		0x21, 0
	.dw 0x7040, 0xc01d,	0x707f, 0xc01d,		0x21, 0
	.dw 0x70c0, 0xc01d,	0x70ff, 0xc01d,		0x21, 0
	.dw 0x7140, 0xc01d,	0x717f, 0xc01d,		0x21, 0
	.dw 0x71c0, 0xc01d,	0x71ff, 0xc01d,		0x21, 0
	.dw 0x7240, 0xc01d,	0x727f, 0xc01d,		0x21, 0
	.dw 0x72c0, 0xc01d,	0x72ff, 0xc01d,		0x21, 0
	.dw 0x7340, 0xc01d,	0x737f, 0xc01d,		0x21, 0
	.dw 0x73c0, 0xc01d,	0x73ff, 0xc01d,		0x21, 0
	.dw 0x7440, 0xc01d,	0x747f, 0xc01d,		0x21, 0
	.dw 0x74c0, 0xc01d,	0x74ff, 0xc01d,		0x21, 0
	.dw 0x7540, 0xc01d,	0x757f, 0xc01d,		0x21, 0
	.dw 0x75c0, 0xc01d,	0x75ff, 0xc01d,		0x21, 0
	.dw 0x7640, 0xc01d,	0x767f, 0xc01d,		0x21, 0
	.dw 0x76c0, 0xc01d,	0x76ff, 0xc01d,		0x21, 0
	.dw 0x7740, 0xc01d,	0x777f, 0xc01d,		0x21, 0
	.dw 0x77c0, 0xc01d,	0x77ff, 0xc01d,		0x21, 0
	.dw 0x7840, 0xc01d,	0x787f, 0xc01d,		0x21, 0
	.dw 0x78c0, 0xc01d,	0x78ff, 0xc01d,		0x21, 0
	.dw 0x7940, 0xc01d,	0x797f, 0xc01d,		0x21, 0
	.dw 0x79c0, 0xc01d,	0x7fff, 0xc01d,		0x21, 0
	.dw 0x8040, 0xc01d,	0x807f, 0xc01d,		0x21, 0
	.dw 0x80c0, 0xc01d,	0x80ff, 0xc01d,		0x21, 0
	.dw 0x8140, 0xc01d,	0x817f, 0xc01d,		0x21, 0
	.dw 0x81c0, 0xc01d,	0x81ff, 0xc01d,		0x21, 0
	.dw 0x8240, 0xc01d,	0x827f, 0xc01d,		0x21, 0
	.dw 0x82c0, 0xc01d,	0x82ff, 0xc01d,		0x21, 0
	.dw 0x8340, 0xc01d,	0x837f, 0xc01d,		0x21, 0
	.dw 0x83c0, 0xc01d,	0x83ff, 0xc01d,		0x21, 0
	.dw 0x8440, 0xc01d,	0x847f, 0xc01d,		0x21, 0
	.dw 0x84c0, 0xc01d,	0x84ff, 0xc01d,		0x21, 0
	.dw 0x8540, 0xc01d,	0x857f, 0xc01d,		0x21, 0
	.dw 0x85c0, 0xc01d,	0x85ff, 0xc01d,		0x21, 0
	.dw 0x8640, 0xc01d,	0x867f, 0xc01d,		0x21, 0
	.dw 0x86c0, 0xc01d,	0x86ff, 0xc01d,		0x21, 0
	.dw 0x8740, 0xc01d,	0x877f, 0xc01d,		0x21, 0
	.dw 0x87c0, 0xc01d,	0x87ff, 0xc01d,		0x21, 0
	.dw 0x8840, 0xc01d,	0x887f, 0xc01d,		0x21, 0
	.dw 0x88c0, 0xc01d,	0x88ff, 0xc01d,		0x21, 0
	.dw 0x8940, 0xc01d,	0x897f, 0xc01d,		0x21, 0
	.dw 0x89c0, 0xc01d,	0x89ff, 0xc01d,		0x21, 0
	.dw 0x8a40, 0xc01d,	0x8a7f, 0xc01d,		0x21, 0
	.dw 0x8ac0, 0xc01d,	0x8aff, 0xc01d,		0x21, 0
	.dw 0x8b40, 0xc01d,	0x8b7f, 0xc01d,		0x21, 0
	.dw 0x8bc0, 0xc01d,	0x8bff, 0xc01d,		0x21, 0
	.dw 0x8c40, 0xc01d,	0x8c7f, 0xc01d,		0x21, 0
	.dw 0x8cc0, 0xc01d,	0x8cff, 0xc01d,		0x21, 0
	.dw 0x8d40, 0xc01d,	0x8d7f, 0xc01d,		0x21, 0
	.dw 0x8dc0, 0xc01d,	0x8dff, 0xc01d,		0x21, 0
	.dw 0x8e40, 0xc01d,	0x8e7f, 0xc01d,		0x21, 0
	.dw 0x8ec0, 0xc01d,	0x8eff, 0xc01d,		0x21, 0
	.dw 0x8f40, 0xc01d,	0x8f7f, 0xc01d,		0x21, 0
	.dw 0x8fc0, 0xc01d,	0x8fff, 0xc01d,		0x21, 0
	.dw 0x9040, 0xc01d,	0x907f, 0xc01d,		0x21, 0
	.dw 0x90c0, 0xc01d,	0x90ff, 0xc01d,		0x21, 0
	.dw 0x9140, 0xc01d,	0x917f, 0xc01d,		0x21, 0
	.dw 0x91c0, 0xc01d,	0x91ff, 0xc01d,		0x21, 0
	.dw 0x9240, 0xc01d,	0x927f, 0xc01d,		0x21, 0
	.dw 0x92c0, 0xc01d,	0x92ff, 0xc01d,		0x21, 0
	.dw 0x9340, 0xc01d,	0x937f, 0xc01d,		0x21, 0
	.dw 0x93c0, 0xc01d,	0x93ff, 0xc01d,		0x21, 0
	.dw 0x9440, 0xc01d,	0x947f, 0xc01d,		0x21, 0
	.dw 0x94c0, 0xc01d,	0x94ff, 0xc01d,		0x21, 0
	.dw 0x9540, 0xc01d,	0x957f, 0xc01d,		0x21, 0
	.dw 0x95c0, 0xc01d,	0x95ff, 0xc01d,		0x21, 0
	.dw 0x9640, 0xc01d,	0x967f, 0xc01d,		0x21, 0
	.dw 0x96c0, 0xc01d,	0x96ff, 0xc01d,		0x21, 0
	.dw 0x9740, 0xc01d,	0x977f, 0xc01d,		0x21, 0
	.dw 0x97c0, 0xc01d,	0x97ff, 0xc01d,		0x21, 0
	.dw 0x9840, 0xc01d,	0x987f, 0xc01d,		0x21, 0
	.dw 0x98c0, 0xc01d,	0x98ff, 0xc01d,		0x21, 0
	.dw 0x9940, 0xc01d,	0x997f, 0xc01d,		0x21, 0
	.dw 0x99c0, 0xc01d,	0x9fff, 0xc01d,		0x21, 0
	.dw 0xa040, 0xc01d,	0xa07f, 0xc01d,		0x21, 0
	.dw 0xa0c0, 0xc01d,	0xa0ff, 0xc01d,		0x21, 0
	.dw 0xa140, 0xc01d,	0xa17f, 0xc01d,		0x21, 0
	.dw 0xa1c0, 0xc01d,	0xa1ff, 0xc01d,		0x21, 0
	.dw 0xa240, 0xc01d,	0xa27f, 0xc01d,		0x21, 0
	.dw 0xa2c0, 0xc01d,	0xa2ff, 0xc01d,		0x21, 0
	.dw 0xa340, 0xc01d,	0xa37f, 0xc01d,		0x21, 0
	.dw 0xa3c0, 0xc01d,	0xa3ff, 0xc01d,		0x21, 0
	.dw 0xa440, 0xc01d,	0xa47f, 0xc01d,		0x21, 0
	.dw 0xa4c0, 0xc01d,	0xa4ff, 0xc01d,		0x21, 0
	.dw 0xa540, 0xc01d,	0xa57f, 0xc01d,		0x21, 0
	.dw 0xa5c0, 0xc01d,	0xa5ff, 0xc01d,		0x21, 0
	.dw 0xa640, 0xc01d,	0xa67f, 0xc01d,		0x21, 0
	.dw 0xa6c0, 0xc01d,	0xa6ff, 0xc01d,		0x21, 0
	.dw 0xa740, 0xc01d,	0xa77f, 0xc01d,		0x21, 0
	.dw 0xa7c0, 0xc01d,	0xa7ff, 0xc01d,		0x21, 0
	.dw 0xa840, 0xc01d,	0xa87f, 0xc01d,		0x21, 0
	.dw 0xa8c0, 0xc01d,	0xa8ff, 0xc01d,		0x21, 0
	.dw 0xa940, 0xc01d,	0xa97f, 0xc01d,		0x21, 0
	.dw 0xa9c0, 0xc01d,	0xa9ff, 0xc01d,		0x21, 0
	.dw 0xaa40, 0xc01d,	0xaa7f, 0xc01d,		0x21, 0
	.dw 0xaac0, 0xc01d,	0xaaff, 0xc01d,		0x21, 0
	.dw 0xab40, 0xc01d,	0xab7f, 0xc01d,		0x21, 0
	.dw 0xabc0, 0xc01d,	0xabff, 0xc01d,		0x21, 0
	.dw 0xac40, 0xc01d,	0xac7f, 0xc01d,		0x21, 0
	.dw 0xacc0, 0xc01d,	0xacff, 0xc01d,		0x21, 0
	.dw 0xad40, 0xc01d,	0xad7f, 0xc01d,		0x21, 0
	.dw 0xadc0, 0xc01d,	0xadff, 0xc01d,		0x21, 0
	.dw 0xae40, 0xc01d,	0xae7f, 0xc01d,		0x21, 0
	.dw 0xaec0, 0xc01d,	0xaeff, 0xc01d,		0x21, 0
	.dw 0xaf40, 0xc01d,	0xaf7f, 0xc01d,		0x21, 0
	.dw 0xafc0, 0xc01d,	0xafff, 0xc01d,		0x21, 0
	.dw 0xb040, 0xc01d,	0xb07f, 0xc01d,		0x21, 0
	.dw 0xb0c0, 0xc01d,	0xb0ff, 0xc01d,		0x21, 0
	.dw 0xb140, 0xc01d,	0xb17f, 0xc01d,		0x21, 0
	.dw 0xb1c0, 0xc01d,	0xb1ff, 0xc01d,		0x21, 0
	.dw 0xb240, 0xc01d,	0xb27f, 0xc01d,		0x21, 0
	.dw 0xb2c0, 0xc01d,	0xb2ff, 0xc01d,		0x21, 0
	.dw 0xb340, 0xc01d,	0xb37f, 0xc01d,		0x21, 0
	.dw 0xb3c0, 0xc01d,	0xb3ff, 0xc01d,		0x21, 0
	.dw 0xb440, 0xc01d,	0xb47f, 0xc01d,		0x21, 0
	.dw 0xb4c0, 0xc01d,	0xb4ff, 0xc01d,		0x21, 0
	.dw 0xb540, 0xc01d,	0xb57f, 0xc01d,		0x21, 0
	.dw 0xb5c0, 0xc01d,	0xb5ff, 0xc01d,		0x21, 0
	.dw 0xb640, 0xc01d,	0xb67f, 0xc01d,		0x21, 0
	.dw 0xb6c0, 0xc01d,	0xb6ff, 0xc01d,		0x21, 0
	.dw 0xb740, 0xc01d,	0xb77f, 0xc01d,		0x21, 0
	.dw 0xb7c0, 0xc01d,	0xb7ff, 0xc01d,		0x21, 0
	.dw 0xb840, 0xc01d,	0xb87f, 0xc01d,		0x21, 0
	.dw 0xb8c0, 0xc01d,	0xb8ff, 0xc01d,		0x21, 0
	.dw 0xb940, 0xc01d,	0xb97f, 0xc01d,		0x21, 0
	.dw 0xb9c0, 0xc01d,	0xbfff, 0xc01d,		0x21, 0
	.dw 0xc040, 0xc01d,	0xc07f, 0xc01d,		0x21, 0
	.dw 0xc0c0, 0xc01d,	0xc0ff, 0xc01d,		0x21, 0
	.dw 0xc140, 0xc01d,	0xc17f, 0xc01d,		0x21, 0
	.dw 0xc1c0, 0xc01d,	0xc1ff, 0xc01d,		0x21, 0
	.dw 0xc240, 0xc01d,	0xc27f, 0xc01d,		0x21, 0
	.dw 0xc2c0, 0xc01d,	0xc2ff, 0xc01d,		0x21, 0
	.dw 0xc340, 0xc01d,	0xc37f, 0xc01d,		0x21, 0
	.dw 0xc3c0, 0xc01d,	0xc3ff, 0xc01d,		0x21, 0
	.dw 0xc440, 0xc01d,	0xc47f, 0xc01d,		0x21, 0
	.dw 0xc4c0, 0xc01d,	0xc4ff, 0xc01d,		0x21, 0
	.dw 0xc540, 0xc01d,	0xc57f, 0xc01d,		0x21, 0
	.dw 0xc5c0, 0xc01d,	0xc5ff, 0xc01d,		0x21, 0
	.dw 0xc640, 0xc01d,	0xc67f, 0xc01d,		0x21, 0
	.dw 0xc6c0, 0xc01d,	0xc6ff, 0xc01d,		0x21, 0
	.dw 0xc740, 0xc01d,	0xc77f, 0xc01d,		0x21, 0
	.dw 0xc7c0, 0xc01d,	0xc7ff, 0xc01d,		0x21, 0
	.dw 0xc840, 0xc01d,	0xc87f, 0xc01d,		0x21, 0
	.dw 0xc8c0, 0xc01d,	0xc8ff, 0xc01d,		0x21, 0
	.dw 0xc940, 0xc01d,	0xc97f, 0xc01d,		0x21, 0
	.dw 0xc9c0, 0xc01d,	0xc9ff, 0xc01d,		0x21, 0
	.dw 0xca40, 0xc01d,	0xca7f, 0xc01d,		0x21, 0
	.dw 0xcac0, 0xc01d,	0xcaff, 0xc01d,		0x21, 0
	.dw 0xcb40, 0xc01d,	0xcb7f, 0xc01d,		0x21, 0
	.dw 0xcbc0, 0xc01d,	0xcbff, 0xc01d,		0x21, 0
	.dw 0xcc40, 0xc01d,	0xcc7f, 0xc01d,		0x21, 0
	.dw 0xccc0, 0xc01d,	0xccff, 0xc01d,		0x21, 0
	.dw 0xcd40, 0xc01d,	0xcd7f, 0xc01d,		0x21, 0
	.dw 0xcdc0, 0xc01d,	0xcdff, 0xc01d,		0x21, 0
	.dw 0xce40, 0xc01d,	0xce7f, 0xc01d,		0x21, 0
	.dw 0xcec0, 0xc01d,	0xceff, 0xc01d,		0x21, 0
	.dw 0xcf40, 0xc01d,	0xcf7f, 0xc01d,		0x21, 0
	.dw 0xcfc0, 0xc01d,	0xcfff, 0xc01d,		0x21, 0
	.dw 0xd040, 0xc01d,	0xd07f, 0xc01d,		0x21, 0
	.dw 0xd0c0, 0xc01d,	0xd0ff, 0xc01d,		0x21, 0
	.dw 0xd140, 0xc01d,	0xd17f, 0xc01d,		0x21, 0
	.dw 0xd1c0, 0xc01d,	0xd1ff, 0xc01d,		0x21, 0
	.dw 0xd240, 0xc01d,	0xd27f, 0xc01d,		0x21, 0
	.dw 0xd2c0, 0xc01d,	0xd2ff, 0xc01d,		0x21, 0
	.dw 0xd340, 0xc01d,	0xd37f, 0xc01d,		0x21, 0
	.dw 0xd3c0, 0xc01d,	0xd3ff, 0xc01d,		0x21, 0
	.dw 0xd440, 0xc01d,	0xd47f, 0xc01d,		0x21, 0
	.dw 0xd4c0, 0xc01d,	0xd4ff, 0xc01d,		0x21, 0
	.dw 0xd540, 0xc01d,	0xd57f, 0xc01d,		0x21, 0
	.dw 0xd5c0, 0xc01d,	0xd5ff, 0xc01d,		0x21, 0
	.dw 0xd640, 0xc01d,	0xd67f, 0xc01d,		0x21, 0
	.dw 0xd6c0, 0xc01d,	0xd6ff, 0xc01d,		0x21, 0
	.dw 0xd740, 0xc01d,	0xd77f, 0xc01d,		0x21, 0
	.dw 0xd7c0, 0xc01d,	0xd7ff, 0xc01d,		0x21, 0
	.dw 0xd840, 0xc01d,	0xd87f, 0xc01d,		0x21, 0
	.dw 0xd8c0, 0xc01d,	0xd8ff, 0xc01d,		0x21, 0
	.dw 0xd940, 0xc01d,	0xd97f, 0xc01d,		0x21, 0
	.dw 0xd9c0, 0xc01d,	0xdfff, 0xc01d,		0x21, 0
	.dw 0xe040, 0xc01d,	0xe07f, 0xc01d,		0x21, 0
	.dw 0xe0c0, 0xc01d,	0xe0ff, 0xc01d,		0x21, 0
	.dw 0xe140, 0xc01d,	0xe17f, 0xc01d,		0x21, 0
	.dw 0xe1c0, 0xc01d,	0xe1ff, 0xc01d,		0x21, 0
	.dw 0xe240, 0xc01d,	0xe27f, 0xc01d,		0x21, 0
	.dw 0xe2c0, 0xc01d,	0xe2ff, 0xc01d,		0x21, 0
	.dw 0xe340, 0xc01d,	0xe37f, 0xc01d,		0x21, 0
	.dw 0xe3c0, 0xc01d,	0xe3ff, 0xc01d,		0x21, 0
	.dw 0xe440, 0xc01d,	0xe47f, 0xc01d,		0x21, 0
	.dw 0xe4c0, 0xc01d,	0xe4ff, 0xc01d,		0x21, 0
	.dw 0xe540, 0xc01d,	0xe57f, 0xc01d,		0x21, 0
	.dw 0xe5c0, 0xc01d,	0xe5ff, 0xc01d,		0x21, 0
	.dw 0xe640, 0xc01d,	0xe67f, 0xc01d,		0x21, 0
	.dw 0xe6c0, 0xc01d,	0xe6ff, 0xc01d,		0x21, 0
	.dw 0xe740, 0xc01d,	0xe77f, 0xc01d,		0x21, 0
	.dw 0xe7c0, 0xc01d,	0xe7ff, 0xc01d,		0x21, 0
	.dw 0xe840, 0xc01d,	0xe87f, 0xc01d,		0x21, 0
	.dw 0xe8c0, 0xc01d,	0xe8ff, 0xc01d,		0x21, 0
	.dw 0xe940, 0xc01d,	0xe97f, 0xc01d,		0x21, 0
	.dw 0xe9c0, 0xc01d,	0xe9ff, 0xc01d,		0x21, 0
	.dw 0xea40, 0xc01d,	0xea7f, 0xc01d,		0x21, 0
	.dw 0xeac0, 0xc01d,	0xeaff, 0xc01d,		0x21, 0
	.dw 0xeb40, 0xc01d,	0xeb7f, 0xc01d,		0x21, 0
	.dw 0xebc0, 0xc01d,	0xebff, 0xc01d,		0x21, 0
	.dw 0xec40, 0xc01d,	0xec7f, 0xc01d,		0x21, 0
	.dw 0xecc0, 0xc01d,	0xecff, 0xc01d,		0x21, 0
	.dw 0xed40, 0xc01d,	0xed7f, 0xc01d,		0x21, 0
	.dw 0xedc0, 0xc01d,	0xedff, 0xc01d,		0x21, 0
	.dw 0xee40, 0xc01d,	0xee7f, 0xc01d,		0x21, 0
	.dw 0xeec0, 0xc01d,	0xeeff, 0xc01d,		0x21, 0
	.dw 0xef40, 0xc01d,	0xef7f, 0xc01d,		0x21, 0
	.dw 0xefc0, 0xc01d,	0xefff, 0xc01d,		0x21, 0
	.dw 0xf040, 0xc01d,	0xf07f, 0xc01d,		0x21, 0
	.dw 0xf0c0, 0xc01d,	0xf0ff, 0xc01d,		0x21, 0
	.dw 0xf140, 0xc01d,	0xf17f, 0xc01d,		0x21, 0
	.dw 0xf1c0, 0xc01d,	0xf1ff, 0xc01d,		0x21, 0
	.dw 0xf240, 0xc01d,	0xf27f, 0xc01d,		0x21, 0
	.dw 0xf2c0, 0xc01d,	0xf2ff, 0xc01d,		0x21, 0
	.dw 0xf340, 0xc01d,	0xf37f, 0xc01d,		0x21, 0
	.dw 0xf3c0, 0xc01d,	0xf3ff, 0xc01d,		0x21, 0
	.dw 0xf440, 0xc01d,	0xf47f, 0xc01d,		0x21, 0
	.dw 0xf4c0, 0xc01d,	0xf4ff, 0xc01d,		0x21, 0
	.dw 0xf540, 0xc01d,	0xf57f, 0xc01d,		0x21, 0
	.dw 0xf5c0, 0xc01d,	0xf5ff, 0xc01d,		0x21, 0
	.dw 0xf640, 0xc01d,	0xf67f, 0xc01d,		0x21, 0
	.dw 0xf6c0, 0xc01d,	0xf6ff, 0xc01d,		0x21, 0
	.dw 0xf740, 0xc01d,	0xf77f, 0xc01d,		0x21, 0
	.dw 0xf7c0, 0xc01d,	0xf7ff, 0xc01d,		0x21, 0
	.dw 0xf840, 0xc01d,	0xf87f, 0xc01d,		0x21, 0
	.dw 0xf8c0, 0xc01d,	0xf8ff, 0xc01d,		0x21, 0
	.dw 0xf940, 0xc01d,	0xf97f, 0xc01d,		0x21, 0
	.dw 0xf9c0, 0xc01d,	0xffff, 0xc01d,		0x21, 0
	.dw 0x0040, 0xc01e,	0x007f, 0xc01e,		0x21, 0
	.dw 0x00c0, 0xc01e,	0x00ff, 0xc01e,		0x21, 0
	.dw 0x0140, 0xc01e,	0x017f, 0xc01e,		0x21, 0
	.dw 0x01c0, 0xc01e,	0x01ff, 0xc01e,		0x21, 0
	.dw 0x0240, 0xc01e,	0x027f, 0xc01e,		0x21, 0
	.dw 0x02c0, 0xc01e,	0x02ff, 0xc01e,		0x21, 0
	.dw 0x0340, 0xc01e,	0x037f, 0xc01e,		0x21, 0
	.dw 0x03c0, 0xc01e,	0x03ff, 0xc01e,		0x21, 0
	.dw 0x0440, 0xc01e,	0x047f, 0xc01e,		0x21, 0
	.dw 0x04c0, 0xc01e,	0x04ff, 0xc01e,		0x21, 0
	.dw 0x0540, 0xc01e,	0x057f, 0xc01e,		0x21, 0
	.dw 0x05c0, 0xc01e,	0x05ff, 0xc01e,		0x21, 0
	.dw 0x0640, 0xc01e,	0x067f, 0xc01e,		0x21, 0
	.dw 0x06c0, 0xc01e,	0x06ff, 0xc01e,		0x21, 0
	.dw 0x0740, 0xc01e,	0x077f, 0xc01e,		0x21, 0
	.dw 0x07c0, 0xc01e,	0x07ff, 0xc01e,		0x21, 0
	.dw 0x0840, 0xc01e,	0x087f, 0xc01e,		0x21, 0
	.dw 0x08c0, 0xc01e,	0x08ff, 0xc01e,		0x21, 0
	.dw 0x0940, 0xc01e,	0x097f, 0xc01e,		0x21, 0
	.dw 0x09c0, 0xc01e,	0x09ff, 0xc01e,		0x21, 0
	.dw 0x0a40, 0xc01e,	0x0a7f, 0xc01e,		0x21, 0
	.dw 0x0ac0, 0xc01e,	0x0aff, 0xc01e,		0x21, 0
	.dw 0x0b40, 0xc01e,	0x0b7f, 0xc01e,		0x21, 0
	.dw 0x0bc0, 0xc01e,	0x0bff, 0xc01e,		0x21, 0
	.dw 0x0c40, 0xc01e,	0x0c7f, 0xc01e,		0x21, 0
	.dw 0x0cc0, 0xc01e,	0x0cff, 0xc01e,		0x21, 0
	.dw 0x0d40, 0xc01e,	0x0d7f, 0xc01e,		0x21, 0
	.dw 0x0dc0, 0xc01e,	0x0dff, 0xc01e,		0x21, 0
	.dw 0x0e40, 0xc01e,	0x0e7f, 0xc01e,		0x21, 0
	.dw 0x0ec0, 0xc01e,	0x0eff, 0xc01e,		0x21, 0
	.dw 0x0f40, 0xc01e,	0x0f7f, 0xc01e,		0x21, 0
	.dw 0x0fc0, 0xc01e,	0x0fff, 0xc01e,		0x21, 0
	.dw 0x1040, 0xc01e,	0x107f, 0xc01e,		0x21, 0
	.dw 0x10c0, 0xc01e,	0x10ff, 0xc01e,		0x21, 0
	.dw 0x1140, 0xc01e,	0x117f, 0xc01e,		0x21, 0
	.dw 0x11c0, 0xc01e,	0x11ff, 0xc01e,		0x21, 0
	.dw 0x1240, 0xc01e,	0x127f, 0xc01e,		0x21, 0
	.dw 0x12c0, 0xc01e,	0x12ff, 0xc01e,		0x21, 0
	.dw 0x1340, 0xc01e,	0x137f, 0xc01e,		0x21, 0
	.dw 0x13c0, 0xc01e,	0x13ff, 0xc01e,		0x21, 0
	.dw 0x1440, 0xc01e,	0x147f, 0xc01e,		0x21, 0
	.dw 0x14c0, 0xc01e,	0x14ff, 0xc01e,		0x21, 0
	.dw 0x1540, 0xc01e,	0x157f, 0xc01e,		0x21, 0
	.dw 0x15c0, 0xc01e,	0x15ff, 0xc01e,		0x21, 0
	.dw 0x1640, 0xc01e,	0x167f, 0xc01e,		0x21, 0
	.dw 0x16c0, 0xc01e,	0x16ff, 0xc01e,		0x21, 0
	.dw 0x1740, 0xc01e,	0x177f, 0xc01e,		0x21, 0
	.dw 0x17c0, 0xc01e,	0x17ff, 0xc01e,		0x21, 0
	.dw 0x1840, 0xc01e,	0x187f, 0xc01e,		0x21, 0
	.dw 0x18c0, 0xc01e,	0x18ff, 0xc01e,		0x21, 0
	.dw 0x1940, 0xc01e,	0x197f, 0xc01e,		0x21, 0
	.dw 0x19c0, 0xc01e,	0x1fff, 0xc01e,		0x21, 0
	.dw 0x2040, 0xc01e,	0x207f, 0xc01e,		0x21, 0
	.dw 0x20c0, 0xc01e,	0x20ff, 0xc01e,		0x21, 0
	.dw 0x2140, 0xc01e,	0x217f, 0xc01e,		0x21, 0
	.dw 0x21c0, 0xc01e,	0x21ff, 0xc01e,		0x21, 0
	.dw 0x2240, 0xc01e,	0x227f, 0xc01e,		0x21, 0
	.dw 0x22c0, 0xc01e,	0x22ff, 0xc01e,		0x21, 0
	.dw 0x2340, 0xc01e,	0x237f, 0xc01e,		0x21, 0
	.dw 0x23c0, 0xc01e,	0x23ff, 0xc01e,		0x21, 0
	.dw 0x2440, 0xc01e,	0x247f, 0xc01e,		0x21, 0
	.dw 0x24c0, 0xc01e,	0x24ff, 0xc01e,		0x21, 0
	.dw 0x2540, 0xc01e,	0x257f, 0xc01e,		0x21, 0
	.dw 0x25c0, 0xc01e,	0x25ff, 0xc01e,		0x21, 0
	.dw 0x2640, 0xc01e,	0x267f, 0xc01e,		0x21, 0
	.dw 0x26c0, 0xc01e,	0x26ff, 0xc01e,		0x21, 0
	.dw 0x2740, 0xc01e,	0x277f, 0xc01e,		0x21, 0
	.dw 0x27c0, 0xc01e,	0x27ff, 0xc01e,		0x21, 0
	.dw 0x2840, 0xc01e,	0x287f, 0xc01e,		0x21, 0
	.dw 0x28c0, 0xc01e,	0x28ff, 0xc01e,		0x21, 0
	.dw 0x2940, 0xc01e,	0x297f, 0xc01e,		0x21, 0
	.dw 0x29c0, 0xc01e,	0x29ff, 0xc01e,		0x21, 0
	.dw 0x2a40, 0xc01e,	0x2a7f, 0xc01e,		0x21, 0
	.dw 0x2ac0, 0xc01e,	0x2aff, 0xc01e,		0x21, 0
	.dw 0x2b40, 0xc01e,	0x2b7f, 0xc01e,		0x21, 0
	.dw 0x2bc0, 0xc01e,	0x2bff, 0xc01e,		0x21, 0
	.dw 0x2c40, 0xc01e,	0x2c7f, 0xc01e,		0x21, 0
	.dw 0x2cc0, 0xc01e,	0x2cff, 0xc01e,		0x21, 0
	.dw 0x2d40, 0xc01e,	0x2d7f, 0xc01e,		0x21, 0
	.dw 0x2dc0, 0xc01e,	0x2dff, 0xc01e,		0x21, 0
	.dw 0x2e40, 0xc01e,	0x2e7f, 0xc01e,		0x21, 0
	.dw 0x2ec0, 0xc01e,	0x2eff, 0xc01e,		0x21, 0
	.dw 0x2f40, 0xc01e,	0x2f7f, 0xc01e,		0x21, 0
	.dw 0x2fc0, 0xc01e,	0x2fff, 0xc01e,		0x21, 0
	.dw 0x3040, 0xc01e,	0x307f, 0xc01e,		0x21, 0
	.dw 0x30c0, 0xc01e,	0x30ff, 0xc01e,		0x21, 0
	.dw 0x3140, 0xc01e,	0x317f, 0xc01e,		0x21, 0
	.dw 0x31c0, 0xc01e,	0x31ff, 0xc01e,		0x21, 0
	.dw 0x3240, 0xc01e,	0x327f, 0xc01e,		0x21, 0
	.dw 0x32c0, 0xc01e,	0x32ff, 0xc01e,		0x21, 0
	.dw 0x3340, 0xc01e,	0x337f, 0xc01e,		0x21, 0
	.dw 0x33c0, 0xc01e,	0x33ff, 0xc01e,		0x21, 0
	.dw 0x3440, 0xc01e,	0x347f, 0xc01e,		0x21, 0
	.dw 0x34c0, 0xc01e,	0x34ff, 0xc01e,		0x21, 0
	.dw 0x3540, 0xc01e,	0x357f, 0xc01e,		0x21, 0
	.dw 0x35c0, 0xc01e,	0x35ff, 0xc01e,		0x21, 0
	.dw 0x3640, 0xc01e,	0x367f, 0xc01e,		0x21, 0
	.dw 0x36c0, 0xc01e,	0x36ff, 0xc01e,		0x21, 0
	.dw 0x3740, 0xc01e,	0x377f, 0xc01e,		0x21, 0
	.dw 0x37c0, 0xc01e,	0x37ff, 0xc01e,		0x21, 0
	.dw 0x3840, 0xc01e,	0x387f, 0xc01e,		0x21, 0
	.dw 0x38c0, 0xc01e,	0x38ff, 0xc01e,		0x21, 0
	.dw 0x3940, 0xc01e,	0x397f, 0xc01e,		0x21, 0
	.dw 0x39c0, 0xc01e,	0x3fff, 0xc01e,		0x21, 0
	.dw 0x4040, 0xc01e,	0x407f, 0xc01e,		0x21, 0
	.dw 0x40c0, 0xc01e,	0x40ff, 0xc01e,		0x21, 0
	.dw 0x4140, 0xc01e,	0x417f, 0xc01e,		0x21, 0
	.dw 0x41c0, 0xc01e,	0x41ff, 0xc01e,		0x21, 0
	.dw 0x4240, 0xc01e,	0x427f, 0xc01e,		0x21, 0
	.dw 0x42c0, 0xc01e,	0x42ff, 0xc01e,		0x21, 0
	.dw 0x4340, 0xc01e,	0x437f, 0xc01e,		0x21, 0
	.dw 0x43c0, 0xc01e,	0x43ff, 0xc01e,		0x21, 0
	.dw 0x4440, 0xc01e,	0x447f, 0xc01e,		0x21, 0
	.dw 0x44c0, 0xc01e,	0x44ff, 0xc01e,		0x21, 0
	.dw 0x4540, 0xc01e,	0x457f, 0xc01e,		0x21, 0
	.dw 0x45c0, 0xc01e,	0x45ff, 0xc01e,		0x21, 0
	.dw 0x4640, 0xc01e,	0x467f, 0xc01e,		0x21, 0
	.dw 0x46c0, 0xc01e,	0x46ff, 0xc01e,		0x21, 0
	.dw 0x4740, 0xc01e,	0x477f, 0xc01e,		0x21, 0
	.dw 0x47c0, 0xc01e,	0x47ff, 0xc01e,		0x21, 0
	.dw 0x4840, 0xc01e,	0x487f, 0xc01e,		0x21, 0
	.dw 0x48c0, 0xc01e,	0x48ff, 0xc01e,		0x21, 0
	.dw 0x4940, 0xc01e,	0x497f, 0xc01e,		0x21, 0
	.dw 0x49c0, 0xc01e,	0x49ff, 0xc01e,		0x21, 0
	.dw 0x4a40, 0xc01e,	0x4a7f, 0xc01e,		0x21, 0
	.dw 0x4ac0, 0xc01e,	0x4aff, 0xc01e,		0x21, 0
	.dw 0x4b40, 0xc01e,	0x4b7f, 0xc01e,		0x21, 0
	.dw 0x4bc0, 0xc01e,	0x4bff, 0xc01e,		0x21, 0
	.dw 0x4c40, 0xc01e,	0x4c7f, 0xc01e,		0x21, 0
	.dw 0x4cc0, 0xc01e,	0x4cff, 0xc01e,		0x21, 0
	.dw 0x4d40, 0xc01e,	0x4d7f, 0xc01e,		0x21, 0
	.dw 0x4dc0, 0xc01e,	0x4dff, 0xc01e,		0x21, 0
	.dw 0x4e40, 0xc01e,	0x4e7f, 0xc01e,		0x21, 0
	.dw 0x4ec0, 0xc01e,	0x4eff, 0xc01e,		0x21, 0
	.dw 0x4f40, 0xc01e,	0x4f7f, 0xc01e,		0x21, 0
	.dw 0x4fc0, 0xc01e,	0x4fff, 0xc01e,		0x21, 0
	.dw 0x5040, 0xc01e,	0x507f, 0xc01e,		0x21, 0
	.dw 0x50c0, 0xc01e,	0x50ff, 0xc01e,		0x21, 0
	.dw 0x5140, 0xc01e,	0x517f, 0xc01e,		0x21, 0
	.dw 0x51c0, 0xc01e,	0x51ff, 0xc01e,		0x21, 0
	.dw 0x5240, 0xc01e,	0x527f, 0xc01e,		0x21, 0
	.dw 0x52c0, 0xc01e,	0x52ff, 0xc01e,		0x21, 0
	.dw 0x5340, 0xc01e,	0x537f, 0xc01e,		0x21, 0
	.dw 0x53c0, 0xc01e,	0x53ff, 0xc01e,		0x21, 0
	.dw 0x5440, 0xc01e,	0x547f, 0xc01e,		0x21, 0
	.dw 0x54c0, 0xc01e,	0x54ff, 0xc01e,		0x21, 0
	.dw 0x5540, 0xc01e,	0x557f, 0xc01e,		0x21, 0
	.dw 0x55c0, 0xc01e,	0x55ff, 0xc01e,		0x21, 0
	.dw 0x5640, 0xc01e,	0x567f, 0xc01e,		0x21, 0
	.dw 0x56c0, 0xc01e,	0x56ff, 0xc01e,		0x21, 0
	.dw 0x5740, 0xc01e,	0x577f, 0xc01e,		0x21, 0
	.dw 0x57c0, 0xc01e,	0x57ff, 0xc01e,		0x21, 0
	.dw 0x5840, 0xc01e,	0x587f, 0xc01e,		0x21, 0
	.dw 0x58c0, 0xc01e,	0x58ff, 0xc01e,		0x21, 0
	.dw 0x5940, 0xc01e,	0x597f, 0xc01e,		0x21, 0
	.dw 0x59c0, 0xc01e,	0x5fff, 0xc01e,		0x21, 0
	.dw 0x6040, 0xc01e,	0x607f, 0xc01e,		0x21, 0
	.dw 0x60c0, 0xc01e,	0x60ff, 0xc01e,		0x21, 0
	.dw 0x6140, 0xc01e,	0x617f, 0xc01e,		0x21, 0
	.dw 0x61c0, 0xc01e,	0x61ff, 0xc01e,		0x21, 0
	.dw 0x6240, 0xc01e,	0x627f, 0xc01e,		0x21, 0
	.dw 0x62c0, 0xc01e,	0x62ff, 0xc01e,		0x21, 0
	.dw 0x6340, 0xc01e,	0x637f, 0xc01e,		0x21, 0
	.dw 0x63c0, 0xc01e,	0x63ff, 0xc01e,		0x21, 0
	.dw 0x6440, 0xc01e,	0x647f, 0xc01e,		0x21, 0
	.dw 0x64c0, 0xc01e,	0x64ff, 0xc01e,		0x21, 0
	.dw 0x6540, 0xc01e,	0x657f, 0xc01e,		0x21, 0
	.dw 0x65c0, 0xc01e,	0x65ff, 0xc01e,		0x21, 0
	.dw 0x6640, 0xc01e,	0x667f, 0xc01e,		0x21, 0
	.dw 0x66c0, 0xc01e,	0x66ff, 0xc01e,		0x21, 0
	.dw 0x6740, 0xc01e,	0x677f, 0xc01e,		0x21, 0
	.dw 0x67c0, 0xc01e,	0x67ff, 0xc01e,		0x21, 0
	.dw 0x6840, 0xc01e,	0x687f, 0xc01e,		0x21, 0
	.dw 0x68c0, 0xc01e,	0x68ff, 0xc01e,		0x21, 0
	.dw 0x6940, 0xc01e,	0x697f, 0xc01e,		0x21, 0
	.dw 0x69c0, 0xc01e,	0x69ff, 0xc01e,		0x21, 0
	.dw 0x6a40, 0xc01e,	0x6a7f, 0xc01e,		0x21, 0
	.dw 0x6ac0, 0xc01e,	0x6aff, 0xc01e,		0x21, 0
	.dw 0x6b40, 0xc01e,	0x6b7f, 0xc01e,		0x21, 0
	.dw 0x6bc0, 0xc01e,	0x6bff, 0xc01e,		0x21, 0
	.dw 0x6c40, 0xc01e,	0x6c7f, 0xc01e,		0x21, 0
	.dw 0x6cc0, 0xc01e,	0x6cff, 0xc01e,		0x21, 0
	.dw 0x6d40, 0xc01e,	0x6d7f, 0xc01e,		0x21, 0
	.dw 0x6dc0, 0xc01e,	0x6dff, 0xc01e,		0x21, 0
	.dw 0x6e40, 0xc01e,	0x6e7f, 0xc01e,		0x21, 0
	.dw 0x6ec0, 0xc01e,	0x6eff, 0xc01e,		0x21, 0
	.dw 0x6f40, 0xc01e,	0x6f7f, 0xc01e,		0x21, 0
	.dw 0x6fc0, 0xc01e,	0x6fff, 0xc01e,		0x21, 0
	.dw 0x7040, 0xc01e,	0x707f, 0xc01e,		0x21, 0
	.dw 0x70c0, 0xc01e,	0x70ff, 0xc01e,		0x21, 0
	.dw 0x7140, 0xc01e,	0x717f, 0xc01e,		0x21, 0
	.dw 0x71c0, 0xc01e,	0x71ff, 0xc01e,		0x21, 0
	.dw 0x7240, 0xc01e,	0x727f, 0xc01e,		0x21, 0
	.dw 0x72c0, 0xc01e,	0x72ff, 0xc01e,		0x21, 0
	.dw 0x7340, 0xc01e,	0x737f, 0xc01e,		0x21, 0
	.dw 0x73c0, 0xc01e,	0x73ff, 0xc01e,		0x21, 0
	.dw 0x7440, 0xc01e,	0x747f, 0xc01e,		0x21, 0
	.dw 0x74c0, 0xc01e,	0x74ff, 0xc01e,		0x21, 0
	.dw 0x7540, 0xc01e,	0x757f, 0xc01e,		0x21, 0
	.dw 0x75c0, 0xc01e,	0x75ff, 0xc01e,		0x21, 0
	.dw 0x7640, 0xc01e,	0x767f, 0xc01e,		0x21, 0
	.dw 0x76c0, 0xc01e,	0x76ff, 0xc01e,		0x21, 0
	.dw 0x7740, 0xc01e,	0x777f, 0xc01e,		0x21, 0
	.dw 0x77c0, 0xc01e,	0x77ff, 0xc01e,		0x21, 0
	.dw 0x7840, 0xc01e,	0x787f, 0xc01e,		0x21, 0
	.dw 0x78c0, 0xc01e,	0x78ff, 0xc01e,		0x21, 0
	.dw 0x7940, 0xc01e,	0x797f, 0xc01e,		0x21, 0
	.dw 0x79c0, 0xc01e,	0x7fff, 0xc01e,		0x21, 0
	.dw 0x8040, 0xc01e,	0x807f, 0xc01e,		0x21, 0
	.dw 0x80c0, 0xc01e,	0x80ff, 0xc01e,		0x21, 0
	.dw 0x8140, 0xc01e,	0x817f, 0xc01e,		0x21, 0
	.dw 0x81c0, 0xc01e,	0x81ff, 0xc01e,		0x21, 0
	.dw 0x8240, 0xc01e,	0x827f, 0xc01e,		0x21, 0
	.dw 0x82c0, 0xc01e,	0x82ff, 0xc01e,		0x21, 0
	.dw 0x8340, 0xc01e,	0x837f, 0xc01e,		0x21, 0
	.dw 0x83c0, 0xc01e,	0x83ff, 0xc01e,		0x21, 0
	.dw 0x8440, 0xc01e,	0x847f, 0xc01e,		0x21, 0
	.dw 0x84c0, 0xc01e,	0x84ff, 0xc01e,		0x21, 0
	.dw 0x8540, 0xc01e,	0x857f, 0xc01e,		0x21, 0
	.dw 0x85c0, 0xc01e,	0x85ff, 0xc01e,		0x21, 0
	.dw 0x8640, 0xc01e,	0x867f, 0xc01e,		0x21, 0
	.dw 0x86c0, 0xc01e,	0x86ff, 0xc01e,		0x21, 0
	.dw 0x8740, 0xc01e,	0x877f, 0xc01e,		0x21, 0
	.dw 0x87c0, 0xc01e,	0x87ff, 0xc01e,		0x21, 0
	.dw 0x8840, 0xc01e,	0x887f, 0xc01e,		0x21, 0
	.dw 0x88c0, 0xc01e,	0x88ff, 0xc01e,		0x21, 0
	.dw 0x8940, 0xc01e,	0x897f, 0xc01e,		0x21, 0
	.dw 0x89c0, 0xc01e,	0x89ff, 0xc01e,		0x21, 0
	.dw 0x8a40, 0xc01e,	0x8a7f, 0xc01e,		0x21, 0
	.dw 0x8ac0, 0xc01e,	0x8aff, 0xc01e,		0x21, 0
	.dw 0x8b40, 0xc01e,	0x8b7f, 0xc01e,		0x21, 0
	.dw 0x8bc0, 0xc01e,	0x8bff, 0xc01e,		0x21, 0
	.dw 0x8c40, 0xc01e,	0x8c7f, 0xc01e,		0x21, 0
	.dw 0x8cc0, 0xc01e,	0x8cff, 0xc01e,		0x21, 0
	.dw 0x8d40, 0xc01e,	0x8d7f, 0xc01e,		0x21, 0
	.dw 0x8dc0, 0xc01e,	0x8dff, 0xc01e,		0x21, 0
	.dw 0x8e40, 0xc01e,	0x8e7f, 0xc01e,		0x21, 0
	.dw 0x8ec0, 0xc01e,	0x8eff, 0xc01e,		0x21, 0
	.dw 0x8f40, 0xc01e,	0x8f7f, 0xc01e,		0x21, 0
	.dw 0x8fc0, 0xc01e,	0x8fff, 0xc01e,		0x21, 0
	.dw 0x9040, 0xc01e,	0x907f, 0xc01e,		0x21, 0
	.dw 0x90c0, 0xc01e,	0x90ff, 0xc01e,		0x21, 0
	.dw 0x9140, 0xc01e,	0x917f, 0xc01e,		0x21, 0
	.dw 0x91c0, 0xc01e,	0x91ff, 0xc01e,		0x21, 0
	.dw 0x9240, 0xc01e,	0x927f, 0xc01e,		0x21, 0
	.dw 0x92c0, 0xc01e,	0x92ff, 0xc01e,		0x21, 0
	.dw 0x9340, 0xc01e,	0x937f, 0xc01e,		0x21, 0
	.dw 0x93c0, 0xc01e,	0x93ff, 0xc01e,		0x21, 0
	.dw 0x9440, 0xc01e,	0x947f, 0xc01e,		0x21, 0
	.dw 0x94c0, 0xc01e,	0x94ff, 0xc01e,		0x21, 0
	.dw 0x9540, 0xc01e,	0x957f, 0xc01e,		0x21, 0
	.dw 0x95c0, 0xc01e,	0x95ff, 0xc01e,		0x21, 0
	.dw 0x9640, 0xc01e,	0x967f, 0xc01e,		0x21, 0
	.dw 0x96c0, 0xc01e,	0x96ff, 0xc01e,		0x21, 0
	.dw 0x9740, 0xc01e,	0x977f, 0xc01e,		0x21, 0
	.dw 0x97c0, 0xc01e,	0x97ff, 0xc01e,		0x21, 0
	.dw 0x9840, 0xc01e,	0x987f, 0xc01e,		0x21, 0
	.dw 0x98c0, 0xc01e,	0x98ff, 0xc01e,		0x21, 0
	.dw 0x9940, 0xc01e,	0x997f, 0xc01e,		0x21, 0
	.dw 0x99c0, 0xc01e,	0x9fff, 0xc01e,		0x21, 0
	.dw 0xa040, 0xc01e,	0xa07f, 0xc01e,		0x21, 0
	.dw 0xa0c0, 0xc01e,	0xa0ff, 0xc01e,		0x21, 0
	.dw 0xa140, 0xc01e,	0xa17f, 0xc01e,		0x21, 0
	.dw 0xa1c0, 0xc01e,	0xa1ff, 0xc01e,		0x21, 0
	.dw 0xa240, 0xc01e,	0xa27f, 0xc01e,		0x21, 0
	.dw 0xa2c0, 0xc01e,	0xa2ff, 0xc01e,		0x21, 0
	.dw 0xa340, 0xc01e,	0xa37f, 0xc01e,		0x21, 0
	.dw 0xa3c0, 0xc01e,	0xa3ff, 0xc01e,		0x21, 0
	.dw 0xa440, 0xc01e,	0xa47f, 0xc01e,		0x21, 0
	.dw 0xa4c0, 0xc01e,	0xa4ff, 0xc01e,		0x21, 0
	.dw 0xa540, 0xc01e,	0xa57f, 0xc01e,		0x21, 0
	.dw 0xa5c0, 0xc01e,	0xa5ff, 0xc01e,		0x21, 0
	.dw 0xa640, 0xc01e,	0xa67f, 0xc01e,		0x21, 0
	.dw 0xa6c0, 0xc01e,	0xa6ff, 0xc01e,		0x21, 0
	.dw 0xa740, 0xc01e,	0xa77f, 0xc01e,		0x21, 0
	.dw 0xa7c0, 0xc01e,	0xa7ff, 0xc01e,		0x21, 0
	.dw 0xa840, 0xc01e,	0xa87f, 0xc01e,		0x21, 0
	.dw 0xa8c0, 0xc01e,	0xa8ff, 0xc01e,		0x21, 0
	.dw 0xa940, 0xc01e,	0xa97f, 0xc01e,		0x21, 0
	.dw 0xa9c0, 0xc01e,	0xa9ff, 0xc01e,		0x21, 0
	.dw 0xaa40, 0xc01e,	0xaa7f, 0xc01e,		0x21, 0
	.dw 0xaac0, 0xc01e,	0xaaff, 0xc01e,		0x21, 0
	.dw 0xab40, 0xc01e,	0xab7f, 0xc01e,		0x21, 0
	.dw 0xabc0, 0xc01e,	0xabff, 0xc01e,		0x21, 0
	.dw 0xac40, 0xc01e,	0xac7f, 0xc01e,		0x21, 0
	.dw 0xacc0, 0xc01e,	0xacff, 0xc01e,		0x21, 0
	.dw 0xad40, 0xc01e,	0xad7f, 0xc01e,		0x21, 0
	.dw 0xadc0, 0xc01e,	0xadff, 0xc01e,		0x21, 0
	.dw 0xae40, 0xc01e,	0xae7f, 0xc01e,		0x21, 0
	.dw 0xaec0, 0xc01e,	0xaeff, 0xc01e,		0x21, 0
	.dw 0xaf40, 0xc01e,	0xaf7f, 0xc01e,		0x21, 0
	.dw 0xafc0, 0xc01e,	0xafff, 0xc01e,		0x21, 0
	.dw 0xb040, 0xc01e,	0xb07f, 0xc01e,		0x21, 0
	.dw 0xb0c0, 0xc01e,	0xb0ff, 0xc01e,		0x21, 0
	.dw 0xb140, 0xc01e,	0xb17f, 0xc01e,		0x21, 0
	.dw 0xb1c0, 0xc01e,	0xb1ff, 0xc01e,		0x21, 0
	.dw 0xb240, 0xc01e,	0xb27f, 0xc01e,		0x21, 0
	.dw 0xb2c0, 0xc01e,	0xb2ff, 0xc01e,		0x21, 0
	.dw 0xb340, 0xc01e,	0xb37f, 0xc01e,		0x21, 0
	.dw 0xb3c0, 0xc01e,	0xb3ff, 0xc01e,		0x21, 0
	.dw 0xb440, 0xc01e,	0xb47f, 0xc01e,		0x21, 0
	.dw 0xb4c0, 0xc01e,	0xb4ff, 0xc01e,		0x21, 0
	.dw 0xb540, 0xc01e,	0xb57f, 0xc01e,		0x21, 0
	.dw 0xb5c0, 0xc01e,	0xb5ff, 0xc01e,		0x21, 0
	.dw 0xb640, 0xc01e,	0xb67f, 0xc01e,		0x21, 0
	.dw 0xb6c0, 0xc01e,	0xb6ff, 0xc01e,		0x21, 0
	.dw 0xb740, 0xc01e,	0xb77f, 0xc01e,		0x21, 0
	.dw 0xb7c0, 0xc01e,	0xb7ff, 0xc01e,		0x21, 0
	.dw 0xb840, 0xc01e,	0xb87f, 0xc01e,		0x21, 0
	.dw 0xb8c0, 0xc01e,	0xb8ff, 0xc01e,		0x21, 0
	.dw 0xb940, 0xc01e,	0xb97f, 0xc01e,		0x21, 0
	.dw 0xb9c0, 0xc01e,	0xbfff, 0xc01e,		0x21, 0
	.dw 0xc040, 0xc01e,	0xc07f, 0xc01e,		0x21, 0
	.dw 0xc0c0, 0xc01e,	0xc0ff, 0xc01e,		0x21, 0
	.dw 0xc140, 0xc01e,	0xc17f, 0xc01e,		0x21, 0
	.dw 0xc1c0, 0xc01e,	0xc1ff, 0xc01e,		0x21, 0
	.dw 0xc240, 0xc01e,	0xc27f, 0xc01e,		0x21, 0
	.dw 0xc2c0, 0xc01e,	0xc2ff, 0xc01e,		0x21, 0
	.dw 0xc340, 0xc01e,	0xc37f, 0xc01e,		0x21, 0
	.dw 0xc3c0, 0xc01e,	0xc3ff, 0xc01e,		0x21, 0
	.dw 0xc440, 0xc01e,	0xc47f, 0xc01e,		0x21, 0
	.dw 0xc4c0, 0xc01e,	0xc4ff, 0xc01e,		0x21, 0
	.dw 0xc540, 0xc01e,	0xc57f, 0xc01e,		0x21, 0
	.dw 0xc5c0, 0xc01e,	0xc5ff, 0xc01e,		0x21, 0
	.dw 0xc640, 0xc01e,	0xc67f, 0xc01e,		0x21, 0
	.dw 0xc6c0, 0xc01e,	0xc6ff, 0xc01e,		0x21, 0
	.dw 0xc740, 0xc01e,	0xc77f, 0xc01e,		0x21, 0
	.dw 0xc7c0, 0xc01e,	0xc7ff, 0xc01e,		0x21, 0
	.dw 0xc840, 0xc01e,	0xc87f, 0xc01e,		0x21, 0
	.dw 0xc8c0, 0xc01e,	0xc8ff, 0xc01e,		0x21, 0
	.dw 0xc940, 0xc01e,	0xc97f, 0xc01e,		0x21, 0
	.dw 0xc9c0, 0xc01e,	0xc9ff, 0xc01e,		0x21, 0
	.dw 0xca40, 0xc01e,	0xca7f, 0xc01e,		0x21, 0
	.dw 0xcac0, 0xc01e,	0xcaff, 0xc01e,		0x21, 0
	.dw 0xcb40, 0xc01e,	0xcb7f, 0xc01e,		0x21, 0
	.dw 0xcbc0, 0xc01e,	0xcbff, 0xc01e,		0x21, 0
	.dw 0xcc40, 0xc01e,	0xcc7f, 0xc01e,		0x21, 0
	.dw 0xccc0, 0xc01e,	0xccff, 0xc01e,		0x21, 0
	.dw 0xcd40, 0xc01e,	0xcd7f, 0xc01e,		0x21, 0
	.dw 0xcdc0, 0xc01e,	0xcdff, 0xc01e,		0x21, 0
	.dw 0xce40, 0xc01e,	0xce7f, 0xc01e,		0x21, 0
	.dw 0xcec0, 0xc01e,	0xceff, 0xc01e,		0x21, 0
	.dw 0xcf40, 0xc01e,	0xcf7f, 0xc01e,		0x21, 0
	.dw 0xcfc0, 0xc01e,	0xcfff, 0xc01e,		0x21, 0
	.dw 0xd040, 0xc01e,	0xd07f, 0xc01e,		0x21, 0
	.dw 0xd0c0, 0xc01e,	0xd0ff, 0xc01e,		0x21, 0
	.dw 0xd140, 0xc01e,	0xd17f, 0xc01e,		0x21, 0
	.dw 0xd1c0, 0xc01e,	0xd1ff, 0xc01e,		0x21, 0
	.dw 0xd240, 0xc01e,	0xd27f, 0xc01e,		0x21, 0
	.dw 0xd2c0, 0xc01e,	0xd2ff, 0xc01e,		0x21, 0
	.dw 0xd340, 0xc01e,	0xd37f, 0xc01e,		0x21, 0
	.dw 0xd3c0, 0xc01e,	0xd3ff, 0xc01e,		0x21, 0
	.dw 0xd440, 0xc01e,	0xd47f, 0xc01e,		0x21, 0
	.dw 0xd4c0, 0xc01e,	0xd4ff, 0xc01e,		0x21, 0
	.dw 0xd540, 0xc01e,	0xd57f, 0xc01e,		0x21, 0
	.dw 0xd5c0, 0xc01e,	0xd5ff, 0xc01e,		0x21, 0
	.dw 0xd640, 0xc01e,	0xd67f, 0xc01e,		0x21, 0
	.dw 0xd6c0, 0xc01e,	0xd6ff, 0xc01e,		0x21, 0
	.dw 0xd740, 0xc01e,	0xd77f, 0xc01e,		0x21, 0
	.dw 0xd7c0, 0xc01e,	0xd7ff, 0xc01e,		0x21, 0
	.dw 0xd840, 0xc01e,	0xd87f, 0xc01e,		0x21, 0
	.dw 0xd8c0, 0xc01e,	0xd8ff, 0xc01e,		0x21, 0
	.dw 0xd940, 0xc01e,	0xd97f, 0xc01e,		0x21, 0
	.dw 0xd9c0, 0xc01e,	0xdfff, 0xc01e,		0x21, 0
	.dw 0xe040, 0xc01e,	0xe07f, 0xc01e,		0x21, 0
	.dw 0xe0c0, 0xc01e,	0xe0ff, 0xc01e,		0x21, 0
	.dw 0xe140, 0xc01e,	0xe17f, 0xc01e,		0x21, 0
	.dw 0xe1c0, 0xc01e,	0xe1ff, 0xc01e,		0x21, 0
	.dw 0xe240, 0xc01e,	0xe27f, 0xc01e,		0x21, 0
	.dw 0xe2c0, 0xc01e,	0xe2ff, 0xc01e,		0x21, 0
	.dw 0xe340, 0xc01e,	0xe37f, 0xc01e,		0x21, 0
	.dw 0xe3c0, 0xc01e,	0xe3ff, 0xc01e,		0x21, 0
	.dw 0xe440, 0xc01e,	0xe47f, 0xc01e,		0x21, 0
	.dw 0xe4c0, 0xc01e,	0xe4ff, 0xc01e,		0x21, 0
	.dw 0xe540, 0xc01e,	0xe57f, 0xc01e,		0x21, 0
	.dw 0xe5c0, 0xc01e,	0xe5ff, 0xc01e,		0x21, 0
	.dw 0xe640, 0xc01e,	0xe67f, 0xc01e,		0x21, 0
	.dw 0xe6c0, 0xc01e,	0xe6ff, 0xc01e,		0x21, 0
	.dw 0xe740, 0xc01e,	0xe77f, 0xc01e,		0x21, 0
	.dw 0xe7c0, 0xc01e,	0xe7ff, 0xc01e,		0x21, 0
	.dw 0xe840, 0xc01e,	0xe87f, 0xc01e,		0x21, 0
	.dw 0xe8c0, 0xc01e,	0xe8ff, 0xc01e,		0x21, 0
	.dw 0xe940, 0xc01e,	0xe97f, 0xc01e,		0x21, 0
	.dw 0xe9c0, 0xc01e,	0xe9ff, 0xc01e,		0x21, 0
	.dw 0xea40, 0xc01e,	0xea7f, 0xc01e,		0x21, 0
	.dw 0xeac0, 0xc01e,	0xeaff, 0xc01e,		0x21, 0
	.dw 0xeb40, 0xc01e,	0xeb7f, 0xc01e,		0x21, 0
	.dw 0xebc0, 0xc01e,	0xebff, 0xc01e,		0x21, 0
	.dw 0xec40, 0xc01e,	0xec7f, 0xc01e,		0x21, 0
	.dw 0xecc0, 0xc01e,	0xecff, 0xc01e,		0x21, 0
	.dw 0xed40, 0xc01e,	0xed7f, 0xc01e,		0x21, 0
	.dw 0xedc0, 0xc01e,	0xedff, 0xc01e,		0x21, 0
	.dw 0xee40, 0xc01e,	0xee7f, 0xc01e,		0x21, 0
	.dw 0xeec0, 0xc01e,	0xeeff, 0xc01e,		0x21, 0
	.dw 0xef40, 0xc01e,	0xef7f, 0xc01e,		0x21, 0
	.dw 0xefc0, 0xc01e,	0xefff, 0xc01e,		0x21, 0
	.dw 0xf040, 0xc01e,	0xf07f, 0xc01e,		0x21, 0
	.dw 0xf0c0, 0xc01e,	0xf0ff, 0xc01e,		0x21, 0
	.dw 0xf140, 0xc01e,	0xf17f, 0xc01e,		0x21, 0
	.dw 0xf1c0, 0xc01e,	0xf1ff, 0xc01e,		0x21, 0
	.dw 0xf240, 0xc01e,	0xf27f, 0xc01e,		0x21, 0
	.dw 0xf2c0, 0xc01e,	0xf2ff, 0xc01e,		0x21, 0
	.dw 0xf340, 0xc01e,	0xf37f, 0xc01e,		0x21, 0
	.dw 0xf3c0, 0xc01e,	0xf3ff, 0xc01e,		0x21, 0
	.dw 0xf440, 0xc01e,	0xf47f, 0xc01e,		0x21, 0
	.dw 0xf4c0, 0xc01e,	0xf4ff, 0xc01e,		0x21, 0
	.dw 0xf540, 0xc01e,	0xf57f, 0xc01e,		0x21, 0
	.dw 0xf5c0, 0xc01e,	0xf5ff, 0xc01e,		0x21, 0
	.dw 0xf640, 0xc01e,	0xf67f, 0xc01e,		0x21, 0
	.dw 0xf6c0, 0xc01e,	0xf6ff, 0xc01e,		0x21, 0
	.dw 0xf740, 0xc01e,	0xf77f, 0xc01e,		0x21, 0
	.dw 0xf7c0, 0xc01e,	0xf7ff, 0xc01e,		0x21, 0
	.dw 0xf840, 0xc01e,	0xf87f, 0xc01e,		0x21, 0
	.dw 0xf8c0, 0xc01e,	0xf8ff, 0xc01e,		0x21, 0
	.dw 0xf940, 0xc01e,	0xf97f, 0xc01e,		0x21, 0
	.dw 0xf9c0, 0xc01e,	0xffff, 0xc01e,		0x21, 0
	.dw 0x0040, 0xc01f,	0x007f, 0xc01f,		0x21, 0
	.dw 0x00c0, 0xc01f,	0x00ff, 0xc01f,		0x21, 0
	.dw 0x0140, 0xc01f,	0x017f, 0xc01f,		0x21, 0
	.dw 0x01c0, 0xc01f,	0x01ff, 0xc01f,		0x21, 0
	.dw 0x0240, 0xc01f,	0x027f, 0xc01f,		0x21, 0
	.dw 0x02c0, 0xc01f,	0x02ff, 0xc01f,		0x21, 0
	.dw 0x0340, 0xc01f,	0x037f, 0xc01f,		0x21, 0
	.dw 0x03c0, 0xc01f,	0x03ff, 0xc01f,		0x21, 0
	.dw 0x0440, 0xc01f,	0x047f, 0xc01f,		0x21, 0
	.dw 0x04c0, 0xc01f,	0x04ff, 0xc01f,		0x21, 0
	.dw 0x0540, 0xc01f,	0x057f, 0xc01f,		0x21, 0
	.dw 0x05c0, 0xc01f,	0x05ff, 0xc01f,		0x21, 0
	.dw 0x0640, 0xc01f,	0x067f, 0xc01f,		0x21, 0
	.dw 0x06c0, 0xc01f,	0x06ff, 0xc01f,		0x21, 0
	.dw 0x0740, 0xc01f,	0x077f, 0xc01f,		0x21, 0
	.dw 0x07c0, 0xc01f,	0x07ff, 0xc01f,		0x21, 0
	.dw 0x0840, 0xc01f,	0x087f, 0xc01f,		0x21, 0
	.dw 0x08c0, 0xc01f,	0x08ff, 0xc01f,		0x21, 0
	.dw 0x0940, 0xc01f,	0x097f, 0xc01f,		0x21, 0
	.dw 0x09c0, 0xc01f,	0x09ff, 0xc01f,		0x21, 0
	.dw 0x0a40, 0xc01f,	0x0a7f, 0xc01f,		0x21, 0
	.dw 0x0ac0, 0xc01f,	0x0aff, 0xc01f,		0x21, 0
	.dw 0x0b40, 0xc01f,	0x0b7f, 0xc01f,		0x21, 0
	.dw 0x0bc0, 0xc01f,	0x0bff, 0xc01f,		0x21, 0
	.dw 0x0c40, 0xc01f,	0x0c7f, 0xc01f,		0x21, 0
	.dw 0x0cc0, 0xc01f,	0x0cff, 0xc01f,		0x21, 0
	.dw 0x0d40, 0xc01f,	0x0d7f, 0xc01f,		0x21, 0
	.dw 0x0dc0, 0xc01f,	0x0dff, 0xc01f,		0x21, 0
	.dw 0x0e40, 0xc01f,	0x0e7f, 0xc01f,		0x21, 0
	.dw 0x0ec0, 0xc01f,	0x0eff, 0xc01f,		0x21, 0
	.dw 0x0f40, 0xc01f,	0x0f7f, 0xc01f,		0x21, 0
	.dw 0x0fc0, 0xc01f,	0x0fff, 0xc01f,		0x21, 0
	.dw 0x1040, 0xc01f,	0x107f, 0xc01f,		0x21, 0
	.dw 0x10c0, 0xc01f,	0x10ff, 0xc01f,		0x21, 0
	.dw 0x1140, 0xc01f,	0x117f, 0xc01f,		0x21, 0
	.dw 0x11c0, 0xc01f,	0x11ff, 0xc01f,		0x21, 0
	.dw 0x1240, 0xc01f,	0x127f, 0xc01f,		0x21, 0
	.dw 0x12c0, 0xc01f,	0x12ff, 0xc01f,		0x21, 0
	.dw 0x1340, 0xc01f,	0x137f, 0xc01f,		0x21, 0
	.dw 0x13c0, 0xc01f,	0x13ff, 0xc01f,		0x21, 0
	.dw 0x1440, 0xc01f,	0x147f, 0xc01f,		0x21, 0
	.dw 0x14c0, 0xc01f,	0x14ff, 0xc01f,		0x21, 0
	.dw 0x1540, 0xc01f,	0x157f, 0xc01f,		0x21, 0
	.dw 0x15c0, 0xc01f,	0x15ff, 0xc01f,		0x21, 0
	.dw 0x1640, 0xc01f,	0x167f, 0xc01f,		0x21, 0
	.dw 0x16c0, 0xc01f,	0x16ff, 0xc01f,		0x21, 0
	.dw 0x1740, 0xc01f,	0x177f, 0xc01f,		0x21, 0
	.dw 0x17c0, 0xc01f,	0x17ff, 0xc01f,		0x21, 0
	.dw 0x1840, 0xc01f,	0x187f, 0xc01f,		0x21, 0
	.dw 0x18c0, 0xc01f,	0x18ff, 0xc01f,		0x21, 0
	.dw 0x1940, 0xc01f,	0x197f, 0xc01f,		0x21, 0
	.dw 0x19c0, 0xc01f,	0x1fff, 0xc01f,		0x21, 0
	.dw 0x2040, 0xc01f,	0x207f, 0xc01f,		0x21, 0
	.dw 0x20c0, 0xc01f,	0x20ff, 0xc01f,		0x21, 0
	.dw 0x2140, 0xc01f,	0x217f, 0xc01f,		0x21, 0
	.dw 0x21c0, 0xc01f,	0x21ff, 0xc01f,		0x21, 0
	.dw 0x2240, 0xc01f,	0x227f, 0xc01f,		0x21, 0
	.dw 0x22c0, 0xc01f,	0x22ff, 0xc01f,		0x21, 0
	.dw 0x2340, 0xc01f,	0x237f, 0xc01f,		0x21, 0
	.dw 0x23c0, 0xc01f,	0x23ff, 0xc01f,		0x21, 0
	.dw 0x2440, 0xc01f,	0x247f, 0xc01f,		0x21, 0
	.dw 0x24c0, 0xc01f,	0x24ff, 0xc01f,		0x21, 0
	.dw 0x2540, 0xc01f,	0x257f, 0xc01f,		0x21, 0
	.dw 0x25c0, 0xc01f,	0x25ff, 0xc01f,		0x21, 0
	.dw 0x2640, 0xc01f,	0x267f, 0xc01f,		0x21, 0
	.dw 0x26c0, 0xc01f,	0x26ff, 0xc01f,		0x21, 0
	.dw 0x2740, 0xc01f,	0x277f, 0xc01f,		0x21, 0
	.dw 0x27c0, 0xc01f,	0x27ff, 0xc01f,		0x21, 0
	.dw 0x2840, 0xc01f,	0x287f, 0xc01f,		0x21, 0
	.dw 0x28c0, 0xc01f,	0x28ff, 0xc01f,		0x21, 0
	.dw 0x2940, 0xc01f,	0x297f, 0xc01f,		0x21, 0
	.dw 0x29c0, 0xc01f,	0x29ff, 0xc01f,		0x21, 0
	.dw 0x2a40, 0xc01f,	0x2a7f, 0xc01f,		0x21, 0
	.dw 0x2ac0, 0xc01f,	0x2aff, 0xc01f,		0x21, 0
	.dw 0x2b40, 0xc01f,	0x2b7f, 0xc01f,		0x21, 0
	.dw 0x2bc0, 0xc01f,	0x2bff, 0xc01f,		0x21, 0
	.dw 0x2c40, 0xc01f,	0x2c7f, 0xc01f,		0x21, 0
	.dw 0x2cc0, 0xc01f,	0x2cff, 0xc01f,		0x21, 0
	.dw 0x2d40, 0xc01f,	0x2d7f, 0xc01f,		0x21, 0
	.dw 0x2dc0, 0xc01f,	0x2dff, 0xc01f,		0x21, 0
	.dw 0x2e40, 0xc01f,	0x2e7f, 0xc01f,		0x21, 0
	.dw 0x2ec0, 0xc01f,	0x2eff, 0xc01f,		0x21, 0
	.dw 0x2f40, 0xc01f,	0x2f7f, 0xc01f,		0x21, 0
	.dw 0x2fc0, 0xc01f,	0x2fff, 0xc01f,		0x21, 0
	.dw 0x3040, 0xc01f,	0x307f, 0xc01f,		0x21, 0
	.dw 0x30c0, 0xc01f,	0x30ff, 0xc01f,		0x21, 0
	.dw 0x3140, 0xc01f,	0x317f, 0xc01f,		0x21, 0
	.dw 0x31c0, 0xc01f,	0x31ff, 0xc01f,		0x21, 0
	.dw 0x3240, 0xc01f,	0x327f, 0xc01f,		0x21, 0
	.dw 0x32c0, 0xc01f,	0x32ff, 0xc01f,		0x21, 0
	.dw 0x3340, 0xc01f,	0x337f, 0xc01f,		0x21, 0
	.dw 0x33c0, 0xc01f,	0x33ff, 0xc01f,		0x21, 0
	.dw 0x3440, 0xc01f,	0x347f, 0xc01f,		0x21, 0
	.dw 0x34c0, 0xc01f,	0x34ff, 0xc01f,		0x21, 0
	.dw 0x3540, 0xc01f,	0x357f, 0xc01f,		0x21, 0
	.dw 0x35c0, 0xc01f,	0x35ff, 0xc01f,		0x21, 0
	.dw 0x3640, 0xc01f,	0x367f, 0xc01f,		0x21, 0
	.dw 0x36c0, 0xc01f,	0x36ff, 0xc01f,		0x21, 0
	.dw 0x3740, 0xc01f,	0x377f, 0xc01f,		0x21, 0
	.dw 0x37c0, 0xc01f,	0x37ff, 0xc01f,		0x21, 0
	.dw 0x3840, 0xc01f,	0x387f, 0xc01f,		0x21, 0
	.dw 0x38c0, 0xc01f,	0x38ff, 0xc01f,		0x21, 0
	.dw 0x3940, 0xc01f,	0x397f, 0xc01f,		0x21, 0
	.dw 0x39c0, 0xc01f,	0x1fff, 0xc020,		0x21, 0
	.dw 0x3a00, 0xc020,	0x5fff, 0xc020,		0x21, 0
	.dw 0x7a00, 0xc020,	0x9fff, 0xc020,		0x21, 0
	.dw 0xba00, 0xc020,	0xdfff, 0xc020,		0x21, 0
	.dw 0xfa00, 0xc020,	0x1fff, 0xc021,		0x21, 0
	.dw 0x3a00, 0xc021,	0x5fff, 0xc021,		0x21, 0
	.dw 0x7a00, 0xc021,	0x9fff, 0xc021,		0x21, 0
	.dw 0xba00, 0xc021,	0xdfff, 0xc021,		0x21, 0
	.dw 0xfa00, 0xc021,	0x1fff, 0xc022,		0x21, 0
	.dw 0x3a00, 0xc022,	0x5fff, 0xc022,		0x21, 0
	.dw 0x7a00, 0xc022,	0x9fff, 0xc022,		0x21, 0
	.dw 0xba00, 0xc022,	0xdfff, 0xc022,		0x21, 0
	.dw 0xfa00, 0xc022,	0x1fff, 0xc023,		0x21, 0
	.dw 0x3a00, 0xc023,	0xffff, 0xc023,		0x21, 0
	.dw 0x1a00, 0xc024,	0x1fff, 0xc024,		0x21, 0
	.dw 0x3a00, 0xc024,	0x3fff, 0xc024,		0x21, 0
	.dw 0x5a00, 0xc024,	0x5fff, 0xc024,		0x21, 0
	.dw 0x7a00, 0xc024,	0x7fff, 0xc024,		0x21, 0
	.dw 0x9a00, 0xc024,	0x9fff, 0xc024,		0x21, 0
	.dw 0xba00, 0xc024,	0xbfff, 0xc024,		0x21, 0
	.dw 0xda00, 0xc024,	0xdfff, 0xc024,		0x21, 0
	.dw 0xfa00, 0xc024,	0xffff, 0xc024,		0x21, 0
	.dw 0x1a00, 0xc025,	0x1fff, 0xc025,		0x21, 0
	.dw 0x3a00, 0xc025,	0x3fff, 0xc025,		0x21, 0
	.dw 0x5a00, 0xc025,	0x5fff, 0xc025,		0x21, 0
	.dw 0x7a00, 0xc025,	0x7fff, 0xc025,		0x21, 0
	.dw 0x9a00, 0xc025,	0x9fff, 0xc025,		0x21, 0
	.dw 0xba00, 0xc025,	0xbfff, 0xc025,		0x21, 0
	.dw 0xda00, 0xc025,	0xdfff, 0xc025,		0x21, 0
	.dw 0xfa00, 0xc025,	0xffff, 0xc025,		0x21, 0
	.dw 0x1a00, 0xc026,	0x1fff, 0xc026,		0x21, 0
	.dw 0x3a00, 0xc026,	0x3fff, 0xc026,		0x21, 0
	.dw 0x5a00, 0xc026,	0x5fff, 0xc026,		0x21, 0
	.dw 0x7a00, 0xc026,	0x7fff, 0xc026,		0x21, 0
	.dw 0x9a00, 0xc026,	0x9fff, 0xc026,		0x21, 0
	.dw 0xba00, 0xc026,	0xbfff, 0xc026,		0x21, 0
	.dw 0xda00, 0xc026,	0xdfff, 0xc026,		0x21, 0
	.dw 0xfa00, 0xc026,	0xffff, 0xc026,		0x21, 0
	.dw 0x1a00, 0xc027,	0x1fff, 0xc027,		0x21, 0
	.dw 0x3a00, 0xc027,	0x1fff, 0xc028,		0x21, 0
	.dw 0x2040, 0xc028,	0x207f, 0xc028,		0x21, 0
	.dw 0x20c0, 0xc028,	0x20ff, 0xc028,		0x21, 0
	.dw 0x2140, 0xc028,	0x217f, 0xc028,		0x21, 0
	.dw 0x21c0, 0xc028,	0x21ff, 0xc028,		0x21, 0
	.dw 0x2240, 0xc028,	0x227f, 0xc028,		0x21, 0
	.dw 0x22c0, 0xc028,	0x22ff, 0xc028,		0x21, 0
	.dw 0x2340, 0xc028,	0x237f, 0xc028,		0x21, 0
	.dw 0x23c0, 0xc028,	0x23ff, 0xc028,		0x21, 0
	.dw 0x2440, 0xc028,	0x247f, 0xc028,		0x21, 0
	.dw 0x24c0, 0xc028,	0x24ff, 0xc028,		0x21, 0
	.dw 0x2540, 0xc028,	0x257f, 0xc028,		0x21, 0
	.dw 0x25c0, 0xc028,	0x25ff, 0xc028,		0x21, 0
	.dw 0x2640, 0xc028,	0x267f, 0xc028,		0x21, 0
	.dw 0x26c0, 0xc028,	0x26ff, 0xc028,		0x21, 0
	.dw 0x2740, 0xc028,	0x277f, 0xc028,		0x21, 0
	.dw 0x27c0, 0xc028,	0x27ff, 0xc028,		0x21, 0
	.dw 0x2840, 0xc028,	0x287f, 0xc028,		0x21, 0
	.dw 0x28c0, 0xc028,	0x28ff, 0xc028,		0x21, 0
	.dw 0x2940, 0xc028,	0x297f, 0xc028,		0x21, 0
	.dw 0x29c0, 0xc028,	0x29ff, 0xc028,		0x21, 0
	.dw 0x2a40, 0xc028,	0x2a7f, 0xc028,		0x21, 0
	.dw 0x2ac0, 0xc028,	0x2aff, 0xc028,		0x21, 0
	.dw 0x2b40, 0xc028,	0x2b7f, 0xc028,		0x21, 0
	.dw 0x2bc0, 0xc028,	0x2bff, 0xc028,		0x21, 0
	.dw 0x2c40, 0xc028,	0x2c7f, 0xc028,		0x21, 0
	.dw 0x2cc0, 0xc028,	0x2cff, 0xc028,		0x21, 0
	.dw 0x2d40, 0xc028,	0x2d7f, 0xc028,		0x21, 0
	.dw 0x2dc0, 0xc028,	0x2dff, 0xc028,		0x21, 0
	.dw 0x2e40, 0xc028,	0x2e7f, 0xc028,		0x21, 0
	.dw 0x2ec0, 0xc028,	0x2eff, 0xc028,		0x21, 0
	.dw 0x2f40, 0xc028,	0x2f7f, 0xc028,		0x21, 0
	.dw 0x2fc0, 0xc028,	0x2fff, 0xc028,		0x21, 0
	.dw 0x3040, 0xc028,	0x307f, 0xc028,		0x21, 0
	.dw 0x30c0, 0xc028,	0x30ff, 0xc028,		0x21, 0
	.dw 0x3140, 0xc028,	0x317f, 0xc028,		0x21, 0
	.dw 0x31c0, 0xc028,	0x31ff, 0xc028,		0x21, 0
	.dw 0x3240, 0xc028,	0x327f, 0xc028,		0x21, 0
	.dw 0x32c0, 0xc028,	0x32ff, 0xc028,		0x21, 0
	.dw 0x3340, 0xc028,	0x337f, 0xc028,		0x21, 0
	.dw 0x33c0, 0xc028,	0x33ff, 0xc028,		0x21, 0
	.dw 0x3440, 0xc028,	0x347f, 0xc028,		0x21, 0
	.dw 0x34c0, 0xc028,	0x34ff, 0xc028,		0x21, 0
	.dw 0x3540, 0xc028,	0x357f, 0xc028,		0x21, 0
	.dw 0x35c0, 0xc028,	0x35ff, 0xc028,		0x21, 0
	.dw 0x3640, 0xc028,	0x367f, 0xc028,		0x21, 0
	.dw 0x36c0, 0xc028,	0x36ff, 0xc028,		0x21, 0
	.dw 0x3740, 0xc028,	0x377f, 0xc028,		0x21, 0
	.dw 0x37c0, 0xc028,	0x37ff, 0xc028,		0x21, 0
	.dw 0x3840, 0xc028,	0x387f, 0xc028,		0x21, 0
	.dw 0x38c0, 0xc028,	0x38ff, 0xc028,		0x21, 0
	.dw 0x3940, 0xc028,	0x397f, 0xc028,		0x21, 0
	.dw 0x39c0, 0xc028,	0x5fff, 0xc028,		0x21, 0
	.dw 0x6040, 0xc028,	0x607f, 0xc028,		0x21, 0
	.dw 0x60c0, 0xc028,	0x60ff, 0xc028,		0x21, 0
	.dw 0x6140, 0xc028,	0x617f, 0xc028,		0x21, 0
	.dw 0x61c0, 0xc028,	0x61ff, 0xc028,		0x21, 0
	.dw 0x6240, 0xc028,	0x627f, 0xc028,		0x21, 0
	.dw 0x62c0, 0xc028,	0x62ff, 0xc028,		0x21, 0
	.dw 0x6340, 0xc028,	0x637f, 0xc028,		0x21, 0
	.dw 0x63c0, 0xc028,	0x63ff, 0xc028,		0x21, 0
	.dw 0x6440, 0xc028,	0x647f, 0xc028,		0x21, 0
	.dw 0x64c0, 0xc028,	0x64ff, 0xc028,		0x21, 0
	.dw 0x6540, 0xc028,	0x657f, 0xc028,		0x21, 0
	.dw 0x65c0, 0xc028,	0x65ff, 0xc028,		0x21, 0
	.dw 0x6640, 0xc028,	0x667f, 0xc028,		0x21, 0
	.dw 0x66c0, 0xc028,	0x66ff, 0xc028,		0x21, 0
	.dw 0x6740, 0xc028,	0x677f, 0xc028,		0x21, 0
	.dw 0x67c0, 0xc028,	0x67ff, 0xc028,		0x21, 0
	.dw 0x6840, 0xc028,	0x687f, 0xc028,		0x21, 0
	.dw 0x68c0, 0xc028,	0x68ff, 0xc028,		0x21, 0
	.dw 0x6940, 0xc028,	0x697f, 0xc028,		0x21, 0
	.dw 0x69c0, 0xc028,	0x69ff, 0xc028,		0x21, 0
	.dw 0x6a40, 0xc028,	0x6a7f, 0xc028,		0x21, 0
	.dw 0x6ac0, 0xc028,	0x6aff, 0xc028,		0x21, 0
	.dw 0x6b40, 0xc028,	0x6b7f, 0xc028,		0x21, 0
	.dw 0x6bc0, 0xc028,	0x6bff, 0xc028,		0x21, 0
	.dw 0x6c40, 0xc028,	0x6c7f, 0xc028,		0x21, 0
	.dw 0x6cc0, 0xc028,	0x6cff, 0xc028,		0x21, 0
	.dw 0x6d40, 0xc028,	0x6d7f, 0xc028,		0x21, 0
	.dw 0x6dc0, 0xc028,	0x6dff, 0xc028,		0x21, 0
	.dw 0x6e40, 0xc028,	0x6e7f, 0xc028,		0x21, 0
	.dw 0x6ec0, 0xc028,	0x6eff, 0xc028,		0x21, 0
	.dw 0x6f40, 0xc028,	0x6f7f, 0xc028,		0x21, 0
	.dw 0x6fc0, 0xc028,	0x6fff, 0xc028,		0x21, 0
	.dw 0x7040, 0xc028,	0x707f, 0xc028,		0x21, 0
	.dw 0x70c0, 0xc028,	0x70ff, 0xc028,		0x21, 0
	.dw 0x7140, 0xc028,	0x717f, 0xc028,		0x21, 0
	.dw 0x71c0, 0xc028,	0x71ff, 0xc028,		0x21, 0
	.dw 0x7240, 0xc028,	0x727f, 0xc028,		0x21, 0
	.dw 0x72c0, 0xc028,	0x72ff, 0xc028,		0x21, 0
	.dw 0x7340, 0xc028,	0x737f, 0xc028,		0x21, 0
	.dw 0x73c0, 0xc028,	0x73ff, 0xc028,		0x21, 0
	.dw 0x7440, 0xc028,	0x747f, 0xc028,		0x21, 0
	.dw 0x74c0, 0xc028,	0x74ff, 0xc028,		0x21, 0
	.dw 0x7540, 0xc028,	0x757f, 0xc028,		0x21, 0
	.dw 0x75c0, 0xc028,	0x75ff, 0xc028,		0x21, 0
	.dw 0x7640, 0xc028,	0x767f, 0xc028,		0x21, 0
	.dw 0x76c0, 0xc028,	0x76ff, 0xc028,		0x21, 0
	.dw 0x7740, 0xc028,	0x777f, 0xc028,		0x21, 0
	.dw 0x77c0, 0xc028,	0x77ff, 0xc028,		0x21, 0
	.dw 0x7840, 0xc028,	0x787f, 0xc028,		0x21, 0
	.dw 0x78c0, 0xc028,	0x78ff, 0xc028,		0x21, 0
	.dw 0x7940, 0xc028,	0x797f, 0xc028,		0x21, 0
	.dw 0x79c0, 0xc028,	0x9fff, 0xc028,		0x21, 0
	.dw 0xa040, 0xc028,	0xa07f, 0xc028,		0x21, 0
	.dw 0xa0c0, 0xc028,	0xa0ff, 0xc028,		0x21, 0
	.dw 0xa140, 0xc028,	0xa17f, 0xc028,		0x21, 0
	.dw 0xa1c0, 0xc028,	0xa1ff, 0xc028,		0x21, 0
	.dw 0xa240, 0xc028,	0xa27f, 0xc028,		0x21, 0
	.dw 0xa2c0, 0xc028,	0xa2ff, 0xc028,		0x21, 0
	.dw 0xa340, 0xc028,	0xa37f, 0xc028,		0x21, 0
	.dw 0xa3c0, 0xc028,	0xa3ff, 0xc028,		0x21, 0
	.dw 0xa440, 0xc028,	0xa47f, 0xc028,		0x21, 0
	.dw 0xa4c0, 0xc028,	0xa4ff, 0xc028,		0x21, 0
	.dw 0xa540, 0xc028,	0xa57f, 0xc028,		0x21, 0
	.dw 0xa5c0, 0xc028,	0xa5ff, 0xc028,		0x21, 0
	.dw 0xa640, 0xc028,	0xa67f, 0xc028,		0x21, 0
	.dw 0xa6c0, 0xc028,	0xa6ff, 0xc028,		0x21, 0
	.dw 0xa740, 0xc028,	0xa77f, 0xc028,		0x21, 0
	.dw 0xa7c0, 0xc028,	0xa7ff, 0xc028,		0x21, 0
	.dw 0xa840, 0xc028,	0xa87f, 0xc028,		0x21, 0
	.dw 0xa8c0, 0xc028,	0xa8ff, 0xc028,		0x21, 0
	.dw 0xa940, 0xc028,	0xa97f, 0xc028,		0x21, 0
	.dw 0xa9c0, 0xc028,	0xa9ff, 0xc028,		0x21, 0
	.dw 0xaa40, 0xc028,	0xaa7f, 0xc028,		0x21, 0
	.dw 0xaac0, 0xc028,	0xaaff, 0xc028,		0x21, 0
	.dw 0xab40, 0xc028,	0xab7f, 0xc028,		0x21, 0
	.dw 0xabc0, 0xc028,	0xabff, 0xc028,		0x21, 0
	.dw 0xac40, 0xc028,	0xac7f, 0xc028,		0x21, 0
	.dw 0xacc0, 0xc028,	0xacff, 0xc028,		0x21, 0
	.dw 0xad40, 0xc028,	0xad7f, 0xc028,		0x21, 0
	.dw 0xadc0, 0xc028,	0xadff, 0xc028,		0x21, 0
	.dw 0xae40, 0xc028,	0xae7f, 0xc028,		0x21, 0
	.dw 0xaec0, 0xc028,	0xaeff, 0xc028,		0x21, 0
	.dw 0xaf40, 0xc028,	0xaf7f, 0xc028,		0x21, 0
	.dw 0xafc0, 0xc028,	0xafff, 0xc028,		0x21, 0
	.dw 0xb040, 0xc028,	0xb07f, 0xc028,		0x21, 0
	.dw 0xb0c0, 0xc028,	0xb0ff, 0xc028,		0x21, 0
	.dw 0xb140, 0xc028,	0xb17f, 0xc028,		0x21, 0
	.dw 0xb1c0, 0xc028,	0xb1ff, 0xc028,		0x21, 0
	.dw 0xb240, 0xc028,	0xb27f, 0xc028,		0x21, 0
	.dw 0xb2c0, 0xc028,	0xb2ff, 0xc028,		0x21, 0
	.dw 0xb340, 0xc028,	0xb37f, 0xc028,		0x21, 0
	.dw 0xb3c0, 0xc028,	0xb3ff, 0xc028,		0x21, 0
	.dw 0xb440, 0xc028,	0xb47f, 0xc028,		0x21, 0
	.dw 0xb4c0, 0xc028,	0xb4ff, 0xc028,		0x21, 0
	.dw 0xb540, 0xc028,	0xb57f, 0xc028,		0x21, 0
	.dw 0xb5c0, 0xc028,	0xb5ff, 0xc028,		0x21, 0
	.dw 0xb640, 0xc028,	0xb67f, 0xc028,		0x21, 0
	.dw 0xb6c0, 0xc028,	0xb6ff, 0xc028,		0x21, 0
	.dw 0xb740, 0xc028,	0xb77f, 0xc028,		0x21, 0
	.dw 0xb7c0, 0xc028,	0xb7ff, 0xc028,		0x21, 0
	.dw 0xb840, 0xc028,	0xb87f, 0xc028,		0x21, 0
	.dw 0xb8c0, 0xc028,	0xb8ff, 0xc028,		0x21, 0
	.dw 0xb940, 0xc028,	0xb97f, 0xc028,		0x21, 0
	.dw 0xb9c0, 0xc028,	0xdfff, 0xc028,		0x21, 0
	.dw 0xe040, 0xc028,	0xe07f, 0xc028,		0x21, 0
	.dw 0xe0c0, 0xc028,	0xe0ff, 0xc028,		0x21, 0
	.dw 0xe140, 0xc028,	0xe17f, 0xc028,		0x21, 0
	.dw 0xe1c0, 0xc028,	0xe1ff, 0xc028,		0x21, 0
	.dw 0xe240, 0xc028,	0xe27f, 0xc028,		0x21, 0
	.dw 0xe2c0, 0xc028,	0xe2ff, 0xc028,		0x21, 0
	.dw 0xe340, 0xc028,	0xe37f, 0xc028,		0x21, 0
	.dw 0xe3c0, 0xc028,	0xe3ff, 0xc028,		0x21, 0
	.dw 0xe440, 0xc028,	0xe47f, 0xc028,		0x21, 0
	.dw 0xe4c0, 0xc028,	0xe4ff, 0xc028,		0x21, 0
	.dw 0xe540, 0xc028,	0xe57f, 0xc028,		0x21, 0
	.dw 0xe5c0, 0xc028,	0xe5ff, 0xc028,		0x21, 0
	.dw 0xe640, 0xc028,	0xe67f, 0xc028,		0x21, 0
	.dw 0xe6c0, 0xc028,	0xe6ff, 0xc028,		0x21, 0
	.dw 0xe740, 0xc028,	0xe77f, 0xc028,		0x21, 0
	.dw 0xe7c0, 0xc028,	0xe7ff, 0xc028,		0x21, 0
	.dw 0xe840, 0xc028,	0xe87f, 0xc028,		0x21, 0
	.dw 0xe8c0, 0xc028,	0xe8ff, 0xc028,		0x21, 0
	.dw 0xe940, 0xc028,	0xe97f, 0xc028,		0x21, 0
	.dw 0xe9c0, 0xc028,	0xe9ff, 0xc028,		0x21, 0
	.dw 0xea40, 0xc028,	0xea7f, 0xc028,		0x21, 0
	.dw 0xeac0, 0xc028,	0xeaff, 0xc028,		0x21, 0
	.dw 0xeb40, 0xc028,	0xeb7f, 0xc028,		0x21, 0
	.dw 0xebc0, 0xc028,	0xebff, 0xc028,		0x21, 0
	.dw 0xec40, 0xc028,	0xec7f, 0xc028,		0x21, 0
	.dw 0xecc0, 0xc028,	0xecff, 0xc028,		0x21, 0
	.dw 0xed40, 0xc028,	0xed7f, 0xc028,		0x21, 0
	.dw 0xedc0, 0xc028,	0xedff, 0xc028,		0x21, 0
	.dw 0xee40, 0xc028,	0xee7f, 0xc028,		0x21, 0
	.dw 0xeec0, 0xc028,	0xeeff, 0xc028,		0x21, 0
	.dw 0xef40, 0xc028,	0xef7f, 0xc028,		0x21, 0
	.dw 0xefc0, 0xc028,	0xefff, 0xc028,		0x21, 0
	.dw 0xf040, 0xc028,	0xf07f, 0xc028,		0x21, 0
	.dw 0xf0c0, 0xc028,	0xf0ff, 0xc028,		0x21, 0
	.dw 0xf140, 0xc028,	0xf17f, 0xc028,		0x21, 0
	.dw 0xf1c0, 0xc028,	0xf1ff, 0xc028,		0x21, 0
	.dw 0xf240, 0xc028,	0xf27f, 0xc028,		0x21, 0
	.dw 0xf2c0, 0xc028,	0xf2ff, 0xc028,		0x21, 0
	.dw 0xf340, 0xc028,	0xf37f, 0xc028,		0x21, 0
	.dw 0xf3c0, 0xc028,	0xf3ff, 0xc028,		0x21, 0
	.dw 0xf440, 0xc028,	0xf47f, 0xc028,		0x21, 0
	.dw 0xf4c0, 0xc028,	0xf4ff, 0xc028,		0x21, 0
	.dw 0xf540, 0xc028,	0xf57f, 0xc028,		0x21, 0
	.dw 0xf5c0, 0xc028,	0xf5ff, 0xc028,		0x21, 0
	.dw 0xf640, 0xc028,	0xf67f, 0xc028,		0x21, 0
	.dw 0xf6c0, 0xc028,	0xf6ff, 0xc028,		0x21, 0
	.dw 0xf740, 0xc028,	0xf77f, 0xc028,		0x21, 0
	.dw 0xf7c0, 0xc028,	0xf7ff, 0xc028,		0x21, 0
	.dw 0xf840, 0xc028,	0xf87f, 0xc028,		0x21, 0
	.dw 0xf8c0, 0xc028,	0xf8ff, 0xc028,		0x21, 0
	.dw 0xf940, 0xc028,	0xf97f, 0xc028,		0x21, 0
	.dw 0xf9c0, 0xc028,	0x1fff, 0xc029,		0x21, 0
	.dw 0x2040, 0xc029,	0x207f, 0xc029,		0x21, 0
	.dw 0x20c0, 0xc029,	0x20ff, 0xc029,		0x21, 0
	.dw 0x2140, 0xc029,	0x217f, 0xc029,		0x21, 0
	.dw 0x21c0, 0xc029,	0x21ff, 0xc029,		0x21, 0
	.dw 0x2240, 0xc029,	0x227f, 0xc029,		0x21, 0
	.dw 0x22c0, 0xc029,	0x22ff, 0xc029,		0x21, 0
	.dw 0x2340, 0xc029,	0x237f, 0xc029,		0x21, 0
	.dw 0x23c0, 0xc029,	0x23ff, 0xc029,		0x21, 0
	.dw 0x2440, 0xc029,	0x247f, 0xc029,		0x21, 0
	.dw 0x24c0, 0xc029,	0x24ff, 0xc029,		0x21, 0
	.dw 0x2540, 0xc029,	0x257f, 0xc029,		0x21, 0
	.dw 0x25c0, 0xc029,	0x25ff, 0xc029,		0x21, 0
	.dw 0x2640, 0xc029,	0x267f, 0xc029,		0x21, 0
	.dw 0x26c0, 0xc029,	0x26ff, 0xc029,		0x21, 0
	.dw 0x2740, 0xc029,	0x277f, 0xc029,		0x21, 0
	.dw 0x27c0, 0xc029,	0x27ff, 0xc029,		0x21, 0
	.dw 0x2840, 0xc029,	0x287f, 0xc029,		0x21, 0
	.dw 0x28c0, 0xc029,	0x28ff, 0xc029,		0x21, 0
	.dw 0x2940, 0xc029,	0x297f, 0xc029,		0x21, 0
	.dw 0x29c0, 0xc029,	0x29ff, 0xc029,		0x21, 0
	.dw 0x2a40, 0xc029,	0x2a7f, 0xc029,		0x21, 0
	.dw 0x2ac0, 0xc029,	0x2aff, 0xc029,		0x21, 0
	.dw 0x2b40, 0xc029,	0x2b7f, 0xc029,		0x21, 0
	.dw 0x2bc0, 0xc029,	0x2bff, 0xc029,		0x21, 0
	.dw 0x2c40, 0xc029,	0x2c7f, 0xc029,		0x21, 0
	.dw 0x2cc0, 0xc029,	0x2cff, 0xc029,		0x21, 0
	.dw 0x2d40, 0xc029,	0x2d7f, 0xc029,		0x21, 0
	.dw 0x2dc0, 0xc029,	0x2dff, 0xc029,		0x21, 0
	.dw 0x2e40, 0xc029,	0x2e7f, 0xc029,		0x21, 0
	.dw 0x2ec0, 0xc029,	0x2eff, 0xc029,		0x21, 0
	.dw 0x2f40, 0xc029,	0x2f7f, 0xc029,		0x21, 0
	.dw 0x2fc0, 0xc029,	0x2fff, 0xc029,		0x21, 0
	.dw 0x3040, 0xc029,	0x307f, 0xc029,		0x21, 0
	.dw 0x30c0, 0xc029,	0x30ff, 0xc029,		0x21, 0
	.dw 0x3140, 0xc029,	0x317f, 0xc029,		0x21, 0
	.dw 0x31c0, 0xc029,	0x31ff, 0xc029,		0x21, 0
	.dw 0x3240, 0xc029,	0x327f, 0xc029,		0x21, 0
	.dw 0x32c0, 0xc029,	0x32ff, 0xc029,		0x21, 0
	.dw 0x3340, 0xc029,	0x337f, 0xc029,		0x21, 0
	.dw 0x33c0, 0xc029,	0x33ff, 0xc029,		0x21, 0
	.dw 0x3440, 0xc029,	0x347f, 0xc029,		0x21, 0
	.dw 0x34c0, 0xc029,	0x34ff, 0xc029,		0x21, 0
	.dw 0x3540, 0xc029,	0x357f, 0xc029,		0x21, 0
	.dw 0x35c0, 0xc029,	0x35ff, 0xc029,		0x21, 0
	.dw 0x3640, 0xc029,	0x367f, 0xc029,		0x21, 0
	.dw 0x36c0, 0xc029,	0x36ff, 0xc029,		0x21, 0
	.dw 0x3740, 0xc029,	0x377f, 0xc029,		0x21, 0
	.dw 0x37c0, 0xc029,	0x37ff, 0xc029,		0x21, 0
	.dw 0x3840, 0xc029,	0x387f, 0xc029,		0x21, 0
	.dw 0x38c0, 0xc029,	0x38ff, 0xc029,		0x21, 0
	.dw 0x3940, 0xc029,	0x397f, 0xc029,		0x21, 0
	.dw 0x39c0, 0xc029,	0x5fff, 0xc029,		0x21, 0
	.dw 0x6040, 0xc029,	0x607f, 0xc029,		0x21, 0
	.dw 0x60c0, 0xc029,	0x60ff, 0xc029,		0x21, 0
	.dw 0x6140, 0xc029,	0x617f, 0xc029,		0x21, 0
	.dw 0x61c0, 0xc029,	0x61ff, 0xc029,		0x21, 0
	.dw 0x6240, 0xc029,	0x627f, 0xc029,		0x21, 0
	.dw 0x62c0, 0xc029,	0x62ff, 0xc029,		0x21, 0
	.dw 0x6340, 0xc029,	0x637f, 0xc029,		0x21, 0
	.dw 0x63c0, 0xc029,	0x63ff, 0xc029,		0x21, 0
	.dw 0x6440, 0xc029,	0x647f, 0xc029,		0x21, 0
	.dw 0x64c0, 0xc029,	0x64ff, 0xc029,		0x21, 0
	.dw 0x6540, 0xc029,	0x657f, 0xc029,		0x21, 0
	.dw 0x65c0, 0xc029,	0x65ff, 0xc029,		0x21, 0
	.dw 0x6640, 0xc029,	0x667f, 0xc029,		0x21, 0
	.dw 0x66c0, 0xc029,	0x66ff, 0xc029,		0x21, 0
	.dw 0x6740, 0xc029,	0x677f, 0xc029,		0x21, 0
	.dw 0x67c0, 0xc029,	0x67ff, 0xc029,		0x21, 0
	.dw 0x6840, 0xc029,	0x687f, 0xc029,		0x21, 0
	.dw 0x68c0, 0xc029,	0x68ff, 0xc029,		0x21, 0
	.dw 0x6940, 0xc029,	0x697f, 0xc029,		0x21, 0
	.dw 0x69c0, 0xc029,	0x69ff, 0xc029,		0x21, 0
	.dw 0x6a40, 0xc029,	0x6a7f, 0xc029,		0x21, 0
	.dw 0x6ac0, 0xc029,	0x6aff, 0xc029,		0x21, 0
	.dw 0x6b40, 0xc029,	0x6b7f, 0xc029,		0x21, 0
	.dw 0x6bc0, 0xc029,	0x6bff, 0xc029,		0x21, 0
	.dw 0x6c40, 0xc029,	0x6c7f, 0xc029,		0x21, 0
	.dw 0x6cc0, 0xc029,	0x6cff, 0xc029,		0x21, 0
	.dw 0x6d40, 0xc029,	0x6d7f, 0xc029,		0x21, 0
	.dw 0x6dc0, 0xc029,	0x6dff, 0xc029,		0x21, 0
	.dw 0x6e40, 0xc029,	0x6e7f, 0xc029,		0x21, 0
	.dw 0x6ec0, 0xc029,	0x6eff, 0xc029,		0x21, 0
	.dw 0x6f40, 0xc029,	0x6f7f, 0xc029,		0x21, 0
	.dw 0x6fc0, 0xc029,	0x6fff, 0xc029,		0x21, 0
	.dw 0x7040, 0xc029,	0x707f, 0xc029,		0x21, 0
	.dw 0x70c0, 0xc029,	0x70ff, 0xc029,		0x21, 0
	.dw 0x7140, 0xc029,	0x717f, 0xc029,		0x21, 0
	.dw 0x71c0, 0xc029,	0x71ff, 0xc029,		0x21, 0
	.dw 0x7240, 0xc029,	0x727f, 0xc029,		0x21, 0
	.dw 0x72c0, 0xc029,	0x72ff, 0xc029,		0x21, 0
	.dw 0x7340, 0xc029,	0x737f, 0xc029,		0x21, 0
	.dw 0x73c0, 0xc029,	0x73ff, 0xc029,		0x21, 0
	.dw 0x7440, 0xc029,	0x747f, 0xc029,		0x21, 0
	.dw 0x74c0, 0xc029,	0x74ff, 0xc029,		0x21, 0
	.dw 0x7540, 0xc029,	0x757f, 0xc029,		0x21, 0
	.dw 0x75c0, 0xc029,	0x75ff, 0xc029,		0x21, 0
	.dw 0x7640, 0xc029,	0x767f, 0xc029,		0x21, 0
	.dw 0x76c0, 0xc029,	0x76ff, 0xc029,		0x21, 0
	.dw 0x7740, 0xc029,	0x777f, 0xc029,		0x21, 0
	.dw 0x77c0, 0xc029,	0x77ff, 0xc029,		0x21, 0
	.dw 0x7840, 0xc029,	0x787f, 0xc029,		0x21, 0
	.dw 0x78c0, 0xc029,	0x78ff, 0xc029,		0x21, 0
	.dw 0x7940, 0xc029,	0x797f, 0xc029,		0x21, 0
	.dw 0x79c0, 0xc029,	0x9fff, 0xc029,		0x21, 0
	.dw 0xa040, 0xc029,	0xa07f, 0xc029,		0x21, 0
	.dw 0xa0c0, 0xc029,	0xa0ff, 0xc029,		0x21, 0
	.dw 0xa140, 0xc029,	0xa17f, 0xc029,		0x21, 0
	.dw 0xa1c0, 0xc029,	0xa1ff, 0xc029,		0x21, 0
	.dw 0xa240, 0xc029,	0xa27f, 0xc029,		0x21, 0
	.dw 0xa2c0, 0xc029,	0xa2ff, 0xc029,		0x21, 0
	.dw 0xa340, 0xc029,	0xa37f, 0xc029,		0x21, 0
	.dw 0xa3c0, 0xc029,	0xa3ff, 0xc029,		0x21, 0
	.dw 0xa440, 0xc029,	0xa47f, 0xc029,		0x21, 0
	.dw 0xa4c0, 0xc029,	0xa4ff, 0xc029,		0x21, 0
	.dw 0xa540, 0xc029,	0xa57f, 0xc029,		0x21, 0
	.dw 0xa5c0, 0xc029,	0xa5ff, 0xc029,		0x21, 0
	.dw 0xa640, 0xc029,	0xa67f, 0xc029,		0x21, 0
	.dw 0xa6c0, 0xc029,	0xa6ff, 0xc029,		0x21, 0
	.dw 0xa740, 0xc029,	0xa77f, 0xc029,		0x21, 0
	.dw 0xa7c0, 0xc029,	0xa7ff, 0xc029,		0x21, 0
	.dw 0xa840, 0xc029,	0xa87f, 0xc029,		0x21, 0
	.dw 0xa8c0, 0xc029,	0xa8ff, 0xc029,		0x21, 0
	.dw 0xa940, 0xc029,	0xa97f, 0xc029,		0x21, 0
	.dw 0xa9c0, 0xc029,	0xa9ff, 0xc029,		0x21, 0
	.dw 0xaa40, 0xc029,	0xaa7f, 0xc029,		0x21, 0
	.dw 0xaac0, 0xc029,	0xaaff, 0xc029,		0x21, 0
	.dw 0xab40, 0xc029,	0xab7f, 0xc029,		0x21, 0
	.dw 0xabc0, 0xc029,	0xabff, 0xc029,		0x21, 0
	.dw 0xac40, 0xc029,	0xac7f, 0xc029,		0x21, 0
	.dw 0xacc0, 0xc029,	0xacff, 0xc029,		0x21, 0
	.dw 0xad40, 0xc029,	0xad7f, 0xc029,		0x21, 0
	.dw 0xadc0, 0xc029,	0xadff, 0xc029,		0x21, 0
	.dw 0xae40, 0xc029,	0xae7f, 0xc029,		0x21, 0
	.dw 0xaec0, 0xc029,	0xaeff, 0xc029,		0x21, 0
	.dw 0xaf40, 0xc029,	0xaf7f, 0xc029,		0x21, 0
	.dw 0xafc0, 0xc029,	0xafff, 0xc029,		0x21, 0
	.dw 0xb040, 0xc029,	0xb07f, 0xc029,		0x21, 0
	.dw 0xb0c0, 0xc029,	0xb0ff, 0xc029,		0x21, 0
	.dw 0xb140, 0xc029,	0xb17f, 0xc029,		0x21, 0
	.dw 0xb1c0, 0xc029,	0xb1ff, 0xc029,		0x21, 0
	.dw 0xb240, 0xc029,	0xb27f, 0xc029,		0x21, 0
	.dw 0xb2c0, 0xc029,	0xb2ff, 0xc029,		0x21, 0
	.dw 0xb340, 0xc029,	0xb37f, 0xc029,		0x21, 0
	.dw 0xb3c0, 0xc029,	0xb3ff, 0xc029,		0x21, 0
	.dw 0xb440, 0xc029,	0xb47f, 0xc029,		0x21, 0
	.dw 0xb4c0, 0xc029,	0xb4ff, 0xc029,		0x21, 0
	.dw 0xb540, 0xc029,	0xb57f, 0xc029,		0x21, 0
	.dw 0xb5c0, 0xc029,	0xb5ff, 0xc029,		0x21, 0
	.dw 0xb640, 0xc029,	0xb67f, 0xc029,		0x21, 0
	.dw 0xb6c0, 0xc029,	0xb6ff, 0xc029,		0x21, 0
	.dw 0xb740, 0xc029,	0xb77f, 0xc029,		0x21, 0
	.dw 0xb7c0, 0xc029,	0xb7ff, 0xc029,		0x21, 0
	.dw 0xb840, 0xc029,	0xb87f, 0xc029,		0x21, 0
	.dw 0xb8c0, 0xc029,	0xb8ff, 0xc029,		0x21, 0
	.dw 0xb940, 0xc029,	0xb97f, 0xc029,		0x21, 0
	.dw 0xb9c0, 0xc029,	0xdfff, 0xc029,		0x21, 0
	.dw 0xe040, 0xc029,	0xe07f, 0xc029,		0x21, 0
	.dw 0xe0c0, 0xc029,	0xe0ff, 0xc029,		0x21, 0
	.dw 0xe140, 0xc029,	0xe17f, 0xc029,		0x21, 0
	.dw 0xe1c0, 0xc029,	0xe1ff, 0xc029,		0x21, 0
	.dw 0xe240, 0xc029,	0xe27f, 0xc029,		0x21, 0
	.dw 0xe2c0, 0xc029,	0xe2ff, 0xc029,		0x21, 0
	.dw 0xe340, 0xc029,	0xe37f, 0xc029,		0x21, 0
	.dw 0xe3c0, 0xc029,	0xe3ff, 0xc029,		0x21, 0
	.dw 0xe440, 0xc029,	0xe47f, 0xc029,		0x21, 0
	.dw 0xe4c0, 0xc029,	0xe4ff, 0xc029,		0x21, 0
	.dw 0xe540, 0xc029,	0xe57f, 0xc029,		0x21, 0
	.dw 0xe5c0, 0xc029,	0xe5ff, 0xc029,		0x21, 0
	.dw 0xe640, 0xc029,	0xe67f, 0xc029,		0x21, 0
	.dw 0xe6c0, 0xc029,	0xe6ff, 0xc029,		0x21, 0
	.dw 0xe740, 0xc029,	0xe77f, 0xc029,		0x21, 0
	.dw 0xe7c0, 0xc029,	0xe7ff, 0xc029,		0x21, 0
	.dw 0xe840, 0xc029,	0xe87f, 0xc029,		0x21, 0
	.dw 0xe8c0, 0xc029,	0xe8ff, 0xc029,		0x21, 0
	.dw 0xe940, 0xc029,	0xe97f, 0xc029,		0x21, 0
	.dw 0xe9c0, 0xc029,	0xe9ff, 0xc029,		0x21, 0
	.dw 0xea40, 0xc029,	0xea7f, 0xc029,		0x21, 0
	.dw 0xeac0, 0xc029,	0xeaff, 0xc029,		0x21, 0
	.dw 0xeb40, 0xc029,	0xeb7f, 0xc029,		0x21, 0
	.dw 0xebc0, 0xc029,	0xebff, 0xc029,		0x21, 0
	.dw 0xec40, 0xc029,	0xec7f, 0xc029,		0x21, 0
	.dw 0xecc0, 0xc029,	0xecff, 0xc029,		0x21, 0
	.dw 0xed40, 0xc029,	0xed7f, 0xc029,		0x21, 0
	.dw 0xedc0, 0xc029,	0xedff, 0xc029,		0x21, 0
	.dw 0xee40, 0xc029,	0xee7f, 0xc029,		0x21, 0
	.dw 0xeec0, 0xc029,	0xeeff, 0xc029,		0x21, 0
	.dw 0xef40, 0xc029,	0xef7f, 0xc029,		0x21, 0
	.dw 0xefc0, 0xc029,	0xefff, 0xc029,		0x21, 0
	.dw 0xf040, 0xc029,	0xf07f, 0xc029,		0x21, 0
	.dw 0xf0c0, 0xc029,	0xf0ff, 0xc029,		0x21, 0
	.dw 0xf140, 0xc029,	0xf17f, 0xc029,		0x21, 0
	.dw 0xf1c0, 0xc029,	0xf1ff, 0xc029,		0x21, 0
	.dw 0xf240, 0xc029,	0xf27f, 0xc029,		0x21, 0
	.dw 0xf2c0, 0xc029,	0xf2ff, 0xc029,		0x21, 0
	.dw 0xf340, 0xc029,	0xf37f, 0xc029,		0x21, 0
	.dw 0xf3c0, 0xc029,	0xf3ff, 0xc029,		0x21, 0
	.dw 0xf440, 0xc029,	0xf47f, 0xc029,		0x21, 0
	.dw 0xf4c0, 0xc029,	0xf4ff, 0xc029,		0x21, 0
	.dw 0xf540, 0xc029,	0xf57f, 0xc029,		0x21, 0
	.dw 0xf5c0, 0xc029,	0xf5ff, 0xc029,		0x21, 0
	.dw 0xf640, 0xc029,	0xf67f, 0xc029,		0x21, 0
	.dw 0xf6c0, 0xc029,	0xf6ff, 0xc029,		0x21, 0
	.dw 0xf740, 0xc029,	0xf77f, 0xc029,		0x21, 0
	.dw 0xf7c0, 0xc029,	0xf7ff, 0xc029,		0x21, 0
	.dw 0xf840, 0xc029,	0xf87f, 0xc029,		0x21, 0
	.dw 0xf8c0, 0xc029,	0xf8ff, 0xc029,		0x21, 0
	.dw 0xf940, 0xc029,	0xf97f, 0xc029,		0x21, 0
	.dw 0xf9c0, 0xc029,	0x1fff, 0xc02a,		0x21, 0
	.dw 0x2040, 0xc02a,	0x207f, 0xc02a,		0x21, 0
	.dw 0x20c0, 0xc02a,	0x20ff, 0xc02a,		0x21, 0
	.dw 0x2140, 0xc02a,	0x217f, 0xc02a,		0x21, 0
	.dw 0x21c0, 0xc02a,	0x21ff, 0xc02a,		0x21, 0
	.dw 0x2240, 0xc02a,	0x227f, 0xc02a,		0x21, 0
	.dw 0x22c0, 0xc02a,	0x22ff, 0xc02a,		0x21, 0
	.dw 0x2340, 0xc02a,	0x237f, 0xc02a,		0x21, 0
	.dw 0x23c0, 0xc02a,	0x23ff, 0xc02a,		0x21, 0
	.dw 0x2440, 0xc02a,	0x247f, 0xc02a,		0x21, 0
	.dw 0x24c0, 0xc02a,	0x24ff, 0xc02a,		0x21, 0
	.dw 0x2540, 0xc02a,	0x257f, 0xc02a,		0x21, 0
	.dw 0x25c0, 0xc02a,	0x25ff, 0xc02a,		0x21, 0
	.dw 0x2640, 0xc02a,	0x267f, 0xc02a,		0x21, 0
	.dw 0x26c0, 0xc02a,	0x26ff, 0xc02a,		0x21, 0
	.dw 0x2740, 0xc02a,	0x277f, 0xc02a,		0x21, 0
	.dw 0x27c0, 0xc02a,	0x27ff, 0xc02a,		0x21, 0
	.dw 0x2840, 0xc02a,	0x287f, 0xc02a,		0x21, 0
	.dw 0x28c0, 0xc02a,	0x28ff, 0xc02a,		0x21, 0
	.dw 0x2940, 0xc02a,	0x297f, 0xc02a,		0x21, 0
	.dw 0x29c0, 0xc02a,	0x29ff, 0xc02a,		0x21, 0
	.dw 0x2a40, 0xc02a,	0x2a7f, 0xc02a,		0x21, 0
	.dw 0x2ac0, 0xc02a,	0x2aff, 0xc02a,		0x21, 0
	.dw 0x2b40, 0xc02a,	0x2b7f, 0xc02a,		0x21, 0
	.dw 0x2bc0, 0xc02a,	0x2bff, 0xc02a,		0x21, 0
	.dw 0x2c40, 0xc02a,	0x2c7f, 0xc02a,		0x21, 0
	.dw 0x2cc0, 0xc02a,	0x2cff, 0xc02a,		0x21, 0
	.dw 0x2d40, 0xc02a,	0x2d7f, 0xc02a,		0x21, 0
	.dw 0x2dc0, 0xc02a,	0x2dff, 0xc02a,		0x21, 0
	.dw 0x2e40, 0xc02a,	0x2e7f, 0xc02a,		0x21, 0
	.dw 0x2ec0, 0xc02a,	0x2eff, 0xc02a,		0x21, 0
	.dw 0x2f40, 0xc02a,	0x2f7f, 0xc02a,		0x21, 0
	.dw 0x2fc0, 0xc02a,	0x2fff, 0xc02a,		0x21, 0
	.dw 0x3040, 0xc02a,	0x307f, 0xc02a,		0x21, 0
	.dw 0x30c0, 0xc02a,	0x30ff, 0xc02a,		0x21, 0
	.dw 0x3140, 0xc02a,	0x317f, 0xc02a,		0x21, 0
	.dw 0x31c0, 0xc02a,	0x31ff, 0xc02a,		0x21, 0
	.dw 0x3240, 0xc02a,	0x327f, 0xc02a,		0x21, 0
	.dw 0x32c0, 0xc02a,	0x32ff, 0xc02a,		0x21, 0
	.dw 0x3340, 0xc02a,	0x337f, 0xc02a,		0x21, 0
	.dw 0x33c0, 0xc02a,	0x33ff, 0xc02a,		0x21, 0
	.dw 0x3440, 0xc02a,	0x347f, 0xc02a,		0x21, 0
	.dw 0x34c0, 0xc02a,	0x34ff, 0xc02a,		0x21, 0
	.dw 0x3540, 0xc02a,	0x357f, 0xc02a,		0x21, 0
	.dw 0x35c0, 0xc02a,	0x35ff, 0xc02a,		0x21, 0
	.dw 0x3640, 0xc02a,	0x367f, 0xc02a,		0x21, 0
	.dw 0x36c0, 0xc02a,	0x36ff, 0xc02a,		0x21, 0
	.dw 0x3740, 0xc02a,	0x377f, 0xc02a,		0x21, 0
	.dw 0x37c0, 0xc02a,	0x37ff, 0xc02a,		0x21, 0
	.dw 0x3840, 0xc02a,	0x387f, 0xc02a,		0x21, 0
	.dw 0x38c0, 0xc02a,	0x38ff, 0xc02a,		0x21, 0
	.dw 0x3940, 0xc02a,	0x397f, 0xc02a,		0x21, 0
	.dw 0x39c0, 0xc02a,	0x5fff, 0xc02a,		0x21, 0
	.dw 0x6040, 0xc02a,	0x607f, 0xc02a,		0x21, 0
	.dw 0x60c0, 0xc02a,	0x60ff, 0xc02a,		0x21, 0
	.dw 0x6140, 0xc02a,	0x617f, 0xc02a,		0x21, 0
	.dw 0x61c0, 0xc02a,	0x61ff, 0xc02a,		0x21, 0
	.dw 0x6240, 0xc02a,	0x627f, 0xc02a,		0x21, 0
	.dw 0x62c0, 0xc02a,	0x62ff, 0xc02a,		0x21, 0
	.dw 0x6340, 0xc02a,	0x637f, 0xc02a,		0x21, 0
	.dw 0x63c0, 0xc02a,	0x63ff, 0xc02a,		0x21, 0
	.dw 0x6440, 0xc02a,	0x647f, 0xc02a,		0x21, 0
	.dw 0x64c0, 0xc02a,	0x64ff, 0xc02a,		0x21, 0
	.dw 0x6540, 0xc02a,	0x657f, 0xc02a,		0x21, 0
	.dw 0x65c0, 0xc02a,	0x65ff, 0xc02a,		0x21, 0
	.dw 0x6640, 0xc02a,	0x667f, 0xc02a,		0x21, 0
	.dw 0x66c0, 0xc02a,	0x66ff, 0xc02a,		0x21, 0
	.dw 0x6740, 0xc02a,	0x677f, 0xc02a,		0x21, 0
	.dw 0x67c0, 0xc02a,	0x67ff, 0xc02a,		0x21, 0
	.dw 0x6840, 0xc02a,	0x687f, 0xc02a,		0x21, 0
	.dw 0x68c0, 0xc02a,	0x68ff, 0xc02a,		0x21, 0
	.dw 0x6940, 0xc02a,	0x697f, 0xc02a,		0x21, 0
	.dw 0x69c0, 0xc02a,	0x69ff, 0xc02a,		0x21, 0
	.dw 0x6a40, 0xc02a,	0x6a7f, 0xc02a,		0x21, 0
	.dw 0x6ac0, 0xc02a,	0x6aff, 0xc02a,		0x21, 0
	.dw 0x6b40, 0xc02a,	0x6b7f, 0xc02a,		0x21, 0
	.dw 0x6bc0, 0xc02a,	0x6bff, 0xc02a,		0x21, 0
	.dw 0x6c40, 0xc02a,	0x6c7f, 0xc02a,		0x21, 0
	.dw 0x6cc0, 0xc02a,	0x6cff, 0xc02a,		0x21, 0
	.dw 0x6d40, 0xc02a,	0x6d7f, 0xc02a,		0x21, 0
	.dw 0x6dc0, 0xc02a,	0x6dff, 0xc02a,		0x21, 0
	.dw 0x6e40, 0xc02a,	0x6e7f, 0xc02a,		0x21, 0
	.dw 0x6ec0, 0xc02a,	0x6eff, 0xc02a,		0x21, 0
	.dw 0x6f40, 0xc02a,	0x6f7f, 0xc02a,		0x21, 0
	.dw 0x6fc0, 0xc02a,	0x6fff, 0xc02a,		0x21, 0
	.dw 0x7040, 0xc02a,	0x707f, 0xc02a,		0x21, 0
	.dw 0x70c0, 0xc02a,	0x70ff, 0xc02a,		0x21, 0
	.dw 0x7140, 0xc02a,	0x717f, 0xc02a,		0x21, 0
	.dw 0x71c0, 0xc02a,	0x71ff, 0xc02a,		0x21, 0
	.dw 0x7240, 0xc02a,	0x727f, 0xc02a,		0x21, 0
	.dw 0x72c0, 0xc02a,	0x72ff, 0xc02a,		0x21, 0
	.dw 0x7340, 0xc02a,	0x737f, 0xc02a,		0x21, 0
	.dw 0x73c0, 0xc02a,	0x73ff, 0xc02a,		0x21, 0
	.dw 0x7440, 0xc02a,	0x747f, 0xc02a,		0x21, 0
	.dw 0x74c0, 0xc02a,	0x74ff, 0xc02a,		0x21, 0
	.dw 0x7540, 0xc02a,	0x757f, 0xc02a,		0x21, 0
	.dw 0x75c0, 0xc02a,	0x75ff, 0xc02a,		0x21, 0
	.dw 0x7640, 0xc02a,	0x767f, 0xc02a,		0x21, 0
	.dw 0x76c0, 0xc02a,	0x76ff, 0xc02a,		0x21, 0
	.dw 0x7740, 0xc02a,	0x777f, 0xc02a,		0x21, 0
	.dw 0x77c0, 0xc02a,	0x77ff, 0xc02a,		0x21, 0
	.dw 0x7840, 0xc02a,	0x787f, 0xc02a,		0x21, 0
	.dw 0x78c0, 0xc02a,	0x78ff, 0xc02a,		0x21, 0
	.dw 0x7940, 0xc02a,	0x797f, 0xc02a,		0x21, 0
	.dw 0x79c0, 0xc02a,	0x9fff, 0xc02a,		0x21, 0
	.dw 0xa040, 0xc02a,	0xa07f, 0xc02a,		0x21, 0
	.dw 0xa0c0, 0xc02a,	0xa0ff, 0xc02a,		0x21, 0
	.dw 0xa140, 0xc02a,	0xa17f, 0xc02a,		0x21, 0
	.dw 0xa1c0, 0xc02a,	0xa1ff, 0xc02a,		0x21, 0
	.dw 0xa240, 0xc02a,	0xa27f, 0xc02a,		0x21, 0
	.dw 0xa2c0, 0xc02a,	0xa2ff, 0xc02a,		0x21, 0
	.dw 0xa340, 0xc02a,	0xa37f, 0xc02a,		0x21, 0
	.dw 0xa3c0, 0xc02a,	0xa3ff, 0xc02a,		0x21, 0
	.dw 0xa440, 0xc02a,	0xa47f, 0xc02a,		0x21, 0
	.dw 0xa4c0, 0xc02a,	0xa4ff, 0xc02a,		0x21, 0
	.dw 0xa540, 0xc02a,	0xa57f, 0xc02a,		0x21, 0
	.dw 0xa5c0, 0xc02a,	0xa5ff, 0xc02a,		0x21, 0
	.dw 0xa640, 0xc02a,	0xa67f, 0xc02a,		0x21, 0
	.dw 0xa6c0, 0xc02a,	0xa6ff, 0xc02a,		0x21, 0
	.dw 0xa740, 0xc02a,	0xa77f, 0xc02a,		0x21, 0
	.dw 0xa7c0, 0xc02a,	0xa7ff, 0xc02a,		0x21, 0
	.dw 0xa840, 0xc02a,	0xa87f, 0xc02a,		0x21, 0
	.dw 0xa8c0, 0xc02a,	0xa8ff, 0xc02a,		0x21, 0
	.dw 0xa940, 0xc02a,	0xa97f, 0xc02a,		0x21, 0
	.dw 0xa9c0, 0xc02a,	0xa9ff, 0xc02a,		0x21, 0
	.dw 0xaa40, 0xc02a,	0xaa7f, 0xc02a,		0x21, 0
	.dw 0xaac0, 0xc02a,	0xaaff, 0xc02a,		0x21, 0
	.dw 0xab40, 0xc02a,	0xab7f, 0xc02a,		0x21, 0
	.dw 0xabc0, 0xc02a,	0xabff, 0xc02a,		0x21, 0
	.dw 0xac40, 0xc02a,	0xac7f, 0xc02a,		0x21, 0
	.dw 0xacc0, 0xc02a,	0xacff, 0xc02a,		0x21, 0
	.dw 0xad40, 0xc02a,	0xad7f, 0xc02a,		0x21, 0
	.dw 0xadc0, 0xc02a,	0xadff, 0xc02a,		0x21, 0
	.dw 0xae40, 0xc02a,	0xae7f, 0xc02a,		0x21, 0
	.dw 0xaec0, 0xc02a,	0xaeff, 0xc02a,		0x21, 0
	.dw 0xaf40, 0xc02a,	0xaf7f, 0xc02a,		0x21, 0
	.dw 0xafc0, 0xc02a,	0xafff, 0xc02a,		0x21, 0
	.dw 0xb040, 0xc02a,	0xb07f, 0xc02a,		0x21, 0
	.dw 0xb0c0, 0xc02a,	0xb0ff, 0xc02a,		0x21, 0
	.dw 0xb140, 0xc02a,	0xb17f, 0xc02a,		0x21, 0
	.dw 0xb1c0, 0xc02a,	0xb1ff, 0xc02a,		0x21, 0
	.dw 0xb240, 0xc02a,	0xb27f, 0xc02a,		0x21, 0
	.dw 0xb2c0, 0xc02a,	0xb2ff, 0xc02a,		0x21, 0
	.dw 0xb340, 0xc02a,	0xb37f, 0xc02a,		0x21, 0
	.dw 0xb3c0, 0xc02a,	0xb3ff, 0xc02a,		0x21, 0
	.dw 0xb440, 0xc02a,	0xb47f, 0xc02a,		0x21, 0
	.dw 0xb4c0, 0xc02a,	0xb4ff, 0xc02a,		0x21, 0
	.dw 0xb540, 0xc02a,	0xb57f, 0xc02a,		0x21, 0
	.dw 0xb5c0, 0xc02a,	0xb5ff, 0xc02a,		0x21, 0
	.dw 0xb640, 0xc02a,	0xb67f, 0xc02a,		0x21, 0
	.dw 0xb6c0, 0xc02a,	0xb6ff, 0xc02a,		0x21, 0
	.dw 0xb740, 0xc02a,	0xb77f, 0xc02a,		0x21, 0
	.dw 0xb7c0, 0xc02a,	0xb7ff, 0xc02a,		0x21, 0
	.dw 0xb840, 0xc02a,	0xb87f, 0xc02a,		0x21, 0
	.dw 0xb8c0, 0xc02a,	0xb8ff, 0xc02a,		0x21, 0
	.dw 0xb940, 0xc02a,	0xb97f, 0xc02a,		0x21, 0
	.dw 0xb9c0, 0xc02a,	0xdfff, 0xc02a,		0x21, 0
	.dw 0xe040, 0xc02a,	0xe07f, 0xc02a,		0x21, 0
	.dw 0xe0c0, 0xc02a,	0xe0ff, 0xc02a,		0x21, 0
	.dw 0xe140, 0xc02a,	0xe17f, 0xc02a,		0x21, 0
	.dw 0xe1c0, 0xc02a,	0xe1ff, 0xc02a,		0x21, 0
	.dw 0xe240, 0xc02a,	0xe27f, 0xc02a,		0x21, 0
	.dw 0xe2c0, 0xc02a,	0xe2ff, 0xc02a,		0x21, 0
	.dw 0xe340, 0xc02a,	0xe37f, 0xc02a,		0x21, 0
	.dw 0xe3c0, 0xc02a,	0xe3ff, 0xc02a,		0x21, 0
	.dw 0xe440, 0xc02a,	0xe47f, 0xc02a,		0x21, 0
	.dw 0xe4c0, 0xc02a,	0xe4ff, 0xc02a,		0x21, 0
	.dw 0xe540, 0xc02a,	0xe57f, 0xc02a,		0x21, 0
	.dw 0xe5c0, 0xc02a,	0xe5ff, 0xc02a,		0x21, 0
	.dw 0xe640, 0xc02a,	0xe67f, 0xc02a,		0x21, 0
	.dw 0xe6c0, 0xc02a,	0xe6ff, 0xc02a,		0x21, 0
	.dw 0xe740, 0xc02a,	0xe77f, 0xc02a,		0x21, 0
	.dw 0xe7c0, 0xc02a,	0xe7ff, 0xc02a,		0x21, 0
	.dw 0xe840, 0xc02a,	0xe87f, 0xc02a,		0x21, 0
	.dw 0xe8c0, 0xc02a,	0xe8ff, 0xc02a,		0x21, 0
	.dw 0xe940, 0xc02a,	0xe97f, 0xc02a,		0x21, 0
	.dw 0xe9c0, 0xc02a,	0xe9ff, 0xc02a,		0x21, 0
	.dw 0xea40, 0xc02a,	0xea7f, 0xc02a,		0x21, 0
	.dw 0xeac0, 0xc02a,	0xeaff, 0xc02a,		0x21, 0
	.dw 0xeb40, 0xc02a,	0xeb7f, 0xc02a,		0x21, 0
	.dw 0xebc0, 0xc02a,	0xebff, 0xc02a,		0x21, 0
	.dw 0xec40, 0xc02a,	0xec7f, 0xc02a,		0x21, 0
	.dw 0xecc0, 0xc02a,	0xecff, 0xc02a,		0x21, 0
	.dw 0xed40, 0xc02a,	0xed7f, 0xc02a,		0x21, 0
	.dw 0xedc0, 0xc02a,	0xedff, 0xc02a,		0x21, 0
	.dw 0xee40, 0xc02a,	0xee7f, 0xc02a,		0x21, 0
	.dw 0xeec0, 0xc02a,	0xeeff, 0xc02a,		0x21, 0
	.dw 0xef40, 0xc02a,	0xef7f, 0xc02a,		0x21, 0
	.dw 0xefc0, 0xc02a,	0xefff, 0xc02a,		0x21, 0
	.dw 0xf040, 0xc02a,	0xf07f, 0xc02a,		0x21, 0
	.dw 0xf0c0, 0xc02a,	0xf0ff, 0xc02a,		0x21, 0
	.dw 0xf140, 0xc02a,	0xf17f, 0xc02a,		0x21, 0
	.dw 0xf1c0, 0xc02a,	0xf1ff, 0xc02a,		0x21, 0
	.dw 0xf240, 0xc02a,	0xf27f, 0xc02a,		0x21, 0
	.dw 0xf2c0, 0xc02a,	0xf2ff, 0xc02a,		0x21, 0
	.dw 0xf340, 0xc02a,	0xf37f, 0xc02a,		0x21, 0
	.dw 0xf3c0, 0xc02a,	0xf3ff, 0xc02a,		0x21, 0
	.dw 0xf440, 0xc02a,	0xf47f, 0xc02a,		0x21, 0
	.dw 0xf4c0, 0xc02a,	0xf4ff, 0xc02a,		0x21, 0
	.dw 0xf540, 0xc02a,	0xf57f, 0xc02a,		0x21, 0
	.dw 0xf5c0, 0xc02a,	0xf5ff, 0xc02a,		0x21, 0
	.dw 0xf640, 0xc02a,	0xf67f, 0xc02a,		0x21, 0
	.dw 0xf6c0, 0xc02a,	0xf6ff, 0xc02a,		0x21, 0
	.dw 0xf740, 0xc02a,	0xf77f, 0xc02a,		0x21, 0
	.dw 0xf7c0, 0xc02a,	0xf7ff, 0xc02a,		0x21, 0
	.dw 0xf840, 0xc02a,	0xf87f, 0xc02a,		0x21, 0
	.dw 0xf8c0, 0xc02a,	0xf8ff, 0xc02a,		0x21, 0
	.dw 0xf940, 0xc02a,	0xf97f, 0xc02a,		0x21, 0
	.dw 0xf9c0, 0xc02a,	0x1fff, 0xc02b,		0x21, 0
	.dw 0x2040, 0xc02b,	0x207f, 0xc02b,		0x21, 0
	.dw 0x20c0, 0xc02b,	0x20ff, 0xc02b,		0x21, 0
	.dw 0x2140, 0xc02b,	0x217f, 0xc02b,		0x21, 0
	.dw 0x21c0, 0xc02b,	0x21ff, 0xc02b,		0x21, 0
	.dw 0x2240, 0xc02b,	0x227f, 0xc02b,		0x21, 0
	.dw 0x22c0, 0xc02b,	0x22ff, 0xc02b,		0x21, 0
	.dw 0x2340, 0xc02b,	0x237f, 0xc02b,		0x21, 0
	.dw 0x23c0, 0xc02b,	0x23ff, 0xc02b,		0x21, 0
	.dw 0x2440, 0xc02b,	0x247f, 0xc02b,		0x21, 0
	.dw 0x24c0, 0xc02b,	0x24ff, 0xc02b,		0x21, 0
	.dw 0x2540, 0xc02b,	0x257f, 0xc02b,		0x21, 0
	.dw 0x25c0, 0xc02b,	0x25ff, 0xc02b,		0x21, 0
	.dw 0x2640, 0xc02b,	0x267f, 0xc02b,		0x21, 0
	.dw 0x26c0, 0xc02b,	0x26ff, 0xc02b,		0x21, 0
	.dw 0x2740, 0xc02b,	0x277f, 0xc02b,		0x21, 0
	.dw 0x27c0, 0xc02b,	0x27ff, 0xc02b,		0x21, 0
	.dw 0x2840, 0xc02b,	0x287f, 0xc02b,		0x21, 0
	.dw 0x28c0, 0xc02b,	0x28ff, 0xc02b,		0x21, 0
	.dw 0x2940, 0xc02b,	0x297f, 0xc02b,		0x21, 0
	.dw 0x29c0, 0xc02b,	0x29ff, 0xc02b,		0x21, 0
	.dw 0x2a40, 0xc02b,	0x2a7f, 0xc02b,		0x21, 0
	.dw 0x2ac0, 0xc02b,	0x2aff, 0xc02b,		0x21, 0
	.dw 0x2b40, 0xc02b,	0x2b7f, 0xc02b,		0x21, 0
	.dw 0x2bc0, 0xc02b,	0x2bff, 0xc02b,		0x21, 0
	.dw 0x2c40, 0xc02b,	0x2c7f, 0xc02b,		0x21, 0
	.dw 0x2cc0, 0xc02b,	0x2cff, 0xc02b,		0x21, 0
	.dw 0x2d40, 0xc02b,	0x2d7f, 0xc02b,		0x21, 0
	.dw 0x2dc0, 0xc02b,	0x2dff, 0xc02b,		0x21, 0
	.dw 0x2e40, 0xc02b,	0x2e7f, 0xc02b,		0x21, 0
	.dw 0x2ec0, 0xc02b,	0x2eff, 0xc02b,		0x21, 0
	.dw 0x2f40, 0xc02b,	0x2f7f, 0xc02b,		0x21, 0
	.dw 0x2fc0, 0xc02b,	0x2fff, 0xc02b,		0x21, 0
	.dw 0x3040, 0xc02b,	0x307f, 0xc02b,		0x21, 0
	.dw 0x30c0, 0xc02b,	0x30ff, 0xc02b,		0x21, 0
	.dw 0x3140, 0xc02b,	0x317f, 0xc02b,		0x21, 0
	.dw 0x31c0, 0xc02b,	0x31ff, 0xc02b,		0x21, 0
	.dw 0x3240, 0xc02b,	0x327f, 0xc02b,		0x21, 0
	.dw 0x32c0, 0xc02b,	0x32ff, 0xc02b,		0x21, 0
	.dw 0x3340, 0xc02b,	0x337f, 0xc02b,		0x21, 0
	.dw 0x33c0, 0xc02b,	0x33ff, 0xc02b,		0x21, 0
	.dw 0x3440, 0xc02b,	0x347f, 0xc02b,		0x21, 0
	.dw 0x34c0, 0xc02b,	0x34ff, 0xc02b,		0x21, 0
	.dw 0x3540, 0xc02b,	0x357f, 0xc02b,		0x21, 0
	.dw 0x35c0, 0xc02b,	0x35ff, 0xc02b,		0x21, 0
	.dw 0x3640, 0xc02b,	0x367f, 0xc02b,		0x21, 0
	.dw 0x36c0, 0xc02b,	0x36ff, 0xc02b,		0x21, 0
	.dw 0x3740, 0xc02b,	0x377f, 0xc02b,		0x21, 0
	.dw 0x37c0, 0xc02b,	0x37ff, 0xc02b,		0x21, 0
	.dw 0x3840, 0xc02b,	0x387f, 0xc02b,		0x21, 0
	.dw 0x38c0, 0xc02b,	0x38ff, 0xc02b,		0x21, 0
	.dw 0x3940, 0xc02b,	0x397f, 0xc02b,		0x21, 0
	.dw 0x39c0, 0xc02b,	0xffff, 0xc02b,		0x21, 0
	.dw 0x0040, 0xc02c,	0x007f, 0xc02c,		0x21, 0
	.dw 0x00c0, 0xc02c,	0x00ff, 0xc02c,		0x21, 0
	.dw 0x0140, 0xc02c,	0x017f, 0xc02c,		0x21, 0
	.dw 0x01c0, 0xc02c,	0x01ff, 0xc02c,		0x21, 0
	.dw 0x0240, 0xc02c,	0x027f, 0xc02c,		0x21, 0
	.dw 0x02c0, 0xc02c,	0x02ff, 0xc02c,		0x21, 0
	.dw 0x0340, 0xc02c,	0x037f, 0xc02c,		0x21, 0
	.dw 0x03c0, 0xc02c,	0x03ff, 0xc02c,		0x21, 0
	.dw 0x0440, 0xc02c,	0x047f, 0xc02c,		0x21, 0
	.dw 0x04c0, 0xc02c,	0x04ff, 0xc02c,		0x21, 0
	.dw 0x0540, 0xc02c,	0x057f, 0xc02c,		0x21, 0
	.dw 0x05c0, 0xc02c,	0x05ff, 0xc02c,		0x21, 0
	.dw 0x0640, 0xc02c,	0x067f, 0xc02c,		0x21, 0
	.dw 0x06c0, 0xc02c,	0x06ff, 0xc02c,		0x21, 0
	.dw 0x0740, 0xc02c,	0x077f, 0xc02c,		0x21, 0
	.dw 0x07c0, 0xc02c,	0x07ff, 0xc02c,		0x21, 0
	.dw 0x0840, 0xc02c,	0x087f, 0xc02c,		0x21, 0
	.dw 0x08c0, 0xc02c,	0x08ff, 0xc02c,		0x21, 0
	.dw 0x0940, 0xc02c,	0x097f, 0xc02c,		0x21, 0
	.dw 0x09c0, 0xc02c,	0x09ff, 0xc02c,		0x21, 0
	.dw 0x0a40, 0xc02c,	0x0a7f, 0xc02c,		0x21, 0
	.dw 0x0ac0, 0xc02c,	0x0aff, 0xc02c,		0x21, 0
	.dw 0x0b40, 0xc02c,	0x0b7f, 0xc02c,		0x21, 0
	.dw 0x0bc0, 0xc02c,	0x0bff, 0xc02c,		0x21, 0
	.dw 0x0c40, 0xc02c,	0x0c7f, 0xc02c,		0x21, 0
	.dw 0x0cc0, 0xc02c,	0x0cff, 0xc02c,		0x21, 0
	.dw 0x0d40, 0xc02c,	0x0d7f, 0xc02c,		0x21, 0
	.dw 0x0dc0, 0xc02c,	0x0dff, 0xc02c,		0x21, 0
	.dw 0x0e40, 0xc02c,	0x0e7f, 0xc02c,		0x21, 0
	.dw 0x0ec0, 0xc02c,	0x0eff, 0xc02c,		0x21, 0
	.dw 0x0f40, 0xc02c,	0x0f7f, 0xc02c,		0x21, 0
	.dw 0x0fc0, 0xc02c,	0x0fff, 0xc02c,		0x21, 0
	.dw 0x1040, 0xc02c,	0x107f, 0xc02c,		0x21, 0
	.dw 0x10c0, 0xc02c,	0x10ff, 0xc02c,		0x21, 0
	.dw 0x1140, 0xc02c,	0x117f, 0xc02c,		0x21, 0
	.dw 0x11c0, 0xc02c,	0x11ff, 0xc02c,		0x21, 0
	.dw 0x1240, 0xc02c,	0x127f, 0xc02c,		0x21, 0
	.dw 0x12c0, 0xc02c,	0x12ff, 0xc02c,		0x21, 0
	.dw 0x1340, 0xc02c,	0x137f, 0xc02c,		0x21, 0
	.dw 0x13c0, 0xc02c,	0x13ff, 0xc02c,		0x21, 0
	.dw 0x1440, 0xc02c,	0x147f, 0xc02c,		0x21, 0
	.dw 0x14c0, 0xc02c,	0x14ff, 0xc02c,		0x21, 0
	.dw 0x1540, 0xc02c,	0x157f, 0xc02c,		0x21, 0
	.dw 0x15c0, 0xc02c,	0x15ff, 0xc02c,		0x21, 0
	.dw 0x1640, 0xc02c,	0x167f, 0xc02c,		0x21, 0
	.dw 0x16c0, 0xc02c,	0x16ff, 0xc02c,		0x21, 0
	.dw 0x1740, 0xc02c,	0x177f, 0xc02c,		0x21, 0
	.dw 0x17c0, 0xc02c,	0x17ff, 0xc02c,		0x21, 0
	.dw 0x1840, 0xc02c,	0x187f, 0xc02c,		0x21, 0
	.dw 0x18c0, 0xc02c,	0x18ff, 0xc02c,		0x21, 0
	.dw 0x1940, 0xc02c,	0x197f, 0xc02c,		0x21, 0
	.dw 0x19c0, 0xc02c,	0x1fff, 0xc02c,		0x21, 0
	.dw 0x2040, 0xc02c,	0x207f, 0xc02c,		0x21, 0
	.dw 0x20c0, 0xc02c,	0x20ff, 0xc02c,		0x21, 0
	.dw 0x2140, 0xc02c,	0x217f, 0xc02c,		0x21, 0
	.dw 0x21c0, 0xc02c,	0x21ff, 0xc02c,		0x21, 0
	.dw 0x2240, 0xc02c,	0x227f, 0xc02c,		0x21, 0
	.dw 0x22c0, 0xc02c,	0x22ff, 0xc02c,		0x21, 0
	.dw 0x2340, 0xc02c,	0x237f, 0xc02c,		0x21, 0
	.dw 0x23c0, 0xc02c,	0x23ff, 0xc02c,		0x21, 0
	.dw 0x2440, 0xc02c,	0x247f, 0xc02c,		0x21, 0
	.dw 0x24c0, 0xc02c,	0x24ff, 0xc02c,		0x21, 0
	.dw 0x2540, 0xc02c,	0x257f, 0xc02c,		0x21, 0
	.dw 0x25c0, 0xc02c,	0x25ff, 0xc02c,		0x21, 0
	.dw 0x2640, 0xc02c,	0x267f, 0xc02c,		0x21, 0
	.dw 0x26c0, 0xc02c,	0x26ff, 0xc02c,		0x21, 0
	.dw 0x2740, 0xc02c,	0x277f, 0xc02c,		0x21, 0
	.dw 0x27c0, 0xc02c,	0x27ff, 0xc02c,		0x21, 0
	.dw 0x2840, 0xc02c,	0x287f, 0xc02c,		0x21, 0
	.dw 0x28c0, 0xc02c,	0x28ff, 0xc02c,		0x21, 0
	.dw 0x2940, 0xc02c,	0x297f, 0xc02c,		0x21, 0
	.dw 0x29c0, 0xc02c,	0x29ff, 0xc02c,		0x21, 0
	.dw 0x2a40, 0xc02c,	0x2a7f, 0xc02c,		0x21, 0
	.dw 0x2ac0, 0xc02c,	0x2aff, 0xc02c,		0x21, 0
	.dw 0x2b40, 0xc02c,	0x2b7f, 0xc02c,		0x21, 0
	.dw 0x2bc0, 0xc02c,	0x2bff, 0xc02c,		0x21, 0
	.dw 0x2c40, 0xc02c,	0x2c7f, 0xc02c,		0x21, 0
	.dw 0x2cc0, 0xc02c,	0x2cff, 0xc02c,		0x21, 0
	.dw 0x2d40, 0xc02c,	0x2d7f, 0xc02c,		0x21, 0
	.dw 0x2dc0, 0xc02c,	0x2dff, 0xc02c,		0x21, 0
	.dw 0x2e40, 0xc02c,	0x2e7f, 0xc02c,		0x21, 0
	.dw 0x2ec0, 0xc02c,	0x2eff, 0xc02c,		0x21, 0
	.dw 0x2f40, 0xc02c,	0x2f7f, 0xc02c,		0x21, 0
	.dw 0x2fc0, 0xc02c,	0x2fff, 0xc02c,		0x21, 0
	.dw 0x3040, 0xc02c,	0x307f, 0xc02c,		0x21, 0
	.dw 0x30c0, 0xc02c,	0x30ff, 0xc02c,		0x21, 0
	.dw 0x3140, 0xc02c,	0x317f, 0xc02c,		0x21, 0
	.dw 0x31c0, 0xc02c,	0x31ff, 0xc02c,		0x21, 0
	.dw 0x3240, 0xc02c,	0x327f, 0xc02c,		0x21, 0
	.dw 0x32c0, 0xc02c,	0x32ff, 0xc02c,		0x21, 0
	.dw 0x3340, 0xc02c,	0x337f, 0xc02c,		0x21, 0
	.dw 0x33c0, 0xc02c,	0x33ff, 0xc02c,		0x21, 0
	.dw 0x3440, 0xc02c,	0x347f, 0xc02c,		0x21, 0
	.dw 0x34c0, 0xc02c,	0x34ff, 0xc02c,		0x21, 0
	.dw 0x3540, 0xc02c,	0x357f, 0xc02c,		0x21, 0
	.dw 0x35c0, 0xc02c,	0x35ff, 0xc02c,		0x21, 0
	.dw 0x3640, 0xc02c,	0x367f, 0xc02c,		0x21, 0
	.dw 0x36c0, 0xc02c,	0x36ff, 0xc02c,		0x21, 0
	.dw 0x3740, 0xc02c,	0x377f, 0xc02c,		0x21, 0
	.dw 0x37c0, 0xc02c,	0x37ff, 0xc02c,		0x21, 0
	.dw 0x3840, 0xc02c,	0x387f, 0xc02c,		0x21, 0
	.dw 0x38c0, 0xc02c,	0x38ff, 0xc02c,		0x21, 0
	.dw 0x3940, 0xc02c,	0x397f, 0xc02c,		0x21, 0
	.dw 0x39c0, 0xc02c,	0x3fff, 0xc02c,		0x21, 0
	.dw 0x4040, 0xc02c,	0x407f, 0xc02c,		0x21, 0
	.dw 0x40c0, 0xc02c,	0x40ff, 0xc02c,		0x21, 0
	.dw 0x4140, 0xc02c,	0x417f, 0xc02c,		0x21, 0
	.dw 0x41c0, 0xc02c,	0x41ff, 0xc02c,		0x21, 0
	.dw 0x4240, 0xc02c,	0x427f, 0xc02c,		0x21, 0
	.dw 0x42c0, 0xc02c,	0x42ff, 0xc02c,		0x21, 0
	.dw 0x4340, 0xc02c,	0x437f, 0xc02c,		0x21, 0
	.dw 0x43c0, 0xc02c,	0x43ff, 0xc02c,		0x21, 0
	.dw 0x4440, 0xc02c,	0x447f, 0xc02c,		0x21, 0
	.dw 0x44c0, 0xc02c,	0x44ff, 0xc02c,		0x21, 0
	.dw 0x4540, 0xc02c,	0x457f, 0xc02c,		0x21, 0
	.dw 0x45c0, 0xc02c,	0x45ff, 0xc02c,		0x21, 0
	.dw 0x4640, 0xc02c,	0x467f, 0xc02c,		0x21, 0
	.dw 0x46c0, 0xc02c,	0x46ff, 0xc02c,		0x21, 0
	.dw 0x4740, 0xc02c,	0x477f, 0xc02c,		0x21, 0
	.dw 0x47c0, 0xc02c,	0x47ff, 0xc02c,		0x21, 0
	.dw 0x4840, 0xc02c,	0x487f, 0xc02c,		0x21, 0
	.dw 0x48c0, 0xc02c,	0x48ff, 0xc02c,		0x21, 0
	.dw 0x4940, 0xc02c,	0x497f, 0xc02c,		0x21, 0
	.dw 0x49c0, 0xc02c,	0x49ff, 0xc02c,		0x21, 0
	.dw 0x4a40, 0xc02c,	0x4a7f, 0xc02c,		0x21, 0
	.dw 0x4ac0, 0xc02c,	0x4aff, 0xc02c,		0x21, 0
	.dw 0x4b40, 0xc02c,	0x4b7f, 0xc02c,		0x21, 0
	.dw 0x4bc0, 0xc02c,	0x4bff, 0xc02c,		0x21, 0
	.dw 0x4c40, 0xc02c,	0x4c7f, 0xc02c,		0x21, 0
	.dw 0x4cc0, 0xc02c,	0x4cff, 0xc02c,		0x21, 0
	.dw 0x4d40, 0xc02c,	0x4d7f, 0xc02c,		0x21, 0
	.dw 0x4dc0, 0xc02c,	0x4dff, 0xc02c,		0x21, 0
	.dw 0x4e40, 0xc02c,	0x4e7f, 0xc02c,		0x21, 0
	.dw 0x4ec0, 0xc02c,	0x4eff, 0xc02c,		0x21, 0
	.dw 0x4f40, 0xc02c,	0x4f7f, 0xc02c,		0x21, 0
	.dw 0x4fc0, 0xc02c,	0x4fff, 0xc02c,		0x21, 0
	.dw 0x5040, 0xc02c,	0x507f, 0xc02c,		0x21, 0
	.dw 0x50c0, 0xc02c,	0x50ff, 0xc02c,		0x21, 0
	.dw 0x5140, 0xc02c,	0x517f, 0xc02c,		0x21, 0
	.dw 0x51c0, 0xc02c,	0x51ff, 0xc02c,		0x21, 0
	.dw 0x5240, 0xc02c,	0x527f, 0xc02c,		0x21, 0
	.dw 0x52c0, 0xc02c,	0x52ff, 0xc02c,		0x21, 0
	.dw 0x5340, 0xc02c,	0x537f, 0xc02c,		0x21, 0
	.dw 0x53c0, 0xc02c,	0x53ff, 0xc02c,		0x21, 0
	.dw 0x5440, 0xc02c,	0x547f, 0xc02c,		0x21, 0
	.dw 0x54c0, 0xc02c,	0x54ff, 0xc02c,		0x21, 0
	.dw 0x5540, 0xc02c,	0x557f, 0xc02c,		0x21, 0
	.dw 0x55c0, 0xc02c,	0x55ff, 0xc02c,		0x21, 0
	.dw 0x5640, 0xc02c,	0x567f, 0xc02c,		0x21, 0
	.dw 0x56c0, 0xc02c,	0x56ff, 0xc02c,		0x21, 0
	.dw 0x5740, 0xc02c,	0x577f, 0xc02c,		0x21, 0
	.dw 0x57c0, 0xc02c,	0x57ff, 0xc02c,		0x21, 0
	.dw 0x5840, 0xc02c,	0x587f, 0xc02c,		0x21, 0
	.dw 0x58c0, 0xc02c,	0x58ff, 0xc02c,		0x21, 0
	.dw 0x5940, 0xc02c,	0x597f, 0xc02c,		0x21, 0
	.dw 0x59c0, 0xc02c,	0x5fff, 0xc02c,		0x21, 0
	.dw 0x6040, 0xc02c,	0x607f, 0xc02c,		0x21, 0
	.dw 0x60c0, 0xc02c,	0x60ff, 0xc02c,		0x21, 0
	.dw 0x6140, 0xc02c,	0x617f, 0xc02c,		0x21, 0
	.dw 0x61c0, 0xc02c,	0x61ff, 0xc02c,		0x21, 0
	.dw 0x6240, 0xc02c,	0x627f, 0xc02c,		0x21, 0
	.dw 0x62c0, 0xc02c,	0x62ff, 0xc02c,		0x21, 0
	.dw 0x6340, 0xc02c,	0x637f, 0xc02c,		0x21, 0
	.dw 0x63c0, 0xc02c,	0x63ff, 0xc02c,		0x21, 0
	.dw 0x6440, 0xc02c,	0x647f, 0xc02c,		0x21, 0
	.dw 0x64c0, 0xc02c,	0x64ff, 0xc02c,		0x21, 0
	.dw 0x6540, 0xc02c,	0x657f, 0xc02c,		0x21, 0
	.dw 0x65c0, 0xc02c,	0x65ff, 0xc02c,		0x21, 0
	.dw 0x6640, 0xc02c,	0x667f, 0xc02c,		0x21, 0
	.dw 0x66c0, 0xc02c,	0x66ff, 0xc02c,		0x21, 0
	.dw 0x6740, 0xc02c,	0x677f, 0xc02c,		0x21, 0
	.dw 0x67c0, 0xc02c,	0x67ff, 0xc02c,		0x21, 0
	.dw 0x6840, 0xc02c,	0x687f, 0xc02c,		0x21, 0
	.dw 0x68c0, 0xc02c,	0x68ff, 0xc02c,		0x21, 0
	.dw 0x6940, 0xc02c,	0x697f, 0xc02c,		0x21, 0
	.dw 0x69c0, 0xc02c,	0x69ff, 0xc02c,		0x21, 0
	.dw 0x6a40, 0xc02c,	0x6a7f, 0xc02c,		0x21, 0
	.dw 0x6ac0, 0xc02c,	0x6aff, 0xc02c,		0x21, 0
	.dw 0x6b40, 0xc02c,	0x6b7f, 0xc02c,		0x21, 0
	.dw 0x6bc0, 0xc02c,	0x6bff, 0xc02c,		0x21, 0
	.dw 0x6c40, 0xc02c,	0x6c7f, 0xc02c,		0x21, 0
	.dw 0x6cc0, 0xc02c,	0x6cff, 0xc02c,		0x21, 0
	.dw 0x6d40, 0xc02c,	0x6d7f, 0xc02c,		0x21, 0
	.dw 0x6dc0, 0xc02c,	0x6dff, 0xc02c,		0x21, 0
	.dw 0x6e40, 0xc02c,	0x6e7f, 0xc02c,		0x21, 0
	.dw 0x6ec0, 0xc02c,	0x6eff, 0xc02c,		0x21, 0
	.dw 0x6f40, 0xc02c,	0x6f7f, 0xc02c,		0x21, 0
	.dw 0x6fc0, 0xc02c,	0x6fff, 0xc02c,		0x21, 0
	.dw 0x7040, 0xc02c,	0x707f, 0xc02c,		0x21, 0
	.dw 0x70c0, 0xc02c,	0x70ff, 0xc02c,		0x21, 0
	.dw 0x7140, 0xc02c,	0x717f, 0xc02c,		0x21, 0
	.dw 0x71c0, 0xc02c,	0x71ff, 0xc02c,		0x21, 0
	.dw 0x7240, 0xc02c,	0x727f, 0xc02c,		0x21, 0
	.dw 0x72c0, 0xc02c,	0x72ff, 0xc02c,		0x21, 0
	.dw 0x7340, 0xc02c,	0x737f, 0xc02c,		0x21, 0
	.dw 0x73c0, 0xc02c,	0x73ff, 0xc02c,		0x21, 0
	.dw 0x7440, 0xc02c,	0x747f, 0xc02c,		0x21, 0
	.dw 0x74c0, 0xc02c,	0x74ff, 0xc02c,		0x21, 0
	.dw 0x7540, 0xc02c,	0x757f, 0xc02c,		0x21, 0
	.dw 0x75c0, 0xc02c,	0x75ff, 0xc02c,		0x21, 0
	.dw 0x7640, 0xc02c,	0x767f, 0xc02c,		0x21, 0
	.dw 0x76c0, 0xc02c,	0x76ff, 0xc02c,		0x21, 0
	.dw 0x7740, 0xc02c,	0x777f, 0xc02c,		0x21, 0
	.dw 0x77c0, 0xc02c,	0x77ff, 0xc02c,		0x21, 0
	.dw 0x7840, 0xc02c,	0x787f, 0xc02c,		0x21, 0
	.dw 0x78c0, 0xc02c,	0x78ff, 0xc02c,		0x21, 0
	.dw 0x7940, 0xc02c,	0x797f, 0xc02c,		0x21, 0
	.dw 0x79c0, 0xc02c,	0x7fff, 0xc02c,		0x21, 0
	.dw 0x8040, 0xc02c,	0x807f, 0xc02c,		0x21, 0
	.dw 0x80c0, 0xc02c,	0x80ff, 0xc02c,		0x21, 0
	.dw 0x8140, 0xc02c,	0x817f, 0xc02c,		0x21, 0
	.dw 0x81c0, 0xc02c,	0x81ff, 0xc02c,		0x21, 0
	.dw 0x8240, 0xc02c,	0x827f, 0xc02c,		0x21, 0
	.dw 0x82c0, 0xc02c,	0x82ff, 0xc02c,		0x21, 0
	.dw 0x8340, 0xc02c,	0x837f, 0xc02c,		0x21, 0
	.dw 0x83c0, 0xc02c,	0x83ff, 0xc02c,		0x21, 0
	.dw 0x8440, 0xc02c,	0x847f, 0xc02c,		0x21, 0
	.dw 0x84c0, 0xc02c,	0x84ff, 0xc02c,		0x21, 0
	.dw 0x8540, 0xc02c,	0x857f, 0xc02c,		0x21, 0
	.dw 0x85c0, 0xc02c,	0x85ff, 0xc02c,		0x21, 0
	.dw 0x8640, 0xc02c,	0x867f, 0xc02c,		0x21, 0
	.dw 0x86c0, 0xc02c,	0x86ff, 0xc02c,		0x21, 0
	.dw 0x8740, 0xc02c,	0x877f, 0xc02c,		0x21, 0
	.dw 0x87c0, 0xc02c,	0x87ff, 0xc02c,		0x21, 0
	.dw 0x8840, 0xc02c,	0x887f, 0xc02c,		0x21, 0
	.dw 0x88c0, 0xc02c,	0x88ff, 0xc02c,		0x21, 0
	.dw 0x8940, 0xc02c,	0x897f, 0xc02c,		0x21, 0
	.dw 0x89c0, 0xc02c,	0x89ff, 0xc02c,		0x21, 0
	.dw 0x8a40, 0xc02c,	0x8a7f, 0xc02c,		0x21, 0
	.dw 0x8ac0, 0xc02c,	0x8aff, 0xc02c,		0x21, 0
	.dw 0x8b40, 0xc02c,	0x8b7f, 0xc02c,		0x21, 0
	.dw 0x8bc0, 0xc02c,	0x8bff, 0xc02c,		0x21, 0
	.dw 0x8c40, 0xc02c,	0x8c7f, 0xc02c,		0x21, 0
	.dw 0x8cc0, 0xc02c,	0x8cff, 0xc02c,		0x21, 0
	.dw 0x8d40, 0xc02c,	0x8d7f, 0xc02c,		0x21, 0
	.dw 0x8dc0, 0xc02c,	0x8dff, 0xc02c,		0x21, 0
	.dw 0x8e40, 0xc02c,	0x8e7f, 0xc02c,		0x21, 0
	.dw 0x8ec0, 0xc02c,	0x8eff, 0xc02c,		0x21, 0
	.dw 0x8f40, 0xc02c,	0x8f7f, 0xc02c,		0x21, 0
	.dw 0x8fc0, 0xc02c,	0x8fff, 0xc02c,		0x21, 0
	.dw 0x9040, 0xc02c,	0x907f, 0xc02c,		0x21, 0
	.dw 0x90c0, 0xc02c,	0x90ff, 0xc02c,		0x21, 0
	.dw 0x9140, 0xc02c,	0x917f, 0xc02c,		0x21, 0
	.dw 0x91c0, 0xc02c,	0x91ff, 0xc02c,		0x21, 0
	.dw 0x9240, 0xc02c,	0x927f, 0xc02c,		0x21, 0
	.dw 0x92c0, 0xc02c,	0x92ff, 0xc02c,		0x21, 0
	.dw 0x9340, 0xc02c,	0x937f, 0xc02c,		0x21, 0
	.dw 0x93c0, 0xc02c,	0x93ff, 0xc02c,		0x21, 0
	.dw 0x9440, 0xc02c,	0x947f, 0xc02c,		0x21, 0
	.dw 0x94c0, 0xc02c,	0x94ff, 0xc02c,		0x21, 0
	.dw 0x9540, 0xc02c,	0x957f, 0xc02c,		0x21, 0
	.dw 0x95c0, 0xc02c,	0x95ff, 0xc02c,		0x21, 0
	.dw 0x9640, 0xc02c,	0x967f, 0xc02c,		0x21, 0
	.dw 0x96c0, 0xc02c,	0x96ff, 0xc02c,		0x21, 0
	.dw 0x9740, 0xc02c,	0x977f, 0xc02c,		0x21, 0
	.dw 0x97c0, 0xc02c,	0x97ff, 0xc02c,		0x21, 0
	.dw 0x9840, 0xc02c,	0x987f, 0xc02c,		0x21, 0
	.dw 0x98c0, 0xc02c,	0x98ff, 0xc02c,		0x21, 0
	.dw 0x9940, 0xc02c,	0x997f, 0xc02c,		0x21, 0
	.dw 0x99c0, 0xc02c,	0x9fff, 0xc02c,		0x21, 0
	.dw 0xa040, 0xc02c,	0xa07f, 0xc02c,		0x21, 0
	.dw 0xa0c0, 0xc02c,	0xa0ff, 0xc02c,		0x21, 0
	.dw 0xa140, 0xc02c,	0xa17f, 0xc02c,		0x21, 0
	.dw 0xa1c0, 0xc02c,	0xa1ff, 0xc02c,		0x21, 0
	.dw 0xa240, 0xc02c,	0xa27f, 0xc02c,		0x21, 0
	.dw 0xa2c0, 0xc02c,	0xa2ff, 0xc02c,		0x21, 0
	.dw 0xa340, 0xc02c,	0xa37f, 0xc02c,		0x21, 0
	.dw 0xa3c0, 0xc02c,	0xa3ff, 0xc02c,		0x21, 0
	.dw 0xa440, 0xc02c,	0xa47f, 0xc02c,		0x21, 0
	.dw 0xa4c0, 0xc02c,	0xa4ff, 0xc02c,		0x21, 0
	.dw 0xa540, 0xc02c,	0xa57f, 0xc02c,		0x21, 0
	.dw 0xa5c0, 0xc02c,	0xa5ff, 0xc02c,		0x21, 0
	.dw 0xa640, 0xc02c,	0xa67f, 0xc02c,		0x21, 0
	.dw 0xa6c0, 0xc02c,	0xa6ff, 0xc02c,		0x21, 0
	.dw 0xa740, 0xc02c,	0xa77f, 0xc02c,		0x21, 0
	.dw 0xa7c0, 0xc02c,	0xa7ff, 0xc02c,		0x21, 0
	.dw 0xa840, 0xc02c,	0xa87f, 0xc02c,		0x21, 0
	.dw 0xa8c0, 0xc02c,	0xa8ff, 0xc02c,		0x21, 0
	.dw 0xa940, 0xc02c,	0xa97f, 0xc02c,		0x21, 0
	.dw 0xa9c0, 0xc02c,	0xa9ff, 0xc02c,		0x21, 0
	.dw 0xaa40, 0xc02c,	0xaa7f, 0xc02c,		0x21, 0
	.dw 0xaac0, 0xc02c,	0xaaff, 0xc02c,		0x21, 0
	.dw 0xab40, 0xc02c,	0xab7f, 0xc02c,		0x21, 0
	.dw 0xabc0, 0xc02c,	0xabff, 0xc02c,		0x21, 0
	.dw 0xac40, 0xc02c,	0xac7f, 0xc02c,		0x21, 0
	.dw 0xacc0, 0xc02c,	0xacff, 0xc02c,		0x21, 0
	.dw 0xad40, 0xc02c,	0xad7f, 0xc02c,		0x21, 0
	.dw 0xadc0, 0xc02c,	0xadff, 0xc02c,		0x21, 0
	.dw 0xae40, 0xc02c,	0xae7f, 0xc02c,		0x21, 0
	.dw 0xaec0, 0xc02c,	0xaeff, 0xc02c,		0x21, 0
	.dw 0xaf40, 0xc02c,	0xaf7f, 0xc02c,		0x21, 0
	.dw 0xafc0, 0xc02c,	0xafff, 0xc02c,		0x21, 0
	.dw 0xb040, 0xc02c,	0xb07f, 0xc02c,		0x21, 0
	.dw 0xb0c0, 0xc02c,	0xb0ff, 0xc02c,		0x21, 0
	.dw 0xb140, 0xc02c,	0xb17f, 0xc02c,		0x21, 0
	.dw 0xb1c0, 0xc02c,	0xb1ff, 0xc02c,		0x21, 0
	.dw 0xb240, 0xc02c,	0xb27f, 0xc02c,		0x21, 0
	.dw 0xb2c0, 0xc02c,	0xb2ff, 0xc02c,		0x21, 0
	.dw 0xb340, 0xc02c,	0xb37f, 0xc02c,		0x21, 0
	.dw 0xb3c0, 0xc02c,	0xb3ff, 0xc02c,		0x21, 0
	.dw 0xb440, 0xc02c,	0xb47f, 0xc02c,		0x21, 0
	.dw 0xb4c0, 0xc02c,	0xb4ff, 0xc02c,		0x21, 0
	.dw 0xb540, 0xc02c,	0xb57f, 0xc02c,		0x21, 0
	.dw 0xb5c0, 0xc02c,	0xb5ff, 0xc02c,		0x21, 0
	.dw 0xb640, 0xc02c,	0xb67f, 0xc02c,		0x21, 0
	.dw 0xb6c0, 0xc02c,	0xb6ff, 0xc02c,		0x21, 0
	.dw 0xb740, 0xc02c,	0xb77f, 0xc02c,		0x21, 0
	.dw 0xb7c0, 0xc02c,	0xb7ff, 0xc02c,		0x21, 0
	.dw 0xb840, 0xc02c,	0xb87f, 0xc02c,		0x21, 0
	.dw 0xb8c0, 0xc02c,	0xb8ff, 0xc02c,		0x21, 0
	.dw 0xb940, 0xc02c,	0xb97f, 0xc02c,		0x21, 0
	.dw 0xb9c0, 0xc02c,	0xbfff, 0xc02c,		0x21, 0
	.dw 0xc040, 0xc02c,	0xc07f, 0xc02c,		0x21, 0
	.dw 0xc0c0, 0xc02c,	0xc0ff, 0xc02c,		0x21, 0
	.dw 0xc140, 0xc02c,	0xc17f, 0xc02c,		0x21, 0
	.dw 0xc1c0, 0xc02c,	0xc1ff, 0xc02c,		0x21, 0
	.dw 0xc240, 0xc02c,	0xc27f, 0xc02c,		0x21, 0
	.dw 0xc2c0, 0xc02c,	0xc2ff, 0xc02c,		0x21, 0
	.dw 0xc340, 0xc02c,	0xc37f, 0xc02c,		0x21, 0
	.dw 0xc3c0, 0xc02c,	0xc3ff, 0xc02c,		0x21, 0
	.dw 0xc440, 0xc02c,	0xc47f, 0xc02c,		0x21, 0
	.dw 0xc4c0, 0xc02c,	0xc4ff, 0xc02c,		0x21, 0
	.dw 0xc540, 0xc02c,	0xc57f, 0xc02c,		0x21, 0
	.dw 0xc5c0, 0xc02c,	0xc5ff, 0xc02c,		0x21, 0
	.dw 0xc640, 0xc02c,	0xc67f, 0xc02c,		0x21, 0
	.dw 0xc6c0, 0xc02c,	0xc6ff, 0xc02c,		0x21, 0
	.dw 0xc740, 0xc02c,	0xc77f, 0xc02c,		0x21, 0
	.dw 0xc7c0, 0xc02c,	0xc7ff, 0xc02c,		0x21, 0
	.dw 0xc840, 0xc02c,	0xc87f, 0xc02c,		0x21, 0
	.dw 0xc8c0, 0xc02c,	0xc8ff, 0xc02c,		0x21, 0
	.dw 0xc940, 0xc02c,	0xc97f, 0xc02c,		0x21, 0
	.dw 0xc9c0, 0xc02c,	0xc9ff, 0xc02c,		0x21, 0
	.dw 0xca40, 0xc02c,	0xca7f, 0xc02c,		0x21, 0
	.dw 0xcac0, 0xc02c,	0xcaff, 0xc02c,		0x21, 0
	.dw 0xcb40, 0xc02c,	0xcb7f, 0xc02c,		0x21, 0
	.dw 0xcbc0, 0xc02c,	0xcbff, 0xc02c,		0x21, 0
	.dw 0xcc40, 0xc02c,	0xcc7f, 0xc02c,		0x21, 0
	.dw 0xccc0, 0xc02c,	0xccff, 0xc02c,		0x21, 0
	.dw 0xcd40, 0xc02c,	0xcd7f, 0xc02c,		0x21, 0
	.dw 0xcdc0, 0xc02c,	0xcdff, 0xc02c,		0x21, 0
	.dw 0xce40, 0xc02c,	0xce7f, 0xc02c,		0x21, 0
	.dw 0xcec0, 0xc02c,	0xceff, 0xc02c,		0x21, 0
	.dw 0xcf40, 0xc02c,	0xcf7f, 0xc02c,		0x21, 0
	.dw 0xcfc0, 0xc02c,	0xcfff, 0xc02c,		0x21, 0
	.dw 0xd040, 0xc02c,	0xd07f, 0xc02c,		0x21, 0
	.dw 0xd0c0, 0xc02c,	0xd0ff, 0xc02c,		0x21, 0
	.dw 0xd140, 0xc02c,	0xd17f, 0xc02c,		0x21, 0
	.dw 0xd1c0, 0xc02c,	0xd1ff, 0xc02c,		0x21, 0
	.dw 0xd240, 0xc02c,	0xd27f, 0xc02c,		0x21, 0
	.dw 0xd2c0, 0xc02c,	0xd2ff, 0xc02c,		0x21, 0
	.dw 0xd340, 0xc02c,	0xd37f, 0xc02c,		0x21, 0
	.dw 0xd3c0, 0xc02c,	0xd3ff, 0xc02c,		0x21, 0
	.dw 0xd440, 0xc02c,	0xd47f, 0xc02c,		0x21, 0
	.dw 0xd4c0, 0xc02c,	0xd4ff, 0xc02c,		0x21, 0
	.dw 0xd540, 0xc02c,	0xd57f, 0xc02c,		0x21, 0
	.dw 0xd5c0, 0xc02c,	0xd5ff, 0xc02c,		0x21, 0
	.dw 0xd640, 0xc02c,	0xd67f, 0xc02c,		0x21, 0
	.dw 0xd6c0, 0xc02c,	0xd6ff, 0xc02c,		0x21, 0
	.dw 0xd740, 0xc02c,	0xd77f, 0xc02c,		0x21, 0
	.dw 0xd7c0, 0xc02c,	0xd7ff, 0xc02c,		0x21, 0
	.dw 0xd840, 0xc02c,	0xd87f, 0xc02c,		0x21, 0
	.dw 0xd8c0, 0xc02c,	0xd8ff, 0xc02c,		0x21, 0
	.dw 0xd940, 0xc02c,	0xd97f, 0xc02c,		0x21, 0
	.dw 0xd9c0, 0xc02c,	0xdfff, 0xc02c,		0x21, 0
	.dw 0xe040, 0xc02c,	0xe07f, 0xc02c,		0x21, 0
	.dw 0xe0c0, 0xc02c,	0xe0ff, 0xc02c,		0x21, 0
	.dw 0xe140, 0xc02c,	0xe17f, 0xc02c,		0x21, 0
	.dw 0xe1c0, 0xc02c,	0xe1ff, 0xc02c,		0x21, 0
	.dw 0xe240, 0xc02c,	0xe27f, 0xc02c,		0x21, 0
	.dw 0xe2c0, 0xc02c,	0xe2ff, 0xc02c,		0x21, 0
	.dw 0xe340, 0xc02c,	0xe37f, 0xc02c,		0x21, 0
	.dw 0xe3c0, 0xc02c,	0xe3ff, 0xc02c,		0x21, 0
	.dw 0xe440, 0xc02c,	0xe47f, 0xc02c,		0x21, 0
	.dw 0xe4c0, 0xc02c,	0xe4ff, 0xc02c,		0x21, 0
	.dw 0xe540, 0xc02c,	0xe57f, 0xc02c,		0x21, 0
	.dw 0xe5c0, 0xc02c,	0xe5ff, 0xc02c,		0x21, 0
	.dw 0xe640, 0xc02c,	0xe67f, 0xc02c,		0x21, 0
	.dw 0xe6c0, 0xc02c,	0xe6ff, 0xc02c,		0x21, 0
	.dw 0xe740, 0xc02c,	0xe77f, 0xc02c,		0x21, 0
	.dw 0xe7c0, 0xc02c,	0xe7ff, 0xc02c,		0x21, 0
	.dw 0xe840, 0xc02c,	0xe87f, 0xc02c,		0x21, 0
	.dw 0xe8c0, 0xc02c,	0xe8ff, 0xc02c,		0x21, 0
	.dw 0xe940, 0xc02c,	0xe97f, 0xc02c,		0x21, 0
	.dw 0xe9c0, 0xc02c,	0xe9ff, 0xc02c,		0x21, 0
	.dw 0xea40, 0xc02c,	0xea7f, 0xc02c,		0x21, 0
	.dw 0xeac0, 0xc02c,	0xeaff, 0xc02c,		0x21, 0
	.dw 0xeb40, 0xc02c,	0xeb7f, 0xc02c,		0x21, 0
	.dw 0xebc0, 0xc02c,	0xebff, 0xc02c,		0x21, 0
	.dw 0xec40, 0xc02c,	0xec7f, 0xc02c,		0x21, 0
	.dw 0xecc0, 0xc02c,	0xecff, 0xc02c,		0x21, 0
	.dw 0xed40, 0xc02c,	0xed7f, 0xc02c,		0x21, 0
	.dw 0xedc0, 0xc02c,	0xedff, 0xc02c,		0x21, 0
	.dw 0xee40, 0xc02c,	0xee7f, 0xc02c,		0x21, 0
	.dw 0xeec0, 0xc02c,	0xeeff, 0xc02c,		0x21, 0
	.dw 0xef40, 0xc02c,	0xef7f, 0xc02c,		0x21, 0
	.dw 0xefc0, 0xc02c,	0xefff, 0xc02c,		0x21, 0
	.dw 0xf040, 0xc02c,	0xf07f, 0xc02c,		0x21, 0
	.dw 0xf0c0, 0xc02c,	0xf0ff, 0xc02c,		0x21, 0
	.dw 0xf140, 0xc02c,	0xf17f, 0xc02c,		0x21, 0
	.dw 0xf1c0, 0xc02c,	0xf1ff, 0xc02c,		0x21, 0
	.dw 0xf240, 0xc02c,	0xf27f, 0xc02c,		0x21, 0
	.dw 0xf2c0, 0xc02c,	0xf2ff, 0xc02c,		0x21, 0
	.dw 0xf340, 0xc02c,	0xf37f, 0xc02c,		0x21, 0
	.dw 0xf3c0, 0xc02c,	0xf3ff, 0xc02c,		0x21, 0
	.dw 0xf440, 0xc02c,	0xf47f, 0xc02c,		0x21, 0
	.dw 0xf4c0, 0xc02c,	0xf4ff, 0xc02c,		0x21, 0
	.dw 0xf540, 0xc02c,	0xf57f, 0xc02c,		0x21, 0
	.dw 0xf5c0, 0xc02c,	0xf5ff, 0xc02c,		0x21, 0
	.dw 0xf640, 0xc02c,	0xf67f, 0xc02c,		0x21, 0
	.dw 0xf6c0, 0xc02c,	0xf6ff, 0xc02c,		0x21, 0
	.dw 0xf740, 0xc02c,	0xf77f, 0xc02c,		0x21, 0
	.dw 0xf7c0, 0xc02c,	0xf7ff, 0xc02c,		0x21, 0
	.dw 0xf840, 0xc02c,	0xf87f, 0xc02c,		0x21, 0
	.dw 0xf8c0, 0xc02c,	0xf8ff, 0xc02c,		0x21, 0
	.dw 0xf940, 0xc02c,	0xf97f, 0xc02c,		0x21, 0
	.dw 0xf9c0, 0xc02c,	0xffff, 0xc02c,		0x21, 0
	.dw 0x0040, 0xc02d,	0x007f, 0xc02d,		0x21, 0
	.dw 0x00c0, 0xc02d,	0x00ff, 0xc02d,		0x21, 0
	.dw 0x0140, 0xc02d,	0x017f, 0xc02d,		0x21, 0
	.dw 0x01c0, 0xc02d,	0x01ff, 0xc02d,		0x21, 0
	.dw 0x0240, 0xc02d,	0x027f, 0xc02d,		0x21, 0
	.dw 0x02c0, 0xc02d,	0x02ff, 0xc02d,		0x21, 0
	.dw 0x0340, 0xc02d,	0x037f, 0xc02d,		0x21, 0
	.dw 0x03c0, 0xc02d,	0x03ff, 0xc02d,		0x21, 0
	.dw 0x0440, 0xc02d,	0x047f, 0xc02d,		0x21, 0
	.dw 0x04c0, 0xc02d,	0x04ff, 0xc02d,		0x21, 0
	.dw 0x0540, 0xc02d,	0x057f, 0xc02d,		0x21, 0
	.dw 0x05c0, 0xc02d,	0x05ff, 0xc02d,		0x21, 0
	.dw 0x0640, 0xc02d,	0x067f, 0xc02d,		0x21, 0
	.dw 0x06c0, 0xc02d,	0x06ff, 0xc02d,		0x21, 0
	.dw 0x0740, 0xc02d,	0x077f, 0xc02d,		0x21, 0
	.dw 0x07c0, 0xc02d,	0x07ff, 0xc02d,		0x21, 0
	.dw 0x0840, 0xc02d,	0x087f, 0xc02d,		0x21, 0
	.dw 0x08c0, 0xc02d,	0x08ff, 0xc02d,		0x21, 0
	.dw 0x0940, 0xc02d,	0x097f, 0xc02d,		0x21, 0
	.dw 0x09c0, 0xc02d,	0x09ff, 0xc02d,		0x21, 0
	.dw 0x0a40, 0xc02d,	0x0a7f, 0xc02d,		0x21, 0
	.dw 0x0ac0, 0xc02d,	0x0aff, 0xc02d,		0x21, 0
	.dw 0x0b40, 0xc02d,	0x0b7f, 0xc02d,		0x21, 0
	.dw 0x0bc0, 0xc02d,	0x0bff, 0xc02d,		0x21, 0
	.dw 0x0c40, 0xc02d,	0x0c7f, 0xc02d,		0x21, 0
	.dw 0x0cc0, 0xc02d,	0x0cff, 0xc02d,		0x21, 0
	.dw 0x0d40, 0xc02d,	0x0d7f, 0xc02d,		0x21, 0
	.dw 0x0dc0, 0xc02d,	0x0dff, 0xc02d,		0x21, 0
	.dw 0x0e40, 0xc02d,	0x0e7f, 0xc02d,		0x21, 0
	.dw 0x0ec0, 0xc02d,	0x0eff, 0xc02d,		0x21, 0
	.dw 0x0f40, 0xc02d,	0x0f7f, 0xc02d,		0x21, 0
	.dw 0x0fc0, 0xc02d,	0x0fff, 0xc02d,		0x21, 0
	.dw 0x1040, 0xc02d,	0x107f, 0xc02d,		0x21, 0
	.dw 0x10c0, 0xc02d,	0x10ff, 0xc02d,		0x21, 0
	.dw 0x1140, 0xc02d,	0x117f, 0xc02d,		0x21, 0
	.dw 0x11c0, 0xc02d,	0x11ff, 0xc02d,		0x21, 0
	.dw 0x1240, 0xc02d,	0x127f, 0xc02d,		0x21, 0
	.dw 0x12c0, 0xc02d,	0x12ff, 0xc02d,		0x21, 0
	.dw 0x1340, 0xc02d,	0x137f, 0xc02d,		0x21, 0
	.dw 0x13c0, 0xc02d,	0x13ff, 0xc02d,		0x21, 0
	.dw 0x1440, 0xc02d,	0x147f, 0xc02d,		0x21, 0
	.dw 0x14c0, 0xc02d,	0x14ff, 0xc02d,		0x21, 0
	.dw 0x1540, 0xc02d,	0x157f, 0xc02d,		0x21, 0
	.dw 0x15c0, 0xc02d,	0x15ff, 0xc02d,		0x21, 0
	.dw 0x1640, 0xc02d,	0x167f, 0xc02d,		0x21, 0
	.dw 0x16c0, 0xc02d,	0x16ff, 0xc02d,		0x21, 0
	.dw 0x1740, 0xc02d,	0x177f, 0xc02d,		0x21, 0
	.dw 0x17c0, 0xc02d,	0x17ff, 0xc02d,		0x21, 0
	.dw 0x1840, 0xc02d,	0x187f, 0xc02d,		0x21, 0
	.dw 0x18c0, 0xc02d,	0x18ff, 0xc02d,		0x21, 0
	.dw 0x1940, 0xc02d,	0x197f, 0xc02d,		0x21, 0
	.dw 0x19c0, 0xc02d,	0x1fff, 0xc02d,		0x21, 0
	.dw 0x2040, 0xc02d,	0x207f, 0xc02d,		0x21, 0
	.dw 0x20c0, 0xc02d,	0x20ff, 0xc02d,		0x21, 0
	.dw 0x2140, 0xc02d,	0x217f, 0xc02d,		0x21, 0
	.dw 0x21c0, 0xc02d,	0x21ff, 0xc02d,		0x21, 0
	.dw 0x2240, 0xc02d,	0x227f, 0xc02d,		0x21, 0
	.dw 0x22c0, 0xc02d,	0x22ff, 0xc02d,		0x21, 0
	.dw 0x2340, 0xc02d,	0x237f, 0xc02d,		0x21, 0
	.dw 0x23c0, 0xc02d,	0x23ff, 0xc02d,		0x21, 0
	.dw 0x2440, 0xc02d,	0x247f, 0xc02d,		0x21, 0
	.dw 0x24c0, 0xc02d,	0x24ff, 0xc02d,		0x21, 0
	.dw 0x2540, 0xc02d,	0x257f, 0xc02d,		0x21, 0
	.dw 0x25c0, 0xc02d,	0x25ff, 0xc02d,		0x21, 0
	.dw 0x2640, 0xc02d,	0x267f, 0xc02d,		0x21, 0
	.dw 0x26c0, 0xc02d,	0x26ff, 0xc02d,		0x21, 0
	.dw 0x2740, 0xc02d,	0x277f, 0xc02d,		0x21, 0
	.dw 0x27c0, 0xc02d,	0x27ff, 0xc02d,		0x21, 0
	.dw 0x2840, 0xc02d,	0x287f, 0xc02d,		0x21, 0
	.dw 0x28c0, 0xc02d,	0x28ff, 0xc02d,		0x21, 0
	.dw 0x2940, 0xc02d,	0x297f, 0xc02d,		0x21, 0
	.dw 0x29c0, 0xc02d,	0x29ff, 0xc02d,		0x21, 0
	.dw 0x2a40, 0xc02d,	0x2a7f, 0xc02d,		0x21, 0
	.dw 0x2ac0, 0xc02d,	0x2aff, 0xc02d,		0x21, 0
	.dw 0x2b40, 0xc02d,	0x2b7f, 0xc02d,		0x21, 0
	.dw 0x2bc0, 0xc02d,	0x2bff, 0xc02d,		0x21, 0
	.dw 0x2c40, 0xc02d,	0x2c7f, 0xc02d,		0x21, 0
	.dw 0x2cc0, 0xc02d,	0x2cff, 0xc02d,		0x21, 0
	.dw 0x2d40, 0xc02d,	0x2d7f, 0xc02d,		0x21, 0
	.dw 0x2dc0, 0xc02d,	0x2dff, 0xc02d,		0x21, 0
	.dw 0x2e40, 0xc02d,	0x2e7f, 0xc02d,		0x21, 0
	.dw 0x2ec0, 0xc02d,	0x2eff, 0xc02d,		0x21, 0
	.dw 0x2f40, 0xc02d,	0x2f7f, 0xc02d,		0x21, 0
	.dw 0x2fc0, 0xc02d,	0x2fff, 0xc02d,		0x21, 0
	.dw 0x3040, 0xc02d,	0x307f, 0xc02d,		0x21, 0
	.dw 0x30c0, 0xc02d,	0x30ff, 0xc02d,		0x21, 0
	.dw 0x3140, 0xc02d,	0x317f, 0xc02d,		0x21, 0
	.dw 0x31c0, 0xc02d,	0x31ff, 0xc02d,		0x21, 0
	.dw 0x3240, 0xc02d,	0x327f, 0xc02d,		0x21, 0
	.dw 0x32c0, 0xc02d,	0x32ff, 0xc02d,		0x21, 0
	.dw 0x3340, 0xc02d,	0x337f, 0xc02d,		0x21, 0
	.dw 0x33c0, 0xc02d,	0x33ff, 0xc02d,		0x21, 0
	.dw 0x3440, 0xc02d,	0x347f, 0xc02d,		0x21, 0
	.dw 0x34c0, 0xc02d,	0x34ff, 0xc02d,		0x21, 0
	.dw 0x3540, 0xc02d,	0x357f, 0xc02d,		0x21, 0
	.dw 0x35c0, 0xc02d,	0x35ff, 0xc02d,		0x21, 0
	.dw 0x3640, 0xc02d,	0x367f, 0xc02d,		0x21, 0
	.dw 0x36c0, 0xc02d,	0x36ff, 0xc02d,		0x21, 0
	.dw 0x3740, 0xc02d,	0x377f, 0xc02d,		0x21, 0
	.dw 0x37c0, 0xc02d,	0x37ff, 0xc02d,		0x21, 0
	.dw 0x3840, 0xc02d,	0x387f, 0xc02d,		0x21, 0
	.dw 0x38c0, 0xc02d,	0x38ff, 0xc02d,		0x21, 0
	.dw 0x3940, 0xc02d,	0x397f, 0xc02d,		0x21, 0
	.dw 0x39c0, 0xc02d,	0x3fff, 0xc02d,		0x21, 0
	.dw 0x4040, 0xc02d,	0x407f, 0xc02d,		0x21, 0
	.dw 0x40c0, 0xc02d,	0x40ff, 0xc02d,		0x21, 0
	.dw 0x4140, 0xc02d,	0x417f, 0xc02d,		0x21, 0
	.dw 0x41c0, 0xc02d,	0x41ff, 0xc02d,		0x21, 0
	.dw 0x4240, 0xc02d,	0x427f, 0xc02d,		0x21, 0
	.dw 0x42c0, 0xc02d,	0x42ff, 0xc02d,		0x21, 0
	.dw 0x4340, 0xc02d,	0x437f, 0xc02d,		0x21, 0
	.dw 0x43c0, 0xc02d,	0x43ff, 0xc02d,		0x21, 0
	.dw 0x4440, 0xc02d,	0x447f, 0xc02d,		0x21, 0
	.dw 0x44c0, 0xc02d,	0x44ff, 0xc02d,		0x21, 0
	.dw 0x4540, 0xc02d,	0x457f, 0xc02d,		0x21, 0
	.dw 0x45c0, 0xc02d,	0x45ff, 0xc02d,		0x21, 0
	.dw 0x4640, 0xc02d,	0x467f, 0xc02d,		0x21, 0
	.dw 0x46c0, 0xc02d,	0x46ff, 0xc02d,		0x21, 0
	.dw 0x4740, 0xc02d,	0x477f, 0xc02d,		0x21, 0
	.dw 0x47c0, 0xc02d,	0x47ff, 0xc02d,		0x21, 0
	.dw 0x4840, 0xc02d,	0x487f, 0xc02d,		0x21, 0
	.dw 0x48c0, 0xc02d,	0x48ff, 0xc02d,		0x21, 0
	.dw 0x4940, 0xc02d,	0x497f, 0xc02d,		0x21, 0
	.dw 0x49c0, 0xc02d,	0x49ff, 0xc02d,		0x21, 0
	.dw 0x4a40, 0xc02d,	0x4a7f, 0xc02d,		0x21, 0
	.dw 0x4ac0, 0xc02d,	0x4aff, 0xc02d,		0x21, 0
	.dw 0x4b40, 0xc02d,	0x4b7f, 0xc02d,		0x21, 0
	.dw 0x4bc0, 0xc02d,	0x4bff, 0xc02d,		0x21, 0
	.dw 0x4c40, 0xc02d,	0x4c7f, 0xc02d,		0x21, 0
	.dw 0x4cc0, 0xc02d,	0x4cff, 0xc02d,		0x21, 0
	.dw 0x4d40, 0xc02d,	0x4d7f, 0xc02d,		0x21, 0
	.dw 0x4dc0, 0xc02d,	0x4dff, 0xc02d,		0x21, 0
	.dw 0x4e40, 0xc02d,	0x4e7f, 0xc02d,		0x21, 0
	.dw 0x4ec0, 0xc02d,	0x4eff, 0xc02d,		0x21, 0
	.dw 0x4f40, 0xc02d,	0x4f7f, 0xc02d,		0x21, 0
	.dw 0x4fc0, 0xc02d,	0x4fff, 0xc02d,		0x21, 0
	.dw 0x5040, 0xc02d,	0x507f, 0xc02d,		0x21, 0
	.dw 0x50c0, 0xc02d,	0x50ff, 0xc02d,		0x21, 0
	.dw 0x5140, 0xc02d,	0x517f, 0xc02d,		0x21, 0
	.dw 0x51c0, 0xc02d,	0x51ff, 0xc02d,		0x21, 0
	.dw 0x5240, 0xc02d,	0x527f, 0xc02d,		0x21, 0
	.dw 0x52c0, 0xc02d,	0x52ff, 0xc02d,		0x21, 0
	.dw 0x5340, 0xc02d,	0x537f, 0xc02d,		0x21, 0
	.dw 0x53c0, 0xc02d,	0x53ff, 0xc02d,		0x21, 0
	.dw 0x5440, 0xc02d,	0x547f, 0xc02d,		0x21, 0
	.dw 0x54c0, 0xc02d,	0x54ff, 0xc02d,		0x21, 0
	.dw 0x5540, 0xc02d,	0x557f, 0xc02d,		0x21, 0
	.dw 0x55c0, 0xc02d,	0x55ff, 0xc02d,		0x21, 0
	.dw 0x5640, 0xc02d,	0x567f, 0xc02d,		0x21, 0
	.dw 0x56c0, 0xc02d,	0x56ff, 0xc02d,		0x21, 0
	.dw 0x5740, 0xc02d,	0x577f, 0xc02d,		0x21, 0
	.dw 0x57c0, 0xc02d,	0x57ff, 0xc02d,		0x21, 0
	.dw 0x5840, 0xc02d,	0x587f, 0xc02d,		0x21, 0
	.dw 0x58c0, 0xc02d,	0x58ff, 0xc02d,		0x21, 0
	.dw 0x5940, 0xc02d,	0x597f, 0xc02d,		0x21, 0
	.dw 0x59c0, 0xc02d,	0x5fff, 0xc02d,		0x21, 0
	.dw 0x6040, 0xc02d,	0x607f, 0xc02d,		0x21, 0
	.dw 0x60c0, 0xc02d,	0x60ff, 0xc02d,		0x21, 0
	.dw 0x6140, 0xc02d,	0x617f, 0xc02d,		0x21, 0
	.dw 0x61c0, 0xc02d,	0x61ff, 0xc02d,		0x21, 0
	.dw 0x6240, 0xc02d,	0x627f, 0xc02d,		0x21, 0
	.dw 0x62c0, 0xc02d,	0x62ff, 0xc02d,		0x21, 0
	.dw 0x6340, 0xc02d,	0x637f, 0xc02d,		0x21, 0
	.dw 0x63c0, 0xc02d,	0x63ff, 0xc02d,		0x21, 0
	.dw 0x6440, 0xc02d,	0x647f, 0xc02d,		0x21, 0
	.dw 0x64c0, 0xc02d,	0x64ff, 0xc02d,		0x21, 0
	.dw 0x6540, 0xc02d,	0x657f, 0xc02d,		0x21, 0
	.dw 0x65c0, 0xc02d,	0x65ff, 0xc02d,		0x21, 0
	.dw 0x6640, 0xc02d,	0x667f, 0xc02d,		0x21, 0
	.dw 0x66c0, 0xc02d,	0x66ff, 0xc02d,		0x21, 0
	.dw 0x6740, 0xc02d,	0x677f, 0xc02d,		0x21, 0
	.dw 0x67c0, 0xc02d,	0x67ff, 0xc02d,		0x21, 0
	.dw 0x6840, 0xc02d,	0x687f, 0xc02d,		0x21, 0
	.dw 0x68c0, 0xc02d,	0x68ff, 0xc02d,		0x21, 0
	.dw 0x6940, 0xc02d,	0x697f, 0xc02d,		0x21, 0
	.dw 0x69c0, 0xc02d,	0x69ff, 0xc02d,		0x21, 0
	.dw 0x6a40, 0xc02d,	0x6a7f, 0xc02d,		0x21, 0
	.dw 0x6ac0, 0xc02d,	0x6aff, 0xc02d,		0x21, 0
	.dw 0x6b40, 0xc02d,	0x6b7f, 0xc02d,		0x21, 0
	.dw 0x6bc0, 0xc02d,	0x6bff, 0xc02d,		0x21, 0
	.dw 0x6c40, 0xc02d,	0x6c7f, 0xc02d,		0x21, 0
	.dw 0x6cc0, 0xc02d,	0x6cff, 0xc02d,		0x21, 0
	.dw 0x6d40, 0xc02d,	0x6d7f, 0xc02d,		0x21, 0
	.dw 0x6dc0, 0xc02d,	0x6dff, 0xc02d,		0x21, 0
	.dw 0x6e40, 0xc02d,	0x6e7f, 0xc02d,		0x21, 0
	.dw 0x6ec0, 0xc02d,	0x6eff, 0xc02d,		0x21, 0
	.dw 0x6f40, 0xc02d,	0x6f7f, 0xc02d,		0x21, 0
	.dw 0x6fc0, 0xc02d,	0x6fff, 0xc02d,		0x21, 0
	.dw 0x7040, 0xc02d,	0x707f, 0xc02d,		0x21, 0
	.dw 0x70c0, 0xc02d,	0x70ff, 0xc02d,		0x21, 0
	.dw 0x7140, 0xc02d,	0x717f, 0xc02d,		0x21, 0
	.dw 0x71c0, 0xc02d,	0x71ff, 0xc02d,		0x21, 0
	.dw 0x7240, 0xc02d,	0x727f, 0xc02d,		0x21, 0
	.dw 0x72c0, 0xc02d,	0x72ff, 0xc02d,		0x21, 0
	.dw 0x7340, 0xc02d,	0x737f, 0xc02d,		0x21, 0
	.dw 0x73c0, 0xc02d,	0x73ff, 0xc02d,		0x21, 0
	.dw 0x7440, 0xc02d,	0x747f, 0xc02d,		0x21, 0
	.dw 0x74c0, 0xc02d,	0x74ff, 0xc02d,		0x21, 0
	.dw 0x7540, 0xc02d,	0x757f, 0xc02d,		0x21, 0
	.dw 0x75c0, 0xc02d,	0x75ff, 0xc02d,		0x21, 0
	.dw 0x7640, 0xc02d,	0x767f, 0xc02d,		0x21, 0
	.dw 0x76c0, 0xc02d,	0x76ff, 0xc02d,		0x21, 0
	.dw 0x7740, 0xc02d,	0x777f, 0xc02d,		0x21, 0
	.dw 0x77c0, 0xc02d,	0x77ff, 0xc02d,		0x21, 0
	.dw 0x7840, 0xc02d,	0x787f, 0xc02d,		0x21, 0
	.dw 0x78c0, 0xc02d,	0x78ff, 0xc02d,		0x21, 0
	.dw 0x7940, 0xc02d,	0x797f, 0xc02d,		0x21, 0
	.dw 0x79c0, 0xc02d,	0x7fff, 0xc02d,		0x21, 0
	.dw 0x8040, 0xc02d,	0x807f, 0xc02d,		0x21, 0
	.dw 0x80c0, 0xc02d,	0x80ff, 0xc02d,		0x21, 0
	.dw 0x8140, 0xc02d,	0x817f, 0xc02d,		0x21, 0
	.dw 0x81c0, 0xc02d,	0x81ff, 0xc02d,		0x21, 0
	.dw 0x8240, 0xc02d,	0x827f, 0xc02d,		0x21, 0
	.dw 0x82c0, 0xc02d,	0x82ff, 0xc02d,		0x21, 0
	.dw 0x8340, 0xc02d,	0x837f, 0xc02d,		0x21, 0
	.dw 0x83c0, 0xc02d,	0x83ff, 0xc02d,		0x21, 0
	.dw 0x8440, 0xc02d,	0x847f, 0xc02d,		0x21, 0
	.dw 0x84c0, 0xc02d,	0x84ff, 0xc02d,		0x21, 0
	.dw 0x8540, 0xc02d,	0x857f, 0xc02d,		0x21, 0
	.dw 0x85c0, 0xc02d,	0x85ff, 0xc02d,		0x21, 0
	.dw 0x8640, 0xc02d,	0x867f, 0xc02d,		0x21, 0
	.dw 0x86c0, 0xc02d,	0x86ff, 0xc02d,		0x21, 0
	.dw 0x8740, 0xc02d,	0x877f, 0xc02d,		0x21, 0
	.dw 0x87c0, 0xc02d,	0x87ff, 0xc02d,		0x21, 0
	.dw 0x8840, 0xc02d,	0x887f, 0xc02d,		0x21, 0
	.dw 0x88c0, 0xc02d,	0x88ff, 0xc02d,		0x21, 0
	.dw 0x8940, 0xc02d,	0x897f, 0xc02d,		0x21, 0
	.dw 0x89c0, 0xc02d,	0x89ff, 0xc02d,		0x21, 0
	.dw 0x8a40, 0xc02d,	0x8a7f, 0xc02d,		0x21, 0
	.dw 0x8ac0, 0xc02d,	0x8aff, 0xc02d,		0x21, 0
	.dw 0x8b40, 0xc02d,	0x8b7f, 0xc02d,		0x21, 0
	.dw 0x8bc0, 0xc02d,	0x8bff, 0xc02d,		0x21, 0
	.dw 0x8c40, 0xc02d,	0x8c7f, 0xc02d,		0x21, 0
	.dw 0x8cc0, 0xc02d,	0x8cff, 0xc02d,		0x21, 0
	.dw 0x8d40, 0xc02d,	0x8d7f, 0xc02d,		0x21, 0
	.dw 0x8dc0, 0xc02d,	0x8dff, 0xc02d,		0x21, 0
	.dw 0x8e40, 0xc02d,	0x8e7f, 0xc02d,		0x21, 0
	.dw 0x8ec0, 0xc02d,	0x8eff, 0xc02d,		0x21, 0
	.dw 0x8f40, 0xc02d,	0x8f7f, 0xc02d,		0x21, 0
	.dw 0x8fc0, 0xc02d,	0x8fff, 0xc02d,		0x21, 0
	.dw 0x9040, 0xc02d,	0x907f, 0xc02d,		0x21, 0
	.dw 0x90c0, 0xc02d,	0x90ff, 0xc02d,		0x21, 0
	.dw 0x9140, 0xc02d,	0x917f, 0xc02d,		0x21, 0
	.dw 0x91c0, 0xc02d,	0x91ff, 0xc02d,		0x21, 0
	.dw 0x9240, 0xc02d,	0x927f, 0xc02d,		0x21, 0
	.dw 0x92c0, 0xc02d,	0x92ff, 0xc02d,		0x21, 0
	.dw 0x9340, 0xc02d,	0x937f, 0xc02d,		0x21, 0
	.dw 0x93c0, 0xc02d,	0x93ff, 0xc02d,		0x21, 0
	.dw 0x9440, 0xc02d,	0x947f, 0xc02d,		0x21, 0
	.dw 0x94c0, 0xc02d,	0x94ff, 0xc02d,		0x21, 0
	.dw 0x9540, 0xc02d,	0x957f, 0xc02d,		0x21, 0
	.dw 0x95c0, 0xc02d,	0x95ff, 0xc02d,		0x21, 0
	.dw 0x9640, 0xc02d,	0x967f, 0xc02d,		0x21, 0
	.dw 0x96c0, 0xc02d,	0x96ff, 0xc02d,		0x21, 0
	.dw 0x9740, 0xc02d,	0x977f, 0xc02d,		0x21, 0
	.dw 0x97c0, 0xc02d,	0x97ff, 0xc02d,		0x21, 0
	.dw 0x9840, 0xc02d,	0x987f, 0xc02d,		0x21, 0
	.dw 0x98c0, 0xc02d,	0x98ff, 0xc02d,		0x21, 0
	.dw 0x9940, 0xc02d,	0x997f, 0xc02d,		0x21, 0
	.dw 0x99c0, 0xc02d,	0x9fff, 0xc02d,		0x21, 0
	.dw 0xa040, 0xc02d,	0xa07f, 0xc02d,		0x21, 0
	.dw 0xa0c0, 0xc02d,	0xa0ff, 0xc02d,		0x21, 0
	.dw 0xa140, 0xc02d,	0xa17f, 0xc02d,		0x21, 0
	.dw 0xa1c0, 0xc02d,	0xa1ff, 0xc02d,		0x21, 0
	.dw 0xa240, 0xc02d,	0xa27f, 0xc02d,		0x21, 0
	.dw 0xa2c0, 0xc02d,	0xa2ff, 0xc02d,		0x21, 0
	.dw 0xa340, 0xc02d,	0xa37f, 0xc02d,		0x21, 0
	.dw 0xa3c0, 0xc02d,	0xa3ff, 0xc02d,		0x21, 0
	.dw 0xa440, 0xc02d,	0xa47f, 0xc02d,		0x21, 0
	.dw 0xa4c0, 0xc02d,	0xa4ff, 0xc02d,		0x21, 0
	.dw 0xa540, 0xc02d,	0xa57f, 0xc02d,		0x21, 0
	.dw 0xa5c0, 0xc02d,	0xa5ff, 0xc02d,		0x21, 0
	.dw 0xa640, 0xc02d,	0xa67f, 0xc02d,		0x21, 0
	.dw 0xa6c0, 0xc02d,	0xa6ff, 0xc02d,		0x21, 0
	.dw 0xa740, 0xc02d,	0xa77f, 0xc02d,		0x21, 0
	.dw 0xa7c0, 0xc02d,	0xa7ff, 0xc02d,		0x21, 0
	.dw 0xa840, 0xc02d,	0xa87f, 0xc02d,		0x21, 0
	.dw 0xa8c0, 0xc02d,	0xa8ff, 0xc02d,		0x21, 0
	.dw 0xa940, 0xc02d,	0xa97f, 0xc02d,		0x21, 0
	.dw 0xa9c0, 0xc02d,	0xa9ff, 0xc02d,		0x21, 0
	.dw 0xaa40, 0xc02d,	0xaa7f, 0xc02d,		0x21, 0
	.dw 0xaac0, 0xc02d,	0xaaff, 0xc02d,		0x21, 0
	.dw 0xab40, 0xc02d,	0xab7f, 0xc02d,		0x21, 0
	.dw 0xabc0, 0xc02d,	0xabff, 0xc02d,		0x21, 0
	.dw 0xac40, 0xc02d,	0xac7f, 0xc02d,		0x21, 0
	.dw 0xacc0, 0xc02d,	0xacff, 0xc02d,		0x21, 0
	.dw 0xad40, 0xc02d,	0xad7f, 0xc02d,		0x21, 0
	.dw 0xadc0, 0xc02d,	0xadff, 0xc02d,		0x21, 0
	.dw 0xae40, 0xc02d,	0xae7f, 0xc02d,		0x21, 0
	.dw 0xaec0, 0xc02d,	0xaeff, 0xc02d,		0x21, 0
	.dw 0xaf40, 0xc02d,	0xaf7f, 0xc02d,		0x21, 0
	.dw 0xafc0, 0xc02d,	0xafff, 0xc02d,		0x21, 0
	.dw 0xb040, 0xc02d,	0xb07f, 0xc02d,		0x21, 0
	.dw 0xb0c0, 0xc02d,	0xb0ff, 0xc02d,		0x21, 0
	.dw 0xb140, 0xc02d,	0xb17f, 0xc02d,		0x21, 0
	.dw 0xb1c0, 0xc02d,	0xb1ff, 0xc02d,		0x21, 0
	.dw 0xb240, 0xc02d,	0xb27f, 0xc02d,		0x21, 0
	.dw 0xb2c0, 0xc02d,	0xb2ff, 0xc02d,		0x21, 0
	.dw 0xb340, 0xc02d,	0xb37f, 0xc02d,		0x21, 0
	.dw 0xb3c0, 0xc02d,	0xb3ff, 0xc02d,		0x21, 0
	.dw 0xb440, 0xc02d,	0xb47f, 0xc02d,		0x21, 0
	.dw 0xb4c0, 0xc02d,	0xb4ff, 0xc02d,		0x21, 0
	.dw 0xb540, 0xc02d,	0xb57f, 0xc02d,		0x21, 0
	.dw 0xb5c0, 0xc02d,	0xb5ff, 0xc02d,		0x21, 0
	.dw 0xb640, 0xc02d,	0xb67f, 0xc02d,		0x21, 0
	.dw 0xb6c0, 0xc02d,	0xb6ff, 0xc02d,		0x21, 0
	.dw 0xb740, 0xc02d,	0xb77f, 0xc02d,		0x21, 0
	.dw 0xb7c0, 0xc02d,	0xb7ff, 0xc02d,		0x21, 0
	.dw 0xb840, 0xc02d,	0xb87f, 0xc02d,		0x21, 0
	.dw 0xb8c0, 0xc02d,	0xb8ff, 0xc02d,		0x21, 0
	.dw 0xb940, 0xc02d,	0xb97f, 0xc02d,		0x21, 0
	.dw 0xb9c0, 0xc02d,	0xbfff, 0xc02d,		0x21, 0
	.dw 0xc040, 0xc02d,	0xc07f, 0xc02d,		0x21, 0
	.dw 0xc0c0, 0xc02d,	0xc0ff, 0xc02d,		0x21, 0
	.dw 0xc140, 0xc02d,	0xc17f, 0xc02d,		0x21, 0
	.dw 0xc1c0, 0xc02d,	0xc1ff, 0xc02d,		0x21, 0
	.dw 0xc240, 0xc02d,	0xc27f, 0xc02d,		0x21, 0
	.dw 0xc2c0, 0xc02d,	0xc2ff, 0xc02d,		0x21, 0
	.dw 0xc340, 0xc02d,	0xc37f, 0xc02d,		0x21, 0
	.dw 0xc3c0, 0xc02d,	0xc3ff, 0xc02d,		0x21, 0
	.dw 0xc440, 0xc02d,	0xc47f, 0xc02d,		0x21, 0
	.dw 0xc4c0, 0xc02d,	0xc4ff, 0xc02d,		0x21, 0
	.dw 0xc540, 0xc02d,	0xc57f, 0xc02d,		0x21, 0
	.dw 0xc5c0, 0xc02d,	0xc5ff, 0xc02d,		0x21, 0
	.dw 0xc640, 0xc02d,	0xc67f, 0xc02d,		0x21, 0
	.dw 0xc6c0, 0xc02d,	0xc6ff, 0xc02d,		0x21, 0
	.dw 0xc740, 0xc02d,	0xc77f, 0xc02d,		0x21, 0
	.dw 0xc7c0, 0xc02d,	0xc7ff, 0xc02d,		0x21, 0
	.dw 0xc840, 0xc02d,	0xc87f, 0xc02d,		0x21, 0
	.dw 0xc8c0, 0xc02d,	0xc8ff, 0xc02d,		0x21, 0
	.dw 0xc940, 0xc02d,	0xc97f, 0xc02d,		0x21, 0
	.dw 0xc9c0, 0xc02d,	0xc9ff, 0xc02d,		0x21, 0
	.dw 0xca40, 0xc02d,	0xca7f, 0xc02d,		0x21, 0
	.dw 0xcac0, 0xc02d,	0xcaff, 0xc02d,		0x21, 0
	.dw 0xcb40, 0xc02d,	0xcb7f, 0xc02d,		0x21, 0
	.dw 0xcbc0, 0xc02d,	0xcbff, 0xc02d,		0x21, 0
	.dw 0xcc40, 0xc02d,	0xcc7f, 0xc02d,		0x21, 0
	.dw 0xccc0, 0xc02d,	0xccff, 0xc02d,		0x21, 0
	.dw 0xcd40, 0xc02d,	0xcd7f, 0xc02d,		0x21, 0
	.dw 0xcdc0, 0xc02d,	0xcdff, 0xc02d,		0x21, 0
	.dw 0xce40, 0xc02d,	0xce7f, 0xc02d,		0x21, 0
	.dw 0xcec0, 0xc02d,	0xceff, 0xc02d,		0x21, 0
	.dw 0xcf40, 0xc02d,	0xcf7f, 0xc02d,		0x21, 0
	.dw 0xcfc0, 0xc02d,	0xcfff, 0xc02d,		0x21, 0
	.dw 0xd040, 0xc02d,	0xd07f, 0xc02d,		0x21, 0
	.dw 0xd0c0, 0xc02d,	0xd0ff, 0xc02d,		0x21, 0
	.dw 0xd140, 0xc02d,	0xd17f, 0xc02d,		0x21, 0
	.dw 0xd1c0, 0xc02d,	0xd1ff, 0xc02d,		0x21, 0
	.dw 0xd240, 0xc02d,	0xd27f, 0xc02d,		0x21, 0
	.dw 0xd2c0, 0xc02d,	0xd2ff, 0xc02d,		0x21, 0
	.dw 0xd340, 0xc02d,	0xd37f, 0xc02d,		0x21, 0
	.dw 0xd3c0, 0xc02d,	0xd3ff, 0xc02d,		0x21, 0
	.dw 0xd440, 0xc02d,	0xd47f, 0xc02d,		0x21, 0
	.dw 0xd4c0, 0xc02d,	0xd4ff, 0xc02d,		0x21, 0
	.dw 0xd540, 0xc02d,	0xd57f, 0xc02d,		0x21, 0
	.dw 0xd5c0, 0xc02d,	0xd5ff, 0xc02d,		0x21, 0
	.dw 0xd640, 0xc02d,	0xd67f, 0xc02d,		0x21, 0
	.dw 0xd6c0, 0xc02d,	0xd6ff, 0xc02d,		0x21, 0
	.dw 0xd740, 0xc02d,	0xd77f, 0xc02d,		0x21, 0
	.dw 0xd7c0, 0xc02d,	0xd7ff, 0xc02d,		0x21, 0
	.dw 0xd840, 0xc02d,	0xd87f, 0xc02d,		0x21, 0
	.dw 0xd8c0, 0xc02d,	0xd8ff, 0xc02d,		0x21, 0
	.dw 0xd940, 0xc02d,	0xd97f, 0xc02d,		0x21, 0
	.dw 0xd9c0, 0xc02d,	0xdfff, 0xc02d,		0x21, 0
	.dw 0xe040, 0xc02d,	0xe07f, 0xc02d,		0x21, 0
	.dw 0xe0c0, 0xc02d,	0xe0ff, 0xc02d,		0x21, 0
	.dw 0xe140, 0xc02d,	0xe17f, 0xc02d,		0x21, 0
	.dw 0xe1c0, 0xc02d,	0xe1ff, 0xc02d,		0x21, 0
	.dw 0xe240, 0xc02d,	0xe27f, 0xc02d,		0x21, 0
	.dw 0xe2c0, 0xc02d,	0xe2ff, 0xc02d,		0x21, 0
	.dw 0xe340, 0xc02d,	0xe37f, 0xc02d,		0x21, 0
	.dw 0xe3c0, 0xc02d,	0xe3ff, 0xc02d,		0x21, 0
	.dw 0xe440, 0xc02d,	0xe47f, 0xc02d,		0x21, 0
	.dw 0xe4c0, 0xc02d,	0xe4ff, 0xc02d,		0x21, 0
	.dw 0xe540, 0xc02d,	0xe57f, 0xc02d,		0x21, 0
	.dw 0xe5c0, 0xc02d,	0xe5ff, 0xc02d,		0x21, 0
	.dw 0xe640, 0xc02d,	0xe67f, 0xc02d,		0x21, 0
	.dw 0xe6c0, 0xc02d,	0xe6ff, 0xc02d,		0x21, 0
	.dw 0xe740, 0xc02d,	0xe77f, 0xc02d,		0x21, 0
	.dw 0xe7c0, 0xc02d,	0xe7ff, 0xc02d,		0x21, 0
	.dw 0xe840, 0xc02d,	0xe87f, 0xc02d,		0x21, 0
	.dw 0xe8c0, 0xc02d,	0xe8ff, 0xc02d,		0x21, 0
	.dw 0xe940, 0xc02d,	0xe97f, 0xc02d,		0x21, 0
	.dw 0xe9c0, 0xc02d,	0xe9ff, 0xc02d,		0x21, 0
	.dw 0xea40, 0xc02d,	0xea7f, 0xc02d,		0x21, 0
	.dw 0xeac0, 0xc02d,	0xeaff, 0xc02d,		0x21, 0
	.dw 0xeb40, 0xc02d,	0xeb7f, 0xc02d,		0x21, 0
	.dw 0xebc0, 0xc02d,	0xebff, 0xc02d,		0x21, 0
	.dw 0xec40, 0xc02d,	0xec7f, 0xc02d,		0x21, 0
	.dw 0xecc0, 0xc02d,	0xecff, 0xc02d,		0x21, 0
	.dw 0xed40, 0xc02d,	0xed7f, 0xc02d,		0x21, 0
	.dw 0xedc0, 0xc02d,	0xedff, 0xc02d,		0x21, 0
	.dw 0xee40, 0xc02d,	0xee7f, 0xc02d,		0x21, 0
	.dw 0xeec0, 0xc02d,	0xeeff, 0xc02d,		0x21, 0
	.dw 0xef40, 0xc02d,	0xef7f, 0xc02d,		0x21, 0
	.dw 0xefc0, 0xc02d,	0xefff, 0xc02d,		0x21, 0
	.dw 0xf040, 0xc02d,	0xf07f, 0xc02d,		0x21, 0
	.dw 0xf0c0, 0xc02d,	0xf0ff, 0xc02d,		0x21, 0
	.dw 0xf140, 0xc02d,	0xf17f, 0xc02d,		0x21, 0
	.dw 0xf1c0, 0xc02d,	0xf1ff, 0xc02d,		0x21, 0
	.dw 0xf240, 0xc02d,	0xf27f, 0xc02d,		0x21, 0
	.dw 0xf2c0, 0xc02d,	0xf2ff, 0xc02d,		0x21, 0
	.dw 0xf340, 0xc02d,	0xf37f, 0xc02d,		0x21, 0
	.dw 0xf3c0, 0xc02d,	0xf3ff, 0xc02d,		0x21, 0
	.dw 0xf440, 0xc02d,	0xf47f, 0xc02d,		0x21, 0
	.dw 0xf4c0, 0xc02d,	0xf4ff, 0xc02d,		0x21, 0
	.dw 0xf540, 0xc02d,	0xf57f, 0xc02d,		0x21, 0
	.dw 0xf5c0, 0xc02d,	0xf5ff, 0xc02d,		0x21, 0
	.dw 0xf640, 0xc02d,	0xf67f, 0xc02d,		0x21, 0
	.dw 0xf6c0, 0xc02d,	0xf6ff, 0xc02d,		0x21, 0
	.dw 0xf740, 0xc02d,	0xf77f, 0xc02d,		0x21, 0
	.dw 0xf7c0, 0xc02d,	0xf7ff, 0xc02d,		0x21, 0
	.dw 0xf840, 0xc02d,	0xf87f, 0xc02d,		0x21, 0
	.dw 0xf8c0, 0xc02d,	0xf8ff, 0xc02d,		0x21, 0
	.dw 0xf940, 0xc02d,	0xf97f, 0xc02d,		0x21, 0
	.dw 0xf9c0, 0xc02d,	0xffff, 0xc02d,		0x21, 0
	.dw 0x0040, 0xc02e,	0x007f, 0xc02e,		0x21, 0
	.dw 0x00c0, 0xc02e,	0x00ff, 0xc02e,		0x21, 0
	.dw 0x0140, 0xc02e,	0x017f, 0xc02e,		0x21, 0
	.dw 0x01c0, 0xc02e,	0x01ff, 0xc02e,		0x21, 0
	.dw 0x0240, 0xc02e,	0x027f, 0xc02e,		0x21, 0
	.dw 0x02c0, 0xc02e,	0x02ff, 0xc02e,		0x21, 0
	.dw 0x0340, 0xc02e,	0x037f, 0xc02e,		0x21, 0
	.dw 0x03c0, 0xc02e,	0x03ff, 0xc02e,		0x21, 0
	.dw 0x0440, 0xc02e,	0x047f, 0xc02e,		0x21, 0
	.dw 0x04c0, 0xc02e,	0x04ff, 0xc02e,		0x21, 0
	.dw 0x0540, 0xc02e,	0x057f, 0xc02e,		0x21, 0
	.dw 0x05c0, 0xc02e,	0x05ff, 0xc02e,		0x21, 0
	.dw 0x0640, 0xc02e,	0x067f, 0xc02e,		0x21, 0
	.dw 0x06c0, 0xc02e,	0x06ff, 0xc02e,		0x21, 0
	.dw 0x0740, 0xc02e,	0x077f, 0xc02e,		0x21, 0
	.dw 0x07c0, 0xc02e,	0x07ff, 0xc02e,		0x21, 0
	.dw 0x0840, 0xc02e,	0x087f, 0xc02e,		0x21, 0
	.dw 0x08c0, 0xc02e,	0x08ff, 0xc02e,		0x21, 0
	.dw 0x0940, 0xc02e,	0x097f, 0xc02e,		0x21, 0
	.dw 0x09c0, 0xc02e,	0x09ff, 0xc02e,		0x21, 0
	.dw 0x0a40, 0xc02e,	0x0a7f, 0xc02e,		0x21, 0
	.dw 0x0ac0, 0xc02e,	0x0aff, 0xc02e,		0x21, 0
	.dw 0x0b40, 0xc02e,	0x0b7f, 0xc02e,		0x21, 0
	.dw 0x0bc0, 0xc02e,	0x0bff, 0xc02e,		0x21, 0
	.dw 0x0c40, 0xc02e,	0x0c7f, 0xc02e,		0x21, 0
	.dw 0x0cc0, 0xc02e,	0x0cff, 0xc02e,		0x21, 0
	.dw 0x0d40, 0xc02e,	0x0d7f, 0xc02e,		0x21, 0
	.dw 0x0dc0, 0xc02e,	0x0dff, 0xc02e,		0x21, 0
	.dw 0x0e40, 0xc02e,	0x0e7f, 0xc02e,		0x21, 0
	.dw 0x0ec0, 0xc02e,	0x0eff, 0xc02e,		0x21, 0
	.dw 0x0f40, 0xc02e,	0x0f7f, 0xc02e,		0x21, 0
	.dw 0x0fc0, 0xc02e,	0x0fff, 0xc02e,		0x21, 0
	.dw 0x1040, 0xc02e,	0x107f, 0xc02e,		0x21, 0
	.dw 0x10c0, 0xc02e,	0x10ff, 0xc02e,		0x21, 0
	.dw 0x1140, 0xc02e,	0x117f, 0xc02e,		0x21, 0
	.dw 0x11c0, 0xc02e,	0x11ff, 0xc02e,		0x21, 0
	.dw 0x1240, 0xc02e,	0x127f, 0xc02e,		0x21, 0
	.dw 0x12c0, 0xc02e,	0x12ff, 0xc02e,		0x21, 0
	.dw 0x1340, 0xc02e,	0x137f, 0xc02e,		0x21, 0
	.dw 0x13c0, 0xc02e,	0x13ff, 0xc02e,		0x21, 0
	.dw 0x1440, 0xc02e,	0x147f, 0xc02e,		0x21, 0
	.dw 0x14c0, 0xc02e,	0x14ff, 0xc02e,		0x21, 0
	.dw 0x1540, 0xc02e,	0x157f, 0xc02e,		0x21, 0
	.dw 0x15c0, 0xc02e,	0x15ff, 0xc02e,		0x21, 0
	.dw 0x1640, 0xc02e,	0x167f, 0xc02e,		0x21, 0
	.dw 0x16c0, 0xc02e,	0x16ff, 0xc02e,		0x21, 0
	.dw 0x1740, 0xc02e,	0x177f, 0xc02e,		0x21, 0
	.dw 0x17c0, 0xc02e,	0x17ff, 0xc02e,		0x21, 0
	.dw 0x1840, 0xc02e,	0x187f, 0xc02e,		0x21, 0
	.dw 0x18c0, 0xc02e,	0x18ff, 0xc02e,		0x21, 0
	.dw 0x1940, 0xc02e,	0x197f, 0xc02e,		0x21, 0
	.dw 0x19c0, 0xc02e,	0x1fff, 0xc02e,		0x21, 0
	.dw 0x2040, 0xc02e,	0x207f, 0xc02e,		0x21, 0
	.dw 0x20c0, 0xc02e,	0x20ff, 0xc02e,		0x21, 0
	.dw 0x2140, 0xc02e,	0x217f, 0xc02e,		0x21, 0
	.dw 0x21c0, 0xc02e,	0x21ff, 0xc02e,		0x21, 0
	.dw 0x2240, 0xc02e,	0x227f, 0xc02e,		0x21, 0
	.dw 0x22c0, 0xc02e,	0x22ff, 0xc02e,		0x21, 0
	.dw 0x2340, 0xc02e,	0x237f, 0xc02e,		0x21, 0
	.dw 0x23c0, 0xc02e,	0x23ff, 0xc02e,		0x21, 0
	.dw 0x2440, 0xc02e,	0x247f, 0xc02e,		0x21, 0
	.dw 0x24c0, 0xc02e,	0x24ff, 0xc02e,		0x21, 0
	.dw 0x2540, 0xc02e,	0x257f, 0xc02e,		0x21, 0
	.dw 0x25c0, 0xc02e,	0x25ff, 0xc02e,		0x21, 0
	.dw 0x2640, 0xc02e,	0x267f, 0xc02e,		0x21, 0
	.dw 0x26c0, 0xc02e,	0x26ff, 0xc02e,		0x21, 0
	.dw 0x2740, 0xc02e,	0x277f, 0xc02e,		0x21, 0
	.dw 0x27c0, 0xc02e,	0x27ff, 0xc02e,		0x21, 0
	.dw 0x2840, 0xc02e,	0x287f, 0xc02e,		0x21, 0
	.dw 0x28c0, 0xc02e,	0x28ff, 0xc02e,		0x21, 0
	.dw 0x2940, 0xc02e,	0x297f, 0xc02e,		0x21, 0
	.dw 0x29c0, 0xc02e,	0x29ff, 0xc02e,		0x21, 0
	.dw 0x2a40, 0xc02e,	0x2a7f, 0xc02e,		0x21, 0
	.dw 0x2ac0, 0xc02e,	0x2aff, 0xc02e,		0x21, 0
	.dw 0x2b40, 0xc02e,	0x2b7f, 0xc02e,		0x21, 0
	.dw 0x2bc0, 0xc02e,	0x2bff, 0xc02e,		0x21, 0
	.dw 0x2c40, 0xc02e,	0x2c7f, 0xc02e,		0x21, 0
	.dw 0x2cc0, 0xc02e,	0x2cff, 0xc02e,		0x21, 0
	.dw 0x2d40, 0xc02e,	0x2d7f, 0xc02e,		0x21, 0
	.dw 0x2dc0, 0xc02e,	0x2dff, 0xc02e,		0x21, 0
	.dw 0x2e40, 0xc02e,	0x2e7f, 0xc02e,		0x21, 0
	.dw 0x2ec0, 0xc02e,	0x2eff, 0xc02e,		0x21, 0
	.dw 0x2f40, 0xc02e,	0x2f7f, 0xc02e,		0x21, 0
	.dw 0x2fc0, 0xc02e,	0x2fff, 0xc02e,		0x21, 0
	.dw 0x3040, 0xc02e,	0x307f, 0xc02e,		0x21, 0
	.dw 0x30c0, 0xc02e,	0x30ff, 0xc02e,		0x21, 0
	.dw 0x3140, 0xc02e,	0x317f, 0xc02e,		0x21, 0
	.dw 0x31c0, 0xc02e,	0x31ff, 0xc02e,		0x21, 0
	.dw 0x3240, 0xc02e,	0x327f, 0xc02e,		0x21, 0
	.dw 0x32c0, 0xc02e,	0x32ff, 0xc02e,		0x21, 0
	.dw 0x3340, 0xc02e,	0x337f, 0xc02e,		0x21, 0
	.dw 0x33c0, 0xc02e,	0x33ff, 0xc02e,		0x21, 0
	.dw 0x3440, 0xc02e,	0x347f, 0xc02e,		0x21, 0
	.dw 0x34c0, 0xc02e,	0x34ff, 0xc02e,		0x21, 0
	.dw 0x3540, 0xc02e,	0x357f, 0xc02e,		0x21, 0
	.dw 0x35c0, 0xc02e,	0x35ff, 0xc02e,		0x21, 0
	.dw 0x3640, 0xc02e,	0x367f, 0xc02e,		0x21, 0
	.dw 0x36c0, 0xc02e,	0x36ff, 0xc02e,		0x21, 0
	.dw 0x3740, 0xc02e,	0x377f, 0xc02e,		0x21, 0
	.dw 0x37c0, 0xc02e,	0x37ff, 0xc02e,		0x21, 0
	.dw 0x3840, 0xc02e,	0x387f, 0xc02e,		0x21, 0
	.dw 0x38c0, 0xc02e,	0x38ff, 0xc02e,		0x21, 0
	.dw 0x3940, 0xc02e,	0x397f, 0xc02e,		0x21, 0
	.dw 0x39c0, 0xc02e,	0x3fff, 0xc02e,		0x21, 0
	.dw 0x4040, 0xc02e,	0x407f, 0xc02e,		0x21, 0
	.dw 0x40c0, 0xc02e,	0x40ff, 0xc02e,		0x21, 0
	.dw 0x4140, 0xc02e,	0x417f, 0xc02e,		0x21, 0
	.dw 0x41c0, 0xc02e,	0x41ff, 0xc02e,		0x21, 0
	.dw 0x4240, 0xc02e,	0x427f, 0xc02e,		0x21, 0
	.dw 0x42c0, 0xc02e,	0x42ff, 0xc02e,		0x21, 0
	.dw 0x4340, 0xc02e,	0x437f, 0xc02e,		0x21, 0
	.dw 0x43c0, 0xc02e,	0x43ff, 0xc02e,		0x21, 0
	.dw 0x4440, 0xc02e,	0x447f, 0xc02e,		0x21, 0
	.dw 0x44c0, 0xc02e,	0x44ff, 0xc02e,		0x21, 0
	.dw 0x4540, 0xc02e,	0x457f, 0xc02e,		0x21, 0
	.dw 0x45c0, 0xc02e,	0x45ff, 0xc02e,		0x21, 0
	.dw 0x4640, 0xc02e,	0x467f, 0xc02e,		0x21, 0
	.dw 0x46c0, 0xc02e,	0x46ff, 0xc02e,		0x21, 0
	.dw 0x4740, 0xc02e,	0x477f, 0xc02e,		0x21, 0
	.dw 0x47c0, 0xc02e,	0x47ff, 0xc02e,		0x21, 0
	.dw 0x4840, 0xc02e,	0x487f, 0xc02e,		0x21, 0
	.dw 0x48c0, 0xc02e,	0x48ff, 0xc02e,		0x21, 0
	.dw 0x4940, 0xc02e,	0x497f, 0xc02e,		0x21, 0
	.dw 0x49c0, 0xc02e,	0x49ff, 0xc02e,		0x21, 0
	.dw 0x4a40, 0xc02e,	0x4a7f, 0xc02e,		0x21, 0
	.dw 0x4ac0, 0xc02e,	0x4aff, 0xc02e,		0x21, 0
	.dw 0x4b40, 0xc02e,	0x4b7f, 0xc02e,		0x21, 0
	.dw 0x4bc0, 0xc02e,	0x4bff, 0xc02e,		0x21, 0
	.dw 0x4c40, 0xc02e,	0x4c7f, 0xc02e,		0x21, 0
	.dw 0x4cc0, 0xc02e,	0x4cff, 0xc02e,		0x21, 0
	.dw 0x4d40, 0xc02e,	0x4d7f, 0xc02e,		0x21, 0
	.dw 0x4dc0, 0xc02e,	0x4dff, 0xc02e,		0x21, 0
	.dw 0x4e40, 0xc02e,	0x4e7f, 0xc02e,		0x21, 0
	.dw 0x4ec0, 0xc02e,	0x4eff, 0xc02e,		0x21, 0
	.dw 0x4f40, 0xc02e,	0x4f7f, 0xc02e,		0x21, 0
	.dw 0x4fc0, 0xc02e,	0x4fff, 0xc02e,		0x21, 0
	.dw 0x5040, 0xc02e,	0x507f, 0xc02e,		0x21, 0
	.dw 0x50c0, 0xc02e,	0x50ff, 0xc02e,		0x21, 0
	.dw 0x5140, 0xc02e,	0x517f, 0xc02e,		0x21, 0
	.dw 0x51c0, 0xc02e,	0x51ff, 0xc02e,		0x21, 0
	.dw 0x5240, 0xc02e,	0x527f, 0xc02e,		0x21, 0
	.dw 0x52c0, 0xc02e,	0x52ff, 0xc02e,		0x21, 0
	.dw 0x5340, 0xc02e,	0x537f, 0xc02e,		0x21, 0
	.dw 0x53c0, 0xc02e,	0x53ff, 0xc02e,		0x21, 0
	.dw 0x5440, 0xc02e,	0x547f, 0xc02e,		0x21, 0
	.dw 0x54c0, 0xc02e,	0x54ff, 0xc02e,		0x21, 0
	.dw 0x5540, 0xc02e,	0x557f, 0xc02e,		0x21, 0
	.dw 0x55c0, 0xc02e,	0x55ff, 0xc02e,		0x21, 0
	.dw 0x5640, 0xc02e,	0x567f, 0xc02e,		0x21, 0
	.dw 0x56c0, 0xc02e,	0x56ff, 0xc02e,		0x21, 0
	.dw 0x5740, 0xc02e,	0x577f, 0xc02e,		0x21, 0
	.dw 0x57c0, 0xc02e,	0x57ff, 0xc02e,		0x21, 0
	.dw 0x5840, 0xc02e,	0x587f, 0xc02e,		0x21, 0
	.dw 0x58c0, 0xc02e,	0x58ff, 0xc02e,		0x21, 0
	.dw 0x5940, 0xc02e,	0x597f, 0xc02e,		0x21, 0
	.dw 0x59c0, 0xc02e,	0x5fff, 0xc02e,		0x21, 0
	.dw 0x6040, 0xc02e,	0x607f, 0xc02e,		0x21, 0
	.dw 0x60c0, 0xc02e,	0x60ff, 0xc02e,		0x21, 0
	.dw 0x6140, 0xc02e,	0x617f, 0xc02e,		0x21, 0
	.dw 0x61c0, 0xc02e,	0x61ff, 0xc02e,		0x21, 0
	.dw 0x6240, 0xc02e,	0x627f, 0xc02e,		0x21, 0
	.dw 0x62c0, 0xc02e,	0x62ff, 0xc02e,		0x21, 0
	.dw 0x6340, 0xc02e,	0x637f, 0xc02e,		0x21, 0
	.dw 0x63c0, 0xc02e,	0x63ff, 0xc02e,		0x21, 0
	.dw 0x6440, 0xc02e,	0x647f, 0xc02e,		0x21, 0
	.dw 0x64c0, 0xc02e,	0x64ff, 0xc02e,		0x21, 0
	.dw 0x6540, 0xc02e,	0x657f, 0xc02e,		0x21, 0
	.dw 0x65c0, 0xc02e,	0x65ff, 0xc02e,		0x21, 0
	.dw 0x6640, 0xc02e,	0x667f, 0xc02e,		0x21, 0
	.dw 0x66c0, 0xc02e,	0x66ff, 0xc02e,		0x21, 0
	.dw 0x6740, 0xc02e,	0x677f, 0xc02e,		0x21, 0
	.dw 0x67c0, 0xc02e,	0x67ff, 0xc02e,		0x21, 0
	.dw 0x6840, 0xc02e,	0x687f, 0xc02e,		0x21, 0
	.dw 0x68c0, 0xc02e,	0x68ff, 0xc02e,		0x21, 0
	.dw 0x6940, 0xc02e,	0x697f, 0xc02e,		0x21, 0
	.dw 0x69c0, 0xc02e,	0x69ff, 0xc02e,		0x21, 0
	.dw 0x6a40, 0xc02e,	0x6a7f, 0xc02e,		0x21, 0
	.dw 0x6ac0, 0xc02e,	0x6aff, 0xc02e,		0x21, 0
	.dw 0x6b40, 0xc02e,	0x6b7f, 0xc02e,		0x21, 0
	.dw 0x6bc0, 0xc02e,	0x6bff, 0xc02e,		0x21, 0
	.dw 0x6c40, 0xc02e,	0x6c7f, 0xc02e,		0x21, 0
	.dw 0x6cc0, 0xc02e,	0x6cff, 0xc02e,		0x21, 0
	.dw 0x6d40, 0xc02e,	0x6d7f, 0xc02e,		0x21, 0
	.dw 0x6dc0, 0xc02e,	0x6dff, 0xc02e,		0x21, 0
	.dw 0x6e40, 0xc02e,	0x6e7f, 0xc02e,		0x21, 0
	.dw 0x6ec0, 0xc02e,	0x6eff, 0xc02e,		0x21, 0
	.dw 0x6f40, 0xc02e,	0x6f7f, 0xc02e,		0x21, 0
	.dw 0x6fc0, 0xc02e,	0x6fff, 0xc02e,		0x21, 0
	.dw 0x7040, 0xc02e,	0x707f, 0xc02e,		0x21, 0
	.dw 0x70c0, 0xc02e,	0x70ff, 0xc02e,		0x21, 0
	.dw 0x7140, 0xc02e,	0x717f, 0xc02e,		0x21, 0
	.dw 0x71c0, 0xc02e,	0x71ff, 0xc02e,		0x21, 0
	.dw 0x7240, 0xc02e,	0x727f, 0xc02e,		0x21, 0
	.dw 0x72c0, 0xc02e,	0x72ff, 0xc02e,		0x21, 0
	.dw 0x7340, 0xc02e,	0x737f, 0xc02e,		0x21, 0
	.dw 0x73c0, 0xc02e,	0x73ff, 0xc02e,		0x21, 0
	.dw 0x7440, 0xc02e,	0x747f, 0xc02e,		0x21, 0
	.dw 0x74c0, 0xc02e,	0x74ff, 0xc02e,		0x21, 0
	.dw 0x7540, 0xc02e,	0x757f, 0xc02e,		0x21, 0
	.dw 0x75c0, 0xc02e,	0x75ff, 0xc02e,		0x21, 0
	.dw 0x7640, 0xc02e,	0x767f, 0xc02e,		0x21, 0
	.dw 0x76c0, 0xc02e,	0x76ff, 0xc02e,		0x21, 0
	.dw 0x7740, 0xc02e,	0x777f, 0xc02e,		0x21, 0
	.dw 0x77c0, 0xc02e,	0x77ff, 0xc02e,		0x21, 0
	.dw 0x7840, 0xc02e,	0x787f, 0xc02e,		0x21, 0
	.dw 0x78c0, 0xc02e,	0x78ff, 0xc02e,		0x21, 0
	.dw 0x7940, 0xc02e,	0x797f, 0xc02e,		0x21, 0
	.dw 0x79c0, 0xc02e,	0x7fff, 0xc02e,		0x21, 0
	.dw 0x8040, 0xc02e,	0x807f, 0xc02e,		0x21, 0
	.dw 0x80c0, 0xc02e,	0x80ff, 0xc02e,		0x21, 0
	.dw 0x8140, 0xc02e,	0x817f, 0xc02e,		0x21, 0
	.dw 0x81c0, 0xc02e,	0x81ff, 0xc02e,		0x21, 0
	.dw 0x8240, 0xc02e,	0x827f, 0xc02e,		0x21, 0
	.dw 0x82c0, 0xc02e,	0x82ff, 0xc02e,		0x21, 0
	.dw 0x8340, 0xc02e,	0x837f, 0xc02e,		0x21, 0
	.dw 0x83c0, 0xc02e,	0x83ff, 0xc02e,		0x21, 0
	.dw 0x8440, 0xc02e,	0x847f, 0xc02e,		0x21, 0
	.dw 0x84c0, 0xc02e,	0x84ff, 0xc02e,		0x21, 0
	.dw 0x8540, 0xc02e,	0x857f, 0xc02e,		0x21, 0
	.dw 0x85c0, 0xc02e,	0x85ff, 0xc02e,		0x21, 0
	.dw 0x8640, 0xc02e,	0x867f, 0xc02e,		0x21, 0
	.dw 0x86c0, 0xc02e,	0x86ff, 0xc02e,		0x21, 0
	.dw 0x8740, 0xc02e,	0x877f, 0xc02e,		0x21, 0
	.dw 0x87c0, 0xc02e,	0x87ff, 0xc02e,		0x21, 0
	.dw 0x8840, 0xc02e,	0x887f, 0xc02e,		0x21, 0
	.dw 0x88c0, 0xc02e,	0x88ff, 0xc02e,		0x21, 0
	.dw 0x8940, 0xc02e,	0x897f, 0xc02e,		0x21, 0
	.dw 0x89c0, 0xc02e,	0x89ff, 0xc02e,		0x21, 0
	.dw 0x8a40, 0xc02e,	0x8a7f, 0xc02e,		0x21, 0
	.dw 0x8ac0, 0xc02e,	0x8aff, 0xc02e,		0x21, 0
	.dw 0x8b40, 0xc02e,	0x8b7f, 0xc02e,		0x21, 0
	.dw 0x8bc0, 0xc02e,	0x8bff, 0xc02e,		0x21, 0
	.dw 0x8c40, 0xc02e,	0x8c7f, 0xc02e,		0x21, 0
	.dw 0x8cc0, 0xc02e,	0x8cff, 0xc02e,		0x21, 0
	.dw 0x8d40, 0xc02e,	0x8d7f, 0xc02e,		0x21, 0
	.dw 0x8dc0, 0xc02e,	0x8dff, 0xc02e,		0x21, 0
	.dw 0x8e40, 0xc02e,	0x8e7f, 0xc02e,		0x21, 0
	.dw 0x8ec0, 0xc02e,	0x8eff, 0xc02e,		0x21, 0
	.dw 0x8f40, 0xc02e,	0x8f7f, 0xc02e,		0x21, 0
	.dw 0x8fc0, 0xc02e,	0x8fff, 0xc02e,		0x21, 0
	.dw 0x9040, 0xc02e,	0x907f, 0xc02e,		0x21, 0
	.dw 0x90c0, 0xc02e,	0x90ff, 0xc02e,		0x21, 0
	.dw 0x9140, 0xc02e,	0x917f, 0xc02e,		0x21, 0
	.dw 0x91c0, 0xc02e,	0x91ff, 0xc02e,		0x21, 0
	.dw 0x9240, 0xc02e,	0x927f, 0xc02e,		0x21, 0
	.dw 0x92c0, 0xc02e,	0x92ff, 0xc02e,		0x21, 0
	.dw 0x9340, 0xc02e,	0x937f, 0xc02e,		0x21, 0
	.dw 0x93c0, 0xc02e,	0x93ff, 0xc02e,		0x21, 0
	.dw 0x9440, 0xc02e,	0x947f, 0xc02e,		0x21, 0
	.dw 0x94c0, 0xc02e,	0x94ff, 0xc02e,		0x21, 0
	.dw 0x9540, 0xc02e,	0x957f, 0xc02e,		0x21, 0
	.dw 0x95c0, 0xc02e,	0x95ff, 0xc02e,		0x21, 0
	.dw 0x9640, 0xc02e,	0x967f, 0xc02e,		0x21, 0
	.dw 0x96c0, 0xc02e,	0x96ff, 0xc02e,		0x21, 0
	.dw 0x9740, 0xc02e,	0x977f, 0xc02e,		0x21, 0
	.dw 0x97c0, 0xc02e,	0x97ff, 0xc02e,		0x21, 0
	.dw 0x9840, 0xc02e,	0x987f, 0xc02e,		0x21, 0
	.dw 0x98c0, 0xc02e,	0x98ff, 0xc02e,		0x21, 0
	.dw 0x9940, 0xc02e,	0x997f, 0xc02e,		0x21, 0
	.dw 0x99c0, 0xc02e,	0x9fff, 0xc02e,		0x21, 0
	.dw 0xa040, 0xc02e,	0xa07f, 0xc02e,		0x21, 0
	.dw 0xa0c0, 0xc02e,	0xa0ff, 0xc02e,		0x21, 0
	.dw 0xa140, 0xc02e,	0xa17f, 0xc02e,		0x21, 0
	.dw 0xa1c0, 0xc02e,	0xa1ff, 0xc02e,		0x21, 0
	.dw 0xa240, 0xc02e,	0xa27f, 0xc02e,		0x21, 0
	.dw 0xa2c0, 0xc02e,	0xa2ff, 0xc02e,		0x21, 0
	.dw 0xa340, 0xc02e,	0xa37f, 0xc02e,		0x21, 0
	.dw 0xa3c0, 0xc02e,	0xa3ff, 0xc02e,		0x21, 0
	.dw 0xa440, 0xc02e,	0xa47f, 0xc02e,		0x21, 0
	.dw 0xa4c0, 0xc02e,	0xa4ff, 0xc02e,		0x21, 0
	.dw 0xa540, 0xc02e,	0xa57f, 0xc02e,		0x21, 0
	.dw 0xa5c0, 0xc02e,	0xa5ff, 0xc02e,		0x21, 0
	.dw 0xa640, 0xc02e,	0xa67f, 0xc02e,		0x21, 0
	.dw 0xa6c0, 0xc02e,	0xa6ff, 0xc02e,		0x21, 0
	.dw 0xa740, 0xc02e,	0xa77f, 0xc02e,		0x21, 0
	.dw 0xa7c0, 0xc02e,	0xa7ff, 0xc02e,		0x21, 0
	.dw 0xa840, 0xc02e,	0xa87f, 0xc02e,		0x21, 0
	.dw 0xa8c0, 0xc02e,	0xa8ff, 0xc02e,		0x21, 0
	.dw 0xa940, 0xc02e,	0xa97f, 0xc02e,		0x21, 0
	.dw 0xa9c0, 0xc02e,	0xa9ff, 0xc02e,		0x21, 0
	.dw 0xaa40, 0xc02e,	0xaa7f, 0xc02e,		0x21, 0
	.dw 0xaac0, 0xc02e,	0xaaff, 0xc02e,		0x21, 0
	.dw 0xab40, 0xc02e,	0xab7f, 0xc02e,		0x21, 0
	.dw 0xabc0, 0xc02e,	0xabff, 0xc02e,		0x21, 0
	.dw 0xac40, 0xc02e,	0xac7f, 0xc02e,		0x21, 0
	.dw 0xacc0, 0xc02e,	0xacff, 0xc02e,		0x21, 0
	.dw 0xad40, 0xc02e,	0xad7f, 0xc02e,		0x21, 0
	.dw 0xadc0, 0xc02e,	0xadff, 0xc02e,		0x21, 0
	.dw 0xae40, 0xc02e,	0xae7f, 0xc02e,		0x21, 0
	.dw 0xaec0, 0xc02e,	0xaeff, 0xc02e,		0x21, 0
	.dw 0xaf40, 0xc02e,	0xaf7f, 0xc02e,		0x21, 0
	.dw 0xafc0, 0xc02e,	0xafff, 0xc02e,		0x21, 0
	.dw 0xb040, 0xc02e,	0xb07f, 0xc02e,		0x21, 0
	.dw 0xb0c0, 0xc02e,	0xb0ff, 0xc02e,		0x21, 0
	.dw 0xb140, 0xc02e,	0xb17f, 0xc02e,		0x21, 0
	.dw 0xb1c0, 0xc02e,	0xb1ff, 0xc02e,		0x21, 0
	.dw 0xb240, 0xc02e,	0xb27f, 0xc02e,		0x21, 0
	.dw 0xb2c0, 0xc02e,	0xb2ff, 0xc02e,		0x21, 0
	.dw 0xb340, 0xc02e,	0xb37f, 0xc02e,		0x21, 0
	.dw 0xb3c0, 0xc02e,	0xb3ff, 0xc02e,		0x21, 0
	.dw 0xb440, 0xc02e,	0xb47f, 0xc02e,		0x21, 0
	.dw 0xb4c0, 0xc02e,	0xb4ff, 0xc02e,		0x21, 0
	.dw 0xb540, 0xc02e,	0xb57f, 0xc02e,		0x21, 0
	.dw 0xb5c0, 0xc02e,	0xb5ff, 0xc02e,		0x21, 0
	.dw 0xb640, 0xc02e,	0xb67f, 0xc02e,		0x21, 0
	.dw 0xb6c0, 0xc02e,	0xb6ff, 0xc02e,		0x21, 0
	.dw 0xb740, 0xc02e,	0xb77f, 0xc02e,		0x21, 0
	.dw 0xb7c0, 0xc02e,	0xb7ff, 0xc02e,		0x21, 0
	.dw 0xb840, 0xc02e,	0xb87f, 0xc02e,		0x21, 0
	.dw 0xb8c0, 0xc02e,	0xb8ff, 0xc02e,		0x21, 0
	.dw 0xb940, 0xc02e,	0xb97f, 0xc02e,		0x21, 0
	.dw 0xb9c0, 0xc02e,	0xbfff, 0xc02e,		0x21, 0
	.dw 0xc040, 0xc02e,	0xc07f, 0xc02e,		0x21, 0
	.dw 0xc0c0, 0xc02e,	0xc0ff, 0xc02e,		0x21, 0
	.dw 0xc140, 0xc02e,	0xc17f, 0xc02e,		0x21, 0
	.dw 0xc1c0, 0xc02e,	0xc1ff, 0xc02e,		0x21, 0
	.dw 0xc240, 0xc02e,	0xc27f, 0xc02e,		0x21, 0
	.dw 0xc2c0, 0xc02e,	0xc2ff, 0xc02e,		0x21, 0
	.dw 0xc340, 0xc02e,	0xc37f, 0xc02e,		0x21, 0
	.dw 0xc3c0, 0xc02e,	0xc3ff, 0xc02e,		0x21, 0
	.dw 0xc440, 0xc02e,	0xc47f, 0xc02e,		0x21, 0
	.dw 0xc4c0, 0xc02e,	0xc4ff, 0xc02e,		0x21, 0
	.dw 0xc540, 0xc02e,	0xc57f, 0xc02e,		0x21, 0
	.dw 0xc5c0, 0xc02e,	0xc5ff, 0xc02e,		0x21, 0
	.dw 0xc640, 0xc02e,	0xc67f, 0xc02e,		0x21, 0
	.dw 0xc6c0, 0xc02e,	0xc6ff, 0xc02e,		0x21, 0
	.dw 0xc740, 0xc02e,	0xc77f, 0xc02e,		0x21, 0
	.dw 0xc7c0, 0xc02e,	0xc7ff, 0xc02e,		0x21, 0
	.dw 0xc840, 0xc02e,	0xc87f, 0xc02e,		0x21, 0
	.dw 0xc8c0, 0xc02e,	0xc8ff, 0xc02e,		0x21, 0
	.dw 0xc940, 0xc02e,	0xc97f, 0xc02e,		0x21, 0
	.dw 0xc9c0, 0xc02e,	0xc9ff, 0xc02e,		0x21, 0
	.dw 0xca40, 0xc02e,	0xca7f, 0xc02e,		0x21, 0
	.dw 0xcac0, 0xc02e,	0xcaff, 0xc02e,		0x21, 0
	.dw 0xcb40, 0xc02e,	0xcb7f, 0xc02e,		0x21, 0
	.dw 0xcbc0, 0xc02e,	0xcbff, 0xc02e,		0x21, 0
	.dw 0xcc40, 0xc02e,	0xcc7f, 0xc02e,		0x21, 0
	.dw 0xccc0, 0xc02e,	0xccff, 0xc02e,		0x21, 0
	.dw 0xcd40, 0xc02e,	0xcd7f, 0xc02e,		0x21, 0
	.dw 0xcdc0, 0xc02e,	0xcdff, 0xc02e,		0x21, 0
	.dw 0xce40, 0xc02e,	0xce7f, 0xc02e,		0x21, 0
	.dw 0xcec0, 0xc02e,	0xceff, 0xc02e,		0x21, 0
	.dw 0xcf40, 0xc02e,	0xcf7f, 0xc02e,		0x21, 0
	.dw 0xcfc0, 0xc02e,	0xcfff, 0xc02e,		0x21, 0
	.dw 0xd040, 0xc02e,	0xd07f, 0xc02e,		0x21, 0
	.dw 0xd0c0, 0xc02e,	0xd0ff, 0xc02e,		0x21, 0
	.dw 0xd140, 0xc02e,	0xd17f, 0xc02e,		0x21, 0
	.dw 0xd1c0, 0xc02e,	0xd1ff, 0xc02e,		0x21, 0
	.dw 0xd240, 0xc02e,	0xd27f, 0xc02e,		0x21, 0
	.dw 0xd2c0, 0xc02e,	0xd2ff, 0xc02e,		0x21, 0
	.dw 0xd340, 0xc02e,	0xd37f, 0xc02e,		0x21, 0
	.dw 0xd3c0, 0xc02e,	0xd3ff, 0xc02e,		0x21, 0
	.dw 0xd440, 0xc02e,	0xd47f, 0xc02e,		0x21, 0
	.dw 0xd4c0, 0xc02e,	0xd4ff, 0xc02e,		0x21, 0
	.dw 0xd540, 0xc02e,	0xd57f, 0xc02e,		0x21, 0
	.dw 0xd5c0, 0xc02e,	0xd5ff, 0xc02e,		0x21, 0
	.dw 0xd640, 0xc02e,	0xd67f, 0xc02e,		0x21, 0
	.dw 0xd6c0, 0xc02e,	0xd6ff, 0xc02e,		0x21, 0
	.dw 0xd740, 0xc02e,	0xd77f, 0xc02e,		0x21, 0
	.dw 0xd7c0, 0xc02e,	0xd7ff, 0xc02e,		0x21, 0
	.dw 0xd840, 0xc02e,	0xd87f, 0xc02e,		0x21, 0
	.dw 0xd8c0, 0xc02e,	0xd8ff, 0xc02e,		0x21, 0
	.dw 0xd940, 0xc02e,	0xd97f, 0xc02e,		0x21, 0
	.dw 0xd9c0, 0xc02e,	0xdfff, 0xc02e,		0x21, 0
	.dw 0xe040, 0xc02e,	0xe07f, 0xc02e,		0x21, 0
	.dw 0xe0c0, 0xc02e,	0xe0ff, 0xc02e,		0x21, 0
	.dw 0xe140, 0xc02e,	0xe17f, 0xc02e,		0x21, 0
	.dw 0xe1c0, 0xc02e,	0xe1ff, 0xc02e,		0x21, 0
	.dw 0xe240, 0xc02e,	0xe27f, 0xc02e,		0x21, 0
	.dw 0xe2c0, 0xc02e,	0xe2ff, 0xc02e,		0x21, 0
	.dw 0xe340, 0xc02e,	0xe37f, 0xc02e,		0x21, 0
	.dw 0xe3c0, 0xc02e,	0xe3ff, 0xc02e,		0x21, 0
	.dw 0xe440, 0xc02e,	0xe47f, 0xc02e,		0x21, 0
	.dw 0xe4c0, 0xc02e,	0xe4ff, 0xc02e,		0x21, 0
	.dw 0xe540, 0xc02e,	0xe57f, 0xc02e,		0x21, 0
	.dw 0xe5c0, 0xc02e,	0xe5ff, 0xc02e,		0x21, 0
	.dw 0xe640, 0xc02e,	0xe67f, 0xc02e,		0x21, 0
	.dw 0xe6c0, 0xc02e,	0xe6ff, 0xc02e,		0x21, 0
	.dw 0xe740, 0xc02e,	0xe77f, 0xc02e,		0x21, 0
	.dw 0xe7c0, 0xc02e,	0xe7ff, 0xc02e,		0x21, 0
	.dw 0xe840, 0xc02e,	0xe87f, 0xc02e,		0x21, 0
	.dw 0xe8c0, 0xc02e,	0xe8ff, 0xc02e,		0x21, 0
	.dw 0xe940, 0xc02e,	0xe97f, 0xc02e,		0x21, 0
	.dw 0xe9c0, 0xc02e,	0xe9ff, 0xc02e,		0x21, 0
	.dw 0xea40, 0xc02e,	0xea7f, 0xc02e,		0x21, 0
	.dw 0xeac0, 0xc02e,	0xeaff, 0xc02e,		0x21, 0
	.dw 0xeb40, 0xc02e,	0xeb7f, 0xc02e,		0x21, 0
	.dw 0xebc0, 0xc02e,	0xebff, 0xc02e,		0x21, 0
	.dw 0xec40, 0xc02e,	0xec7f, 0xc02e,		0x21, 0
	.dw 0xecc0, 0xc02e,	0xecff, 0xc02e,		0x21, 0
	.dw 0xed40, 0xc02e,	0xed7f, 0xc02e,		0x21, 0
	.dw 0xedc0, 0xc02e,	0xedff, 0xc02e,		0x21, 0
	.dw 0xee40, 0xc02e,	0xee7f, 0xc02e,		0x21, 0
	.dw 0xeec0, 0xc02e,	0xeeff, 0xc02e,		0x21, 0
	.dw 0xef40, 0xc02e,	0xef7f, 0xc02e,		0x21, 0
	.dw 0xefc0, 0xc02e,	0xefff, 0xc02e,		0x21, 0
	.dw 0xf040, 0xc02e,	0xf07f, 0xc02e,		0x21, 0
	.dw 0xf0c0, 0xc02e,	0xf0ff, 0xc02e,		0x21, 0
	.dw 0xf140, 0xc02e,	0xf17f, 0xc02e,		0x21, 0
	.dw 0xf1c0, 0xc02e,	0xf1ff, 0xc02e,		0x21, 0
	.dw 0xf240, 0xc02e,	0xf27f, 0xc02e,		0x21, 0
	.dw 0xf2c0, 0xc02e,	0xf2ff, 0xc02e,		0x21, 0
	.dw 0xf340, 0xc02e,	0xf37f, 0xc02e,		0x21, 0
	.dw 0xf3c0, 0xc02e,	0xf3ff, 0xc02e,		0x21, 0
	.dw 0xf440, 0xc02e,	0xf47f, 0xc02e,		0x21, 0
	.dw 0xf4c0, 0xc02e,	0xf4ff, 0xc02e,		0x21, 0
	.dw 0xf540, 0xc02e,	0xf57f, 0xc02e,		0x21, 0
	.dw 0xf5c0, 0xc02e,	0xf5ff, 0xc02e,		0x21, 0
	.dw 0xf640, 0xc02e,	0xf67f, 0xc02e,		0x21, 0
	.dw 0xf6c0, 0xc02e,	0xf6ff, 0xc02e,		0x21, 0
	.dw 0xf740, 0xc02e,	0xf77f, 0xc02e,		0x21, 0
	.dw 0xf7c0, 0xc02e,	0xf7ff, 0xc02e,		0x21, 0
	.dw 0xf840, 0xc02e,	0xf87f, 0xc02e,		0x21, 0
	.dw 0xf8c0, 0xc02e,	0xf8ff, 0xc02e,		0x21, 0
	.dw 0xf940, 0xc02e,	0xf97f, 0xc02e,		0x21, 0
	.dw 0xf9c0, 0xc02e,	0xffff, 0xc02e,		0x21, 0
	.dw 0x0040, 0xc02f,	0x007f, 0xc02f,		0x21, 0
	.dw 0x00c0, 0xc02f,	0x00ff, 0xc02f,		0x21, 0
	.dw 0x0140, 0xc02f,	0x017f, 0xc02f,		0x21, 0
	.dw 0x01c0, 0xc02f,	0x01ff, 0xc02f,		0x21, 0
	.dw 0x0240, 0xc02f,	0x027f, 0xc02f,		0x21, 0
	.dw 0x02c0, 0xc02f,	0x02ff, 0xc02f,		0x21, 0
	.dw 0x0340, 0xc02f,	0x037f, 0xc02f,		0x21, 0
	.dw 0x03c0, 0xc02f,	0x03ff, 0xc02f,		0x21, 0
	.dw 0x0440, 0xc02f,	0x047f, 0xc02f,		0x21, 0
	.dw 0x04c0, 0xc02f,	0x04ff, 0xc02f,		0x21, 0
	.dw 0x0540, 0xc02f,	0x057f, 0xc02f,		0x21, 0
	.dw 0x05c0, 0xc02f,	0x05ff, 0xc02f,		0x21, 0
	.dw 0x0640, 0xc02f,	0x067f, 0xc02f,		0x21, 0
	.dw 0x06c0, 0xc02f,	0x06ff, 0xc02f,		0x21, 0
	.dw 0x0740, 0xc02f,	0x077f, 0xc02f,		0x21, 0
	.dw 0x07c0, 0xc02f,	0x07ff, 0xc02f,		0x21, 0
	.dw 0x0840, 0xc02f,	0x087f, 0xc02f,		0x21, 0
	.dw 0x08c0, 0xc02f,	0x08ff, 0xc02f,		0x21, 0
	.dw 0x0940, 0xc02f,	0x097f, 0xc02f,		0x21, 0
	.dw 0x09c0, 0xc02f,	0x09ff, 0xc02f,		0x21, 0
	.dw 0x0a40, 0xc02f,	0x0a7f, 0xc02f,		0x21, 0
	.dw 0x0ac0, 0xc02f,	0x0aff, 0xc02f,		0x21, 0
	.dw 0x0b40, 0xc02f,	0x0b7f, 0xc02f,		0x21, 0
	.dw 0x0bc0, 0xc02f,	0x0bff, 0xc02f,		0x21, 0
	.dw 0x0c40, 0xc02f,	0x0c7f, 0xc02f,		0x21, 0
	.dw 0x0cc0, 0xc02f,	0x0cff, 0xc02f,		0x21, 0
	.dw 0x0d40, 0xc02f,	0x0d7f, 0xc02f,		0x21, 0
	.dw 0x0dc0, 0xc02f,	0x0dff, 0xc02f,		0x21, 0
	.dw 0x0e40, 0xc02f,	0x0e7f, 0xc02f,		0x21, 0
	.dw 0x0ec0, 0xc02f,	0x0eff, 0xc02f,		0x21, 0
	.dw 0x0f40, 0xc02f,	0x0f7f, 0xc02f,		0x21, 0
	.dw 0x0fc0, 0xc02f,	0x0fff, 0xc02f,		0x21, 0
	.dw 0x1040, 0xc02f,	0x107f, 0xc02f,		0x21, 0
	.dw 0x10c0, 0xc02f,	0x10ff, 0xc02f,		0x21, 0
	.dw 0x1140, 0xc02f,	0x117f, 0xc02f,		0x21, 0
	.dw 0x11c0, 0xc02f,	0x11ff, 0xc02f,		0x21, 0
	.dw 0x1240, 0xc02f,	0x127f, 0xc02f,		0x21, 0
	.dw 0x12c0, 0xc02f,	0x12ff, 0xc02f,		0x21, 0
	.dw 0x1340, 0xc02f,	0x137f, 0xc02f,		0x21, 0
	.dw 0x13c0, 0xc02f,	0x13ff, 0xc02f,		0x21, 0
	.dw 0x1440, 0xc02f,	0x147f, 0xc02f,		0x21, 0
	.dw 0x14c0, 0xc02f,	0x14ff, 0xc02f,		0x21, 0
	.dw 0x1540, 0xc02f,	0x157f, 0xc02f,		0x21, 0
	.dw 0x15c0, 0xc02f,	0x15ff, 0xc02f,		0x21, 0
	.dw 0x1640, 0xc02f,	0x167f, 0xc02f,		0x21, 0
	.dw 0x16c0, 0xc02f,	0x16ff, 0xc02f,		0x21, 0
	.dw 0x1740, 0xc02f,	0x177f, 0xc02f,		0x21, 0
	.dw 0x17c0, 0xc02f,	0x17ff, 0xc02f,		0x21, 0
	.dw 0x1840, 0xc02f,	0x187f, 0xc02f,		0x21, 0
	.dw 0x18c0, 0xc02f,	0x18ff, 0xc02f,		0x21, 0
	.dw 0x1940, 0xc02f,	0x197f, 0xc02f,		0x21, 0
	.dw 0x19c0, 0xc02f,	0x1fff, 0xc02f,		0x21, 0
	.dw 0x2040, 0xc02f,	0x207f, 0xc02f,		0x21, 0
	.dw 0x20c0, 0xc02f,	0x20ff, 0xc02f,		0x21, 0
	.dw 0x2140, 0xc02f,	0x217f, 0xc02f,		0x21, 0
	.dw 0x21c0, 0xc02f,	0x21ff, 0xc02f,		0x21, 0
	.dw 0x2240, 0xc02f,	0x227f, 0xc02f,		0x21, 0
	.dw 0x22c0, 0xc02f,	0x22ff, 0xc02f,		0x21, 0
	.dw 0x2340, 0xc02f,	0x237f, 0xc02f,		0x21, 0
	.dw 0x23c0, 0xc02f,	0x23ff, 0xc02f,		0x21, 0
	.dw 0x2440, 0xc02f,	0x247f, 0xc02f,		0x21, 0
	.dw 0x24c0, 0xc02f,	0x24ff, 0xc02f,		0x21, 0
	.dw 0x2540, 0xc02f,	0x257f, 0xc02f,		0x21, 0
	.dw 0x25c0, 0xc02f,	0x25ff, 0xc02f,		0x21, 0
	.dw 0x2640, 0xc02f,	0x267f, 0xc02f,		0x21, 0
	.dw 0x26c0, 0xc02f,	0x26ff, 0xc02f,		0x21, 0
	.dw 0x2740, 0xc02f,	0x277f, 0xc02f,		0x21, 0
	.dw 0x27c0, 0xc02f,	0x27ff, 0xc02f,		0x21, 0
	.dw 0x2840, 0xc02f,	0x287f, 0xc02f,		0x21, 0
	.dw 0x28c0, 0xc02f,	0x28ff, 0xc02f,		0x21, 0
	.dw 0x2940, 0xc02f,	0x297f, 0xc02f,		0x21, 0
	.dw 0x29c0, 0xc02f,	0x29ff, 0xc02f,		0x21, 0
	.dw 0x2a40, 0xc02f,	0x2a7f, 0xc02f,		0x21, 0
	.dw 0x2ac0, 0xc02f,	0x2aff, 0xc02f,		0x21, 0
	.dw 0x2b40, 0xc02f,	0x2b7f, 0xc02f,		0x21, 0
	.dw 0x2bc0, 0xc02f,	0x2bff, 0xc02f,		0x21, 0
	.dw 0x2c40, 0xc02f,	0x2c7f, 0xc02f,		0x21, 0
	.dw 0x2cc0, 0xc02f,	0x2cff, 0xc02f,		0x21, 0
	.dw 0x2d40, 0xc02f,	0x2d7f, 0xc02f,		0x21, 0
	.dw 0x2dc0, 0xc02f,	0x2dff, 0xc02f,		0x21, 0
	.dw 0x2e40, 0xc02f,	0x2e7f, 0xc02f,		0x21, 0
	.dw 0x2ec0, 0xc02f,	0x2eff, 0xc02f,		0x21, 0
	.dw 0x2f40, 0xc02f,	0x2f7f, 0xc02f,		0x21, 0
	.dw 0x2fc0, 0xc02f,	0x2fff, 0xc02f,		0x21, 0
	.dw 0x3040, 0xc02f,	0x307f, 0xc02f,		0x21, 0
	.dw 0x30c0, 0xc02f,	0x30ff, 0xc02f,		0x21, 0
	.dw 0x3140, 0xc02f,	0x317f, 0xc02f,		0x21, 0
	.dw 0x31c0, 0xc02f,	0x31ff, 0xc02f,		0x21, 0
	.dw 0x3240, 0xc02f,	0x327f, 0xc02f,		0x21, 0
	.dw 0x32c0, 0xc02f,	0x32ff, 0xc02f,		0x21, 0
	.dw 0x3340, 0xc02f,	0x337f, 0xc02f,		0x21, 0
	.dw 0x33c0, 0xc02f,	0x33ff, 0xc02f,		0x21, 0
	.dw 0x3440, 0xc02f,	0x347f, 0xc02f,		0x21, 0
	.dw 0x34c0, 0xc02f,	0x34ff, 0xc02f,		0x21, 0
	.dw 0x3540, 0xc02f,	0x357f, 0xc02f,		0x21, 0
	.dw 0x35c0, 0xc02f,	0x35ff, 0xc02f,		0x21, 0
	.dw 0x3640, 0xc02f,	0x367f, 0xc02f,		0x21, 0
	.dw 0x36c0, 0xc02f,	0x36ff, 0xc02f,		0x21, 0
	.dw 0x3740, 0xc02f,	0x377f, 0xc02f,		0x21, 0
	.dw 0x37c0, 0xc02f,	0x37ff, 0xc02f,		0x21, 0
	.dw 0x3840, 0xc02f,	0x387f, 0xc02f,		0x21, 0
	.dw 0x38c0, 0xc02f,	0x38ff, 0xc02f,		0x21, 0
	.dw 0x3940, 0xc02f,	0x397f, 0xc02f,		0x21, 0
	.dw 0x39c0, 0xc02f,	0x1fff, 0xc030,		0x21, 0
	.dw 0x3a00, 0xc030,	0x5fff, 0xc030,		0x21, 0
	.dw 0x7a00, 0xc030,	0x9fff, 0xc030,		0x21, 0
	.dw 0xba00, 0xc030,	0xdfff, 0xc030,		0x21, 0
	.dw 0xfa00, 0xc030,	0x1fff, 0xc031,		0x21, 0
	.dw 0x3a00, 0xc031,	0x5fff, 0xc031,		0x21, 0
	.dw 0x7a00, 0xc031,	0x9fff, 0xc031,		0x21, 0
	.dw 0xba00, 0xc031,	0xdfff, 0xc031,		0x21, 0
	.dw 0xfa00, 0xc031,	0x1fff, 0xc032,		0x21, 0
	.dw 0x3a00, 0xc032,	0x5fff, 0xc032,		0x21, 0
	.dw 0x7a00, 0xc032,	0x9fff, 0xc032,		0x21, 0
	.dw 0xba00, 0xc032,	0xdfff, 0xc032,		0x21, 0
	.dw 0xfa00, 0xc032,	0xffff, 0xc033,		0x21, 0
	.dw 0x1a00, 0xc034,	0x1fff, 0xc034,		0x21, 0
	.dw 0x3a00, 0xc034,	0x3fff, 0xc034,		0x21, 0
	.dw 0x5a00, 0xc034,	0x5fff, 0xc034,		0x21, 0
	.dw 0x7a00, 0xc034,	0x7fff, 0xc034,		0x21, 0
	.dw 0x9a00, 0xc034,	0x9fff, 0xc034,		0x21, 0
	.dw 0xba00, 0xc034,	0xbfff, 0xc034,		0x21, 0
	.dw 0xda00, 0xc034,	0xdfff, 0xc034,		0x21, 0
	.dw 0xfa00, 0xc034,	0xffff, 0xc034,		0x21, 0
	.dw 0x1a00, 0xc035,	0x1fff, 0xc035,		0x21, 0
	.dw 0x3a00, 0xc035,	0x3fff, 0xc035,		0x21, 0
	.dw 0x5a00, 0xc035,	0x5fff, 0xc035,		0x21, 0
	.dw 0x7a00, 0xc035,	0x7fff, 0xc035,		0x21, 0
	.dw 0x9a00, 0xc035,	0x9fff, 0xc035,		0x21, 0
	.dw 0xba00, 0xc035,	0xbfff, 0xc035,		0x21, 0
	.dw 0xda00, 0xc035,	0xdfff, 0xc035,		0x21, 0
	.dw 0xfa00, 0xc035,	0xffff, 0xc035,		0x21, 0
	.dw 0x1a00, 0xc036,	0x1fff, 0xc036,		0x21, 0
	.dw 0x3a00, 0xc036,	0x3fff, 0xc036,		0x21, 0
	.dw 0x5a00, 0xc036,	0x5fff, 0xc036,		0x21, 0
	.dw 0x7a00, 0xc036,	0x7fff, 0xc036,		0x21, 0
	.dw 0x9a00, 0xc036,	0x9fff, 0xc036,		0x21, 0
	.dw 0xba00, 0xc036,	0xbfff, 0xc036,		0x21, 0
	.dw 0xda00, 0xc036,	0xdfff, 0xc036,		0x21, 0
	.dw 0xfa00, 0xc036,	0xffff, 0xc036,		0x21, 0
	.dw 0x1a00, 0xc037,	0x1fff, 0xc037,		0x21, 0
	.dw 0x3a00, 0xc037,	0x1fff, 0xc038,		0x21, 0
	.dw 0x2040, 0xc038,	0x207f, 0xc038,		0x21, 0
	.dw 0x20c0, 0xc038,	0x20ff, 0xc038,		0x21, 0
	.dw 0x2140, 0xc038,	0x217f, 0xc038,		0x21, 0
	.dw 0x21c0, 0xc038,	0x21ff, 0xc038,		0x21, 0
	.dw 0x2240, 0xc038,	0x227f, 0xc038,		0x21, 0
	.dw 0x22c0, 0xc038,	0x22ff, 0xc038,		0x21, 0
	.dw 0x2340, 0xc038,	0x237f, 0xc038,		0x21, 0
	.dw 0x23c0, 0xc038,	0x23ff, 0xc038,		0x21, 0
	.dw 0x2440, 0xc038,	0x247f, 0xc038,		0x21, 0
	.dw 0x24c0, 0xc038,	0x24ff, 0xc038,		0x21, 0
	.dw 0x2540, 0xc038,	0x257f, 0xc038,		0x21, 0
	.dw 0x25c0, 0xc038,	0x25ff, 0xc038,		0x21, 0
	.dw 0x2640, 0xc038,	0x267f, 0xc038,		0x21, 0
	.dw 0x26c0, 0xc038,	0x26ff, 0xc038,		0x21, 0
	.dw 0x2740, 0xc038,	0x277f, 0xc038,		0x21, 0
	.dw 0x27c0, 0xc038,	0x27ff, 0xc038,		0x21, 0
	.dw 0x2840, 0xc038,	0x287f, 0xc038,		0x21, 0
	.dw 0x28c0, 0xc038,	0x28ff, 0xc038,		0x21, 0
	.dw 0x2940, 0xc038,	0x297f, 0xc038,		0x21, 0
	.dw 0x29c0, 0xc038,	0x29ff, 0xc038,		0x21, 0
	.dw 0x2a40, 0xc038,	0x2a7f, 0xc038,		0x21, 0
	.dw 0x2ac0, 0xc038,	0x2aff, 0xc038,		0x21, 0
	.dw 0x2b40, 0xc038,	0x2b7f, 0xc038,		0x21, 0
	.dw 0x2bc0, 0xc038,	0x2bff, 0xc038,		0x21, 0
	.dw 0x2c40, 0xc038,	0x2c7f, 0xc038,		0x21, 0
	.dw 0x2cc0, 0xc038,	0x2cff, 0xc038,		0x21, 0
	.dw 0x2d40, 0xc038,	0x2d7f, 0xc038,		0x21, 0
	.dw 0x2dc0, 0xc038,	0x2dff, 0xc038,		0x21, 0
	.dw 0x2e40, 0xc038,	0x2e7f, 0xc038,		0x21, 0
	.dw 0x2ec0, 0xc038,	0x2eff, 0xc038,		0x21, 0
	.dw 0x2f40, 0xc038,	0x2f7f, 0xc038,		0x21, 0
	.dw 0x2fc0, 0xc038,	0x2fff, 0xc038,		0x21, 0
	.dw 0x3040, 0xc038,	0x307f, 0xc038,		0x21, 0
	.dw 0x30c0, 0xc038,	0x30ff, 0xc038,		0x21, 0
	.dw 0x3140, 0xc038,	0x317f, 0xc038,		0x21, 0
	.dw 0x31c0, 0xc038,	0x31ff, 0xc038,		0x21, 0
	.dw 0x3240, 0xc038,	0x327f, 0xc038,		0x21, 0
	.dw 0x32c0, 0xc038,	0x32ff, 0xc038,		0x21, 0
	.dw 0x3340, 0xc038,	0x337f, 0xc038,		0x21, 0
	.dw 0x33c0, 0xc038,	0x33ff, 0xc038,		0x21, 0
	.dw 0x3440, 0xc038,	0x347f, 0xc038,		0x21, 0
	.dw 0x34c0, 0xc038,	0x34ff, 0xc038,		0x21, 0
	.dw 0x3540, 0xc038,	0x357f, 0xc038,		0x21, 0
	.dw 0x35c0, 0xc038,	0x35ff, 0xc038,		0x21, 0
	.dw 0x3640, 0xc038,	0x367f, 0xc038,		0x21, 0
	.dw 0x36c0, 0xc038,	0x36ff, 0xc038,		0x21, 0
	.dw 0x3740, 0xc038,	0x377f, 0xc038,		0x21, 0
	.dw 0x37c0, 0xc038,	0x37ff, 0xc038,		0x21, 0
	.dw 0x3840, 0xc038,	0x387f, 0xc038,		0x21, 0
	.dw 0x38c0, 0xc038,	0x38ff, 0xc038,		0x21, 0
	.dw 0x3940, 0xc038,	0x397f, 0xc038,		0x21, 0
	.dw 0x39c0, 0xc038,	0x5fff, 0xc038,		0x21, 0
	.dw 0x6040, 0xc038,	0x607f, 0xc038,		0x21, 0
	.dw 0x60c0, 0xc038,	0x60ff, 0xc038,		0x21, 0
	.dw 0x6140, 0xc038,	0x617f, 0xc038,		0x21, 0
	.dw 0x61c0, 0xc038,	0x61ff, 0xc038,		0x21, 0
	.dw 0x6240, 0xc038,	0x627f, 0xc038,		0x21, 0
	.dw 0x62c0, 0xc038,	0x62ff, 0xc038,		0x21, 0
	.dw 0x6340, 0xc038,	0x637f, 0xc038,		0x21, 0
	.dw 0x63c0, 0xc038,	0x63ff, 0xc038,		0x21, 0
	.dw 0x6440, 0xc038,	0x647f, 0xc038,		0x21, 0
	.dw 0x64c0, 0xc038,	0x64ff, 0xc038,		0x21, 0
	.dw 0x6540, 0xc038,	0x657f, 0xc038,		0x21, 0
	.dw 0x65c0, 0xc038,	0x65ff, 0xc038,		0x21, 0
	.dw 0x6640, 0xc038,	0x667f, 0xc038,		0x21, 0
	.dw 0x66c0, 0xc038,	0x66ff, 0xc038,		0x21, 0
	.dw 0x6740, 0xc038,	0x677f, 0xc038,		0x21, 0
	.dw 0x67c0, 0xc038,	0x67ff, 0xc038,		0x21, 0
	.dw 0x6840, 0xc038,	0x687f, 0xc038,		0x21, 0
	.dw 0x68c0, 0xc038,	0x68ff, 0xc038,		0x21, 0
	.dw 0x6940, 0xc038,	0x697f, 0xc038,		0x21, 0
	.dw 0x69c0, 0xc038,	0x69ff, 0xc038,		0x21, 0
	.dw 0x6a40, 0xc038,	0x6a7f, 0xc038,		0x21, 0
	.dw 0x6ac0, 0xc038,	0x6aff, 0xc038,		0x21, 0
	.dw 0x6b40, 0xc038,	0x6b7f, 0xc038,		0x21, 0
	.dw 0x6bc0, 0xc038,	0x6bff, 0xc038,		0x21, 0
	.dw 0x6c40, 0xc038,	0x6c7f, 0xc038,		0x21, 0
	.dw 0x6cc0, 0xc038,	0x6cff, 0xc038,		0x21, 0
	.dw 0x6d40, 0xc038,	0x6d7f, 0xc038,		0x21, 0
	.dw 0x6dc0, 0xc038,	0x6dff, 0xc038,		0x21, 0
	.dw 0x6e40, 0xc038,	0x6e7f, 0xc038,		0x21, 0
	.dw 0x6ec0, 0xc038,	0x6eff, 0xc038,		0x21, 0
	.dw 0x6f40, 0xc038,	0x6f7f, 0xc038,		0x21, 0
	.dw 0x6fc0, 0xc038,	0x6fff, 0xc038,		0x21, 0
	.dw 0x7040, 0xc038,	0x707f, 0xc038,		0x21, 0
	.dw 0x70c0, 0xc038,	0x70ff, 0xc038,		0x21, 0
	.dw 0x7140, 0xc038,	0x717f, 0xc038,		0x21, 0
	.dw 0x71c0, 0xc038,	0x71ff, 0xc038,		0x21, 0
	.dw 0x7240, 0xc038,	0x727f, 0xc038,		0x21, 0
	.dw 0x72c0, 0xc038,	0x72ff, 0xc038,		0x21, 0
	.dw 0x7340, 0xc038,	0x737f, 0xc038,		0x21, 0
	.dw 0x73c0, 0xc038,	0x73ff, 0xc038,		0x21, 0
	.dw 0x7440, 0xc038,	0x747f, 0xc038,		0x21, 0
	.dw 0x74c0, 0xc038,	0x74ff, 0xc038,		0x21, 0
	.dw 0x7540, 0xc038,	0x757f, 0xc038,		0x21, 0
	.dw 0x75c0, 0xc038,	0x75ff, 0xc038,		0x21, 0
	.dw 0x7640, 0xc038,	0x767f, 0xc038,		0x21, 0
	.dw 0x76c0, 0xc038,	0x76ff, 0xc038,		0x21, 0
	.dw 0x7740, 0xc038,	0x777f, 0xc038,		0x21, 0
	.dw 0x77c0, 0xc038,	0x77ff, 0xc038,		0x21, 0
	.dw 0x7840, 0xc038,	0x787f, 0xc038,		0x21, 0
	.dw 0x78c0, 0xc038,	0x78ff, 0xc038,		0x21, 0
	.dw 0x7940, 0xc038,	0x797f, 0xc038,		0x21, 0
	.dw 0x79c0, 0xc038,	0x9fff, 0xc038,		0x21, 0
	.dw 0xa040, 0xc038,	0xa07f, 0xc038,		0x21, 0
	.dw 0xa0c0, 0xc038,	0xa0ff, 0xc038,		0x21, 0
	.dw 0xa140, 0xc038,	0xa17f, 0xc038,		0x21, 0
	.dw 0xa1c0, 0xc038,	0xa1ff, 0xc038,		0x21, 0
	.dw 0xa240, 0xc038,	0xa27f, 0xc038,		0x21, 0
	.dw 0xa2c0, 0xc038,	0xa2ff, 0xc038,		0x21, 0
	.dw 0xa340, 0xc038,	0xa37f, 0xc038,		0x21, 0
	.dw 0xa3c0, 0xc038,	0xa3ff, 0xc038,		0x21, 0
	.dw 0xa440, 0xc038,	0xa47f, 0xc038,		0x21, 0
	.dw 0xa4c0, 0xc038,	0xa4ff, 0xc038,		0x21, 0
	.dw 0xa540, 0xc038,	0xa57f, 0xc038,		0x21, 0
	.dw 0xa5c0, 0xc038,	0xa5ff, 0xc038,		0x21, 0
	.dw 0xa640, 0xc038,	0xa67f, 0xc038,		0x21, 0
	.dw 0xa6c0, 0xc038,	0xa6ff, 0xc038,		0x21, 0
	.dw 0xa740, 0xc038,	0xa77f, 0xc038,		0x21, 0
	.dw 0xa7c0, 0xc038,	0xa7ff, 0xc038,		0x21, 0
	.dw 0xa840, 0xc038,	0xa87f, 0xc038,		0x21, 0
	.dw 0xa8c0, 0xc038,	0xa8ff, 0xc038,		0x21, 0
	.dw 0xa940, 0xc038,	0xa97f, 0xc038,		0x21, 0
	.dw 0xa9c0, 0xc038,	0xa9ff, 0xc038,		0x21, 0
	.dw 0xaa40, 0xc038,	0xaa7f, 0xc038,		0x21, 0
	.dw 0xaac0, 0xc038,	0xaaff, 0xc038,		0x21, 0
	.dw 0xab40, 0xc038,	0xab7f, 0xc038,		0x21, 0
	.dw 0xabc0, 0xc038,	0xabff, 0xc038,		0x21, 0
	.dw 0xac40, 0xc038,	0xac7f, 0xc038,		0x21, 0
	.dw 0xacc0, 0xc038,	0xacff, 0xc038,		0x21, 0
	.dw 0xad40, 0xc038,	0xad7f, 0xc038,		0x21, 0
	.dw 0xadc0, 0xc038,	0xadff, 0xc038,		0x21, 0
	.dw 0xae40, 0xc038,	0xae7f, 0xc038,		0x21, 0
	.dw 0xaec0, 0xc038,	0xaeff, 0xc038,		0x21, 0
	.dw 0xaf40, 0xc038,	0xaf7f, 0xc038,		0x21, 0
	.dw 0xafc0, 0xc038,	0xafff, 0xc038,		0x21, 0
	.dw 0xb040, 0xc038,	0xb07f, 0xc038,		0x21, 0
	.dw 0xb0c0, 0xc038,	0xb0ff, 0xc038,		0x21, 0
	.dw 0xb140, 0xc038,	0xb17f, 0xc038,		0x21, 0
	.dw 0xb1c0, 0xc038,	0xb1ff, 0xc038,		0x21, 0
	.dw 0xb240, 0xc038,	0xb27f, 0xc038,		0x21, 0
	.dw 0xb2c0, 0xc038,	0xb2ff, 0xc038,		0x21, 0
	.dw 0xb340, 0xc038,	0xb37f, 0xc038,		0x21, 0
	.dw 0xb3c0, 0xc038,	0xb3ff, 0xc038,		0x21, 0
	.dw 0xb440, 0xc038,	0xb47f, 0xc038,		0x21, 0
	.dw 0xb4c0, 0xc038,	0xb4ff, 0xc038,		0x21, 0
	.dw 0xb540, 0xc038,	0xb57f, 0xc038,		0x21, 0
	.dw 0xb5c0, 0xc038,	0xb5ff, 0xc038,		0x21, 0
	.dw 0xb640, 0xc038,	0xb67f, 0xc038,		0x21, 0
	.dw 0xb6c0, 0xc038,	0xb6ff, 0xc038,		0x21, 0
	.dw 0xb740, 0xc038,	0xb77f, 0xc038,		0x21, 0
	.dw 0xb7c0, 0xc038,	0xb7ff, 0xc038,		0x21, 0
	.dw 0xb840, 0xc038,	0xb87f, 0xc038,		0x21, 0
	.dw 0xb8c0, 0xc038,	0xb8ff, 0xc038,		0x21, 0
	.dw 0xb940, 0xc038,	0xb97f, 0xc038,		0x21, 0
	.dw 0xb9c0, 0xc038,	0xdfff, 0xc038,		0x21, 0
	.dw 0xe040, 0xc038,	0xe07f, 0xc038,		0x21, 0
	.dw 0xe0c0, 0xc038,	0xe0ff, 0xc038,		0x21, 0
	.dw 0xe140, 0xc038,	0xe17f, 0xc038,		0x21, 0
	.dw 0xe1c0, 0xc038,	0xe1ff, 0xc038,		0x21, 0
	.dw 0xe240, 0xc038,	0xe27f, 0xc038,		0x21, 0
	.dw 0xe2c0, 0xc038,	0xe2ff, 0xc038,		0x21, 0
	.dw 0xe340, 0xc038,	0xe37f, 0xc038,		0x21, 0
	.dw 0xe3c0, 0xc038,	0xe3ff, 0xc038,		0x21, 0
	.dw 0xe440, 0xc038,	0xe47f, 0xc038,		0x21, 0
	.dw 0xe4c0, 0xc038,	0xe4ff, 0xc038,		0x21, 0
	.dw 0xe540, 0xc038,	0xe57f, 0xc038,		0x21, 0
	.dw 0xe5c0, 0xc038,	0xe5ff, 0xc038,		0x21, 0
	.dw 0xe640, 0xc038,	0xe67f, 0xc038,		0x21, 0
	.dw 0xe6c0, 0xc038,	0xe6ff, 0xc038,		0x21, 0
	.dw 0xe740, 0xc038,	0xe77f, 0xc038,		0x21, 0
	.dw 0xe7c0, 0xc038,	0xe7ff, 0xc038,		0x21, 0
	.dw 0xe840, 0xc038,	0xe87f, 0xc038,		0x21, 0
	.dw 0xe8c0, 0xc038,	0xe8ff, 0xc038,		0x21, 0
	.dw 0xe940, 0xc038,	0xe97f, 0xc038,		0x21, 0
	.dw 0xe9c0, 0xc038,	0xe9ff, 0xc038,		0x21, 0
	.dw 0xea40, 0xc038,	0xea7f, 0xc038,		0x21, 0
	.dw 0xeac0, 0xc038,	0xeaff, 0xc038,		0x21, 0
	.dw 0xeb40, 0xc038,	0xeb7f, 0xc038,		0x21, 0
	.dw 0xebc0, 0xc038,	0xebff, 0xc038,		0x21, 0
	.dw 0xec40, 0xc038,	0xec7f, 0xc038,		0x21, 0
	.dw 0xecc0, 0xc038,	0xecff, 0xc038,		0x21, 0
	.dw 0xed40, 0xc038,	0xed7f, 0xc038,		0x21, 0
	.dw 0xedc0, 0xc038,	0xedff, 0xc038,		0x21, 0
	.dw 0xee40, 0xc038,	0xee7f, 0xc038,		0x21, 0
	.dw 0xeec0, 0xc038,	0xeeff, 0xc038,		0x21, 0
	.dw 0xef40, 0xc038,	0xef7f, 0xc038,		0x21, 0
	.dw 0xefc0, 0xc038,	0xefff, 0xc038,		0x21, 0
	.dw 0xf040, 0xc038,	0xf07f, 0xc038,		0x21, 0
	.dw 0xf0c0, 0xc038,	0xf0ff, 0xc038,		0x21, 0
	.dw 0xf140, 0xc038,	0xf17f, 0xc038,		0x21, 0
	.dw 0xf1c0, 0xc038,	0xf1ff, 0xc038,		0x21, 0
	.dw 0xf240, 0xc038,	0xf27f, 0xc038,		0x21, 0
	.dw 0xf2c0, 0xc038,	0xf2ff, 0xc038,		0x21, 0
	.dw 0xf340, 0xc038,	0xf37f, 0xc038,		0x21, 0
	.dw 0xf3c0, 0xc038,	0xf3ff, 0xc038,		0x21, 0
	.dw 0xf440, 0xc038,	0xf47f, 0xc038,		0x21, 0
	.dw 0xf4c0, 0xc038,	0xf4ff, 0xc038,		0x21, 0
	.dw 0xf540, 0xc038,	0xf57f, 0xc038,		0x21, 0
	.dw 0xf5c0, 0xc038,	0xf5ff, 0xc038,		0x21, 0
	.dw 0xf640, 0xc038,	0xf67f, 0xc038,		0x21, 0
	.dw 0xf6c0, 0xc038,	0xf6ff, 0xc038,		0x21, 0
	.dw 0xf740, 0xc038,	0xf77f, 0xc038,		0x21, 0
	.dw 0xf7c0, 0xc038,	0xf7ff, 0xc038,		0x21, 0
	.dw 0xf840, 0xc038,	0xf87f, 0xc038,		0x21, 0
	.dw 0xf8c0, 0xc038,	0xf8ff, 0xc038,		0x21, 0
	.dw 0xf940, 0xc038,	0xf97f, 0xc038,		0x21, 0
	.dw 0xf9c0, 0xc038,	0x1fff, 0xc039,		0x21, 0
	.dw 0x2040, 0xc039,	0x207f, 0xc039,		0x21, 0
	.dw 0x20c0, 0xc039,	0x20ff, 0xc039,		0x21, 0
	.dw 0x2140, 0xc039,	0x217f, 0xc039,		0x21, 0
	.dw 0x21c0, 0xc039,	0x21ff, 0xc039,		0x21, 0
	.dw 0x2240, 0xc039,	0x227f, 0xc039,		0x21, 0
	.dw 0x22c0, 0xc039,	0x22ff, 0xc039,		0x21, 0
	.dw 0x2340, 0xc039,	0x237f, 0xc039,		0x21, 0
	.dw 0x23c0, 0xc039,	0x23ff, 0xc039,		0x21, 0
	.dw 0x2440, 0xc039,	0x247f, 0xc039,		0x21, 0
	.dw 0x24c0, 0xc039,	0x24ff, 0xc039,		0x21, 0
	.dw 0x2540, 0xc039,	0x257f, 0xc039,		0x21, 0
	.dw 0x25c0, 0xc039,	0x25ff, 0xc039,		0x21, 0
	.dw 0x2640, 0xc039,	0x267f, 0xc039,		0x21, 0
	.dw 0x26c0, 0xc039,	0x26ff, 0xc039,		0x21, 0
	.dw 0x2740, 0xc039,	0x277f, 0xc039,		0x21, 0
	.dw 0x27c0, 0xc039,	0x27ff, 0xc039,		0x21, 0
	.dw 0x2840, 0xc039,	0x287f, 0xc039,		0x21, 0
	.dw 0x28c0, 0xc039,	0x28ff, 0xc039,		0x21, 0
	.dw 0x2940, 0xc039,	0x297f, 0xc039,		0x21, 0
	.dw 0x29c0, 0xc039,	0x29ff, 0xc039,		0x21, 0
	.dw 0x2a40, 0xc039,	0x2a7f, 0xc039,		0x21, 0
	.dw 0x2ac0, 0xc039,	0x2aff, 0xc039,		0x21, 0
	.dw 0x2b40, 0xc039,	0x2b7f, 0xc039,		0x21, 0
	.dw 0x2bc0, 0xc039,	0x2bff, 0xc039,		0x21, 0
	.dw 0x2c40, 0xc039,	0x2c7f, 0xc039,		0x21, 0
	.dw 0x2cc0, 0xc039,	0x2cff, 0xc039,		0x21, 0
	.dw 0x2d40, 0xc039,	0x2d7f, 0xc039,		0x21, 0
	.dw 0x2dc0, 0xc039,	0x2dff, 0xc039,		0x21, 0
	.dw 0x2e40, 0xc039,	0x2e7f, 0xc039,		0x21, 0
	.dw 0x2ec0, 0xc039,	0x2eff, 0xc039,		0x21, 0
	.dw 0x2f40, 0xc039,	0x2f7f, 0xc039,		0x21, 0
	.dw 0x2fc0, 0xc039,	0x2fff, 0xc039,		0x21, 0
	.dw 0x3040, 0xc039,	0x307f, 0xc039,		0x21, 0
	.dw 0x30c0, 0xc039,	0x30ff, 0xc039,		0x21, 0
	.dw 0x3140, 0xc039,	0x317f, 0xc039,		0x21, 0
	.dw 0x31c0, 0xc039,	0x31ff, 0xc039,		0x21, 0
	.dw 0x3240, 0xc039,	0x327f, 0xc039,		0x21, 0
	.dw 0x32c0, 0xc039,	0x32ff, 0xc039,		0x21, 0
	.dw 0x3340, 0xc039,	0x337f, 0xc039,		0x21, 0
	.dw 0x33c0, 0xc039,	0x33ff, 0xc039,		0x21, 0
	.dw 0x3440, 0xc039,	0x347f, 0xc039,		0x21, 0
	.dw 0x34c0, 0xc039,	0x34ff, 0xc039,		0x21, 0
	.dw 0x3540, 0xc039,	0x357f, 0xc039,		0x21, 0
	.dw 0x35c0, 0xc039,	0x35ff, 0xc039,		0x21, 0
	.dw 0x3640, 0xc039,	0x367f, 0xc039,		0x21, 0
	.dw 0x36c0, 0xc039,	0x36ff, 0xc039,		0x21, 0
	.dw 0x3740, 0xc039,	0x377f, 0xc039,		0x21, 0
	.dw 0x37c0, 0xc039,	0x37ff, 0xc039,		0x21, 0
	.dw 0x3840, 0xc039,	0x387f, 0xc039,		0x21, 0
	.dw 0x38c0, 0xc039,	0x38ff, 0xc039,		0x21, 0
	.dw 0x3940, 0xc039,	0x397f, 0xc039,		0x21, 0
	.dw 0x39c0, 0xc039,	0x5fff, 0xc039,		0x21, 0
	.dw 0x6040, 0xc039,	0x607f, 0xc039,		0x21, 0
	.dw 0x60c0, 0xc039,	0x60ff, 0xc039,		0x21, 0
	.dw 0x6140, 0xc039,	0x617f, 0xc039,		0x21, 0
	.dw 0x61c0, 0xc039,	0x61ff, 0xc039,		0x21, 0
	.dw 0x6240, 0xc039,	0x627f, 0xc039,		0x21, 0
	.dw 0x62c0, 0xc039,	0x62ff, 0xc039,		0x21, 0
	.dw 0x6340, 0xc039,	0x637f, 0xc039,		0x21, 0
	.dw 0x63c0, 0xc039,	0x63ff, 0xc039,		0x21, 0
	.dw 0x6440, 0xc039,	0x647f, 0xc039,		0x21, 0
	.dw 0x64c0, 0xc039,	0x64ff, 0xc039,		0x21, 0
	.dw 0x6540, 0xc039,	0x657f, 0xc039,		0x21, 0
	.dw 0x65c0, 0xc039,	0x65ff, 0xc039,		0x21, 0
	.dw 0x6640, 0xc039,	0x667f, 0xc039,		0x21, 0
	.dw 0x66c0, 0xc039,	0x66ff, 0xc039,		0x21, 0
	.dw 0x6740, 0xc039,	0x677f, 0xc039,		0x21, 0
	.dw 0x67c0, 0xc039,	0x67ff, 0xc039,		0x21, 0
	.dw 0x6840, 0xc039,	0x687f, 0xc039,		0x21, 0
	.dw 0x68c0, 0xc039,	0x68ff, 0xc039,		0x21, 0
	.dw 0x6940, 0xc039,	0x697f, 0xc039,		0x21, 0
	.dw 0x69c0, 0xc039,	0x69ff, 0xc039,		0x21, 0
	.dw 0x6a40, 0xc039,	0x6a7f, 0xc039,		0x21, 0
	.dw 0x6ac0, 0xc039,	0x6aff, 0xc039,		0x21, 0
	.dw 0x6b40, 0xc039,	0x6b7f, 0xc039,		0x21, 0
	.dw 0x6bc0, 0xc039,	0x6bff, 0xc039,		0x21, 0
	.dw 0x6c40, 0xc039,	0x6c7f, 0xc039,		0x21, 0
	.dw 0x6cc0, 0xc039,	0x6cff, 0xc039,		0x21, 0
	.dw 0x6d40, 0xc039,	0x6d7f, 0xc039,		0x21, 0
	.dw 0x6dc0, 0xc039,	0x6dff, 0xc039,		0x21, 0
	.dw 0x6e40, 0xc039,	0x6e7f, 0xc039,		0x21, 0
	.dw 0x6ec0, 0xc039,	0x6eff, 0xc039,		0x21, 0
	.dw 0x6f40, 0xc039,	0x6f7f, 0xc039,		0x21, 0
	.dw 0x6fc0, 0xc039,	0x6fff, 0xc039,		0x21, 0
	.dw 0x7040, 0xc039,	0x707f, 0xc039,		0x21, 0
	.dw 0x70c0, 0xc039,	0x70ff, 0xc039,		0x21, 0
	.dw 0x7140, 0xc039,	0x717f, 0xc039,		0x21, 0
	.dw 0x71c0, 0xc039,	0x71ff, 0xc039,		0x21, 0
	.dw 0x7240, 0xc039,	0x727f, 0xc039,		0x21, 0
	.dw 0x72c0, 0xc039,	0x72ff, 0xc039,		0x21, 0
	.dw 0x7340, 0xc039,	0x737f, 0xc039,		0x21, 0
	.dw 0x73c0, 0xc039,	0x73ff, 0xc039,		0x21, 0
	.dw 0x7440, 0xc039,	0x747f, 0xc039,		0x21, 0
	.dw 0x74c0, 0xc039,	0x74ff, 0xc039,		0x21, 0
	.dw 0x7540, 0xc039,	0x757f, 0xc039,		0x21, 0
	.dw 0x75c0, 0xc039,	0x75ff, 0xc039,		0x21, 0
	.dw 0x7640, 0xc039,	0x767f, 0xc039,		0x21, 0
	.dw 0x76c0, 0xc039,	0x76ff, 0xc039,		0x21, 0
	.dw 0x7740, 0xc039,	0x777f, 0xc039,		0x21, 0
	.dw 0x77c0, 0xc039,	0x77ff, 0xc039,		0x21, 0
	.dw 0x7840, 0xc039,	0x787f, 0xc039,		0x21, 0
	.dw 0x78c0, 0xc039,	0x78ff, 0xc039,		0x21, 0
	.dw 0x7940, 0xc039,	0x797f, 0xc039,		0x21, 0
	.dw 0x79c0, 0xc039,	0x9fff, 0xc039,		0x21, 0
	.dw 0xa040, 0xc039,	0xa07f, 0xc039,		0x21, 0
	.dw 0xa0c0, 0xc039,	0xa0ff, 0xc039,		0x21, 0
	.dw 0xa140, 0xc039,	0xa17f, 0xc039,		0x21, 0
	.dw 0xa1c0, 0xc039,	0xa1ff, 0xc039,		0x21, 0
	.dw 0xa240, 0xc039,	0xa27f, 0xc039,		0x21, 0
	.dw 0xa2c0, 0xc039,	0xa2ff, 0xc039,		0x21, 0
	.dw 0xa340, 0xc039,	0xa37f, 0xc039,		0x21, 0
	.dw 0xa3c0, 0xc039,	0xa3ff, 0xc039,		0x21, 0
	.dw 0xa440, 0xc039,	0xa47f, 0xc039,		0x21, 0
	.dw 0xa4c0, 0xc039,	0xa4ff, 0xc039,		0x21, 0
	.dw 0xa540, 0xc039,	0xa57f, 0xc039,		0x21, 0
	.dw 0xa5c0, 0xc039,	0xa5ff, 0xc039,		0x21, 0
	.dw 0xa640, 0xc039,	0xa67f, 0xc039,		0x21, 0
	.dw 0xa6c0, 0xc039,	0xa6ff, 0xc039,		0x21, 0
	.dw 0xa740, 0xc039,	0xa77f, 0xc039,		0x21, 0
	.dw 0xa7c0, 0xc039,	0xa7ff, 0xc039,		0x21, 0
	.dw 0xa840, 0xc039,	0xa87f, 0xc039,		0x21, 0
	.dw 0xa8c0, 0xc039,	0xa8ff, 0xc039,		0x21, 0
	.dw 0xa940, 0xc039,	0xa97f, 0xc039,		0x21, 0
	.dw 0xa9c0, 0xc039,	0xa9ff, 0xc039,		0x21, 0
	.dw 0xaa40, 0xc039,	0xaa7f, 0xc039,		0x21, 0
	.dw 0xaac0, 0xc039,	0xaaff, 0xc039,		0x21, 0
	.dw 0xab40, 0xc039,	0xab7f, 0xc039,		0x21, 0
	.dw 0xabc0, 0xc039,	0xabff, 0xc039,		0x21, 0
	.dw 0xac40, 0xc039,	0xac7f, 0xc039,		0x21, 0
	.dw 0xacc0, 0xc039,	0xacff, 0xc039,		0x21, 0
	.dw 0xad40, 0xc039,	0xad7f, 0xc039,		0x21, 0
	.dw 0xadc0, 0xc039,	0xadff, 0xc039,		0x21, 0
	.dw 0xae40, 0xc039,	0xae7f, 0xc039,		0x21, 0
	.dw 0xaec0, 0xc039,	0xaeff, 0xc039,		0x21, 0
	.dw 0xaf40, 0xc039,	0xaf7f, 0xc039,		0x21, 0
	.dw 0xafc0, 0xc039,	0xafff, 0xc039,		0x21, 0
	.dw 0xb040, 0xc039,	0xb07f, 0xc039,		0x21, 0
	.dw 0xb0c0, 0xc039,	0xb0ff, 0xc039,		0x21, 0
	.dw 0xb140, 0xc039,	0xb17f, 0xc039,		0x21, 0
	.dw 0xb1c0, 0xc039,	0xb1ff, 0xc039,		0x21, 0
	.dw 0xb240, 0xc039,	0xb27f, 0xc039,		0x21, 0
	.dw 0xb2c0, 0xc039,	0xb2ff, 0xc039,		0x21, 0
	.dw 0xb340, 0xc039,	0xb37f, 0xc039,		0x21, 0
	.dw 0xb3c0, 0xc039,	0xb3ff, 0xc039,		0x21, 0
	.dw 0xb440, 0xc039,	0xb47f, 0xc039,		0x21, 0
	.dw 0xb4c0, 0xc039,	0xb4ff, 0xc039,		0x21, 0
	.dw 0xb540, 0xc039,	0xb57f, 0xc039,		0x21, 0
	.dw 0xb5c0, 0xc039,	0xb5ff, 0xc039,		0x21, 0
	.dw 0xb640, 0xc039,	0xb67f, 0xc039,		0x21, 0
	.dw 0xb6c0, 0xc039,	0xb6ff, 0xc039,		0x21, 0
	.dw 0xb740, 0xc039,	0xb77f, 0xc039,		0x21, 0
	.dw 0xb7c0, 0xc039,	0xb7ff, 0xc039,		0x21, 0
	.dw 0xb840, 0xc039,	0xb87f, 0xc039,		0x21, 0
	.dw 0xb8c0, 0xc039,	0xb8ff, 0xc039,		0x21, 0
	.dw 0xb940, 0xc039,	0xb97f, 0xc039,		0x21, 0
	.dw 0xb9c0, 0xc039,	0xdfff, 0xc039,		0x21, 0
	.dw 0xe040, 0xc039,	0xe07f, 0xc039,		0x21, 0
	.dw 0xe0c0, 0xc039,	0xe0ff, 0xc039,		0x21, 0
	.dw 0xe140, 0xc039,	0xe17f, 0xc039,		0x21, 0
	.dw 0xe1c0, 0xc039,	0xe1ff, 0xc039,		0x21, 0
	.dw 0xe240, 0xc039,	0xe27f, 0xc039,		0x21, 0
	.dw 0xe2c0, 0xc039,	0xe2ff, 0xc039,		0x21, 0
	.dw 0xe340, 0xc039,	0xe37f, 0xc039,		0x21, 0
	.dw 0xe3c0, 0xc039,	0xe3ff, 0xc039,		0x21, 0
	.dw 0xe440, 0xc039,	0xe47f, 0xc039,		0x21, 0
	.dw 0xe4c0, 0xc039,	0xe4ff, 0xc039,		0x21, 0
	.dw 0xe540, 0xc039,	0xe57f, 0xc039,		0x21, 0
	.dw 0xe5c0, 0xc039,	0xe5ff, 0xc039,		0x21, 0
	.dw 0xe640, 0xc039,	0xe67f, 0xc039,		0x21, 0
	.dw 0xe6c0, 0xc039,	0xe6ff, 0xc039,		0x21, 0
	.dw 0xe740, 0xc039,	0xe77f, 0xc039,		0x21, 0
	.dw 0xe7c0, 0xc039,	0xe7ff, 0xc039,		0x21, 0
	.dw 0xe840, 0xc039,	0xe87f, 0xc039,		0x21, 0
	.dw 0xe8c0, 0xc039,	0xe8ff, 0xc039,		0x21, 0
	.dw 0xe940, 0xc039,	0xe97f, 0xc039,		0x21, 0
	.dw 0xe9c0, 0xc039,	0xe9ff, 0xc039,		0x21, 0
	.dw 0xea40, 0xc039,	0xea7f, 0xc039,		0x21, 0
	.dw 0xeac0, 0xc039,	0xeaff, 0xc039,		0x21, 0
	.dw 0xeb40, 0xc039,	0xeb7f, 0xc039,		0x21, 0
	.dw 0xebc0, 0xc039,	0xebff, 0xc039,		0x21, 0
	.dw 0xec40, 0xc039,	0xec7f, 0xc039,		0x21, 0
	.dw 0xecc0, 0xc039,	0xecff, 0xc039,		0x21, 0
	.dw 0xed40, 0xc039,	0xed7f, 0xc039,		0x21, 0
	.dw 0xedc0, 0xc039,	0xedff, 0xc039,		0x21, 0
	.dw 0xee40, 0xc039,	0xee7f, 0xc039,		0x21, 0
	.dw 0xeec0, 0xc039,	0xeeff, 0xc039,		0x21, 0
	.dw 0xef40, 0xc039,	0xef7f, 0xc039,		0x21, 0
	.dw 0xefc0, 0xc039,	0xefff, 0xc039,		0x21, 0
	.dw 0xf040, 0xc039,	0xf07f, 0xc039,		0x21, 0
	.dw 0xf0c0, 0xc039,	0xf0ff, 0xc039,		0x21, 0
	.dw 0xf140, 0xc039,	0xf17f, 0xc039,		0x21, 0
	.dw 0xf1c0, 0xc039,	0xf1ff, 0xc039,		0x21, 0
	.dw 0xf240, 0xc039,	0xf27f, 0xc039,		0x21, 0
	.dw 0xf2c0, 0xc039,	0xf2ff, 0xc039,		0x21, 0
	.dw 0xf340, 0xc039,	0xf37f, 0xc039,		0x21, 0
	.dw 0xf3c0, 0xc039,	0xf3ff, 0xc039,		0x21, 0
	.dw 0xf440, 0xc039,	0xf47f, 0xc039,		0x21, 0
	.dw 0xf4c0, 0xc039,	0xf4ff, 0xc039,		0x21, 0
	.dw 0xf540, 0xc039,	0xf57f, 0xc039,		0x21, 0
	.dw 0xf5c0, 0xc039,	0xf5ff, 0xc039,		0x21, 0
	.dw 0xf640, 0xc039,	0xf67f, 0xc039,		0x21, 0
	.dw 0xf6c0, 0xc039,	0xf6ff, 0xc039,		0x21, 0
	.dw 0xf740, 0xc039,	0xf77f, 0xc039,		0x21, 0
	.dw 0xf7c0, 0xc039,	0xf7ff, 0xc039,		0x21, 0
	.dw 0xf840, 0xc039,	0xf87f, 0xc039,		0x21, 0
	.dw 0xf8c0, 0xc039,	0xf8ff, 0xc039,		0x21, 0
	.dw 0xf940, 0xc039,	0xf97f, 0xc039,		0x21, 0
	.dw 0xf9c0, 0xc039,	0x1fff, 0xc03a,		0x21, 0
	.dw 0x2040, 0xc03a,	0x207f, 0xc03a,		0x21, 0
	.dw 0x20c0, 0xc03a,	0x20ff, 0xc03a,		0x21, 0
	.dw 0x2140, 0xc03a,	0x217f, 0xc03a,		0x21, 0
	.dw 0x21c0, 0xc03a,	0x21ff, 0xc03a,		0x21, 0
	.dw 0x2240, 0xc03a,	0x227f, 0xc03a,		0x21, 0
	.dw 0x22c0, 0xc03a,	0x22ff, 0xc03a,		0x21, 0
	.dw 0x2340, 0xc03a,	0x237f, 0xc03a,		0x21, 0
	.dw 0x23c0, 0xc03a,	0x23ff, 0xc03a,		0x21, 0
	.dw 0x2440, 0xc03a,	0x247f, 0xc03a,		0x21, 0
	.dw 0x24c0, 0xc03a,	0x24ff, 0xc03a,		0x21, 0
	.dw 0x2540, 0xc03a,	0x257f, 0xc03a,		0x21, 0
	.dw 0x25c0, 0xc03a,	0x25ff, 0xc03a,		0x21, 0
	.dw 0x2640, 0xc03a,	0x267f, 0xc03a,		0x21, 0
	.dw 0x26c0, 0xc03a,	0x26ff, 0xc03a,		0x21, 0
	.dw 0x2740, 0xc03a,	0x277f, 0xc03a,		0x21, 0
	.dw 0x27c0, 0xc03a,	0x27ff, 0xc03a,		0x21, 0
	.dw 0x2840, 0xc03a,	0x287f, 0xc03a,		0x21, 0
	.dw 0x28c0, 0xc03a,	0x28ff, 0xc03a,		0x21, 0
	.dw 0x2940, 0xc03a,	0x297f, 0xc03a,		0x21, 0
	.dw 0x29c0, 0xc03a,	0x29ff, 0xc03a,		0x21, 0
	.dw 0x2a40, 0xc03a,	0x2a7f, 0xc03a,		0x21, 0
	.dw 0x2ac0, 0xc03a,	0x2aff, 0xc03a,		0x21, 0
	.dw 0x2b40, 0xc03a,	0x2b7f, 0xc03a,		0x21, 0
	.dw 0x2bc0, 0xc03a,	0x2bff, 0xc03a,		0x21, 0
	.dw 0x2c40, 0xc03a,	0x2c7f, 0xc03a,		0x21, 0
	.dw 0x2cc0, 0xc03a,	0x2cff, 0xc03a,		0x21, 0
	.dw 0x2d40, 0xc03a,	0x2d7f, 0xc03a,		0x21, 0
	.dw 0x2dc0, 0xc03a,	0x2dff, 0xc03a,		0x21, 0
	.dw 0x2e40, 0xc03a,	0x2e7f, 0xc03a,		0x21, 0
	.dw 0x2ec0, 0xc03a,	0x2eff, 0xc03a,		0x21, 0
	.dw 0x2f40, 0xc03a,	0x2f7f, 0xc03a,		0x21, 0
	.dw 0x2fc0, 0xc03a,	0x2fff, 0xc03a,		0x21, 0
	.dw 0x3040, 0xc03a,	0x307f, 0xc03a,		0x21, 0
	.dw 0x30c0, 0xc03a,	0x30ff, 0xc03a,		0x21, 0
	.dw 0x3140, 0xc03a,	0x317f, 0xc03a,		0x21, 0
	.dw 0x31c0, 0xc03a,	0x31ff, 0xc03a,		0x21, 0
	.dw 0x3240, 0xc03a,	0x327f, 0xc03a,		0x21, 0
	.dw 0x32c0, 0xc03a,	0x32ff, 0xc03a,		0x21, 0
	.dw 0x3340, 0xc03a,	0x337f, 0xc03a,		0x21, 0
	.dw 0x33c0, 0xc03a,	0x33ff, 0xc03a,		0x21, 0
	.dw 0x3440, 0xc03a,	0x347f, 0xc03a,		0x21, 0
	.dw 0x34c0, 0xc03a,	0x34ff, 0xc03a,		0x21, 0
	.dw 0x3540, 0xc03a,	0x357f, 0xc03a,		0x21, 0
	.dw 0x35c0, 0xc03a,	0x35ff, 0xc03a,		0x21, 0
	.dw 0x3640, 0xc03a,	0x367f, 0xc03a,		0x21, 0
	.dw 0x36c0, 0xc03a,	0x36ff, 0xc03a,		0x21, 0
	.dw 0x3740, 0xc03a,	0x377f, 0xc03a,		0x21, 0
	.dw 0x37c0, 0xc03a,	0x37ff, 0xc03a,		0x21, 0
	.dw 0x3840, 0xc03a,	0x387f, 0xc03a,		0x21, 0
	.dw 0x38c0, 0xc03a,	0x38ff, 0xc03a,		0x21, 0
	.dw 0x3940, 0xc03a,	0x397f, 0xc03a,		0x21, 0
	.dw 0x39c0, 0xc03a,	0x5fff, 0xc03a,		0x21, 0
	.dw 0x6040, 0xc03a,	0x607f, 0xc03a,		0x21, 0
	.dw 0x60c0, 0xc03a,	0x60ff, 0xc03a,		0x21, 0
	.dw 0x6140, 0xc03a,	0x617f, 0xc03a,		0x21, 0
	.dw 0x61c0, 0xc03a,	0x61ff, 0xc03a,		0x21, 0
	.dw 0x6240, 0xc03a,	0x627f, 0xc03a,		0x21, 0
	.dw 0x62c0, 0xc03a,	0x62ff, 0xc03a,		0x21, 0
	.dw 0x6340, 0xc03a,	0x637f, 0xc03a,		0x21, 0
	.dw 0x63c0, 0xc03a,	0x63ff, 0xc03a,		0x21, 0
	.dw 0x6440, 0xc03a,	0x647f, 0xc03a,		0x21, 0
	.dw 0x64c0, 0xc03a,	0x64ff, 0xc03a,		0x21, 0
	.dw 0x6540, 0xc03a,	0x657f, 0xc03a,		0x21, 0
	.dw 0x65c0, 0xc03a,	0x65ff, 0xc03a,		0x21, 0
	.dw 0x6640, 0xc03a,	0x667f, 0xc03a,		0x21, 0
	.dw 0x66c0, 0xc03a,	0x66ff, 0xc03a,		0x21, 0
	.dw 0x6740, 0xc03a,	0x677f, 0xc03a,		0x21, 0
	.dw 0x67c0, 0xc03a,	0x67ff, 0xc03a,		0x21, 0
	.dw 0x6840, 0xc03a,	0x687f, 0xc03a,		0x21, 0
	.dw 0x68c0, 0xc03a,	0x68ff, 0xc03a,		0x21, 0
	.dw 0x6940, 0xc03a,	0x697f, 0xc03a,		0x21, 0
	.dw 0x69c0, 0xc03a,	0x69ff, 0xc03a,		0x21, 0
	.dw 0x6a40, 0xc03a,	0x6a7f, 0xc03a,		0x21, 0
	.dw 0x6ac0, 0xc03a,	0x6aff, 0xc03a,		0x21, 0
	.dw 0x6b40, 0xc03a,	0x6b7f, 0xc03a,		0x21, 0
	.dw 0x6bc0, 0xc03a,	0x6bff, 0xc03a,		0x21, 0
	.dw 0x6c40, 0xc03a,	0x6c7f, 0xc03a,		0x21, 0
	.dw 0x6cc0, 0xc03a,	0x6cff, 0xc03a,		0x21, 0
	.dw 0x6d40, 0xc03a,	0x6d7f, 0xc03a,		0x21, 0
	.dw 0x6dc0, 0xc03a,	0x6dff, 0xc03a,		0x21, 0
	.dw 0x6e40, 0xc03a,	0x6e7f, 0xc03a,		0x21, 0
	.dw 0x6ec0, 0xc03a,	0x6eff, 0xc03a,		0x21, 0
	.dw 0x6f40, 0xc03a,	0x6f7f, 0xc03a,		0x21, 0
	.dw 0x6fc0, 0xc03a,	0x6fff, 0xc03a,		0x21, 0
	.dw 0x7040, 0xc03a,	0x707f, 0xc03a,		0x21, 0
	.dw 0x70c0, 0xc03a,	0x70ff, 0xc03a,		0x21, 0
	.dw 0x7140, 0xc03a,	0x717f, 0xc03a,		0x21, 0
	.dw 0x71c0, 0xc03a,	0x71ff, 0xc03a,		0x21, 0
	.dw 0x7240, 0xc03a,	0x727f, 0xc03a,		0x21, 0
	.dw 0x72c0, 0xc03a,	0x72ff, 0xc03a,		0x21, 0
	.dw 0x7340, 0xc03a,	0x737f, 0xc03a,		0x21, 0
	.dw 0x73c0, 0xc03a,	0x73ff, 0xc03a,		0x21, 0
	.dw 0x7440, 0xc03a,	0x747f, 0xc03a,		0x21, 0
	.dw 0x74c0, 0xc03a,	0x74ff, 0xc03a,		0x21, 0
	.dw 0x7540, 0xc03a,	0x757f, 0xc03a,		0x21, 0
	.dw 0x75c0, 0xc03a,	0x75ff, 0xc03a,		0x21, 0
	.dw 0x7640, 0xc03a,	0x767f, 0xc03a,		0x21, 0
	.dw 0x76c0, 0xc03a,	0x76ff, 0xc03a,		0x21, 0
	.dw 0x7740, 0xc03a,	0x777f, 0xc03a,		0x21, 0
	.dw 0x77c0, 0xc03a,	0x77ff, 0xc03a,		0x21, 0
	.dw 0x7840, 0xc03a,	0x787f, 0xc03a,		0x21, 0
	.dw 0x78c0, 0xc03a,	0x78ff, 0xc03a,		0x21, 0
	.dw 0x7940, 0xc03a,	0x797f, 0xc03a,		0x21, 0
	.dw 0x79c0, 0xc03a,	0x9fff, 0xc03a,		0x21, 0
	.dw 0xa040, 0xc03a,	0xa07f, 0xc03a,		0x21, 0
	.dw 0xa0c0, 0xc03a,	0xa0ff, 0xc03a,		0x21, 0
	.dw 0xa140, 0xc03a,	0xa17f, 0xc03a,		0x21, 0
	.dw 0xa1c0, 0xc03a,	0xa1ff, 0xc03a,		0x21, 0
	.dw 0xa240, 0xc03a,	0xa27f, 0xc03a,		0x21, 0
	.dw 0xa2c0, 0xc03a,	0xa2ff, 0xc03a,		0x21, 0
	.dw 0xa340, 0xc03a,	0xa37f, 0xc03a,		0x21, 0
	.dw 0xa3c0, 0xc03a,	0xa3ff, 0xc03a,		0x21, 0
	.dw 0xa440, 0xc03a,	0xa47f, 0xc03a,		0x21, 0
	.dw 0xa4c0, 0xc03a,	0xa4ff, 0xc03a,		0x21, 0
	.dw 0xa540, 0xc03a,	0xa57f, 0xc03a,		0x21, 0
	.dw 0xa5c0, 0xc03a,	0xa5ff, 0xc03a,		0x21, 0
	.dw 0xa640, 0xc03a,	0xa67f, 0xc03a,		0x21, 0
	.dw 0xa6c0, 0xc03a,	0xa6ff, 0xc03a,		0x21, 0
	.dw 0xa740, 0xc03a,	0xa77f, 0xc03a,		0x21, 0
	.dw 0xa7c0, 0xc03a,	0xa7ff, 0xc03a,		0x21, 0
	.dw 0xa840, 0xc03a,	0xa87f, 0xc03a,		0x21, 0
	.dw 0xa8c0, 0xc03a,	0xa8ff, 0xc03a,		0x21, 0
	.dw 0xa940, 0xc03a,	0xa97f, 0xc03a,		0x21, 0
	.dw 0xa9c0, 0xc03a,	0xa9ff, 0xc03a,		0x21, 0
	.dw 0xaa40, 0xc03a,	0xaa7f, 0xc03a,		0x21, 0
	.dw 0xaac0, 0xc03a,	0xaaff, 0xc03a,		0x21, 0
	.dw 0xab40, 0xc03a,	0xab7f, 0xc03a,		0x21, 0
	.dw 0xabc0, 0xc03a,	0xabff, 0xc03a,		0x21, 0
	.dw 0xac40, 0xc03a,	0xac7f, 0xc03a,		0x21, 0
	.dw 0xacc0, 0xc03a,	0xacff, 0xc03a,		0x21, 0
	.dw 0xad40, 0xc03a,	0xad7f, 0xc03a,		0x21, 0
	.dw 0xadc0, 0xc03a,	0xadff, 0xc03a,		0x21, 0
	.dw 0xae40, 0xc03a,	0xae7f, 0xc03a,		0x21, 0
	.dw 0xaec0, 0xc03a,	0xaeff, 0xc03a,		0x21, 0
	.dw 0xaf40, 0xc03a,	0xaf7f, 0xc03a,		0x21, 0
	.dw 0xafc0, 0xc03a,	0xafff, 0xc03a,		0x21, 0
	.dw 0xb040, 0xc03a,	0xb07f, 0xc03a,		0x21, 0
	.dw 0xb0c0, 0xc03a,	0xb0ff, 0xc03a,		0x21, 0
	.dw 0xb140, 0xc03a,	0xb17f, 0xc03a,		0x21, 0
	.dw 0xb1c0, 0xc03a,	0xb1ff, 0xc03a,		0x21, 0
	.dw 0xb240, 0xc03a,	0xb27f, 0xc03a,		0x21, 0
	.dw 0xb2c0, 0xc03a,	0xb2ff, 0xc03a,		0x21, 0
	.dw 0xb340, 0xc03a,	0xb37f, 0xc03a,		0x21, 0
	.dw 0xb3c0, 0xc03a,	0xb3ff, 0xc03a,		0x21, 0
	.dw 0xb440, 0xc03a,	0xb47f, 0xc03a,		0x21, 0
	.dw 0xb4c0, 0xc03a,	0xb4ff, 0xc03a,		0x21, 0
	.dw 0xb540, 0xc03a,	0xb57f, 0xc03a,		0x21, 0
	.dw 0xb5c0, 0xc03a,	0xb5ff, 0xc03a,		0x21, 0
	.dw 0xb640, 0xc03a,	0xb67f, 0xc03a,		0x21, 0
	.dw 0xb6c0, 0xc03a,	0xb6ff, 0xc03a,		0x21, 0
	.dw 0xb740, 0xc03a,	0xb77f, 0xc03a,		0x21, 0
	.dw 0xb7c0, 0xc03a,	0xb7ff, 0xc03a,		0x21, 0
	.dw 0xb840, 0xc03a,	0xb87f, 0xc03a,		0x21, 0
	.dw 0xb8c0, 0xc03a,	0xb8ff, 0xc03a,		0x21, 0
	.dw 0xb940, 0xc03a,	0xb97f, 0xc03a,		0x21, 0
	.dw 0xb9c0, 0xc03a,	0xdfff, 0xc03a,		0x21, 0
	.dw 0xe040, 0xc03a,	0xe07f, 0xc03a,		0x21, 0
	.dw 0xe0c0, 0xc03a,	0xe0ff, 0xc03a,		0x21, 0
	.dw 0xe140, 0xc03a,	0xe17f, 0xc03a,		0x21, 0
	.dw 0xe1c0, 0xc03a,	0xe1ff, 0xc03a,		0x21, 0
	.dw 0xe240, 0xc03a,	0xe27f, 0xc03a,		0x21, 0
	.dw 0xe2c0, 0xc03a,	0xe2ff, 0xc03a,		0x21, 0
	.dw 0xe340, 0xc03a,	0xe37f, 0xc03a,		0x21, 0
	.dw 0xe3c0, 0xc03a,	0xe3ff, 0xc03a,		0x21, 0
	.dw 0xe440, 0xc03a,	0xe47f, 0xc03a,		0x21, 0
	.dw 0xe4c0, 0xc03a,	0xe4ff, 0xc03a,		0x21, 0
	.dw 0xe540, 0xc03a,	0xe57f, 0xc03a,		0x21, 0
	.dw 0xe5c0, 0xc03a,	0xe5ff, 0xc03a,		0x21, 0
	.dw 0xe640, 0xc03a,	0xe67f, 0xc03a,		0x21, 0
	.dw 0xe6c0, 0xc03a,	0xe6ff, 0xc03a,		0x21, 0
	.dw 0xe740, 0xc03a,	0xe77f, 0xc03a,		0x21, 0
	.dw 0xe7c0, 0xc03a,	0xe7ff, 0xc03a,		0x21, 0
	.dw 0xe840, 0xc03a,	0xe87f, 0xc03a,		0x21, 0
	.dw 0xe8c0, 0xc03a,	0xe8ff, 0xc03a,		0x21, 0
	.dw 0xe940, 0xc03a,	0xe97f, 0xc03a,		0x21, 0
	.dw 0xe9c0, 0xc03a,	0xe9ff, 0xc03a,		0x21, 0
	.dw 0xea40, 0xc03a,	0xea7f, 0xc03a,		0x21, 0
	.dw 0xeac0, 0xc03a,	0xeaff, 0xc03a,		0x21, 0
	.dw 0xeb40, 0xc03a,	0xeb7f, 0xc03a,		0x21, 0
	.dw 0xebc0, 0xc03a,	0xebff, 0xc03a,		0x21, 0
	.dw 0xec40, 0xc03a,	0xec7f, 0xc03a,		0x21, 0
	.dw 0xecc0, 0xc03a,	0xecff, 0xc03a,		0x21, 0
	.dw 0xed40, 0xc03a,	0xed7f, 0xc03a,		0x21, 0
	.dw 0xedc0, 0xc03a,	0xedff, 0xc03a,		0x21, 0
	.dw 0xee40, 0xc03a,	0xee7f, 0xc03a,		0x21, 0
	.dw 0xeec0, 0xc03a,	0xeeff, 0xc03a,		0x21, 0
	.dw 0xef40, 0xc03a,	0xef7f, 0xc03a,		0x21, 0
	.dw 0xefc0, 0xc03a,	0xefff, 0xc03a,		0x21, 0
	.dw 0xf040, 0xc03a,	0xf07f, 0xc03a,		0x21, 0
	.dw 0xf0c0, 0xc03a,	0xf0ff, 0xc03a,		0x21, 0
	.dw 0xf140, 0xc03a,	0xf17f, 0xc03a,		0x21, 0
	.dw 0xf1c0, 0xc03a,	0xf1ff, 0xc03a,		0x21, 0
	.dw 0xf240, 0xc03a,	0xf27f, 0xc03a,		0x21, 0
	.dw 0xf2c0, 0xc03a,	0xf2ff, 0xc03a,		0x21, 0
	.dw 0xf340, 0xc03a,	0xf37f, 0xc03a,		0x21, 0
	.dw 0xf3c0, 0xc03a,	0xf3ff, 0xc03a,		0x21, 0
	.dw 0xf440, 0xc03a,	0xf47f, 0xc03a,		0x21, 0
	.dw 0xf4c0, 0xc03a,	0xf4ff, 0xc03a,		0x21, 0
	.dw 0xf540, 0xc03a,	0xf57f, 0xc03a,		0x21, 0
	.dw 0xf5c0, 0xc03a,	0xf5ff, 0xc03a,		0x21, 0
	.dw 0xf640, 0xc03a,	0xf67f, 0xc03a,		0x21, 0
	.dw 0xf6c0, 0xc03a,	0xf6ff, 0xc03a,		0x21, 0
	.dw 0xf740, 0xc03a,	0xf77f, 0xc03a,		0x21, 0
	.dw 0xf7c0, 0xc03a,	0xf7ff, 0xc03a,		0x21, 0
	.dw 0xf840, 0xc03a,	0xf87f, 0xc03a,		0x21, 0
	.dw 0xf8c0, 0xc03a,	0xf8ff, 0xc03a,		0x21, 0
	.dw 0xf940, 0xc03a,	0xf97f, 0xc03a,		0x21, 0
	.dw 0xf9c0, 0xc03a,	0xffff, 0xc03b,		0x21, 0
	.dw 0x0040, 0xc03c,	0x007f, 0xc03c,		0x21, 0
	.dw 0x00c0, 0xc03c,	0x00ff, 0xc03c,		0x21, 0
	.dw 0x0140, 0xc03c,	0x017f, 0xc03c,		0x21, 0
	.dw 0x01c0, 0xc03c,	0x01ff, 0xc03c,		0x21, 0
	.dw 0x0240, 0xc03c,	0x027f, 0xc03c,		0x21, 0
	.dw 0x02c0, 0xc03c,	0x02ff, 0xc03c,		0x21, 0
	.dw 0x0340, 0xc03c,	0x037f, 0xc03c,		0x21, 0
	.dw 0x03c0, 0xc03c,	0x03ff, 0xc03c,		0x21, 0
	.dw 0x0440, 0xc03c,	0x047f, 0xc03c,		0x21, 0
	.dw 0x04c0, 0xc03c,	0x04ff, 0xc03c,		0x21, 0
	.dw 0x0540, 0xc03c,	0x057f, 0xc03c,		0x21, 0
	.dw 0x05c0, 0xc03c,	0x05ff, 0xc03c,		0x21, 0
	.dw 0x0640, 0xc03c,	0x067f, 0xc03c,		0x21, 0
	.dw 0x06c0, 0xc03c,	0x06ff, 0xc03c,		0x21, 0
	.dw 0x0740, 0xc03c,	0x077f, 0xc03c,		0x21, 0
	.dw 0x07c0, 0xc03c,	0x07ff, 0xc03c,		0x21, 0
	.dw 0x0840, 0xc03c,	0x087f, 0xc03c,		0x21, 0
	.dw 0x08c0, 0xc03c,	0x08ff, 0xc03c,		0x21, 0
	.dw 0x0940, 0xc03c,	0x097f, 0xc03c,		0x21, 0
	.dw 0x09c0, 0xc03c,	0x09ff, 0xc03c,		0x21, 0
	.dw 0x0a40, 0xc03c,	0x0a7f, 0xc03c,		0x21, 0
	.dw 0x0ac0, 0xc03c,	0x0aff, 0xc03c,		0x21, 0
	.dw 0x0b40, 0xc03c,	0x0b7f, 0xc03c,		0x21, 0
	.dw 0x0bc0, 0xc03c,	0x0bff, 0xc03c,		0x21, 0
	.dw 0x0c40, 0xc03c,	0x0c7f, 0xc03c,		0x21, 0
	.dw 0x0cc0, 0xc03c,	0x0cff, 0xc03c,		0x21, 0
	.dw 0x0d40, 0xc03c,	0x0d7f, 0xc03c,		0x21, 0
	.dw 0x0dc0, 0xc03c,	0x0dff, 0xc03c,		0x21, 0
	.dw 0x0e40, 0xc03c,	0x0e7f, 0xc03c,		0x21, 0
	.dw 0x0ec0, 0xc03c,	0x0eff, 0xc03c,		0x21, 0
	.dw 0x0f40, 0xc03c,	0x0f7f, 0xc03c,		0x21, 0
	.dw 0x0fc0, 0xc03c,	0x0fff, 0xc03c,		0x21, 0
	.dw 0x1040, 0xc03c,	0x107f, 0xc03c,		0x21, 0
	.dw 0x10c0, 0xc03c,	0x10ff, 0xc03c,		0x21, 0
	.dw 0x1140, 0xc03c,	0x117f, 0xc03c,		0x21, 0
	.dw 0x11c0, 0xc03c,	0x11ff, 0xc03c,		0x21, 0
	.dw 0x1240, 0xc03c,	0x127f, 0xc03c,		0x21, 0
	.dw 0x12c0, 0xc03c,	0x12ff, 0xc03c,		0x21, 0
	.dw 0x1340, 0xc03c,	0x137f, 0xc03c,		0x21, 0
	.dw 0x13c0, 0xc03c,	0x13ff, 0xc03c,		0x21, 0
	.dw 0x1440, 0xc03c,	0x147f, 0xc03c,		0x21, 0
	.dw 0x14c0, 0xc03c,	0x14ff, 0xc03c,		0x21, 0
	.dw 0x1540, 0xc03c,	0x157f, 0xc03c,		0x21, 0
	.dw 0x15c0, 0xc03c,	0x15ff, 0xc03c,		0x21, 0
	.dw 0x1640, 0xc03c,	0x167f, 0xc03c,		0x21, 0
	.dw 0x16c0, 0xc03c,	0x16ff, 0xc03c,		0x21, 0
	.dw 0x1740, 0xc03c,	0x177f, 0xc03c,		0x21, 0
	.dw 0x17c0, 0xc03c,	0x17ff, 0xc03c,		0x21, 0
	.dw 0x1840, 0xc03c,	0x187f, 0xc03c,		0x21, 0
	.dw 0x18c0, 0xc03c,	0x18ff, 0xc03c,		0x21, 0
	.dw 0x1940, 0xc03c,	0x197f, 0xc03c,		0x21, 0
	.dw 0x19c0, 0xc03c,	0x1fff, 0xc03c,		0x21, 0
	.dw 0x2040, 0xc03c,	0x207f, 0xc03c,		0x21, 0
	.dw 0x20c0, 0xc03c,	0x20ff, 0xc03c,		0x21, 0
	.dw 0x2140, 0xc03c,	0x217f, 0xc03c,		0x21, 0
	.dw 0x21c0, 0xc03c,	0x21ff, 0xc03c,		0x21, 0
	.dw 0x2240, 0xc03c,	0x227f, 0xc03c,		0x21, 0
	.dw 0x22c0, 0xc03c,	0x22ff, 0xc03c,		0x21, 0
	.dw 0x2340, 0xc03c,	0x237f, 0xc03c,		0x21, 0
	.dw 0x23c0, 0xc03c,	0x23ff, 0xc03c,		0x21, 0
	.dw 0x2440, 0xc03c,	0x247f, 0xc03c,		0x21, 0
	.dw 0x24c0, 0xc03c,	0x24ff, 0xc03c,		0x21, 0
	.dw 0x2540, 0xc03c,	0x257f, 0xc03c,		0x21, 0
	.dw 0x25c0, 0xc03c,	0x25ff, 0xc03c,		0x21, 0
	.dw 0x2640, 0xc03c,	0x267f, 0xc03c,		0x21, 0
	.dw 0x26c0, 0xc03c,	0x26ff, 0xc03c,		0x21, 0
	.dw 0x2740, 0xc03c,	0x277f, 0xc03c,		0x21, 0
	.dw 0x27c0, 0xc03c,	0x27ff, 0xc03c,		0x21, 0
	.dw 0x2840, 0xc03c,	0x287f, 0xc03c,		0x21, 0
	.dw 0x28c0, 0xc03c,	0x28ff, 0xc03c,		0x21, 0
	.dw 0x2940, 0xc03c,	0x297f, 0xc03c,		0x21, 0
	.dw 0x29c0, 0xc03c,	0x29ff, 0xc03c,		0x21, 0
	.dw 0x2a40, 0xc03c,	0x2a7f, 0xc03c,		0x21, 0
	.dw 0x2ac0, 0xc03c,	0x2aff, 0xc03c,		0x21, 0
	.dw 0x2b40, 0xc03c,	0x2b7f, 0xc03c,		0x21, 0
	.dw 0x2bc0, 0xc03c,	0x2bff, 0xc03c,		0x21, 0
	.dw 0x2c40, 0xc03c,	0x2c7f, 0xc03c,		0x21, 0
	.dw 0x2cc0, 0xc03c,	0x2cff, 0xc03c,		0x21, 0
	.dw 0x2d40, 0xc03c,	0x2d7f, 0xc03c,		0x21, 0
	.dw 0x2dc0, 0xc03c,	0x2dff, 0xc03c,		0x21, 0
	.dw 0x2e40, 0xc03c,	0x2e7f, 0xc03c,		0x21, 0
	.dw 0x2ec0, 0xc03c,	0x2eff, 0xc03c,		0x21, 0
	.dw 0x2f40, 0xc03c,	0x2f7f, 0xc03c,		0x21, 0
	.dw 0x2fc0, 0xc03c,	0x2fff, 0xc03c,		0x21, 0
	.dw 0x3040, 0xc03c,	0x307f, 0xc03c,		0x21, 0
	.dw 0x30c0, 0xc03c,	0x30ff, 0xc03c,		0x21, 0
	.dw 0x3140, 0xc03c,	0x317f, 0xc03c,		0x21, 0
	.dw 0x31c0, 0xc03c,	0x31ff, 0xc03c,		0x21, 0
	.dw 0x3240, 0xc03c,	0x327f, 0xc03c,		0x21, 0
	.dw 0x32c0, 0xc03c,	0x32ff, 0xc03c,		0x21, 0
	.dw 0x3340, 0xc03c,	0x337f, 0xc03c,		0x21, 0
	.dw 0x33c0, 0xc03c,	0x33ff, 0xc03c,		0x21, 0
	.dw 0x3440, 0xc03c,	0x347f, 0xc03c,		0x21, 0
	.dw 0x34c0, 0xc03c,	0x34ff, 0xc03c,		0x21, 0
	.dw 0x3540, 0xc03c,	0x357f, 0xc03c,		0x21, 0
	.dw 0x35c0, 0xc03c,	0x35ff, 0xc03c,		0x21, 0
	.dw 0x3640, 0xc03c,	0x367f, 0xc03c,		0x21, 0
	.dw 0x36c0, 0xc03c,	0x36ff, 0xc03c,		0x21, 0
	.dw 0x3740, 0xc03c,	0x377f, 0xc03c,		0x21, 0
	.dw 0x37c0, 0xc03c,	0x37ff, 0xc03c,		0x21, 0
	.dw 0x3840, 0xc03c,	0x387f, 0xc03c,		0x21, 0
	.dw 0x38c0, 0xc03c,	0x38ff, 0xc03c,		0x21, 0
	.dw 0x3940, 0xc03c,	0x397f, 0xc03c,		0x21, 0
	.dw 0x39c0, 0xc03c,	0x3fff, 0xc03c,		0x21, 0
	.dw 0x4040, 0xc03c,	0x407f, 0xc03c,		0x21, 0
	.dw 0x40c0, 0xc03c,	0x40ff, 0xc03c,		0x21, 0
	.dw 0x4140, 0xc03c,	0x417f, 0xc03c,		0x21, 0
	.dw 0x41c0, 0xc03c,	0x41ff, 0xc03c,		0x21, 0
	.dw 0x4240, 0xc03c,	0x427f, 0xc03c,		0x21, 0
	.dw 0x42c0, 0xc03c,	0x42ff, 0xc03c,		0x21, 0
	.dw 0x4340, 0xc03c,	0x437f, 0xc03c,		0x21, 0
	.dw 0x43c0, 0xc03c,	0x43ff, 0xc03c,		0x21, 0
	.dw 0x4440, 0xc03c,	0x447f, 0xc03c,		0x21, 0
	.dw 0x44c0, 0xc03c,	0x44ff, 0xc03c,		0x21, 0
	.dw 0x4540, 0xc03c,	0x457f, 0xc03c,		0x21, 0
	.dw 0x45c0, 0xc03c,	0x45ff, 0xc03c,		0x21, 0
	.dw 0x4640, 0xc03c,	0x467f, 0xc03c,		0x21, 0
	.dw 0x46c0, 0xc03c,	0x46ff, 0xc03c,		0x21, 0
	.dw 0x4740, 0xc03c,	0x477f, 0xc03c,		0x21, 0
	.dw 0x47c0, 0xc03c,	0x47ff, 0xc03c,		0x21, 0
	.dw 0x4840, 0xc03c,	0x487f, 0xc03c,		0x21, 0
	.dw 0x48c0, 0xc03c,	0x48ff, 0xc03c,		0x21, 0
	.dw 0x4940, 0xc03c,	0x497f, 0xc03c,		0x21, 0
	.dw 0x49c0, 0xc03c,	0x49ff, 0xc03c,		0x21, 0
	.dw 0x4a40, 0xc03c,	0x4a7f, 0xc03c,		0x21, 0
	.dw 0x4ac0, 0xc03c,	0x4aff, 0xc03c,		0x21, 0
	.dw 0x4b40, 0xc03c,	0x4b7f, 0xc03c,		0x21, 0
	.dw 0x4bc0, 0xc03c,	0x4bff, 0xc03c,		0x21, 0
	.dw 0x4c40, 0xc03c,	0x4c7f, 0xc03c,		0x21, 0
	.dw 0x4cc0, 0xc03c,	0x4cff, 0xc03c,		0x21, 0
	.dw 0x4d40, 0xc03c,	0x4d7f, 0xc03c,		0x21, 0
	.dw 0x4dc0, 0xc03c,	0x4dff, 0xc03c,		0x21, 0
	.dw 0x4e40, 0xc03c,	0x4e7f, 0xc03c,		0x21, 0
	.dw 0x4ec0, 0xc03c,	0x4eff, 0xc03c,		0x21, 0
	.dw 0x4f40, 0xc03c,	0x4f7f, 0xc03c,		0x21, 0
	.dw 0x4fc0, 0xc03c,	0x4fff, 0xc03c,		0x21, 0
	.dw 0x5040, 0xc03c,	0x507f, 0xc03c,		0x21, 0
	.dw 0x50c0, 0xc03c,	0x50ff, 0xc03c,		0x21, 0
	.dw 0x5140, 0xc03c,	0x517f, 0xc03c,		0x21, 0
	.dw 0x51c0, 0xc03c,	0x51ff, 0xc03c,		0x21, 0
	.dw 0x5240, 0xc03c,	0x527f, 0xc03c,		0x21, 0
	.dw 0x52c0, 0xc03c,	0x52ff, 0xc03c,		0x21, 0
	.dw 0x5340, 0xc03c,	0x537f, 0xc03c,		0x21, 0
	.dw 0x53c0, 0xc03c,	0x53ff, 0xc03c,		0x21, 0
	.dw 0x5440, 0xc03c,	0x547f, 0xc03c,		0x21, 0
	.dw 0x54c0, 0xc03c,	0x54ff, 0xc03c,		0x21, 0
	.dw 0x5540, 0xc03c,	0x557f, 0xc03c,		0x21, 0
	.dw 0x55c0, 0xc03c,	0x55ff, 0xc03c,		0x21, 0
	.dw 0x5640, 0xc03c,	0x567f, 0xc03c,		0x21, 0
	.dw 0x56c0, 0xc03c,	0x56ff, 0xc03c,		0x21, 0
	.dw 0x5740, 0xc03c,	0x577f, 0xc03c,		0x21, 0
	.dw 0x57c0, 0xc03c,	0x57ff, 0xc03c,		0x21, 0
	.dw 0x5840, 0xc03c,	0x587f, 0xc03c,		0x21, 0
	.dw 0x58c0, 0xc03c,	0x58ff, 0xc03c,		0x21, 0
	.dw 0x5940, 0xc03c,	0x597f, 0xc03c,		0x21, 0
	.dw 0x59c0, 0xc03c,	0x5fff, 0xc03c,		0x21, 0
	.dw 0x6040, 0xc03c,	0x607f, 0xc03c,		0x21, 0
	.dw 0x60c0, 0xc03c,	0x60ff, 0xc03c,		0x21, 0
	.dw 0x6140, 0xc03c,	0x617f, 0xc03c,		0x21, 0
	.dw 0x61c0, 0xc03c,	0x61ff, 0xc03c,		0x21, 0
	.dw 0x6240, 0xc03c,	0x627f, 0xc03c,		0x21, 0
	.dw 0x62c0, 0xc03c,	0x62ff, 0xc03c,		0x21, 0
	.dw 0x6340, 0xc03c,	0x637f, 0xc03c,		0x21, 0
	.dw 0x63c0, 0xc03c,	0x63ff, 0xc03c,		0x21, 0
	.dw 0x6440, 0xc03c,	0x647f, 0xc03c,		0x21, 0
	.dw 0x64c0, 0xc03c,	0x64ff, 0xc03c,		0x21, 0
	.dw 0x6540, 0xc03c,	0x657f, 0xc03c,		0x21, 0
	.dw 0x65c0, 0xc03c,	0x65ff, 0xc03c,		0x21, 0
	.dw 0x6640, 0xc03c,	0x667f, 0xc03c,		0x21, 0
	.dw 0x66c0, 0xc03c,	0x66ff, 0xc03c,		0x21, 0
	.dw 0x6740, 0xc03c,	0x677f, 0xc03c,		0x21, 0
	.dw 0x67c0, 0xc03c,	0x67ff, 0xc03c,		0x21, 0
	.dw 0x6840, 0xc03c,	0x687f, 0xc03c,		0x21, 0
	.dw 0x68c0, 0xc03c,	0x68ff, 0xc03c,		0x21, 0
	.dw 0x6940, 0xc03c,	0x697f, 0xc03c,		0x21, 0
	.dw 0x69c0, 0xc03c,	0x69ff, 0xc03c,		0x21, 0
	.dw 0x6a40, 0xc03c,	0x6a7f, 0xc03c,		0x21, 0
	.dw 0x6ac0, 0xc03c,	0x6aff, 0xc03c,		0x21, 0
	.dw 0x6b40, 0xc03c,	0x6b7f, 0xc03c,		0x21, 0
	.dw 0x6bc0, 0xc03c,	0x6bff, 0xc03c,		0x21, 0
	.dw 0x6c40, 0xc03c,	0x6c7f, 0xc03c,		0x21, 0
	.dw 0x6cc0, 0xc03c,	0x6cff, 0xc03c,		0x21, 0
	.dw 0x6d40, 0xc03c,	0x6d7f, 0xc03c,		0x21, 0
	.dw 0x6dc0, 0xc03c,	0x6dff, 0xc03c,		0x21, 0
	.dw 0x6e40, 0xc03c,	0x6e7f, 0xc03c,		0x21, 0
	.dw 0x6ec0, 0xc03c,	0x6eff, 0xc03c,		0x21, 0
	.dw 0x6f40, 0xc03c,	0x6f7f, 0xc03c,		0x21, 0
	.dw 0x6fc0, 0xc03c,	0x6fff, 0xc03c,		0x21, 0
	.dw 0x7040, 0xc03c,	0x707f, 0xc03c,		0x21, 0
	.dw 0x70c0, 0xc03c,	0x70ff, 0xc03c,		0x21, 0
	.dw 0x7140, 0xc03c,	0x717f, 0xc03c,		0x21, 0
	.dw 0x71c0, 0xc03c,	0x71ff, 0xc03c,		0x21, 0
	.dw 0x7240, 0xc03c,	0x727f, 0xc03c,		0x21, 0
	.dw 0x72c0, 0xc03c,	0x72ff, 0xc03c,		0x21, 0
	.dw 0x7340, 0xc03c,	0x737f, 0xc03c,		0x21, 0
	.dw 0x73c0, 0xc03c,	0x73ff, 0xc03c,		0x21, 0
	.dw 0x7440, 0xc03c,	0x747f, 0xc03c,		0x21, 0
	.dw 0x74c0, 0xc03c,	0x74ff, 0xc03c,		0x21, 0
	.dw 0x7540, 0xc03c,	0x757f, 0xc03c,		0x21, 0
	.dw 0x75c0, 0xc03c,	0x75ff, 0xc03c,		0x21, 0
	.dw 0x7640, 0xc03c,	0x767f, 0xc03c,		0x21, 0
	.dw 0x76c0, 0xc03c,	0x76ff, 0xc03c,		0x21, 0
	.dw 0x7740, 0xc03c,	0x777f, 0xc03c,		0x21, 0
	.dw 0x77c0, 0xc03c,	0x77ff, 0xc03c,		0x21, 0
	.dw 0x7840, 0xc03c,	0x787f, 0xc03c,		0x21, 0
	.dw 0x78c0, 0xc03c,	0x78ff, 0xc03c,		0x21, 0
	.dw 0x7940, 0xc03c,	0x797f, 0xc03c,		0x21, 0
	.dw 0x79c0, 0xc03c,	0x7fff, 0xc03c,		0x21, 0
	.dw 0x8040, 0xc03c,	0x807f, 0xc03c,		0x21, 0
	.dw 0x80c0, 0xc03c,	0x80ff, 0xc03c,		0x21, 0
	.dw 0x8140, 0xc03c,	0x817f, 0xc03c,		0x21, 0
	.dw 0x81c0, 0xc03c,	0x81ff, 0xc03c,		0x21, 0
	.dw 0x8240, 0xc03c,	0x827f, 0xc03c,		0x21, 0
	.dw 0x82c0, 0xc03c,	0x82ff, 0xc03c,		0x21, 0
	.dw 0x8340, 0xc03c,	0x837f, 0xc03c,		0x21, 0
	.dw 0x83c0, 0xc03c,	0x83ff, 0xc03c,		0x21, 0
	.dw 0x8440, 0xc03c,	0x847f, 0xc03c,		0x21, 0
	.dw 0x84c0, 0xc03c,	0x84ff, 0xc03c,		0x21, 0
	.dw 0x8540, 0xc03c,	0x857f, 0xc03c,		0x21, 0
	.dw 0x85c0, 0xc03c,	0x85ff, 0xc03c,		0x21, 0
	.dw 0x8640, 0xc03c,	0x867f, 0xc03c,		0x21, 0
	.dw 0x86c0, 0xc03c,	0x86ff, 0xc03c,		0x21, 0
	.dw 0x8740, 0xc03c,	0x877f, 0xc03c,		0x21, 0
	.dw 0x87c0, 0xc03c,	0x87ff, 0xc03c,		0x21, 0
	.dw 0x8840, 0xc03c,	0x887f, 0xc03c,		0x21, 0
	.dw 0x88c0, 0xc03c,	0x88ff, 0xc03c,		0x21, 0
	.dw 0x8940, 0xc03c,	0x897f, 0xc03c,		0x21, 0
	.dw 0x89c0, 0xc03c,	0x89ff, 0xc03c,		0x21, 0
	.dw 0x8a40, 0xc03c,	0x8a7f, 0xc03c,		0x21, 0
	.dw 0x8ac0, 0xc03c,	0x8aff, 0xc03c,		0x21, 0
	.dw 0x8b40, 0xc03c,	0x8b7f, 0xc03c,		0x21, 0
	.dw 0x8bc0, 0xc03c,	0x8bff, 0xc03c,		0x21, 0
	.dw 0x8c40, 0xc03c,	0x8c7f, 0xc03c,		0x21, 0
	.dw 0x8cc0, 0xc03c,	0x8cff, 0xc03c,		0x21, 0
	.dw 0x8d40, 0xc03c,	0x8d7f, 0xc03c,		0x21, 0
	.dw 0x8dc0, 0xc03c,	0x8dff, 0xc03c,		0x21, 0
	.dw 0x8e40, 0xc03c,	0x8e7f, 0xc03c,		0x21, 0
	.dw 0x8ec0, 0xc03c,	0x8eff, 0xc03c,		0x21, 0
	.dw 0x8f40, 0xc03c,	0x8f7f, 0xc03c,		0x21, 0
	.dw 0x8fc0, 0xc03c,	0x8fff, 0xc03c,		0x21, 0
	.dw 0x9040, 0xc03c,	0x907f, 0xc03c,		0x21, 0
	.dw 0x90c0, 0xc03c,	0x90ff, 0xc03c,		0x21, 0
	.dw 0x9140, 0xc03c,	0x917f, 0xc03c,		0x21, 0
	.dw 0x91c0, 0xc03c,	0x91ff, 0xc03c,		0x21, 0
	.dw 0x9240, 0xc03c,	0x927f, 0xc03c,		0x21, 0
	.dw 0x92c0, 0xc03c,	0x92ff, 0xc03c,		0x21, 0
	.dw 0x9340, 0xc03c,	0x937f, 0xc03c,		0x21, 0
	.dw 0x93c0, 0xc03c,	0x93ff, 0xc03c,		0x21, 0
	.dw 0x9440, 0xc03c,	0x947f, 0xc03c,		0x21, 0
	.dw 0x94c0, 0xc03c,	0x94ff, 0xc03c,		0x21, 0
	.dw 0x9540, 0xc03c,	0x957f, 0xc03c,		0x21, 0
	.dw 0x95c0, 0xc03c,	0x95ff, 0xc03c,		0x21, 0
	.dw 0x9640, 0xc03c,	0x967f, 0xc03c,		0x21, 0
	.dw 0x96c0, 0xc03c,	0x96ff, 0xc03c,		0x21, 0
	.dw 0x9740, 0xc03c,	0x977f, 0xc03c,		0x21, 0
	.dw 0x97c0, 0xc03c,	0x97ff, 0xc03c,		0x21, 0
	.dw 0x9840, 0xc03c,	0x987f, 0xc03c,		0x21, 0
	.dw 0x98c0, 0xc03c,	0x98ff, 0xc03c,		0x21, 0
	.dw 0x9940, 0xc03c,	0x997f, 0xc03c,		0x21, 0
	.dw 0x99c0, 0xc03c,	0x9fff, 0xc03c,		0x21, 0
	.dw 0xa040, 0xc03c,	0xa07f, 0xc03c,		0x21, 0
	.dw 0xa0c0, 0xc03c,	0xa0ff, 0xc03c,		0x21, 0
	.dw 0xa140, 0xc03c,	0xa17f, 0xc03c,		0x21, 0
	.dw 0xa1c0, 0xc03c,	0xa1ff, 0xc03c,		0x21, 0
	.dw 0xa240, 0xc03c,	0xa27f, 0xc03c,		0x21, 0
	.dw 0xa2c0, 0xc03c,	0xa2ff, 0xc03c,		0x21, 0
	.dw 0xa340, 0xc03c,	0xa37f, 0xc03c,		0x21, 0
	.dw 0xa3c0, 0xc03c,	0xa3ff, 0xc03c,		0x21, 0
	.dw 0xa440, 0xc03c,	0xa47f, 0xc03c,		0x21, 0
	.dw 0xa4c0, 0xc03c,	0xa4ff, 0xc03c,		0x21, 0
	.dw 0xa540, 0xc03c,	0xa57f, 0xc03c,		0x21, 0
	.dw 0xa5c0, 0xc03c,	0xa5ff, 0xc03c,		0x21, 0
	.dw 0xa640, 0xc03c,	0xa67f, 0xc03c,		0x21, 0
	.dw 0xa6c0, 0xc03c,	0xa6ff, 0xc03c,		0x21, 0
	.dw 0xa740, 0xc03c,	0xa77f, 0xc03c,		0x21, 0
	.dw 0xa7c0, 0xc03c,	0xa7ff, 0xc03c,		0x21, 0
	.dw 0xa840, 0xc03c,	0xa87f, 0xc03c,		0x21, 0
	.dw 0xa8c0, 0xc03c,	0xa8ff, 0xc03c,		0x21, 0
	.dw 0xa940, 0xc03c,	0xa97f, 0xc03c,		0x21, 0
	.dw 0xa9c0, 0xc03c,	0xa9ff, 0xc03c,		0x21, 0
	.dw 0xaa40, 0xc03c,	0xaa7f, 0xc03c,		0x21, 0
	.dw 0xaac0, 0xc03c,	0xaaff, 0xc03c,		0x21, 0
	.dw 0xab40, 0xc03c,	0xab7f, 0xc03c,		0x21, 0
	.dw 0xabc0, 0xc03c,	0xabff, 0xc03c,		0x21, 0
	.dw 0xac40, 0xc03c,	0xac7f, 0xc03c,		0x21, 0
	.dw 0xacc0, 0xc03c,	0xacff, 0xc03c,		0x21, 0
	.dw 0xad40, 0xc03c,	0xad7f, 0xc03c,		0x21, 0
	.dw 0xadc0, 0xc03c,	0xadff, 0xc03c,		0x21, 0
	.dw 0xae40, 0xc03c,	0xae7f, 0xc03c,		0x21, 0
	.dw 0xaec0, 0xc03c,	0xaeff, 0xc03c,		0x21, 0
	.dw 0xaf40, 0xc03c,	0xaf7f, 0xc03c,		0x21, 0
	.dw 0xafc0, 0xc03c,	0xafff, 0xc03c,		0x21, 0
	.dw 0xb040, 0xc03c,	0xb07f, 0xc03c,		0x21, 0
	.dw 0xb0c0, 0xc03c,	0xb0ff, 0xc03c,		0x21, 0
	.dw 0xb140, 0xc03c,	0xb17f, 0xc03c,		0x21, 0
	.dw 0xb1c0, 0xc03c,	0xb1ff, 0xc03c,		0x21, 0
	.dw 0xb240, 0xc03c,	0xb27f, 0xc03c,		0x21, 0
	.dw 0xb2c0, 0xc03c,	0xb2ff, 0xc03c,		0x21, 0
	.dw 0xb340, 0xc03c,	0xb37f, 0xc03c,		0x21, 0
	.dw 0xb3c0, 0xc03c,	0xb3ff, 0xc03c,		0x21, 0
	.dw 0xb440, 0xc03c,	0xb47f, 0xc03c,		0x21, 0
	.dw 0xb4c0, 0xc03c,	0xb4ff, 0xc03c,		0x21, 0
	.dw 0xb540, 0xc03c,	0xb57f, 0xc03c,		0x21, 0
	.dw 0xb5c0, 0xc03c,	0xb5ff, 0xc03c,		0x21, 0
	.dw 0xb640, 0xc03c,	0xb67f, 0xc03c,		0x21, 0
	.dw 0xb6c0, 0xc03c,	0xb6ff, 0xc03c,		0x21, 0
	.dw 0xb740, 0xc03c,	0xb77f, 0xc03c,		0x21, 0
	.dw 0xb7c0, 0xc03c,	0xb7ff, 0xc03c,		0x21, 0
	.dw 0xb840, 0xc03c,	0xb87f, 0xc03c,		0x21, 0
	.dw 0xb8c0, 0xc03c,	0xb8ff, 0xc03c,		0x21, 0
	.dw 0xb940, 0xc03c,	0xb97f, 0xc03c,		0x21, 0
	.dw 0xb9c0, 0xc03c,	0xbfff, 0xc03c,		0x21, 0
	.dw 0xc040, 0xc03c,	0xc07f, 0xc03c,		0x21, 0
	.dw 0xc0c0, 0xc03c,	0xc0ff, 0xc03c,		0x21, 0
	.dw 0xc140, 0xc03c,	0xc17f, 0xc03c,		0x21, 0
	.dw 0xc1c0, 0xc03c,	0xc1ff, 0xc03c,		0x21, 0
	.dw 0xc240, 0xc03c,	0xc27f, 0xc03c,		0x21, 0
	.dw 0xc2c0, 0xc03c,	0xc2ff, 0xc03c,		0x21, 0
	.dw 0xc340, 0xc03c,	0xc37f, 0xc03c,		0x21, 0
	.dw 0xc3c0, 0xc03c,	0xc3ff, 0xc03c,		0x21, 0
	.dw 0xc440, 0xc03c,	0xc47f, 0xc03c,		0x21, 0
	.dw 0xc4c0, 0xc03c,	0xc4ff, 0xc03c,		0x21, 0
	.dw 0xc540, 0xc03c,	0xc57f, 0xc03c,		0x21, 0
	.dw 0xc5c0, 0xc03c,	0xc5ff, 0xc03c,		0x21, 0
	.dw 0xc640, 0xc03c,	0xc67f, 0xc03c,		0x21, 0
	.dw 0xc6c0, 0xc03c,	0xc6ff, 0xc03c,		0x21, 0
	.dw 0xc740, 0xc03c,	0xc77f, 0xc03c,		0x21, 0
	.dw 0xc7c0, 0xc03c,	0xc7ff, 0xc03c,		0x21, 0
	.dw 0xc840, 0xc03c,	0xc87f, 0xc03c,		0x21, 0
	.dw 0xc8c0, 0xc03c,	0xc8ff, 0xc03c,		0x21, 0
	.dw 0xc940, 0xc03c,	0xc97f, 0xc03c,		0x21, 0
	.dw 0xc9c0, 0xc03c,	0xc9ff, 0xc03c,		0x21, 0
	.dw 0xca40, 0xc03c,	0xca7f, 0xc03c,		0x21, 0
	.dw 0xcac0, 0xc03c,	0xcaff, 0xc03c,		0x21, 0
	.dw 0xcb40, 0xc03c,	0xcb7f, 0xc03c,		0x21, 0
	.dw 0xcbc0, 0xc03c,	0xcbff, 0xc03c,		0x21, 0
	.dw 0xcc40, 0xc03c,	0xcc7f, 0xc03c,		0x21, 0
	.dw 0xccc0, 0xc03c,	0xccff, 0xc03c,		0x21, 0
	.dw 0xcd40, 0xc03c,	0xcd7f, 0xc03c,		0x21, 0
	.dw 0xcdc0, 0xc03c,	0xcdff, 0xc03c,		0x21, 0
	.dw 0xce40, 0xc03c,	0xce7f, 0xc03c,		0x21, 0
	.dw 0xcec0, 0xc03c,	0xceff, 0xc03c,		0x21, 0
	.dw 0xcf40, 0xc03c,	0xcf7f, 0xc03c,		0x21, 0
	.dw 0xcfc0, 0xc03c,	0xcfff, 0xc03c,		0x21, 0
	.dw 0xd040, 0xc03c,	0xd07f, 0xc03c,		0x21, 0
	.dw 0xd0c0, 0xc03c,	0xd0ff, 0xc03c,		0x21, 0
	.dw 0xd140, 0xc03c,	0xd17f, 0xc03c,		0x21, 0
	.dw 0xd1c0, 0xc03c,	0xd1ff, 0xc03c,		0x21, 0
	.dw 0xd240, 0xc03c,	0xd27f, 0xc03c,		0x21, 0
	.dw 0xd2c0, 0xc03c,	0xd2ff, 0xc03c,		0x21, 0
	.dw 0xd340, 0xc03c,	0xd37f, 0xc03c,		0x21, 0
	.dw 0xd3c0, 0xc03c,	0xd3ff, 0xc03c,		0x21, 0
	.dw 0xd440, 0xc03c,	0xd47f, 0xc03c,		0x21, 0
	.dw 0xd4c0, 0xc03c,	0xd4ff, 0xc03c,		0x21, 0
	.dw 0xd540, 0xc03c,	0xd57f, 0xc03c,		0x21, 0
	.dw 0xd5c0, 0xc03c,	0xd5ff, 0xc03c,		0x21, 0
	.dw 0xd640, 0xc03c,	0xd67f, 0xc03c,		0x21, 0
	.dw 0xd6c0, 0xc03c,	0xd6ff, 0xc03c,		0x21, 0
	.dw 0xd740, 0xc03c,	0xd77f, 0xc03c,		0x21, 0
	.dw 0xd7c0, 0xc03c,	0xd7ff, 0xc03c,		0x21, 0
	.dw 0xd840, 0xc03c,	0xd87f, 0xc03c,		0x21, 0
	.dw 0xd8c0, 0xc03c,	0xd8ff, 0xc03c,		0x21, 0
	.dw 0xd940, 0xc03c,	0xd97f, 0xc03c,		0x21, 0
	.dw 0xd9c0, 0xc03c,	0xdfff, 0xc03c,		0x21, 0
	.dw 0xe040, 0xc03c,	0xe07f, 0xc03c,		0x21, 0
	.dw 0xe0c0, 0xc03c,	0xe0ff, 0xc03c,		0x21, 0
	.dw 0xe140, 0xc03c,	0xe17f, 0xc03c,		0x21, 0
	.dw 0xe1c0, 0xc03c,	0xe1ff, 0xc03c,		0x21, 0
	.dw 0xe240, 0xc03c,	0xe27f, 0xc03c,		0x21, 0
	.dw 0xe2c0, 0xc03c,	0xe2ff, 0xc03c,		0x21, 0
	.dw 0xe340, 0xc03c,	0xe37f, 0xc03c,		0x21, 0
	.dw 0xe3c0, 0xc03c,	0xe3ff, 0xc03c,		0x21, 0
	.dw 0xe440, 0xc03c,	0xe47f, 0xc03c,		0x21, 0
	.dw 0xe4c0, 0xc03c,	0xe4ff, 0xc03c,		0x21, 0
	.dw 0xe540, 0xc03c,	0xe57f, 0xc03c,		0x21, 0
	.dw 0xe5c0, 0xc03c,	0xe5ff, 0xc03c,		0x21, 0
	.dw 0xe640, 0xc03c,	0xe67f, 0xc03c,		0x21, 0
	.dw 0xe6c0, 0xc03c,	0xe6ff, 0xc03c,		0x21, 0
	.dw 0xe740, 0xc03c,	0xe77f, 0xc03c,		0x21, 0
	.dw 0xe7c0, 0xc03c,	0xe7ff, 0xc03c,		0x21, 0
	.dw 0xe840, 0xc03c,	0xe87f, 0xc03c,		0x21, 0
	.dw 0xe8c0, 0xc03c,	0xe8ff, 0xc03c,		0x21, 0
	.dw 0xe940, 0xc03c,	0xe97f, 0xc03c,		0x21, 0
	.dw 0xe9c0, 0xc03c,	0xe9ff, 0xc03c,		0x21, 0
	.dw 0xea40, 0xc03c,	0xea7f, 0xc03c,		0x21, 0
	.dw 0xeac0, 0xc03c,	0xeaff, 0xc03c,		0x21, 0
	.dw 0xeb40, 0xc03c,	0xeb7f, 0xc03c,		0x21, 0
	.dw 0xebc0, 0xc03c,	0xebff, 0xc03c,		0x21, 0
	.dw 0xec40, 0xc03c,	0xec7f, 0xc03c,		0x21, 0
	.dw 0xecc0, 0xc03c,	0xecff, 0xc03c,		0x21, 0
	.dw 0xed40, 0xc03c,	0xed7f, 0xc03c,		0x21, 0
	.dw 0xedc0, 0xc03c,	0xedff, 0xc03c,		0x21, 0
	.dw 0xee40, 0xc03c,	0xee7f, 0xc03c,		0x21, 0
	.dw 0xeec0, 0xc03c,	0xeeff, 0xc03c,		0x21, 0
	.dw 0xef40, 0xc03c,	0xef7f, 0xc03c,		0x21, 0
	.dw 0xefc0, 0xc03c,	0xefff, 0xc03c,		0x21, 0
	.dw 0xf040, 0xc03c,	0xf07f, 0xc03c,		0x21, 0
	.dw 0xf0c0, 0xc03c,	0xf0ff, 0xc03c,		0x21, 0
	.dw 0xf140, 0xc03c,	0xf17f, 0xc03c,		0x21, 0
	.dw 0xf1c0, 0xc03c,	0xf1ff, 0xc03c,		0x21, 0
	.dw 0xf240, 0xc03c,	0xf27f, 0xc03c,		0x21, 0
	.dw 0xf2c0, 0xc03c,	0xf2ff, 0xc03c,		0x21, 0
	.dw 0xf340, 0xc03c,	0xf37f, 0xc03c,		0x21, 0
	.dw 0xf3c0, 0xc03c,	0xf3ff, 0xc03c,		0x21, 0
	.dw 0xf440, 0xc03c,	0xf47f, 0xc03c,		0x21, 0
	.dw 0xf4c0, 0xc03c,	0xf4ff, 0xc03c,		0x21, 0
	.dw 0xf540, 0xc03c,	0xf57f, 0xc03c,		0x21, 0
	.dw 0xf5c0, 0xc03c,	0xf5ff, 0xc03c,		0x21, 0
	.dw 0xf640, 0xc03c,	0xf67f, 0xc03c,		0x21, 0
	.dw 0xf6c0, 0xc03c,	0xf6ff, 0xc03c,		0x21, 0
	.dw 0xf740, 0xc03c,	0xf77f, 0xc03c,		0x21, 0
	.dw 0xf7c0, 0xc03c,	0xf7ff, 0xc03c,		0x21, 0
	.dw 0xf840, 0xc03c,	0xf87f, 0xc03c,		0x21, 0
	.dw 0xf8c0, 0xc03c,	0xf8ff, 0xc03c,		0x21, 0
	.dw 0xf940, 0xc03c,	0xf97f, 0xc03c,		0x21, 0
	.dw 0xf9c0, 0xc03c,	0xffff, 0xc03c,		0x21, 0
	.dw 0x0040, 0xc03d,	0x007f, 0xc03d,		0x21, 0
	.dw 0x00c0, 0xc03d,	0x00ff, 0xc03d,		0x21, 0
	.dw 0x0140, 0xc03d,	0x017f, 0xc03d,		0x21, 0
	.dw 0x01c0, 0xc03d,	0x01ff, 0xc03d,		0x21, 0
	.dw 0x0240, 0xc03d,	0x027f, 0xc03d,		0x21, 0
	.dw 0x02c0, 0xc03d,	0x02ff, 0xc03d,		0x21, 0
	.dw 0x0340, 0xc03d,	0x037f, 0xc03d,		0x21, 0
	.dw 0x03c0, 0xc03d,	0x03ff, 0xc03d,		0x21, 0
	.dw 0x0440, 0xc03d,	0x047f, 0xc03d,		0x21, 0
	.dw 0x04c0, 0xc03d,	0x04ff, 0xc03d,		0x21, 0
	.dw 0x0540, 0xc03d,	0x057f, 0xc03d,		0x21, 0
	.dw 0x05c0, 0xc03d,	0x05ff, 0xc03d,		0x21, 0
	.dw 0x0640, 0xc03d,	0x067f, 0xc03d,		0x21, 0
	.dw 0x06c0, 0xc03d,	0x06ff, 0xc03d,		0x21, 0
	.dw 0x0740, 0xc03d,	0x077f, 0xc03d,		0x21, 0
	.dw 0x07c0, 0xc03d,	0x07ff, 0xc03d,		0x21, 0
	.dw 0x0840, 0xc03d,	0x087f, 0xc03d,		0x21, 0
	.dw 0x08c0, 0xc03d,	0x08ff, 0xc03d,		0x21, 0
	.dw 0x0940, 0xc03d,	0x097f, 0xc03d,		0x21, 0
	.dw 0x09c0, 0xc03d,	0x09ff, 0xc03d,		0x21, 0
	.dw 0x0a40, 0xc03d,	0x0a7f, 0xc03d,		0x21, 0
	.dw 0x0ac0, 0xc03d,	0x0aff, 0xc03d,		0x21, 0
	.dw 0x0b40, 0xc03d,	0x0b7f, 0xc03d,		0x21, 0
	.dw 0x0bc0, 0xc03d,	0x0bff, 0xc03d,		0x21, 0
	.dw 0x0c40, 0xc03d,	0x0c7f, 0xc03d,		0x21, 0
	.dw 0x0cc0, 0xc03d,	0x0cff, 0xc03d,		0x21, 0
	.dw 0x0d40, 0xc03d,	0x0d7f, 0xc03d,		0x21, 0
	.dw 0x0dc0, 0xc03d,	0x0dff, 0xc03d,		0x21, 0
	.dw 0x0e40, 0xc03d,	0x0e7f, 0xc03d,		0x21, 0
	.dw 0x0ec0, 0xc03d,	0x0eff, 0xc03d,		0x21, 0
	.dw 0x0f40, 0xc03d,	0x0f7f, 0xc03d,		0x21, 0
	.dw 0x0fc0, 0xc03d,	0x0fff, 0xc03d,		0x21, 0
	.dw 0x1040, 0xc03d,	0x107f, 0xc03d,		0x21, 0
	.dw 0x10c0, 0xc03d,	0x10ff, 0xc03d,		0x21, 0
	.dw 0x1140, 0xc03d,	0x117f, 0xc03d,		0x21, 0
	.dw 0x11c0, 0xc03d,	0x11ff, 0xc03d,		0x21, 0
	.dw 0x1240, 0xc03d,	0x127f, 0xc03d,		0x21, 0
	.dw 0x12c0, 0xc03d,	0x12ff, 0xc03d,		0x21, 0
	.dw 0x1340, 0xc03d,	0x137f, 0xc03d,		0x21, 0
	.dw 0x13c0, 0xc03d,	0x13ff, 0xc03d,		0x21, 0
	.dw 0x1440, 0xc03d,	0x147f, 0xc03d,		0x21, 0
	.dw 0x14c0, 0xc03d,	0x14ff, 0xc03d,		0x21, 0
	.dw 0x1540, 0xc03d,	0x157f, 0xc03d,		0x21, 0
	.dw 0x15c0, 0xc03d,	0x15ff, 0xc03d,		0x21, 0
	.dw 0x1640, 0xc03d,	0x167f, 0xc03d,		0x21, 0
	.dw 0x16c0, 0xc03d,	0x16ff, 0xc03d,		0x21, 0
	.dw 0x1740, 0xc03d,	0x177f, 0xc03d,		0x21, 0
	.dw 0x17c0, 0xc03d,	0x17ff, 0xc03d,		0x21, 0
	.dw 0x1840, 0xc03d,	0x187f, 0xc03d,		0x21, 0
	.dw 0x18c0, 0xc03d,	0x18ff, 0xc03d,		0x21, 0
	.dw 0x1940, 0xc03d,	0x197f, 0xc03d,		0x21, 0
	.dw 0x19c0, 0xc03d,	0x1fff, 0xc03d,		0x21, 0
	.dw 0x2040, 0xc03d,	0x207f, 0xc03d,		0x21, 0
	.dw 0x20c0, 0xc03d,	0x20ff, 0xc03d,		0x21, 0
	.dw 0x2140, 0xc03d,	0x217f, 0xc03d,		0x21, 0
	.dw 0x21c0, 0xc03d,	0x21ff, 0xc03d,		0x21, 0
	.dw 0x2240, 0xc03d,	0x227f, 0xc03d,		0x21, 0
	.dw 0x22c0, 0xc03d,	0x22ff, 0xc03d,		0x21, 0
	.dw 0x2340, 0xc03d,	0x237f, 0xc03d,		0x21, 0
	.dw 0x23c0, 0xc03d,	0x23ff, 0xc03d,		0x21, 0
	.dw 0x2440, 0xc03d,	0x247f, 0xc03d,		0x21, 0
	.dw 0x24c0, 0xc03d,	0x24ff, 0xc03d,		0x21, 0
	.dw 0x2540, 0xc03d,	0x257f, 0xc03d,		0x21, 0
	.dw 0x25c0, 0xc03d,	0x25ff, 0xc03d,		0x21, 0
	.dw 0x2640, 0xc03d,	0x267f, 0xc03d,		0x21, 0
	.dw 0x26c0, 0xc03d,	0x26ff, 0xc03d,		0x21, 0
	.dw 0x2740, 0xc03d,	0x277f, 0xc03d,		0x21, 0
	.dw 0x27c0, 0xc03d,	0x27ff, 0xc03d,		0x21, 0
	.dw 0x2840, 0xc03d,	0x287f, 0xc03d,		0x21, 0
	.dw 0x28c0, 0xc03d,	0x28ff, 0xc03d,		0x21, 0
	.dw 0x2940, 0xc03d,	0x297f, 0xc03d,		0x21, 0
	.dw 0x29c0, 0xc03d,	0x29ff, 0xc03d,		0x21, 0
	.dw 0x2a40, 0xc03d,	0x2a7f, 0xc03d,		0x21, 0
	.dw 0x2ac0, 0xc03d,	0x2aff, 0xc03d,		0x21, 0
	.dw 0x2b40, 0xc03d,	0x2b7f, 0xc03d,		0x21, 0
	.dw 0x2bc0, 0xc03d,	0x2bff, 0xc03d,		0x21, 0
	.dw 0x2c40, 0xc03d,	0x2c7f, 0xc03d,		0x21, 0
	.dw 0x2cc0, 0xc03d,	0x2cff, 0xc03d,		0x21, 0
	.dw 0x2d40, 0xc03d,	0x2d7f, 0xc03d,		0x21, 0
	.dw 0x2dc0, 0xc03d,	0x2dff, 0xc03d,		0x21, 0
	.dw 0x2e40, 0xc03d,	0x2e7f, 0xc03d,		0x21, 0
	.dw 0x2ec0, 0xc03d,	0x2eff, 0xc03d,		0x21, 0
	.dw 0x2f40, 0xc03d,	0x2f7f, 0xc03d,		0x21, 0
	.dw 0x2fc0, 0xc03d,	0x2fff, 0xc03d,		0x21, 0
	.dw 0x3040, 0xc03d,	0x307f, 0xc03d,		0x21, 0
	.dw 0x30c0, 0xc03d,	0x30ff, 0xc03d,		0x21, 0
	.dw 0x3140, 0xc03d,	0x317f, 0xc03d,		0x21, 0
	.dw 0x31c0, 0xc03d,	0x31ff, 0xc03d,		0x21, 0
	.dw 0x3240, 0xc03d,	0x327f, 0xc03d,		0x21, 0
	.dw 0x32c0, 0xc03d,	0x32ff, 0xc03d,		0x21, 0
	.dw 0x3340, 0xc03d,	0x337f, 0xc03d,		0x21, 0
	.dw 0x33c0, 0xc03d,	0x33ff, 0xc03d,		0x21, 0
	.dw 0x3440, 0xc03d,	0x347f, 0xc03d,		0x21, 0
	.dw 0x34c0, 0xc03d,	0x34ff, 0xc03d,		0x21, 0
	.dw 0x3540, 0xc03d,	0x357f, 0xc03d,		0x21, 0
	.dw 0x35c0, 0xc03d,	0x35ff, 0xc03d,		0x21, 0
	.dw 0x3640, 0xc03d,	0x367f, 0xc03d,		0x21, 0
	.dw 0x36c0, 0xc03d,	0x36ff, 0xc03d,		0x21, 0
	.dw 0x3740, 0xc03d,	0x377f, 0xc03d,		0x21, 0
	.dw 0x37c0, 0xc03d,	0x37ff, 0xc03d,		0x21, 0
	.dw 0x3840, 0xc03d,	0x387f, 0xc03d,		0x21, 0
	.dw 0x38c0, 0xc03d,	0x38ff, 0xc03d,		0x21, 0
	.dw 0x3940, 0xc03d,	0x397f, 0xc03d,		0x21, 0
	.dw 0x39c0, 0xc03d,	0x3fff, 0xc03d,		0x21, 0
	.dw 0x4040, 0xc03d,	0x407f, 0xc03d,		0x21, 0
	.dw 0x40c0, 0xc03d,	0x40ff, 0xc03d,		0x21, 0
	.dw 0x4140, 0xc03d,	0x417f, 0xc03d,		0x21, 0
	.dw 0x41c0, 0xc03d,	0x41ff, 0xc03d,		0x21, 0
	.dw 0x4240, 0xc03d,	0x427f, 0xc03d,		0x21, 0
	.dw 0x42c0, 0xc03d,	0x42ff, 0xc03d,		0x21, 0
	.dw 0x4340, 0xc03d,	0x437f, 0xc03d,		0x21, 0
	.dw 0x43c0, 0xc03d,	0x43ff, 0xc03d,		0x21, 0
	.dw 0x4440, 0xc03d,	0x447f, 0xc03d,		0x21, 0
	.dw 0x44c0, 0xc03d,	0x44ff, 0xc03d,		0x21, 0
	.dw 0x4540, 0xc03d,	0x457f, 0xc03d,		0x21, 0
	.dw 0x45c0, 0xc03d,	0x45ff, 0xc03d,		0x21, 0
	.dw 0x4640, 0xc03d,	0x467f, 0xc03d,		0x21, 0
	.dw 0x46c0, 0xc03d,	0x46ff, 0xc03d,		0x21, 0
	.dw 0x4740, 0xc03d,	0x477f, 0xc03d,		0x21, 0
	.dw 0x47c0, 0xc03d,	0x47ff, 0xc03d,		0x21, 0
	.dw 0x4840, 0xc03d,	0x487f, 0xc03d,		0x21, 0
	.dw 0x48c0, 0xc03d,	0x48ff, 0xc03d,		0x21, 0
	.dw 0x4940, 0xc03d,	0x497f, 0xc03d,		0x21, 0
	.dw 0x49c0, 0xc03d,	0x49ff, 0xc03d,		0x21, 0
	.dw 0x4a40, 0xc03d,	0x4a7f, 0xc03d,		0x21, 0
	.dw 0x4ac0, 0xc03d,	0x4aff, 0xc03d,		0x21, 0
	.dw 0x4b40, 0xc03d,	0x4b7f, 0xc03d,		0x21, 0
	.dw 0x4bc0, 0xc03d,	0x4bff, 0xc03d,		0x21, 0
	.dw 0x4c40, 0xc03d,	0x4c7f, 0xc03d,		0x21, 0
	.dw 0x4cc0, 0xc03d,	0x4cff, 0xc03d,		0x21, 0
	.dw 0x4d40, 0xc03d,	0x4d7f, 0xc03d,		0x21, 0
	.dw 0x4dc0, 0xc03d,	0x4dff, 0xc03d,		0x21, 0
	.dw 0x4e40, 0xc03d,	0x4e7f, 0xc03d,		0x21, 0
	.dw 0x4ec0, 0xc03d,	0x4eff, 0xc03d,		0x21, 0
	.dw 0x4f40, 0xc03d,	0x4f7f, 0xc03d,		0x21, 0
	.dw 0x4fc0, 0xc03d,	0x4fff, 0xc03d,		0x21, 0
	.dw 0x5040, 0xc03d,	0x507f, 0xc03d,		0x21, 0
	.dw 0x50c0, 0xc03d,	0x50ff, 0xc03d,		0x21, 0
	.dw 0x5140, 0xc03d,	0x517f, 0xc03d,		0x21, 0
	.dw 0x51c0, 0xc03d,	0x51ff, 0xc03d,		0x21, 0
	.dw 0x5240, 0xc03d,	0x527f, 0xc03d,		0x21, 0
	.dw 0x52c0, 0xc03d,	0x52ff, 0xc03d,		0x21, 0
	.dw 0x5340, 0xc03d,	0x537f, 0xc03d,		0x21, 0
	.dw 0x53c0, 0xc03d,	0x53ff, 0xc03d,		0x21, 0
	.dw 0x5440, 0xc03d,	0x547f, 0xc03d,		0x21, 0
	.dw 0x54c0, 0xc03d,	0x54ff, 0xc03d,		0x21, 0
	.dw 0x5540, 0xc03d,	0x557f, 0xc03d,		0x21, 0
	.dw 0x55c0, 0xc03d,	0x55ff, 0xc03d,		0x21, 0
	.dw 0x5640, 0xc03d,	0x567f, 0xc03d,		0x21, 0
	.dw 0x56c0, 0xc03d,	0x56ff, 0xc03d,		0x21, 0
	.dw 0x5740, 0xc03d,	0x577f, 0xc03d,		0x21, 0
	.dw 0x57c0, 0xc03d,	0x57ff, 0xc03d,		0x21, 0
	.dw 0x5840, 0xc03d,	0x587f, 0xc03d,		0x21, 0
	.dw 0x58c0, 0xc03d,	0x58ff, 0xc03d,		0x21, 0
	.dw 0x5940, 0xc03d,	0x597f, 0xc03d,		0x21, 0
	.dw 0x59c0, 0xc03d,	0x5fff, 0xc03d,		0x21, 0
	.dw 0x6040, 0xc03d,	0x607f, 0xc03d,		0x21, 0
	.dw 0x60c0, 0xc03d,	0x60ff, 0xc03d,		0x21, 0
	.dw 0x6140, 0xc03d,	0x617f, 0xc03d,		0x21, 0
	.dw 0x61c0, 0xc03d,	0x61ff, 0xc03d,		0x21, 0
	.dw 0x6240, 0xc03d,	0x627f, 0xc03d,		0x21, 0
	.dw 0x62c0, 0xc03d,	0x62ff, 0xc03d,		0x21, 0
	.dw 0x6340, 0xc03d,	0x637f, 0xc03d,		0x21, 0
	.dw 0x63c0, 0xc03d,	0x63ff, 0xc03d,		0x21, 0
	.dw 0x6440, 0xc03d,	0x647f, 0xc03d,		0x21, 0
	.dw 0x64c0, 0xc03d,	0x64ff, 0xc03d,		0x21, 0
	.dw 0x6540, 0xc03d,	0x657f, 0xc03d,		0x21, 0
	.dw 0x65c0, 0xc03d,	0x65ff, 0xc03d,		0x21, 0
	.dw 0x6640, 0xc03d,	0x667f, 0xc03d,		0x21, 0
	.dw 0x66c0, 0xc03d,	0x66ff, 0xc03d,		0x21, 0
	.dw 0x6740, 0xc03d,	0x677f, 0xc03d,		0x21, 0
	.dw 0x67c0, 0xc03d,	0x67ff, 0xc03d,		0x21, 0
	.dw 0x6840, 0xc03d,	0x687f, 0xc03d,		0x21, 0
	.dw 0x68c0, 0xc03d,	0x68ff, 0xc03d,		0x21, 0
	.dw 0x6940, 0xc03d,	0x697f, 0xc03d,		0x21, 0
	.dw 0x69c0, 0xc03d,	0x69ff, 0xc03d,		0x21, 0
	.dw 0x6a40, 0xc03d,	0x6a7f, 0xc03d,		0x21, 0
	.dw 0x6ac0, 0xc03d,	0x6aff, 0xc03d,		0x21, 0
	.dw 0x6b40, 0xc03d,	0x6b7f, 0xc03d,		0x21, 0
	.dw 0x6bc0, 0xc03d,	0x6bff, 0xc03d,		0x21, 0
	.dw 0x6c40, 0xc03d,	0x6c7f, 0xc03d,		0x21, 0
	.dw 0x6cc0, 0xc03d,	0x6cff, 0xc03d,		0x21, 0
	.dw 0x6d40, 0xc03d,	0x6d7f, 0xc03d,		0x21, 0
	.dw 0x6dc0, 0xc03d,	0x6dff, 0xc03d,		0x21, 0
	.dw 0x6e40, 0xc03d,	0x6e7f, 0xc03d,		0x21, 0
	.dw 0x6ec0, 0xc03d,	0x6eff, 0xc03d,		0x21, 0
	.dw 0x6f40, 0xc03d,	0x6f7f, 0xc03d,		0x21, 0
	.dw 0x6fc0, 0xc03d,	0x6fff, 0xc03d,		0x21, 0
	.dw 0x7040, 0xc03d,	0x707f, 0xc03d,		0x21, 0
	.dw 0x70c0, 0xc03d,	0x70ff, 0xc03d,		0x21, 0
	.dw 0x7140, 0xc03d,	0x717f, 0xc03d,		0x21, 0
	.dw 0x71c0, 0xc03d,	0x71ff, 0xc03d,		0x21, 0
	.dw 0x7240, 0xc03d,	0x727f, 0xc03d,		0x21, 0
	.dw 0x72c0, 0xc03d,	0x72ff, 0xc03d,		0x21, 0
	.dw 0x7340, 0xc03d,	0x737f, 0xc03d,		0x21, 0
	.dw 0x73c0, 0xc03d,	0x73ff, 0xc03d,		0x21, 0
	.dw 0x7440, 0xc03d,	0x747f, 0xc03d,		0x21, 0
	.dw 0x74c0, 0xc03d,	0x74ff, 0xc03d,		0x21, 0
	.dw 0x7540, 0xc03d,	0x757f, 0xc03d,		0x21, 0
	.dw 0x75c0, 0xc03d,	0x75ff, 0xc03d,		0x21, 0
	.dw 0x7640, 0xc03d,	0x767f, 0xc03d,		0x21, 0
	.dw 0x76c0, 0xc03d,	0x76ff, 0xc03d,		0x21, 0
	.dw 0x7740, 0xc03d,	0x777f, 0xc03d,		0x21, 0
	.dw 0x77c0, 0xc03d,	0x77ff, 0xc03d,		0x21, 0
	.dw 0x7840, 0xc03d,	0x787f, 0xc03d,		0x21, 0
	.dw 0x78c0, 0xc03d,	0x78ff, 0xc03d,		0x21, 0
	.dw 0x7940, 0xc03d,	0x797f, 0xc03d,		0x21, 0
	.dw 0x79c0, 0xc03d,	0x7fff, 0xc03d,		0x21, 0
	.dw 0x8040, 0xc03d,	0x807f, 0xc03d,		0x21, 0
	.dw 0x80c0, 0xc03d,	0x80ff, 0xc03d,		0x21, 0
	.dw 0x8140, 0xc03d,	0x817f, 0xc03d,		0x21, 0
	.dw 0x81c0, 0xc03d,	0x81ff, 0xc03d,		0x21, 0
	.dw 0x8240, 0xc03d,	0x827f, 0xc03d,		0x21, 0
	.dw 0x82c0, 0xc03d,	0x82ff, 0xc03d,		0x21, 0
	.dw 0x8340, 0xc03d,	0x837f, 0xc03d,		0x21, 0
	.dw 0x83c0, 0xc03d,	0x83ff, 0xc03d,		0x21, 0
	.dw 0x8440, 0xc03d,	0x847f, 0xc03d,		0x21, 0
	.dw 0x84c0, 0xc03d,	0x84ff, 0xc03d,		0x21, 0
	.dw 0x8540, 0xc03d,	0x857f, 0xc03d,		0x21, 0
	.dw 0x85c0, 0xc03d,	0x85ff, 0xc03d,		0x21, 0
	.dw 0x8640, 0xc03d,	0x867f, 0xc03d,		0x21, 0
	.dw 0x86c0, 0xc03d,	0x86ff, 0xc03d,		0x21, 0
	.dw 0x8740, 0xc03d,	0x877f, 0xc03d,		0x21, 0
	.dw 0x87c0, 0xc03d,	0x87ff, 0xc03d,		0x21, 0
	.dw 0x8840, 0xc03d,	0x887f, 0xc03d,		0x21, 0
	.dw 0x88c0, 0xc03d,	0x88ff, 0xc03d,		0x21, 0
	.dw 0x8940, 0xc03d,	0x897f, 0xc03d,		0x21, 0
	.dw 0x89c0, 0xc03d,	0x89ff, 0xc03d,		0x21, 0
	.dw 0x8a40, 0xc03d,	0x8a7f, 0xc03d,		0x21, 0
	.dw 0x8ac0, 0xc03d,	0x8aff, 0xc03d,		0x21, 0
	.dw 0x8b40, 0xc03d,	0x8b7f, 0xc03d,		0x21, 0
	.dw 0x8bc0, 0xc03d,	0x8bff, 0xc03d,		0x21, 0
	.dw 0x8c40, 0xc03d,	0x8c7f, 0xc03d,		0x21, 0
	.dw 0x8cc0, 0xc03d,	0x8cff, 0xc03d,		0x21, 0
	.dw 0x8d40, 0xc03d,	0x8d7f, 0xc03d,		0x21, 0
	.dw 0x8dc0, 0xc03d,	0x8dff, 0xc03d,		0x21, 0
	.dw 0x8e40, 0xc03d,	0x8e7f, 0xc03d,		0x21, 0
	.dw 0x8ec0, 0xc03d,	0x8eff, 0xc03d,		0x21, 0
	.dw 0x8f40, 0xc03d,	0x8f7f, 0xc03d,		0x21, 0
	.dw 0x8fc0, 0xc03d,	0x8fff, 0xc03d,		0x21, 0
	.dw 0x9040, 0xc03d,	0x907f, 0xc03d,		0x21, 0
	.dw 0x90c0, 0xc03d,	0x90ff, 0xc03d,		0x21, 0
	.dw 0x9140, 0xc03d,	0x917f, 0xc03d,		0x21, 0
	.dw 0x91c0, 0xc03d,	0x91ff, 0xc03d,		0x21, 0
	.dw 0x9240, 0xc03d,	0x927f, 0xc03d,		0x21, 0
	.dw 0x92c0, 0xc03d,	0x92ff, 0xc03d,		0x21, 0
	.dw 0x9340, 0xc03d,	0x937f, 0xc03d,		0x21, 0
	.dw 0x93c0, 0xc03d,	0x93ff, 0xc03d,		0x21, 0
	.dw 0x9440, 0xc03d,	0x947f, 0xc03d,		0x21, 0
	.dw 0x94c0, 0xc03d,	0x94ff, 0xc03d,		0x21, 0
	.dw 0x9540, 0xc03d,	0x957f, 0xc03d,		0x21, 0
	.dw 0x95c0, 0xc03d,	0x95ff, 0xc03d,		0x21, 0
	.dw 0x9640, 0xc03d,	0x967f, 0xc03d,		0x21, 0
	.dw 0x96c0, 0xc03d,	0x96ff, 0xc03d,		0x21, 0
	.dw 0x9740, 0xc03d,	0x977f, 0xc03d,		0x21, 0
	.dw 0x97c0, 0xc03d,	0x97ff, 0xc03d,		0x21, 0
	.dw 0x9840, 0xc03d,	0x987f, 0xc03d,		0x21, 0
	.dw 0x98c0, 0xc03d,	0x98ff, 0xc03d,		0x21, 0
	.dw 0x9940, 0xc03d,	0x997f, 0xc03d,		0x21, 0
	.dw 0x99c0, 0xc03d,	0x9fff, 0xc03d,		0x21, 0
	.dw 0xa040, 0xc03d,	0xa07f, 0xc03d,		0x21, 0
	.dw 0xa0c0, 0xc03d,	0xa0ff, 0xc03d,		0x21, 0
	.dw 0xa140, 0xc03d,	0xa17f, 0xc03d,		0x21, 0
	.dw 0xa1c0, 0xc03d,	0xa1ff, 0xc03d,		0x21, 0
	.dw 0xa240, 0xc03d,	0xa27f, 0xc03d,		0x21, 0
	.dw 0xa2c0, 0xc03d,	0xa2ff, 0xc03d,		0x21, 0
	.dw 0xa340, 0xc03d,	0xa37f, 0xc03d,		0x21, 0
	.dw 0xa3c0, 0xc03d,	0xa3ff, 0xc03d,		0x21, 0
	.dw 0xa440, 0xc03d,	0xa47f, 0xc03d,		0x21, 0
	.dw 0xa4c0, 0xc03d,	0xa4ff, 0xc03d,		0x21, 0
	.dw 0xa540, 0xc03d,	0xa57f, 0xc03d,		0x21, 0
	.dw 0xa5c0, 0xc03d,	0xa5ff, 0xc03d,		0x21, 0
	.dw 0xa640, 0xc03d,	0xa67f, 0xc03d,		0x21, 0
	.dw 0xa6c0, 0xc03d,	0xa6ff, 0xc03d,		0x21, 0
	.dw 0xa740, 0xc03d,	0xa77f, 0xc03d,		0x21, 0
	.dw 0xa7c0, 0xc03d,	0xa7ff, 0xc03d,		0x21, 0
	.dw 0xa840, 0xc03d,	0xa87f, 0xc03d,		0x21, 0
	.dw 0xa8c0, 0xc03d,	0xa8ff, 0xc03d,		0x21, 0
	.dw 0xa940, 0xc03d,	0xa97f, 0xc03d,		0x21, 0
	.dw 0xa9c0, 0xc03d,	0xa9ff, 0xc03d,		0x21, 0
	.dw 0xaa40, 0xc03d,	0xaa7f, 0xc03d,		0x21, 0
	.dw 0xaac0, 0xc03d,	0xaaff, 0xc03d,		0x21, 0
	.dw 0xab40, 0xc03d,	0xab7f, 0xc03d,		0x21, 0
	.dw 0xabc0, 0xc03d,	0xabff, 0xc03d,		0x21, 0
	.dw 0xac40, 0xc03d,	0xac7f, 0xc03d,		0x21, 0
	.dw 0xacc0, 0xc03d,	0xacff, 0xc03d,		0x21, 0
	.dw 0xad40, 0xc03d,	0xad7f, 0xc03d,		0x21, 0
	.dw 0xadc0, 0xc03d,	0xadff, 0xc03d,		0x21, 0
	.dw 0xae40, 0xc03d,	0xae7f, 0xc03d,		0x21, 0
	.dw 0xaec0, 0xc03d,	0xaeff, 0xc03d,		0x21, 0
	.dw 0xaf40, 0xc03d,	0xaf7f, 0xc03d,		0x21, 0
	.dw 0xafc0, 0xc03d,	0xafff, 0xc03d,		0x21, 0
	.dw 0xb040, 0xc03d,	0xb07f, 0xc03d,		0x21, 0
	.dw 0xb0c0, 0xc03d,	0xb0ff, 0xc03d,		0x21, 0
	.dw 0xb140, 0xc03d,	0xb17f, 0xc03d,		0x21, 0
	.dw 0xb1c0, 0xc03d,	0xb1ff, 0xc03d,		0x21, 0
	.dw 0xb240, 0xc03d,	0xb27f, 0xc03d,		0x21, 0
	.dw 0xb2c0, 0xc03d,	0xb2ff, 0xc03d,		0x21, 0
	.dw 0xb340, 0xc03d,	0xb37f, 0xc03d,		0x21, 0
	.dw 0xb3c0, 0xc03d,	0xb3ff, 0xc03d,		0x21, 0
	.dw 0xb440, 0xc03d,	0xb47f, 0xc03d,		0x21, 0
	.dw 0xb4c0, 0xc03d,	0xb4ff, 0xc03d,		0x21, 0
	.dw 0xb540, 0xc03d,	0xb57f, 0xc03d,		0x21, 0
	.dw 0xb5c0, 0xc03d,	0xb5ff, 0xc03d,		0x21, 0
	.dw 0xb640, 0xc03d,	0xb67f, 0xc03d,		0x21, 0
	.dw 0xb6c0, 0xc03d,	0xb6ff, 0xc03d,		0x21, 0
	.dw 0xb740, 0xc03d,	0xb77f, 0xc03d,		0x21, 0
	.dw 0xb7c0, 0xc03d,	0xb7ff, 0xc03d,		0x21, 0
	.dw 0xb840, 0xc03d,	0xb87f, 0xc03d,		0x21, 0
	.dw 0xb8c0, 0xc03d,	0xb8ff, 0xc03d,		0x21, 0
	.dw 0xb940, 0xc03d,	0xb97f, 0xc03d,		0x21, 0
	.dw 0xb9c0, 0xc03d,	0xbfff, 0xc03d,		0x21, 0
	.dw 0xc040, 0xc03d,	0xc07f, 0xc03d,		0x21, 0
	.dw 0xc0c0, 0xc03d,	0xc0ff, 0xc03d,		0x21, 0
	.dw 0xc140, 0xc03d,	0xc17f, 0xc03d,		0x21, 0
	.dw 0xc1c0, 0xc03d,	0xc1ff, 0xc03d,		0x21, 0
	.dw 0xc240, 0xc03d,	0xc27f, 0xc03d,		0x21, 0
	.dw 0xc2c0, 0xc03d,	0xc2ff, 0xc03d,		0x21, 0
	.dw 0xc340, 0xc03d,	0xc37f, 0xc03d,		0x21, 0
	.dw 0xc3c0, 0xc03d,	0xc3ff, 0xc03d,		0x21, 0
	.dw 0xc440, 0xc03d,	0xc47f, 0xc03d,		0x21, 0
	.dw 0xc4c0, 0xc03d,	0xc4ff, 0xc03d,		0x21, 0
	.dw 0xc540, 0xc03d,	0xc57f, 0xc03d,		0x21, 0
	.dw 0xc5c0, 0xc03d,	0xc5ff, 0xc03d,		0x21, 0
	.dw 0xc640, 0xc03d,	0xc67f, 0xc03d,		0x21, 0
	.dw 0xc6c0, 0xc03d,	0xc6ff, 0xc03d,		0x21, 0
	.dw 0xc740, 0xc03d,	0xc77f, 0xc03d,		0x21, 0
	.dw 0xc7c0, 0xc03d,	0xc7ff, 0xc03d,		0x21, 0
	.dw 0xc840, 0xc03d,	0xc87f, 0xc03d,		0x21, 0
	.dw 0xc8c0, 0xc03d,	0xc8ff, 0xc03d,		0x21, 0
	.dw 0xc940, 0xc03d,	0xc97f, 0xc03d,		0x21, 0
	.dw 0xc9c0, 0xc03d,	0xc9ff, 0xc03d,		0x21, 0
	.dw 0xca40, 0xc03d,	0xca7f, 0xc03d,		0x21, 0
	.dw 0xcac0, 0xc03d,	0xcaff, 0xc03d,		0x21, 0
	.dw 0xcb40, 0xc03d,	0xcb7f, 0xc03d,		0x21, 0
	.dw 0xcbc0, 0xc03d,	0xcbff, 0xc03d,		0x21, 0
	.dw 0xcc40, 0xc03d,	0xcc7f, 0xc03d,		0x21, 0
	.dw 0xccc0, 0xc03d,	0xccff, 0xc03d,		0x21, 0
	.dw 0xcd40, 0xc03d,	0xcd7f, 0xc03d,		0x21, 0
	.dw 0xcdc0, 0xc03d,	0xcdff, 0xc03d,		0x21, 0
	.dw 0xce40, 0xc03d,	0xce7f, 0xc03d,		0x21, 0
	.dw 0xcec0, 0xc03d,	0xceff, 0xc03d,		0x21, 0
	.dw 0xcf40, 0xc03d,	0xcf7f, 0xc03d,		0x21, 0
	.dw 0xcfc0, 0xc03d,	0xcfff, 0xc03d,		0x21, 0
	.dw 0xd040, 0xc03d,	0xd07f, 0xc03d,		0x21, 0
	.dw 0xd0c0, 0xc03d,	0xd0ff, 0xc03d,		0x21, 0
	.dw 0xd140, 0xc03d,	0xd17f, 0xc03d,		0x21, 0
	.dw 0xd1c0, 0xc03d,	0xd1ff, 0xc03d,		0x21, 0
	.dw 0xd240, 0xc03d,	0xd27f, 0xc03d,		0x21, 0
	.dw 0xd2c0, 0xc03d,	0xd2ff, 0xc03d,		0x21, 0
	.dw 0xd340, 0xc03d,	0xd37f, 0xc03d,		0x21, 0
	.dw 0xd3c0, 0xc03d,	0xd3ff, 0xc03d,		0x21, 0
	.dw 0xd440, 0xc03d,	0xd47f, 0xc03d,		0x21, 0
	.dw 0xd4c0, 0xc03d,	0xd4ff, 0xc03d,		0x21, 0
	.dw 0xd540, 0xc03d,	0xd57f, 0xc03d,		0x21, 0
	.dw 0xd5c0, 0xc03d,	0xd5ff, 0xc03d,		0x21, 0
	.dw 0xd640, 0xc03d,	0xd67f, 0xc03d,		0x21, 0
	.dw 0xd6c0, 0xc03d,	0xd6ff, 0xc03d,		0x21, 0
	.dw 0xd740, 0xc03d,	0xd77f, 0xc03d,		0x21, 0
	.dw 0xd7c0, 0xc03d,	0xd7ff, 0xc03d,		0x21, 0
	.dw 0xd840, 0xc03d,	0xd87f, 0xc03d,		0x21, 0
	.dw 0xd8c0, 0xc03d,	0xd8ff, 0xc03d,		0x21, 0
	.dw 0xd940, 0xc03d,	0xd97f, 0xc03d,		0x21, 0
	.dw 0xd9c0, 0xc03d,	0xdfff, 0xc03d,		0x21, 0
	.dw 0xe040, 0xc03d,	0xe07f, 0xc03d,		0x21, 0
	.dw 0xe0c0, 0xc03d,	0xe0ff, 0xc03d,		0x21, 0
	.dw 0xe140, 0xc03d,	0xe17f, 0xc03d,		0x21, 0
	.dw 0xe1c0, 0xc03d,	0xe1ff, 0xc03d,		0x21, 0
	.dw 0xe240, 0xc03d,	0xe27f, 0xc03d,		0x21, 0
	.dw 0xe2c0, 0xc03d,	0xe2ff, 0xc03d,		0x21, 0
	.dw 0xe340, 0xc03d,	0xe37f, 0xc03d,		0x21, 0
	.dw 0xe3c0, 0xc03d,	0xe3ff, 0xc03d,		0x21, 0
	.dw 0xe440, 0xc03d,	0xe47f, 0xc03d,		0x21, 0
	.dw 0xe4c0, 0xc03d,	0xe4ff, 0xc03d,		0x21, 0
	.dw 0xe540, 0xc03d,	0xe57f, 0xc03d,		0x21, 0
	.dw 0xe5c0, 0xc03d,	0xe5ff, 0xc03d,		0x21, 0
	.dw 0xe640, 0xc03d,	0xe67f, 0xc03d,		0x21, 0
	.dw 0xe6c0, 0xc03d,	0xe6ff, 0xc03d,		0x21, 0
	.dw 0xe740, 0xc03d,	0xe77f, 0xc03d,		0x21, 0
	.dw 0xe7c0, 0xc03d,	0xe7ff, 0xc03d,		0x21, 0
	.dw 0xe840, 0xc03d,	0xe87f, 0xc03d,		0x21, 0
	.dw 0xe8c0, 0xc03d,	0xe8ff, 0xc03d,		0x21, 0
	.dw 0xe940, 0xc03d,	0xe97f, 0xc03d,		0x21, 0
	.dw 0xe9c0, 0xc03d,	0xe9ff, 0xc03d,		0x21, 0
	.dw 0xea40, 0xc03d,	0xea7f, 0xc03d,		0x21, 0
	.dw 0xeac0, 0xc03d,	0xeaff, 0xc03d,		0x21, 0
	.dw 0xeb40, 0xc03d,	0xeb7f, 0xc03d,		0x21, 0
	.dw 0xebc0, 0xc03d,	0xebff, 0xc03d,		0x21, 0
	.dw 0xec40, 0xc03d,	0xec7f, 0xc03d,		0x21, 0
	.dw 0xecc0, 0xc03d,	0xecff, 0xc03d,		0x21, 0
	.dw 0xed40, 0xc03d,	0xed7f, 0xc03d,		0x21, 0
	.dw 0xedc0, 0xc03d,	0xedff, 0xc03d,		0x21, 0
	.dw 0xee40, 0xc03d,	0xee7f, 0xc03d,		0x21, 0
	.dw 0xeec0, 0xc03d,	0xeeff, 0xc03d,		0x21, 0
	.dw 0xef40, 0xc03d,	0xef7f, 0xc03d,		0x21, 0
	.dw 0xefc0, 0xc03d,	0xefff, 0xc03d,		0x21, 0
	.dw 0xf040, 0xc03d,	0xf07f, 0xc03d,		0x21, 0
	.dw 0xf0c0, 0xc03d,	0xf0ff, 0xc03d,		0x21, 0
	.dw 0xf140, 0xc03d,	0xf17f, 0xc03d,		0x21, 0
	.dw 0xf1c0, 0xc03d,	0xf1ff, 0xc03d,		0x21, 0
	.dw 0xf240, 0xc03d,	0xf27f, 0xc03d,		0x21, 0
	.dw 0xf2c0, 0xc03d,	0xf2ff, 0xc03d,		0x21, 0
	.dw 0xf340, 0xc03d,	0xf37f, 0xc03d,		0x21, 0
	.dw 0xf3c0, 0xc03d,	0xf3ff, 0xc03d,		0x21, 0
	.dw 0xf440, 0xc03d,	0xf47f, 0xc03d,		0x21, 0
	.dw 0xf4c0, 0xc03d,	0xf4ff, 0xc03d,		0x21, 0
	.dw 0xf540, 0xc03d,	0xf57f, 0xc03d,		0x21, 0
	.dw 0xf5c0, 0xc03d,	0xf5ff, 0xc03d,		0x21, 0
	.dw 0xf640, 0xc03d,	0xf67f, 0xc03d,		0x21, 0
	.dw 0xf6c0, 0xc03d,	0xf6ff, 0xc03d,		0x21, 0
	.dw 0xf740, 0xc03d,	0xf77f, 0xc03d,		0x21, 0
	.dw 0xf7c0, 0xc03d,	0xf7ff, 0xc03d,		0x21, 0
	.dw 0xf840, 0xc03d,	0xf87f, 0xc03d,		0x21, 0
	.dw 0xf8c0, 0xc03d,	0xf8ff, 0xc03d,		0x21, 0
	.dw 0xf940, 0xc03d,	0xf97f, 0xc03d,		0x21, 0
	.dw 0xf9c0, 0xc03d,	0xffff, 0xc03d,		0x21, 0
	.dw 0x0040, 0xc03e,	0x007f, 0xc03e,		0x21, 0
	.dw 0x00c0, 0xc03e,	0x00ff, 0xc03e,		0x21, 0
	.dw 0x0140, 0xc03e,	0x017f, 0xc03e,		0x21, 0
	.dw 0x01c0, 0xc03e,	0x01ff, 0xc03e,		0x21, 0
	.dw 0x0240, 0xc03e,	0x027f, 0xc03e,		0x21, 0
	.dw 0x02c0, 0xc03e,	0x02ff, 0xc03e,		0x21, 0
	.dw 0x0340, 0xc03e,	0x037f, 0xc03e,		0x21, 0
	.dw 0x03c0, 0xc03e,	0x03ff, 0xc03e,		0x21, 0
	.dw 0x0440, 0xc03e,	0x047f, 0xc03e,		0x21, 0
	.dw 0x04c0, 0xc03e,	0x04ff, 0xc03e,		0x21, 0
	.dw 0x0540, 0xc03e,	0x057f, 0xc03e,		0x21, 0
	.dw 0x05c0, 0xc03e,	0x05ff, 0xc03e,		0x21, 0
	.dw 0x0640, 0xc03e,	0x067f, 0xc03e,		0x21, 0
	.dw 0x06c0, 0xc03e,	0x06ff, 0xc03e,		0x21, 0
	.dw 0x0740, 0xc03e,	0x077f, 0xc03e,		0x21, 0
	.dw 0x07c0, 0xc03e,	0x07ff, 0xc03e,		0x21, 0
	.dw 0x0840, 0xc03e,	0x087f, 0xc03e,		0x21, 0
	.dw 0x08c0, 0xc03e,	0x08ff, 0xc03e,		0x21, 0
	.dw 0x0940, 0xc03e,	0x097f, 0xc03e,		0x21, 0
	.dw 0x09c0, 0xc03e,	0x09ff, 0xc03e,		0x21, 0
	.dw 0x0a40, 0xc03e,	0x0a7f, 0xc03e,		0x21, 0
	.dw 0x0ac0, 0xc03e,	0x0aff, 0xc03e,		0x21, 0
	.dw 0x0b40, 0xc03e,	0x0b7f, 0xc03e,		0x21, 0
	.dw 0x0bc0, 0xc03e,	0x0bff, 0xc03e,		0x21, 0
	.dw 0x0c40, 0xc03e,	0x0c7f, 0xc03e,		0x21, 0
	.dw 0x0cc0, 0xc03e,	0x0cff, 0xc03e,		0x21, 0
	.dw 0x0d40, 0xc03e,	0x0d7f, 0xc03e,		0x21, 0
	.dw 0x0dc0, 0xc03e,	0x0dff, 0xc03e,		0x21, 0
	.dw 0x0e40, 0xc03e,	0x0e7f, 0xc03e,		0x21, 0
	.dw 0x0ec0, 0xc03e,	0x0eff, 0xc03e,		0x21, 0
	.dw 0x0f40, 0xc03e,	0x0f7f, 0xc03e,		0x21, 0
	.dw 0x0fc0, 0xc03e,	0x0fff, 0xc03e,		0x21, 0
	.dw 0x1040, 0xc03e,	0x107f, 0xc03e,		0x21, 0
	.dw 0x10c0, 0xc03e,	0x10ff, 0xc03e,		0x21, 0
	.dw 0x1140, 0xc03e,	0x117f, 0xc03e,		0x21, 0
	.dw 0x11c0, 0xc03e,	0x11ff, 0xc03e,		0x21, 0
	.dw 0x1240, 0xc03e,	0x127f, 0xc03e,		0x21, 0
	.dw 0x12c0, 0xc03e,	0x12ff, 0xc03e,		0x21, 0
	.dw 0x1340, 0xc03e,	0x137f, 0xc03e,		0x21, 0
	.dw 0x13c0, 0xc03e,	0x13ff, 0xc03e,		0x21, 0
	.dw 0x1440, 0xc03e,	0x147f, 0xc03e,		0x21, 0
	.dw 0x14c0, 0xc03e,	0x14ff, 0xc03e,		0x21, 0
	.dw 0x1540, 0xc03e,	0x157f, 0xc03e,		0x21, 0
	.dw 0x15c0, 0xc03e,	0x15ff, 0xc03e,		0x21, 0
	.dw 0x1640, 0xc03e,	0x167f, 0xc03e,		0x21, 0
	.dw 0x16c0, 0xc03e,	0x16ff, 0xc03e,		0x21, 0
	.dw 0x1740, 0xc03e,	0x177f, 0xc03e,		0x21, 0
	.dw 0x17c0, 0xc03e,	0x17ff, 0xc03e,		0x21, 0
	.dw 0x1840, 0xc03e,	0x187f, 0xc03e,		0x21, 0
	.dw 0x18c0, 0xc03e,	0x18ff, 0xc03e,		0x21, 0
	.dw 0x1940, 0xc03e,	0x197f, 0xc03e,		0x21, 0
	.dw 0x19c0, 0xc03e,	0x1fff, 0xc03e,		0x21, 0
	.dw 0x2040, 0xc03e,	0x207f, 0xc03e,		0x21, 0
	.dw 0x20c0, 0xc03e,	0x20ff, 0xc03e,		0x21, 0
	.dw 0x2140, 0xc03e,	0x217f, 0xc03e,		0x21, 0
	.dw 0x21c0, 0xc03e,	0x21ff, 0xc03e,		0x21, 0
	.dw 0x2240, 0xc03e,	0x227f, 0xc03e,		0x21, 0
	.dw 0x22c0, 0xc03e,	0x22ff, 0xc03e,		0x21, 0
	.dw 0x2340, 0xc03e,	0x237f, 0xc03e,		0x21, 0
	.dw 0x23c0, 0xc03e,	0x23ff, 0xc03e,		0x21, 0
	.dw 0x2440, 0xc03e,	0x247f, 0xc03e,		0x21, 0
	.dw 0x24c0, 0xc03e,	0x24ff, 0xc03e,		0x21, 0
	.dw 0x2540, 0xc03e,	0x257f, 0xc03e,		0x21, 0
	.dw 0x25c0, 0xc03e,	0x25ff, 0xc03e,		0x21, 0
	.dw 0x2640, 0xc03e,	0x267f, 0xc03e,		0x21, 0
	.dw 0x26c0, 0xc03e,	0x26ff, 0xc03e,		0x21, 0
	.dw 0x2740, 0xc03e,	0x277f, 0xc03e,		0x21, 0
	.dw 0x27c0, 0xc03e,	0x27ff, 0xc03e,		0x21, 0
	.dw 0x2840, 0xc03e,	0x287f, 0xc03e,		0x21, 0
	.dw 0x28c0, 0xc03e,	0x28ff, 0xc03e,		0x21, 0
	.dw 0x2940, 0xc03e,	0x297f, 0xc03e,		0x21, 0
	.dw 0x29c0, 0xc03e,	0x29ff, 0xc03e,		0x21, 0
	.dw 0x2a40, 0xc03e,	0x2a7f, 0xc03e,		0x21, 0
	.dw 0x2ac0, 0xc03e,	0x2aff, 0xc03e,		0x21, 0
	.dw 0x2b40, 0xc03e,	0x2b7f, 0xc03e,		0x21, 0
	.dw 0x2bc0, 0xc03e,	0x2bff, 0xc03e,		0x21, 0
	.dw 0x2c40, 0xc03e,	0x2c7f, 0xc03e,		0x21, 0
	.dw 0x2cc0, 0xc03e,	0x2cff, 0xc03e,		0x21, 0
	.dw 0x2d40, 0xc03e,	0x2d7f, 0xc03e,		0x21, 0
	.dw 0x2dc0, 0xc03e,	0x2dff, 0xc03e,		0x21, 0
	.dw 0x2e40, 0xc03e,	0x2e7f, 0xc03e,		0x21, 0
	.dw 0x2ec0, 0xc03e,	0x2eff, 0xc03e,		0x21, 0
	.dw 0x2f40, 0xc03e,	0x2f7f, 0xc03e,		0x21, 0
	.dw 0x2fc0, 0xc03e,	0x2fff, 0xc03e,		0x21, 0
	.dw 0x3040, 0xc03e,	0x307f, 0xc03e,		0x21, 0
	.dw 0x30c0, 0xc03e,	0x30ff, 0xc03e,		0x21, 0
	.dw 0x3140, 0xc03e,	0x317f, 0xc03e,		0x21, 0
	.dw 0x31c0, 0xc03e,	0x31ff, 0xc03e,		0x21, 0
	.dw 0x3240, 0xc03e,	0x327f, 0xc03e,		0x21, 0
	.dw 0x32c0, 0xc03e,	0x32ff, 0xc03e,		0x21, 0
	.dw 0x3340, 0xc03e,	0x337f, 0xc03e,		0x21, 0
	.dw 0x33c0, 0xc03e,	0x33ff, 0xc03e,		0x21, 0
	.dw 0x3440, 0xc03e,	0x347f, 0xc03e,		0x21, 0
	.dw 0x34c0, 0xc03e,	0x34ff, 0xc03e,		0x21, 0
	.dw 0x3540, 0xc03e,	0x357f, 0xc03e,		0x21, 0
	.dw 0x35c0, 0xc03e,	0x35ff, 0xc03e,		0x21, 0
	.dw 0x3640, 0xc03e,	0x367f, 0xc03e,		0x21, 0
	.dw 0x36c0, 0xc03e,	0x36ff, 0xc03e,		0x21, 0
	.dw 0x3740, 0xc03e,	0x377f, 0xc03e,		0x21, 0
	.dw 0x37c0, 0xc03e,	0x37ff, 0xc03e,		0x21, 0
	.dw 0x3840, 0xc03e,	0x387f, 0xc03e,		0x21, 0
	.dw 0x38c0, 0xc03e,	0x38ff, 0xc03e,		0x21, 0
	.dw 0x3940, 0xc03e,	0x397f, 0xc03e,		0x21, 0
	.dw 0x39c0, 0xc03e,	0x3fff, 0xc03e,		0x21, 0
	.dw 0x4040, 0xc03e,	0x407f, 0xc03e,		0x21, 0
	.dw 0x40c0, 0xc03e,	0x40ff, 0xc03e,		0x21, 0
	.dw 0x4140, 0xc03e,	0x417f, 0xc03e,		0x21, 0
	.dw 0x41c0, 0xc03e,	0x41ff, 0xc03e,		0x21, 0
	.dw 0x4240, 0xc03e,	0x427f, 0xc03e,		0x21, 0
	.dw 0x42c0, 0xc03e,	0x42ff, 0xc03e,		0x21, 0
	.dw 0x4340, 0xc03e,	0x437f, 0xc03e,		0x21, 0
	.dw 0x43c0, 0xc03e,	0x43ff, 0xc03e,		0x21, 0
	.dw 0x4440, 0xc03e,	0x447f, 0xc03e,		0x21, 0
	.dw 0x44c0, 0xc03e,	0x44ff, 0xc03e,		0x21, 0
	.dw 0x4540, 0xc03e,	0x457f, 0xc03e,		0x21, 0
	.dw 0x45c0, 0xc03e,	0x45ff, 0xc03e,		0x21, 0
	.dw 0x4640, 0xc03e,	0x467f, 0xc03e,		0x21, 0
	.dw 0x46c0, 0xc03e,	0x46ff, 0xc03e,		0x21, 0
	.dw 0x4740, 0xc03e,	0x477f, 0xc03e,		0x21, 0
	.dw 0x47c0, 0xc03e,	0x47ff, 0xc03e,		0x21, 0
	.dw 0x4840, 0xc03e,	0x487f, 0xc03e,		0x21, 0
	.dw 0x48c0, 0xc03e,	0x48ff, 0xc03e,		0x21, 0
	.dw 0x4940, 0xc03e,	0x497f, 0xc03e,		0x21, 0
	.dw 0x49c0, 0xc03e,	0x49ff, 0xc03e,		0x21, 0
	.dw 0x4a40, 0xc03e,	0x4a7f, 0xc03e,		0x21, 0
	.dw 0x4ac0, 0xc03e,	0x4aff, 0xc03e,		0x21, 0
	.dw 0x4b40, 0xc03e,	0x4b7f, 0xc03e,		0x21, 0
	.dw 0x4bc0, 0xc03e,	0x4bff, 0xc03e,		0x21, 0
	.dw 0x4c40, 0xc03e,	0x4c7f, 0xc03e,		0x21, 0
	.dw 0x4cc0, 0xc03e,	0x4cff, 0xc03e,		0x21, 0
	.dw 0x4d40, 0xc03e,	0x4d7f, 0xc03e,		0x21, 0
	.dw 0x4dc0, 0xc03e,	0x4dff, 0xc03e,		0x21, 0
	.dw 0x4e40, 0xc03e,	0x4e7f, 0xc03e,		0x21, 0
	.dw 0x4ec0, 0xc03e,	0x4eff, 0xc03e,		0x21, 0
	.dw 0x4f40, 0xc03e,	0x4f7f, 0xc03e,		0x21, 0
	.dw 0x4fc0, 0xc03e,	0x4fff, 0xc03e,		0x21, 0
	.dw 0x5040, 0xc03e,	0x507f, 0xc03e,		0x21, 0
	.dw 0x50c0, 0xc03e,	0x50ff, 0xc03e,		0x21, 0
	.dw 0x5140, 0xc03e,	0x517f, 0xc03e,		0x21, 0
	.dw 0x51c0, 0xc03e,	0x51ff, 0xc03e,		0x21, 0
	.dw 0x5240, 0xc03e,	0x527f, 0xc03e,		0x21, 0
	.dw 0x52c0, 0xc03e,	0x52ff, 0xc03e,		0x21, 0
	.dw 0x5340, 0xc03e,	0x537f, 0xc03e,		0x21, 0
	.dw 0x53c0, 0xc03e,	0x53ff, 0xc03e,		0x21, 0
	.dw 0x5440, 0xc03e,	0x547f, 0xc03e,		0x21, 0
	.dw 0x54c0, 0xc03e,	0x54ff, 0xc03e,		0x21, 0
	.dw 0x5540, 0xc03e,	0x557f, 0xc03e,		0x21, 0
	.dw 0x55c0, 0xc03e,	0x55ff, 0xc03e,		0x21, 0
	.dw 0x5640, 0xc03e,	0x567f, 0xc03e,		0x21, 0
	.dw 0x56c0, 0xc03e,	0x56ff, 0xc03e,		0x21, 0
	.dw 0x5740, 0xc03e,	0x577f, 0xc03e,		0x21, 0
	.dw 0x57c0, 0xc03e,	0x57ff, 0xc03e,		0x21, 0
	.dw 0x5840, 0xc03e,	0x587f, 0xc03e,		0x21, 0
	.dw 0x58c0, 0xc03e,	0x58ff, 0xc03e,		0x21, 0
	.dw 0x5940, 0xc03e,	0x597f, 0xc03e,		0x21, 0
	.dw 0x59c0, 0xc03e,	0x5fff, 0xc03e,		0x21, 0
	.dw 0x6040, 0xc03e,	0x607f, 0xc03e,		0x21, 0
	.dw 0x60c0, 0xc03e,	0x60ff, 0xc03e,		0x21, 0
	.dw 0x6140, 0xc03e,	0x617f, 0xc03e,		0x21, 0
	.dw 0x61c0, 0xc03e,	0x61ff, 0xc03e,		0x21, 0
	.dw 0x6240, 0xc03e,	0x627f, 0xc03e,		0x21, 0
	.dw 0x62c0, 0xc03e,	0x62ff, 0xc03e,		0x21, 0
	.dw 0x6340, 0xc03e,	0x637f, 0xc03e,		0x21, 0
	.dw 0x63c0, 0xc03e,	0x63ff, 0xc03e,		0x21, 0
	.dw 0x6440, 0xc03e,	0x647f, 0xc03e,		0x21, 0
	.dw 0x64c0, 0xc03e,	0x64ff, 0xc03e,		0x21, 0
	.dw 0x6540, 0xc03e,	0x657f, 0xc03e,		0x21, 0
	.dw 0x65c0, 0xc03e,	0x65ff, 0xc03e,		0x21, 0
	.dw 0x6640, 0xc03e,	0x667f, 0xc03e,		0x21, 0
	.dw 0x66c0, 0xc03e,	0x66ff, 0xc03e,		0x21, 0
	.dw 0x6740, 0xc03e,	0x677f, 0xc03e,		0x21, 0
	.dw 0x67c0, 0xc03e,	0x67ff, 0xc03e,		0x21, 0
	.dw 0x6840, 0xc03e,	0x687f, 0xc03e,		0x21, 0
	.dw 0x68c0, 0xc03e,	0x68ff, 0xc03e,		0x21, 0
	.dw 0x6940, 0xc03e,	0x697f, 0xc03e,		0x21, 0
	.dw 0x69c0, 0xc03e,	0x69ff, 0xc03e,		0x21, 0
	.dw 0x6a40, 0xc03e,	0x6a7f, 0xc03e,		0x21, 0
	.dw 0x6ac0, 0xc03e,	0x6aff, 0xc03e,		0x21, 0
	.dw 0x6b40, 0xc03e,	0x6b7f, 0xc03e,		0x21, 0
	.dw 0x6bc0, 0xc03e,	0x6bff, 0xc03e,		0x21, 0
	.dw 0x6c40, 0xc03e,	0x6c7f, 0xc03e,		0x21, 0
	.dw 0x6cc0, 0xc03e,	0x6cff, 0xc03e,		0x21, 0
	.dw 0x6d40, 0xc03e,	0x6d7f, 0xc03e,		0x21, 0
	.dw 0x6dc0, 0xc03e,	0x6dff, 0xc03e,		0x21, 0
	.dw 0x6e40, 0xc03e,	0x6e7f, 0xc03e,		0x21, 0
	.dw 0x6ec0, 0xc03e,	0x6eff, 0xc03e,		0x21, 0
	.dw 0x6f40, 0xc03e,	0x6f7f, 0xc03e,		0x21, 0
	.dw 0x6fc0, 0xc03e,	0x6fff, 0xc03e,		0x21, 0
	.dw 0x7040, 0xc03e,	0x707f, 0xc03e,		0x21, 0
	.dw 0x70c0, 0xc03e,	0x70ff, 0xc03e,		0x21, 0
	.dw 0x7140, 0xc03e,	0x717f, 0xc03e,		0x21, 0
	.dw 0x71c0, 0xc03e,	0x71ff, 0xc03e,		0x21, 0
	.dw 0x7240, 0xc03e,	0x727f, 0xc03e,		0x21, 0
	.dw 0x72c0, 0xc03e,	0x72ff, 0xc03e,		0x21, 0
	.dw 0x7340, 0xc03e,	0x737f, 0xc03e,		0x21, 0
	.dw 0x73c0, 0xc03e,	0x73ff, 0xc03e,		0x21, 0
	.dw 0x7440, 0xc03e,	0x747f, 0xc03e,		0x21, 0
	.dw 0x74c0, 0xc03e,	0x74ff, 0xc03e,		0x21, 0
	.dw 0x7540, 0xc03e,	0x757f, 0xc03e,		0x21, 0
	.dw 0x75c0, 0xc03e,	0x75ff, 0xc03e,		0x21, 0
	.dw 0x7640, 0xc03e,	0x767f, 0xc03e,		0x21, 0
	.dw 0x76c0, 0xc03e,	0x76ff, 0xc03e,		0x21, 0
	.dw 0x7740, 0xc03e,	0x777f, 0xc03e,		0x21, 0
	.dw 0x77c0, 0xc03e,	0x77ff, 0xc03e,		0x21, 0
	.dw 0x7840, 0xc03e,	0x787f, 0xc03e,		0x21, 0
	.dw 0x78c0, 0xc03e,	0x78ff, 0xc03e,		0x21, 0
	.dw 0x7940, 0xc03e,	0x797f, 0xc03e,		0x21, 0
	.dw 0x79c0, 0xc03e,	0x7fff, 0xc03e,		0x21, 0
	.dw 0x8040, 0xc03e,	0x807f, 0xc03e,		0x21, 0
	.dw 0x80c0, 0xc03e,	0x80ff, 0xc03e,		0x21, 0
	.dw 0x8140, 0xc03e,	0x817f, 0xc03e,		0x21, 0
	.dw 0x81c0, 0xc03e,	0x81ff, 0xc03e,		0x21, 0
	.dw 0x8240, 0xc03e,	0x827f, 0xc03e,		0x21, 0
	.dw 0x82c0, 0xc03e,	0x82ff, 0xc03e,		0x21, 0
	.dw 0x8340, 0xc03e,	0x837f, 0xc03e,		0x21, 0
	.dw 0x83c0, 0xc03e,	0x83ff, 0xc03e,		0x21, 0
	.dw 0x8440, 0xc03e,	0x847f, 0xc03e,		0x21, 0
	.dw 0x84c0, 0xc03e,	0x84ff, 0xc03e,		0x21, 0
	.dw 0x8540, 0xc03e,	0x857f, 0xc03e,		0x21, 0
	.dw 0x85c0, 0xc03e,	0x85ff, 0xc03e,		0x21, 0
	.dw 0x8640, 0xc03e,	0x867f, 0xc03e,		0x21, 0
	.dw 0x86c0, 0xc03e,	0x86ff, 0xc03e,		0x21, 0
	.dw 0x8740, 0xc03e,	0x877f, 0xc03e,		0x21, 0
	.dw 0x87c0, 0xc03e,	0x87ff, 0xc03e,		0x21, 0
	.dw 0x8840, 0xc03e,	0x887f, 0xc03e,		0x21, 0
	.dw 0x88c0, 0xc03e,	0x88ff, 0xc03e,		0x21, 0
	.dw 0x8940, 0xc03e,	0x897f, 0xc03e,		0x21, 0
	.dw 0x89c0, 0xc03e,	0x89ff, 0xc03e,		0x21, 0
	.dw 0x8a40, 0xc03e,	0x8a7f, 0xc03e,		0x21, 0
	.dw 0x8ac0, 0xc03e,	0x8aff, 0xc03e,		0x21, 0
	.dw 0x8b40, 0xc03e,	0x8b7f, 0xc03e,		0x21, 0
	.dw 0x8bc0, 0xc03e,	0x8bff, 0xc03e,		0x21, 0
	.dw 0x8c40, 0xc03e,	0x8c7f, 0xc03e,		0x21, 0
	.dw 0x8cc0, 0xc03e,	0x8cff, 0xc03e,		0x21, 0
	.dw 0x8d40, 0xc03e,	0x8d7f, 0xc03e,		0x21, 0
	.dw 0x8dc0, 0xc03e,	0x8dff, 0xc03e,		0x21, 0
	.dw 0x8e40, 0xc03e,	0x8e7f, 0xc03e,		0x21, 0
	.dw 0x8ec0, 0xc03e,	0x8eff, 0xc03e,		0x21, 0
	.dw 0x8f40, 0xc03e,	0x8f7f, 0xc03e,		0x21, 0
	.dw 0x8fc0, 0xc03e,	0x8fff, 0xc03e,		0x21, 0
	.dw 0x9040, 0xc03e,	0x907f, 0xc03e,		0x21, 0
	.dw 0x90c0, 0xc03e,	0x90ff, 0xc03e,		0x21, 0
	.dw 0x9140, 0xc03e,	0x917f, 0xc03e,		0x21, 0
	.dw 0x91c0, 0xc03e,	0x91ff, 0xc03e,		0x21, 0
	.dw 0x9240, 0xc03e,	0x927f, 0xc03e,		0x21, 0
	.dw 0x92c0, 0xc03e,	0x92ff, 0xc03e,		0x21, 0
	.dw 0x9340, 0xc03e,	0x937f, 0xc03e,		0x21, 0
	.dw 0x93c0, 0xc03e,	0x93ff, 0xc03e,		0x21, 0
	.dw 0x9440, 0xc03e,	0x947f, 0xc03e,		0x21, 0
	.dw 0x94c0, 0xc03e,	0x94ff, 0xc03e,		0x21, 0
	.dw 0x9540, 0xc03e,	0x957f, 0xc03e,		0x21, 0
	.dw 0x95c0, 0xc03e,	0x95ff, 0xc03e,		0x21, 0
	.dw 0x9640, 0xc03e,	0x967f, 0xc03e,		0x21, 0
	.dw 0x96c0, 0xc03e,	0x96ff, 0xc03e,		0x21, 0
	.dw 0x9740, 0xc03e,	0x977f, 0xc03e,		0x21, 0
	.dw 0x97c0, 0xc03e,	0x97ff, 0xc03e,		0x21, 0
	.dw 0x9840, 0xc03e,	0x987f, 0xc03e,		0x21, 0
	.dw 0x98c0, 0xc03e,	0x98ff, 0xc03e,		0x21, 0
	.dw 0x9940, 0xc03e,	0x997f, 0xc03e,		0x21, 0
	.dw 0x99c0, 0xc03e,	0x9fff, 0xc03e,		0x21, 0
	.dw 0xa040, 0xc03e,	0xa07f, 0xc03e,		0x21, 0
	.dw 0xa0c0, 0xc03e,	0xa0ff, 0xc03e,		0x21, 0
	.dw 0xa140, 0xc03e,	0xa17f, 0xc03e,		0x21, 0
	.dw 0xa1c0, 0xc03e,	0xa1ff, 0xc03e,		0x21, 0
	.dw 0xa240, 0xc03e,	0xa27f, 0xc03e,		0x21, 0
	.dw 0xa2c0, 0xc03e,	0xa2ff, 0xc03e,		0x21, 0
	.dw 0xa340, 0xc03e,	0xa37f, 0xc03e,		0x21, 0
	.dw 0xa3c0, 0xc03e,	0xa3ff, 0xc03e,		0x21, 0
	.dw 0xa440, 0xc03e,	0xa47f, 0xc03e,		0x21, 0
	.dw 0xa4c0, 0xc03e,	0xa4ff, 0xc03e,		0x21, 0
	.dw 0xa540, 0xc03e,	0xa57f, 0xc03e,		0x21, 0
	.dw 0xa5c0, 0xc03e,	0xa5ff, 0xc03e,		0x21, 0
	.dw 0xa640, 0xc03e,	0xa67f, 0xc03e,		0x21, 0
	.dw 0xa6c0, 0xc03e,	0xa6ff, 0xc03e,		0x21, 0
	.dw 0xa740, 0xc03e,	0xa77f, 0xc03e,		0x21, 0
	.dw 0xa7c0, 0xc03e,	0xa7ff, 0xc03e,		0x21, 0
	.dw 0xa840, 0xc03e,	0xa87f, 0xc03e,		0x21, 0
	.dw 0xa8c0, 0xc03e,	0xa8ff, 0xc03e,		0x21, 0
	.dw 0xa940, 0xc03e,	0xa97f, 0xc03e,		0x21, 0
	.dw 0xa9c0, 0xc03e,	0xa9ff, 0xc03e,		0x21, 0
	.dw 0xaa40, 0xc03e,	0xaa7f, 0xc03e,		0x21, 0
	.dw 0xaac0, 0xc03e,	0xaaff, 0xc03e,		0x21, 0
	.dw 0xab40, 0xc03e,	0xab7f, 0xc03e,		0x21, 0
	.dw 0xabc0, 0xc03e,	0xabff, 0xc03e,		0x21, 0
	.dw 0xac40, 0xc03e,	0xac7f, 0xc03e,		0x21, 0
	.dw 0xacc0, 0xc03e,	0xacff, 0xc03e,		0x21, 0
	.dw 0xad40, 0xc03e,	0xad7f, 0xc03e,		0x21, 0
	.dw 0xadc0, 0xc03e,	0xadff, 0xc03e,		0x21, 0
	.dw 0xae40, 0xc03e,	0xae7f, 0xc03e,		0x21, 0
	.dw 0xaec0, 0xc03e,	0xaeff, 0xc03e,		0x21, 0
	.dw 0xaf40, 0xc03e,	0xaf7f, 0xc03e,		0x21, 0
	.dw 0xafc0, 0xc03e,	0xafff, 0xc03e,		0x21, 0
	.dw 0xb040, 0xc03e,	0xb07f, 0xc03e,		0x21, 0
	.dw 0xb0c0, 0xc03e,	0xb0ff, 0xc03e,		0x21, 0
	.dw 0xb140, 0xc03e,	0xb17f, 0xc03e,		0x21, 0
	.dw 0xb1c0, 0xc03e,	0xb1ff, 0xc03e,		0x21, 0
	.dw 0xb240, 0xc03e,	0xb27f, 0xc03e,		0x21, 0
	.dw 0xb2c0, 0xc03e,	0xb2ff, 0xc03e,		0x21, 0
	.dw 0xb340, 0xc03e,	0xb37f, 0xc03e,		0x21, 0
	.dw 0xb3c0, 0xc03e,	0xb3ff, 0xc03e,		0x21, 0
	.dw 0xb440, 0xc03e,	0xb47f, 0xc03e,		0x21, 0
	.dw 0xb4c0, 0xc03e,	0xb4ff, 0xc03e,		0x21, 0
	.dw 0xb540, 0xc03e,	0xb57f, 0xc03e,		0x21, 0
	.dw 0xb5c0, 0xc03e,	0xb5ff, 0xc03e,		0x21, 0
	.dw 0xb640, 0xc03e,	0xb67f, 0xc03e,		0x21, 0
	.dw 0xb6c0, 0xc03e,	0xb6ff, 0xc03e,		0x21, 0
	.dw 0xb740, 0xc03e,	0xb77f, 0xc03e,		0x21, 0
	.dw 0xb7c0, 0xc03e,	0xb7ff, 0xc03e,		0x21, 0
	.dw 0xb840, 0xc03e,	0xb87f, 0xc03e,		0x21, 0
	.dw 0xb8c0, 0xc03e,	0xb8ff, 0xc03e,		0x21, 0
	.dw 0xb940, 0xc03e,	0xb97f, 0xc03e,		0x21, 0
	.dw 0xb9c0, 0xc03e,	0xbfff, 0xc03e,		0x21, 0
	.dw 0xc040, 0xc03e,	0xc07f, 0xc03e,		0x21, 0
	.dw 0xc0c0, 0xc03e,	0xc0ff, 0xc03e,		0x21, 0
	.dw 0xc140, 0xc03e,	0xc17f, 0xc03e,		0x21, 0
	.dw 0xc1c0, 0xc03e,	0xc1ff, 0xc03e,		0x21, 0
	.dw 0xc240, 0xc03e,	0xc27f, 0xc03e,		0x21, 0
	.dw 0xc2c0, 0xc03e,	0xc2ff, 0xc03e,		0x21, 0
	.dw 0xc340, 0xc03e,	0xc37f, 0xc03e,		0x21, 0
	.dw 0xc3c0, 0xc03e,	0xc3ff, 0xc03e,		0x21, 0
	.dw 0xc440, 0xc03e,	0xc47f, 0xc03e,		0x21, 0
	.dw 0xc4c0, 0xc03e,	0xc4ff, 0xc03e,		0x21, 0
	.dw 0xc540, 0xc03e,	0xc57f, 0xc03e,		0x21, 0
	.dw 0xc5c0, 0xc03e,	0xc5ff, 0xc03e,		0x21, 0
	.dw 0xc640, 0xc03e,	0xc67f, 0xc03e,		0x21, 0
	.dw 0xc6c0, 0xc03e,	0xc6ff, 0xc03e,		0x21, 0
	.dw 0xc740, 0xc03e,	0xc77f, 0xc03e,		0x21, 0
	.dw 0xc7c0, 0xc03e,	0xc7ff, 0xc03e,		0x21, 0
	.dw 0xc840, 0xc03e,	0xc87f, 0xc03e,		0x21, 0
	.dw 0xc8c0, 0xc03e,	0xc8ff, 0xc03e,		0x21, 0
	.dw 0xc940, 0xc03e,	0xc97f, 0xc03e,		0x21, 0
	.dw 0xc9c0, 0xc03e,	0xc9ff, 0xc03e,		0x21, 0
	.dw 0xca40, 0xc03e,	0xca7f, 0xc03e,		0x21, 0
	.dw 0xcac0, 0xc03e,	0xcaff, 0xc03e,		0x21, 0
	.dw 0xcb40, 0xc03e,	0xcb7f, 0xc03e,		0x21, 0
	.dw 0xcbc0, 0xc03e,	0xcbff, 0xc03e,		0x21, 0
	.dw 0xcc40, 0xc03e,	0xcc7f, 0xc03e,		0x21, 0
	.dw 0xccc0, 0xc03e,	0xccff, 0xc03e,		0x21, 0
	.dw 0xcd40, 0xc03e,	0xcd7f, 0xc03e,		0x21, 0
	.dw 0xcdc0, 0xc03e,	0xcdff, 0xc03e,		0x21, 0
	.dw 0xce40, 0xc03e,	0xce7f, 0xc03e,		0x21, 0
	.dw 0xcec0, 0xc03e,	0xceff, 0xc03e,		0x21, 0
	.dw 0xcf40, 0xc03e,	0xcf7f, 0xc03e,		0x21, 0
	.dw 0xcfc0, 0xc03e,	0xcfff, 0xc03e,		0x21, 0
	.dw 0xd040, 0xc03e,	0xd07f, 0xc03e,		0x21, 0
	.dw 0xd0c0, 0xc03e,	0xd0ff, 0xc03e,		0x21, 0
	.dw 0xd140, 0xc03e,	0xd17f, 0xc03e,		0x21, 0
	.dw 0xd1c0, 0xc03e,	0xd1ff, 0xc03e,		0x21, 0
	.dw 0xd240, 0xc03e,	0xd27f, 0xc03e,		0x21, 0
	.dw 0xd2c0, 0xc03e,	0xd2ff, 0xc03e,		0x21, 0
	.dw 0xd340, 0xc03e,	0xd37f, 0xc03e,		0x21, 0
	.dw 0xd3c0, 0xc03e,	0xd3ff, 0xc03e,		0x21, 0
	.dw 0xd440, 0xc03e,	0xd47f, 0xc03e,		0x21, 0
	.dw 0xd4c0, 0xc03e,	0xd4ff, 0xc03e,		0x21, 0
	.dw 0xd540, 0xc03e,	0xd57f, 0xc03e,		0x21, 0
	.dw 0xd5c0, 0xc03e,	0xd5ff, 0xc03e,		0x21, 0
	.dw 0xd640, 0xc03e,	0xd67f, 0xc03e,		0x21, 0
	.dw 0xd6c0, 0xc03e,	0xd6ff, 0xc03e,		0x21, 0
	.dw 0xd740, 0xc03e,	0xd77f, 0xc03e,		0x21, 0
	.dw 0xd7c0, 0xc03e,	0xd7ff, 0xc03e,		0x21, 0
	.dw 0xd840, 0xc03e,	0xd87f, 0xc03e,		0x21, 0
	.dw 0xd8c0, 0xc03e,	0xd8ff, 0xc03e,		0x21, 0
	.dw 0xd940, 0xc03e,	0xd97f, 0xc03e,		0x21, 0
	.dw 0xd9c0, 0xc03e,	0xdfff, 0xc03e,		0x21, 0
	.dw 0xe040, 0xc03e,	0xe07f, 0xc03e,		0x21, 0
	.dw 0xe0c0, 0xc03e,	0xe0ff, 0xc03e,		0x21, 0
	.dw 0xe140, 0xc03e,	0xe17f, 0xc03e,		0x21, 0
	.dw 0xe1c0, 0xc03e,	0xe1ff, 0xc03e,		0x21, 0
	.dw 0xe240, 0xc03e,	0xe27f, 0xc03e,		0x21, 0
	.dw 0xe2c0, 0xc03e,	0xe2ff, 0xc03e,		0x21, 0
	.dw 0xe340, 0xc03e,	0xe37f, 0xc03e,		0x21, 0
	.dw 0xe3c0, 0xc03e,	0xe3ff, 0xc03e,		0x21, 0
	.dw 0xe440, 0xc03e,	0xe47f, 0xc03e,		0x21, 0
	.dw 0xe4c0, 0xc03e,	0xe4ff, 0xc03e,		0x21, 0
	.dw 0xe540, 0xc03e,	0xe57f, 0xc03e,		0x21, 0
	.dw 0xe5c0, 0xc03e,	0xe5ff, 0xc03e,		0x21, 0
	.dw 0xe640, 0xc03e,	0xe67f, 0xc03e,		0x21, 0
	.dw 0xe6c0, 0xc03e,	0xe6ff, 0xc03e,		0x21, 0
	.dw 0xe740, 0xc03e,	0xe77f, 0xc03e,		0x21, 0
	.dw 0xe7c0, 0xc03e,	0xe7ff, 0xc03e,		0x21, 0
	.dw 0xe840, 0xc03e,	0xe87f, 0xc03e,		0x21, 0
	.dw 0xe8c0, 0xc03e,	0xe8ff, 0xc03e,		0x21, 0
	.dw 0xe940, 0xc03e,	0xe97f, 0xc03e,		0x21, 0
	.dw 0xe9c0, 0xc03e,	0xe9ff, 0xc03e,		0x21, 0
	.dw 0xea40, 0xc03e,	0xea7f, 0xc03e,		0x21, 0
	.dw 0xeac0, 0xc03e,	0xeaff, 0xc03e,		0x21, 0
	.dw 0xeb40, 0xc03e,	0xeb7f, 0xc03e,		0x21, 0
	.dw 0xebc0, 0xc03e,	0xebff, 0xc03e,		0x21, 0
	.dw 0xec40, 0xc03e,	0xec7f, 0xc03e,		0x21, 0
	.dw 0xecc0, 0xc03e,	0xecff, 0xc03e,		0x21, 0
	.dw 0xed40, 0xc03e,	0xed7f, 0xc03e,		0x21, 0
	.dw 0xedc0, 0xc03e,	0xedff, 0xc03e,		0x21, 0
	.dw 0xee40, 0xc03e,	0xee7f, 0xc03e,		0x21, 0
	.dw 0xeec0, 0xc03e,	0xeeff, 0xc03e,		0x21, 0
	.dw 0xef40, 0xc03e,	0xef7f, 0xc03e,		0x21, 0
	.dw 0xefc0, 0xc03e,	0xefff, 0xc03e,		0x21, 0
	.dw 0xf040, 0xc03e,	0xf07f, 0xc03e,		0x21, 0
	.dw 0xf0c0, 0xc03e,	0xf0ff, 0xc03e,		0x21, 0
	.dw 0xf140, 0xc03e,	0xf17f, 0xc03e,		0x21, 0
	.dw 0xf1c0, 0xc03e,	0xf1ff, 0xc03e,		0x21, 0
	.dw 0xf240, 0xc03e,	0xf27f, 0xc03e,		0x21, 0
	.dw 0xf2c0, 0xc03e,	0xf2ff, 0xc03e,		0x21, 0
	.dw 0xf340, 0xc03e,	0xf37f, 0xc03e,		0x21, 0
	.dw 0xf3c0, 0xc03e,	0xf3ff, 0xc03e,		0x21, 0
	.dw 0xf440, 0xc03e,	0xf47f, 0xc03e,		0x21, 0
	.dw 0xf4c0, 0xc03e,	0xf4ff, 0xc03e,		0x21, 0
	.dw 0xf540, 0xc03e,	0xf57f, 0xc03e,		0x21, 0
	.dw 0xf5c0, 0xc03e,	0xf5ff, 0xc03e,		0x21, 0
	.dw 0xf640, 0xc03e,	0xf67f, 0xc03e,		0x21, 0
	.dw 0xf6c0, 0xc03e,	0xf6ff, 0xc03e,		0x21, 0
	.dw 0xf740, 0xc03e,	0xf77f, 0xc03e,		0x21, 0
	.dw 0xf7c0, 0xc03e,	0xf7ff, 0xc03e,		0x21, 0
	.dw 0xf840, 0xc03e,	0xf87f, 0xc03e,		0x21, 0
	.dw 0xf8c0, 0xc03e,	0xf8ff, 0xc03e,		0x21, 0
	.dw 0xf940, 0xc03e,	0xf97f, 0xc03e,		0x21, 0
	.dw 0xf9c0, 0xc03e,	0xffff, 0xc03e,		0x21, 0
	.dw 0x0040, 0xc03f,	0x007f, 0xc03f,		0x21, 0
	.dw 0x00c0, 0xc03f,	0x00ff, 0xc03f,		0x21, 0
	.dw 0x0140, 0xc03f,	0x017f, 0xc03f,		0x21, 0
	.dw 0x01c0, 0xc03f,	0x01ff, 0xc03f,		0x21, 0
	.dw 0x0240, 0xc03f,	0x027f, 0xc03f,		0x21, 0
	.dw 0x02c0, 0xc03f,	0x02ff, 0xc03f,		0x21, 0
	.dw 0x0340, 0xc03f,	0x037f, 0xc03f,		0x21, 0
	.dw 0x03c0, 0xc03f,	0x03ff, 0xc03f,		0x21, 0
	.dw 0x0440, 0xc03f,	0x047f, 0xc03f,		0x21, 0
	.dw 0x04c0, 0xc03f,	0x04ff, 0xc03f,		0x21, 0
	.dw 0x0540, 0xc03f,	0x057f, 0xc03f,		0x21, 0
	.dw 0x05c0, 0xc03f,	0x05ff, 0xc03f,		0x21, 0
	.dw 0x0640, 0xc03f,	0x067f, 0xc03f,		0x21, 0
	.dw 0x06c0, 0xc03f,	0x06ff, 0xc03f,		0x21, 0
	.dw 0x0740, 0xc03f,	0x077f, 0xc03f,		0x21, 0
	.dw 0x07c0, 0xc03f,	0x07ff, 0xc03f,		0x21, 0
	.dw 0x0840, 0xc03f,	0x087f, 0xc03f,		0x21, 0
	.dw 0x08c0, 0xc03f,	0x08ff, 0xc03f,		0x21, 0
	.dw 0x0940, 0xc03f,	0x097f, 0xc03f,		0x21, 0
	.dw 0x09c0, 0xc03f,	0x09ff, 0xc03f,		0x21, 0
	.dw 0x0a40, 0xc03f,	0x0a7f, 0xc03f,		0x21, 0
	.dw 0x0ac0, 0xc03f,	0x0aff, 0xc03f,		0x21, 0
	.dw 0x0b40, 0xc03f,	0x0b7f, 0xc03f,		0x21, 0
	.dw 0x0bc0, 0xc03f,	0x0bff, 0xc03f,		0x21, 0
	.dw 0x0c40, 0xc03f,	0x0c7f, 0xc03f,		0x21, 0
	.dw 0x0cc0, 0xc03f,	0x0cff, 0xc03f,		0x21, 0
	.dw 0x0d40, 0xc03f,	0x0d7f, 0xc03f,		0x21, 0
	.dw 0x0dc0, 0xc03f,	0x0dff, 0xc03f,		0x21, 0
	.dw 0x0e40, 0xc03f,	0x0e7f, 0xc03f,		0x21, 0
	.dw 0x0ec0, 0xc03f,	0x0eff, 0xc03f,		0x21, 0
	.dw 0x0f40, 0xc03f,	0x0f7f, 0xc03f,		0x21, 0
	.dw 0x0fc0, 0xc03f,	0x0fff, 0xc03f,		0x21, 0
	.dw 0x1040, 0xc03f,	0x107f, 0xc03f,		0x21, 0
	.dw 0x10c0, 0xc03f,	0x10ff, 0xc03f,		0x21, 0
	.dw 0x1140, 0xc03f,	0x117f, 0xc03f,		0x21, 0
	.dw 0x11c0, 0xc03f,	0x11ff, 0xc03f,		0x21, 0
	.dw 0x1240, 0xc03f,	0x127f, 0xc03f,		0x21, 0
	.dw 0x12c0, 0xc03f,	0x12ff, 0xc03f,		0x21, 0
	.dw 0x1340, 0xc03f,	0x137f, 0xc03f,		0x21, 0
	.dw 0x13c0, 0xc03f,	0x13ff, 0xc03f,		0x21, 0
	.dw 0x1440, 0xc03f,	0x147f, 0xc03f,		0x21, 0
	.dw 0x14c0, 0xc03f,	0x14ff, 0xc03f,		0x21, 0
	.dw 0x1540, 0xc03f,	0x157f, 0xc03f,		0x21, 0
	.dw 0x15c0, 0xc03f,	0x15ff, 0xc03f,		0x21, 0
	.dw 0x1640, 0xc03f,	0x167f, 0xc03f,		0x21, 0
	.dw 0x16c0, 0xc03f,	0x16ff, 0xc03f,		0x21, 0
	.dw 0x1740, 0xc03f,	0x177f, 0xc03f,		0x21, 0
	.dw 0x17c0, 0xc03f,	0x17ff, 0xc03f,		0x21, 0
	.dw 0x1840, 0xc03f,	0x187f, 0xc03f,		0x21, 0
	.dw 0x18c0, 0xc03f,	0x18ff, 0xc03f,		0x21, 0
	.dw 0x1940, 0xc03f,	0x197f, 0xc03f,		0x21, 0
	.dw 0x19c0, 0xc03f,	0x1fff, 0xc03f,		0x21, 0
	.dw 0x2040, 0xc03f,	0x207f, 0xc03f,		0x21, 0
	.dw 0x20c0, 0xc03f,	0x20ff, 0xc03f,		0x21, 0
	.dw 0x2140, 0xc03f,	0x217f, 0xc03f,		0x21, 0
	.dw 0x21c0, 0xc03f,	0x21ff, 0xc03f,		0x21, 0
	.dw 0x2240, 0xc03f,	0x227f, 0xc03f,		0x21, 0
	.dw 0x22c0, 0xc03f,	0x22ff, 0xc03f,		0x21, 0
	.dw 0x2340, 0xc03f,	0x237f, 0xc03f,		0x21, 0
	.dw 0x23c0, 0xc03f,	0x23ff, 0xc03f,		0x21, 0
	.dw 0x2440, 0xc03f,	0x247f, 0xc03f,		0x21, 0
	.dw 0x24c0, 0xc03f,	0x24ff, 0xc03f,		0x21, 0
	.dw 0x2540, 0xc03f,	0x257f, 0xc03f,		0x21, 0
	.dw 0x25c0, 0xc03f,	0x25ff, 0xc03f,		0x21, 0
	.dw 0x2640, 0xc03f,	0x267f, 0xc03f,		0x21, 0
	.dw 0x26c0, 0xc03f,	0x26ff, 0xc03f,		0x21, 0
	.dw 0x2740, 0xc03f,	0x277f, 0xc03f,		0x21, 0
	.dw 0x27c0, 0xc03f,	0x27ff, 0xc03f,		0x21, 0
	.dw 0x2840, 0xc03f,	0x287f, 0xc03f,		0x21, 0
	.dw 0x28c0, 0xc03f,	0x28ff, 0xc03f,		0x21, 0
	.dw 0x2940, 0xc03f,	0x297f, 0xc03f,		0x21, 0
	.dw 0x29c0, 0xc03f,	0x29ff, 0xc03f,		0x21, 0
	.dw 0x2a40, 0xc03f,	0x2a7f, 0xc03f,		0x21, 0
	.dw 0x2ac0, 0xc03f,	0x2aff, 0xc03f,		0x21, 0
	.dw 0x2b40, 0xc03f,	0x2b7f, 0xc03f,		0x21, 0
	.dw 0x2bc0, 0xc03f,	0x2bff, 0xc03f,		0x21, 0
	.dw 0x2c40, 0xc03f,	0x2c7f, 0xc03f,		0x21, 0
	.dw 0x2cc0, 0xc03f,	0x2cff, 0xc03f,		0x21, 0
	.dw 0x2d40, 0xc03f,	0x2d7f, 0xc03f,		0x21, 0
	.dw 0x2dc0, 0xc03f,	0x2dff, 0xc03f,		0x21, 0
	.dw 0x2e40, 0xc03f,	0x2e7f, 0xc03f,		0x21, 0
	.dw 0x2ec0, 0xc03f,	0x2eff, 0xc03f,		0x21, 0
	.dw 0x2f40, 0xc03f,	0x2f7f, 0xc03f,		0x21, 0
	.dw 0x2fc0, 0xc03f,	0x2fff, 0xc03f,		0x21, 0
	.dw 0x3040, 0xc03f,	0x307f, 0xc03f,		0x21, 0
	.dw 0x30c0, 0xc03f,	0x30ff, 0xc03f,		0x21, 0
	.dw 0x3140, 0xc03f,	0x317f, 0xc03f,		0x21, 0
	.dw 0x31c0, 0xc03f,	0x31ff, 0xc03f,		0x21, 0
	.dw 0x3240, 0xc03f,	0x327f, 0xc03f,		0x21, 0
	.dw 0x32c0, 0xc03f,	0x32ff, 0xc03f,		0x21, 0
	.dw 0x3340, 0xc03f,	0x337f, 0xc03f,		0x21, 0
	.dw 0x33c0, 0xc03f,	0x33ff, 0xc03f,		0x21, 0
	.dw 0x3440, 0xc03f,	0x347f, 0xc03f,		0x21, 0
	.dw 0x34c0, 0xc03f,	0x34ff, 0xc03f,		0x21, 0
	.dw 0x3540, 0xc03f,	0x357f, 0xc03f,		0x21, 0
	.dw 0x35c0, 0xc03f,	0x35ff, 0xc03f,		0x21, 0
	.dw 0x3640, 0xc03f,	0x367f, 0xc03f,		0x21, 0
	.dw 0x36c0, 0xc03f,	0x36ff, 0xc03f,		0x21, 0
	.dw 0x3740, 0xc03f,	0x377f, 0xc03f,		0x21, 0
	.dw 0x37c0, 0xc03f,	0x37ff, 0xc03f,		0x21, 0
	.dw 0x3840, 0xc03f,	0x387f, 0xc03f,		0x21, 0
	.dw 0x38c0, 0xc03f,	0x38ff, 0xc03f,		0x21, 0
	.dw 0x3940, 0xc03f,	0x397f, 0xc03f,		0x21, 0
	.dw 0x39c0, 0xc03f,	0x1fff, 0xc040,		0x21, 0
	.dw 0x3a00, 0xc040,	0x5fff, 0xc040,		0x21, 0
	.dw 0x7a00, 0xc040,	0x9fff, 0xc040,		0x21, 0
	.dw 0xba00, 0xc040,	0xdfff, 0xc040,		0x21, 0
	.dw 0xfa00, 0xc040,	0x1fff, 0xc041,		0x21, 0
	.dw 0x3a00, 0xc041,	0x5fff, 0xc041,		0x21, 0
	.dw 0x7a00, 0xc041,	0x9fff, 0xc041,		0x21, 0
	.dw 0xba00, 0xc041,	0xdfff, 0xc041,		0x21, 0
	.dw 0xfa00, 0xc041,	0x1fff, 0xc042,		0x21, 0
	.dw 0x3a00, 0xc042,	0x5fff, 0xc042,		0x21, 0
	.dw 0x7a00, 0xc042,	0x9fff, 0xc042,		0x21, 0
	.dw 0xba00, 0xc042,	0xdfff, 0xc042,		0x21, 0
	.dw 0xfa00, 0xc042,	0x1fff, 0xc043,		0x21, 0
	.dw 0x3a00, 0xc043,	0xffff, 0xc043,		0x21, 0
	.dw 0x1a00, 0xc044,	0x1fff, 0xc044,		0x21, 0
	.dw 0x3a00, 0xc044,	0x3fff, 0xc044,		0x21, 0
	.dw 0x5a00, 0xc044,	0x5fff, 0xc044,		0x21, 0
	.dw 0x7a00, 0xc044,	0x7fff, 0xc044,		0x21, 0
	.dw 0x9a00, 0xc044,	0x9fff, 0xc044,		0x21, 0
	.dw 0xba00, 0xc044,	0xbfff, 0xc044,		0x21, 0
	.dw 0xda00, 0xc044,	0xdfff, 0xc044,		0x21, 0
	.dw 0xfa00, 0xc044,	0xffff, 0xc044,		0x21, 0
	.dw 0x1a00, 0xc045,	0x1fff, 0xc045,		0x21, 0
	.dw 0x3a00, 0xc045,	0x3fff, 0xc045,		0x21, 0
	.dw 0x5a00, 0xc045,	0x5fff, 0xc045,		0x21, 0
	.dw 0x7a00, 0xc045,	0x7fff, 0xc045,		0x21, 0
	.dw 0x9a00, 0xc045,	0x9fff, 0xc045,		0x21, 0
	.dw 0xba00, 0xc045,	0xbfff, 0xc045,		0x21, 0
	.dw 0xda00, 0xc045,	0xdfff, 0xc045,		0x21, 0
	.dw 0xfa00, 0xc045,	0xffff, 0xc045,		0x21, 0
	.dw 0x1a00, 0xc046,	0x1fff, 0xc046,		0x21, 0
	.dw 0x3a00, 0xc046,	0x3fff, 0xc046,		0x21, 0
	.dw 0x5a00, 0xc046,	0x5fff, 0xc046,		0x21, 0
	.dw 0x7a00, 0xc046,	0x7fff, 0xc046,		0x21, 0
	.dw 0x9a00, 0xc046,	0x9fff, 0xc046,		0x21, 0
	.dw 0xba00, 0xc046,	0xbfff, 0xc046,		0x21, 0
	.dw 0xda00, 0xc046,	0xdfff, 0xc046,		0x21, 0
	.dw 0xfa00, 0xc046,	0xffff, 0xc046,		0x21, 0
	.dw 0x1a00, 0xc047,	0x1fff, 0xc047,		0x21, 0
	.dw 0x3a00, 0xc047,	0x1fff, 0xc050,		0x21, 0
	.dw 0x3a00, 0xc050,	0x5fff, 0xc050,		0x21, 0
	.dw 0x7a00, 0xc050,	0x9fff, 0xc050,		0x21, 0
	.dw 0xba00, 0xc050,	0xdfff, 0xc050,		0x21, 0
	.dw 0xfa00, 0xc050,	0x1fff, 0xc051,		0x21, 0
	.dw 0x3a00, 0xc051,	0x5fff, 0xc051,		0x21, 0
	.dw 0x7a00, 0xc051,	0x9fff, 0xc051,		0x21, 0
	.dw 0xba00, 0xc051,	0xdfff, 0xc051,		0x21, 0
	.dw 0xfa00, 0xc051,	0x1fff, 0xc052,		0x21, 0
	.dw 0x3a00, 0xc052,	0x5fff, 0xc052,		0x21, 0
	.dw 0x7a00, 0xc052,	0x9fff, 0xc052,		0x21, 0
	.dw 0xba00, 0xc052,	0xdfff, 0xc052,		0x21, 0
	.dw 0xfa00, 0xc052,	0xffff, 0xc053,		0x21, 0
	.dw 0x1a00, 0xc054,	0x1fff, 0xc054,		0x21, 0
	.dw 0x3a00, 0xc054,	0x3fff, 0xc054,		0x21, 0
	.dw 0x5a00, 0xc054,	0x5fff, 0xc054,		0x21, 0
	.dw 0x7a00, 0xc054,	0x7fff, 0xc054,		0x21, 0
	.dw 0x9a00, 0xc054,	0x9fff, 0xc054,		0x21, 0
	.dw 0xba00, 0xc054,	0xbfff, 0xc054,		0x21, 0
	.dw 0xda00, 0xc054,	0xdfff, 0xc054,		0x21, 0
	.dw 0xfa00, 0xc054,	0xffff, 0xc054,		0x21, 0
	.dw 0x1a00, 0xc055,	0x1fff, 0xc055,		0x21, 0
	.dw 0x3a00, 0xc055,	0x3fff, 0xc055,		0x21, 0
	.dw 0x5a00, 0xc055,	0x5fff, 0xc055,		0x21, 0
	.dw 0x7a00, 0xc055,	0x7fff, 0xc055,		0x21, 0
	.dw 0x9a00, 0xc055,	0x9fff, 0xc055,		0x21, 0
	.dw 0xba00, 0xc055,	0xbfff, 0xc055,		0x21, 0
	.dw 0xda00, 0xc055,	0xdfff, 0xc055,		0x21, 0
	.dw 0xfa00, 0xc055,	0xffff, 0xc055,		0x21, 0
	.dw 0x1a00, 0xc056,	0x1fff, 0xc056,		0x21, 0
	.dw 0x3a00, 0xc056,	0x3fff, 0xc056,		0x21, 0
	.dw 0x5a00, 0xc056,	0x5fff, 0xc056,		0x21, 0
	.dw 0x7a00, 0xc056,	0x7fff, 0xc056,		0x21, 0
	.dw 0x9a00, 0xc056,	0x9fff, 0xc056,		0x21, 0
	.dw 0xba00, 0xc056,	0xbfff, 0xc056,		0x21, 0
	.dw 0xda00, 0xc056,	0xdfff, 0xc056,		0x21, 0
	.dw 0xfa00, 0xc056,	0xffff, 0xc056,		0x21, 0
	.dw 0x1a00, 0xc057,	0x1fff, 0xc057,		0x21, 0
	.dw 0x3a00, 0xc057,	0xffff, 0xc05f,		0x21, 0
	.dw 0x1a00, 0xc060,	0x3fff, 0xc060,		0x21, 0
	.dw 0x5a00, 0xc060,	0x7fff, 0xc060,		0x21, 0
	.dw 0x9a00, 0xc060,	0xbfff, 0xc060,		0x21, 0
	.dw 0xda00, 0xc060,	0xffff, 0xc060,		0x21, 0
	.dw 0x1a00, 0xc061,	0x3fff, 0xc061,		0x21, 0
	.dw 0x5a00, 0xc061,	0x7fff, 0xc061,		0x21, 0
	.dw 0x9a00, 0xc061,	0xbfff, 0xc061,		0x21, 0
	.dw 0xda00, 0xc061,	0xffff, 0xc061,		0x21, 0
	.dw 0x1a00, 0xc062,	0x3fff, 0xc062,		0x21, 0
	.dw 0x5a00, 0xc062,	0x7fff, 0xc062,		0x21, 0
	.dw 0x9a00, 0xc062,	0xbfff, 0xc062,		0x21, 0
	.dw 0xda00, 0xc062,	0xffff, 0xc062,		0x21, 0
	.dw 0x1a00, 0xc063,	0xffff, 0xc06f,		0x21, 0
	.dw 0x1a00, 0xc070,	0x3fff, 0xc070,		0x21, 0
	.dw 0x5a00, 0xc070,	0x7fff, 0xc070,		0x21, 0
	.dw 0x9a00, 0xc070,	0xbfff, 0xc070,		0x21, 0
	.dw 0xda00, 0xc070,	0xffff, 0xc070,		0x21, 0
	.dw 0x1a00, 0xc071,	0x3fff, 0xc071,		0x21, 0
	.dw 0x5a00, 0xc071,	0x7fff, 0xc071,		0x21, 0
	.dw 0x9a00, 0xc071,	0xbfff, 0xc071,		0x21, 0
	.dw 0xda00, 0xc071,	0xffff, 0xc071,		0x21, 0
	.dw 0x1a00, 0xc072,	0x3fff, 0xc072,		0x21, 0
	.dw 0x5a00, 0xc072,	0x7fff, 0xc072,		0x21, 0
	.dw 0x9a00, 0xc072,	0xbfff, 0xc072,		0x21, 0
	.dw 0xda00, 0xc072,	0xffff, 0xc07f,		0x21, 0
	.dw 0x1a00, 0xc080,	0x1fff, 0xc080,		0x21, 0
	.dw 0x3a00, 0xc080,	0x3fff, 0xc080,		0x21, 0
	.dw 0x5a00, 0xc080,	0x5fff, 0xc080,		0x21, 0
	.dw 0x7a00, 0xc080,	0x7fff, 0xc080,		0x21, 0
	.dw 0x9a00, 0xc080,	0x9fff, 0xc080,		0x21, 0
	.dw 0xba00, 0xc080,	0xbfff, 0xc080,		0x21, 0
	.dw 0xda00, 0xc080,	0xdfff, 0xc080,		0x21, 0
	.dw 0xfa00, 0xc080,	0xffff, 0xc080,		0x21, 0
	.dw 0x1a00, 0xc081,	0x1fff, 0xc081,		0x21, 0
	.dw 0x3a00, 0xc081,	0x3fff, 0xc081,		0x21, 0
	.dw 0x5a00, 0xc081,	0x5fff, 0xc081,		0x21, 0
	.dw 0x7a00, 0xc081,	0x7fff, 0xc081,		0x21, 0
	.dw 0x9a00, 0xc081,	0x9fff, 0xc081,		0x21, 0
	.dw 0xba00, 0xc081,	0xbfff, 0xc081,		0x21, 0
	.dw 0xda00, 0xc081,	0xdfff, 0xc081,		0x21, 0
	.dw 0xfa00, 0xc081,	0xffff, 0xc081,		0x21, 0
	.dw 0x1a00, 0xc082,	0x1fff, 0xc082,		0x21, 0
	.dw 0x3a00, 0xc082,	0x3fff, 0xc082,		0x21, 0
	.dw 0x5a00, 0xc082,	0x5fff, 0xc082,		0x21, 0
	.dw 0x7a00, 0xc082,	0x7fff, 0xc082,		0x21, 0
	.dw 0x9a00, 0xc082,	0x9fff, 0xc082,		0x21, 0
	.dw 0xba00, 0xc082,	0xbfff, 0xc082,		0x21, 0
	.dw 0xda00, 0xc082,	0xdfff, 0xc082,		0x21, 0
	.dw 0xfa00, 0xc082,	0xffff, 0xc082,		0x21, 0
	.dw 0x1a00, 0xc083,	0x1fff, 0xc083,		0x21, 0
	.dw 0x3a00, 0xc083,	0xffff, 0xc083,		0x21, 0
	.dw 0x1a00, 0xc084,	0x1fff, 0xc084,		0x21, 0
	.dw 0x3a00, 0xc084,	0x3fff, 0xc084,		0x21, 0
	.dw 0x5a00, 0xc084,	0x5fff, 0xc084,		0x21, 0
	.dw 0x7a00, 0xc084,	0x7fff, 0xc084,		0x21, 0
	.dw 0x9a00, 0xc084,	0x9fff, 0xc084,		0x21, 0
	.dw 0xba00, 0xc084,	0xbfff, 0xc084,		0x21, 0
	.dw 0xda00, 0xc084,	0xdfff, 0xc084,		0x21, 0
	.dw 0xfa00, 0xc084,	0xffff, 0xc084,		0x21, 0
	.dw 0x1a00, 0xc085,	0x1fff, 0xc085,		0x21, 0
	.dw 0x3a00, 0xc085,	0x3fff, 0xc085,		0x21, 0
	.dw 0x5a00, 0xc085,	0x5fff, 0xc085,		0x21, 0
	.dw 0x7a00, 0xc085,	0x7fff, 0xc085,		0x21, 0
	.dw 0x9a00, 0xc085,	0x9fff, 0xc085,		0x21, 0
	.dw 0xba00, 0xc085,	0xbfff, 0xc085,		0x21, 0
	.dw 0xda00, 0xc085,	0xdfff, 0xc085,		0x21, 0
	.dw 0xfa00, 0xc085,	0xffff, 0xc085,		0x21, 0
	.dw 0x1a00, 0xc086,	0x1fff, 0xc086,		0x21, 0
	.dw 0x3a00, 0xc086,	0x3fff, 0xc086,		0x21, 0
	.dw 0x5a00, 0xc086,	0x5fff, 0xc086,		0x21, 0
	.dw 0x7a00, 0xc086,	0x7fff, 0xc086,		0x21, 0
	.dw 0x9a00, 0xc086,	0x9fff, 0xc086,		0x21, 0
	.dw 0xba00, 0xc086,	0xbfff, 0xc086,		0x21, 0
	.dw 0xda00, 0xc086,	0xdfff, 0xc086,		0x21, 0
	.dw 0xfa00, 0xc086,	0xffff, 0xc086,		0x21, 0
	.dw 0x1a00, 0xc087,	0x1fff, 0xc087,		0x21, 0
	.dw 0x3a00, 0xc087,	0x1fff, 0xc088,		0x21, 0
	.dw 0x2040, 0xc088,	0x207f, 0xc088,		0x21, 0
	.dw 0x20c0, 0xc088,	0x20ff, 0xc088,		0x21, 0
	.dw 0x2140, 0xc088,	0x217f, 0xc088,		0x21, 0
	.dw 0x21c0, 0xc088,	0x21ff, 0xc088,		0x21, 0
	.dw 0x2240, 0xc088,	0x227f, 0xc088,		0x21, 0
	.dw 0x22c0, 0xc088,	0x22ff, 0xc088,		0x21, 0
	.dw 0x2340, 0xc088,	0x237f, 0xc088,		0x21, 0
	.dw 0x23c0, 0xc088,	0x23ff, 0xc088,		0x21, 0
	.dw 0x2440, 0xc088,	0x247f, 0xc088,		0x21, 0
	.dw 0x24c0, 0xc088,	0x24ff, 0xc088,		0x21, 0
	.dw 0x2540, 0xc088,	0x257f, 0xc088,		0x21, 0
	.dw 0x25c0, 0xc088,	0x25ff, 0xc088,		0x21, 0
	.dw 0x2640, 0xc088,	0x267f, 0xc088,		0x21, 0
	.dw 0x26c0, 0xc088,	0x26ff, 0xc088,		0x21, 0
	.dw 0x2740, 0xc088,	0x277f, 0xc088,		0x21, 0
	.dw 0x27c0, 0xc088,	0x27ff, 0xc088,		0x21, 0
	.dw 0x2840, 0xc088,	0x287f, 0xc088,		0x21, 0
	.dw 0x28c0, 0xc088,	0x28ff, 0xc088,		0x21, 0
	.dw 0x2940, 0xc088,	0x297f, 0xc088,		0x21, 0
	.dw 0x29c0, 0xc088,	0x29ff, 0xc088,		0x21, 0
	.dw 0x2a40, 0xc088,	0x2a7f, 0xc088,		0x21, 0
	.dw 0x2ac0, 0xc088,	0x2aff, 0xc088,		0x21, 0
	.dw 0x2b40, 0xc088,	0x2b7f, 0xc088,		0x21, 0
	.dw 0x2bc0, 0xc088,	0x2bff, 0xc088,		0x21, 0
	.dw 0x2c40, 0xc088,	0x2c7f, 0xc088,		0x21, 0
	.dw 0x2cc0, 0xc088,	0x2cff, 0xc088,		0x21, 0
	.dw 0x2d40, 0xc088,	0x2d7f, 0xc088,		0x21, 0
	.dw 0x2dc0, 0xc088,	0x2dff, 0xc088,		0x21, 0
	.dw 0x2e40, 0xc088,	0x2e7f, 0xc088,		0x21, 0
	.dw 0x2ec0, 0xc088,	0x2eff, 0xc088,		0x21, 0
	.dw 0x2f40, 0xc088,	0x2f7f, 0xc088,		0x21, 0
	.dw 0x2fc0, 0xc088,	0x2fff, 0xc088,		0x21, 0
	.dw 0x3040, 0xc088,	0x307f, 0xc088,		0x21, 0
	.dw 0x30c0, 0xc088,	0x30ff, 0xc088,		0x21, 0
	.dw 0x3140, 0xc088,	0x317f, 0xc088,		0x21, 0
	.dw 0x31c0, 0xc088,	0x31ff, 0xc088,		0x21, 0
	.dw 0x3240, 0xc088,	0x327f, 0xc088,		0x21, 0
	.dw 0x32c0, 0xc088,	0x32ff, 0xc088,		0x21, 0
	.dw 0x3340, 0xc088,	0x337f, 0xc088,		0x21, 0
	.dw 0x33c0, 0xc088,	0x33ff, 0xc088,		0x21, 0
	.dw 0x3440, 0xc088,	0x347f, 0xc088,		0x21, 0
	.dw 0x34c0, 0xc088,	0x34ff, 0xc088,		0x21, 0
	.dw 0x3540, 0xc088,	0x357f, 0xc088,		0x21, 0
	.dw 0x35c0, 0xc088,	0x35ff, 0xc088,		0x21, 0
	.dw 0x3640, 0xc088,	0x367f, 0xc088,		0x21, 0
	.dw 0x36c0, 0xc088,	0x36ff, 0xc088,		0x21, 0
	.dw 0x3740, 0xc088,	0x377f, 0xc088,		0x21, 0
	.dw 0x37c0, 0xc088,	0x37ff, 0xc088,		0x21, 0
	.dw 0x3840, 0xc088,	0x387f, 0xc088,		0x21, 0
	.dw 0x38c0, 0xc088,	0x38ff, 0xc088,		0x21, 0
	.dw 0x3940, 0xc088,	0x397f, 0xc088,		0x21, 0
	.dw 0x39c0, 0xc088,	0x5fff, 0xc088,		0x21, 0
	.dw 0x6040, 0xc088,	0x607f, 0xc088,		0x21, 0
	.dw 0x60c0, 0xc088,	0x60ff, 0xc088,		0x21, 0
	.dw 0x6140, 0xc088,	0x617f, 0xc088,		0x21, 0
	.dw 0x61c0, 0xc088,	0x61ff, 0xc088,		0x21, 0
	.dw 0x6240, 0xc088,	0x627f, 0xc088,		0x21, 0
	.dw 0x62c0, 0xc088,	0x62ff, 0xc088,		0x21, 0
	.dw 0x6340, 0xc088,	0x637f, 0xc088,		0x21, 0
	.dw 0x63c0, 0xc088,	0x63ff, 0xc088,		0x21, 0
	.dw 0x6440, 0xc088,	0x647f, 0xc088,		0x21, 0
	.dw 0x64c0, 0xc088,	0x64ff, 0xc088,		0x21, 0
	.dw 0x6540, 0xc088,	0x657f, 0xc088,		0x21, 0
	.dw 0x65c0, 0xc088,	0x65ff, 0xc088,		0x21, 0
	.dw 0x6640, 0xc088,	0x667f, 0xc088,		0x21, 0
	.dw 0x66c0, 0xc088,	0x66ff, 0xc088,		0x21, 0
	.dw 0x6740, 0xc088,	0x677f, 0xc088,		0x21, 0
	.dw 0x67c0, 0xc088,	0x67ff, 0xc088,		0x21, 0
	.dw 0x6840, 0xc088,	0x687f, 0xc088,		0x21, 0
	.dw 0x68c0, 0xc088,	0x68ff, 0xc088,		0x21, 0
	.dw 0x6940, 0xc088,	0x697f, 0xc088,		0x21, 0
	.dw 0x69c0, 0xc088,	0x69ff, 0xc088,		0x21, 0
	.dw 0x6a40, 0xc088,	0x6a7f, 0xc088,		0x21, 0
	.dw 0x6ac0, 0xc088,	0x6aff, 0xc088,		0x21, 0
	.dw 0x6b40, 0xc088,	0x6b7f, 0xc088,		0x21, 0
	.dw 0x6bc0, 0xc088,	0x6bff, 0xc088,		0x21, 0
	.dw 0x6c40, 0xc088,	0x6c7f, 0xc088,		0x21, 0
	.dw 0x6cc0, 0xc088,	0x6cff, 0xc088,		0x21, 0
	.dw 0x6d40, 0xc088,	0x6d7f, 0xc088,		0x21, 0
	.dw 0x6dc0, 0xc088,	0x6dff, 0xc088,		0x21, 0
	.dw 0x6e40, 0xc088,	0x6e7f, 0xc088,		0x21, 0
	.dw 0x6ec0, 0xc088,	0x6eff, 0xc088,		0x21, 0
	.dw 0x6f40, 0xc088,	0x6f7f, 0xc088,		0x21, 0
	.dw 0x6fc0, 0xc088,	0x6fff, 0xc088,		0x21, 0
	.dw 0x7040, 0xc088,	0x707f, 0xc088,		0x21, 0
	.dw 0x70c0, 0xc088,	0x70ff, 0xc088,		0x21, 0
	.dw 0x7140, 0xc088,	0x717f, 0xc088,		0x21, 0
	.dw 0x71c0, 0xc088,	0x71ff, 0xc088,		0x21, 0
	.dw 0x7240, 0xc088,	0x727f, 0xc088,		0x21, 0
	.dw 0x72c0, 0xc088,	0x72ff, 0xc088,		0x21, 0
	.dw 0x7340, 0xc088,	0x737f, 0xc088,		0x21, 0
	.dw 0x73c0, 0xc088,	0x73ff, 0xc088,		0x21, 0
	.dw 0x7440, 0xc088,	0x747f, 0xc088,		0x21, 0
	.dw 0x74c0, 0xc088,	0x74ff, 0xc088,		0x21, 0
	.dw 0x7540, 0xc088,	0x757f, 0xc088,		0x21, 0
	.dw 0x75c0, 0xc088,	0x75ff, 0xc088,		0x21, 0
	.dw 0x7640, 0xc088,	0x767f, 0xc088,		0x21, 0
	.dw 0x76c0, 0xc088,	0x76ff, 0xc088,		0x21, 0
	.dw 0x7740, 0xc088,	0x777f, 0xc088,		0x21, 0
	.dw 0x77c0, 0xc088,	0x77ff, 0xc088,		0x21, 0
	.dw 0x7840, 0xc088,	0x787f, 0xc088,		0x21, 0
	.dw 0x78c0, 0xc088,	0x78ff, 0xc088,		0x21, 0
	.dw 0x7940, 0xc088,	0x797f, 0xc088,		0x21, 0
	.dw 0x79c0, 0xc088,	0x9fff, 0xc088,		0x21, 0
	.dw 0xa040, 0xc088,	0xa07f, 0xc088,		0x21, 0
	.dw 0xa0c0, 0xc088,	0xa0ff, 0xc088,		0x21, 0
	.dw 0xa140, 0xc088,	0xa17f, 0xc088,		0x21, 0
	.dw 0xa1c0, 0xc088,	0xa1ff, 0xc088,		0x21, 0
	.dw 0xa240, 0xc088,	0xa27f, 0xc088,		0x21, 0
	.dw 0xa2c0, 0xc088,	0xa2ff, 0xc088,		0x21, 0
	.dw 0xa340, 0xc088,	0xa37f, 0xc088,		0x21, 0
	.dw 0xa3c0, 0xc088,	0xa3ff, 0xc088,		0x21, 0
	.dw 0xa440, 0xc088,	0xa47f, 0xc088,		0x21, 0
	.dw 0xa4c0, 0xc088,	0xa4ff, 0xc088,		0x21, 0
	.dw 0xa540, 0xc088,	0xa57f, 0xc088,		0x21, 0
	.dw 0xa5c0, 0xc088,	0xa5ff, 0xc088,		0x21, 0
	.dw 0xa640, 0xc088,	0xa67f, 0xc088,		0x21, 0
	.dw 0xa6c0, 0xc088,	0xa6ff, 0xc088,		0x21, 0
	.dw 0xa740, 0xc088,	0xa77f, 0xc088,		0x21, 0
	.dw 0xa7c0, 0xc088,	0xa7ff, 0xc088,		0x21, 0
	.dw 0xa840, 0xc088,	0xa87f, 0xc088,		0x21, 0
	.dw 0xa8c0, 0xc088,	0xa8ff, 0xc088,		0x21, 0
	.dw 0xa940, 0xc088,	0xa97f, 0xc088,		0x21, 0
	.dw 0xa9c0, 0xc088,	0xa9ff, 0xc088,		0x21, 0
	.dw 0xaa40, 0xc088,	0xaa7f, 0xc088,		0x21, 0
	.dw 0xaac0, 0xc088,	0xaaff, 0xc088,		0x21, 0
	.dw 0xab40, 0xc088,	0xab7f, 0xc088,		0x21, 0
	.dw 0xabc0, 0xc088,	0xabff, 0xc088,		0x21, 0
	.dw 0xac40, 0xc088,	0xac7f, 0xc088,		0x21, 0
	.dw 0xacc0, 0xc088,	0xacff, 0xc088,		0x21, 0
	.dw 0xad40, 0xc088,	0xad7f, 0xc088,		0x21, 0
	.dw 0xadc0, 0xc088,	0xadff, 0xc088,		0x21, 0
	.dw 0xae40, 0xc088,	0xae7f, 0xc088,		0x21, 0
	.dw 0xaec0, 0xc088,	0xaeff, 0xc088,		0x21, 0
	.dw 0xaf40, 0xc088,	0xaf7f, 0xc088,		0x21, 0
	.dw 0xafc0, 0xc088,	0xafff, 0xc088,		0x21, 0
	.dw 0xb040, 0xc088,	0xb07f, 0xc088,		0x21, 0
	.dw 0xb0c0, 0xc088,	0xb0ff, 0xc088,		0x21, 0
	.dw 0xb140, 0xc088,	0xb17f, 0xc088,		0x21, 0
	.dw 0xb1c0, 0xc088,	0xb1ff, 0xc088,		0x21, 0
	.dw 0xb240, 0xc088,	0xb27f, 0xc088,		0x21, 0
	.dw 0xb2c0, 0xc088,	0xb2ff, 0xc088,		0x21, 0
	.dw 0xb340, 0xc088,	0xb37f, 0xc088,		0x21, 0
	.dw 0xb3c0, 0xc088,	0xb3ff, 0xc088,		0x21, 0
	.dw 0xb440, 0xc088,	0xb47f, 0xc088,		0x21, 0
	.dw 0xb4c0, 0xc088,	0xb4ff, 0xc088,		0x21, 0
	.dw 0xb540, 0xc088,	0xb57f, 0xc088,		0x21, 0
	.dw 0xb5c0, 0xc088,	0xb5ff, 0xc088,		0x21, 0
	.dw 0xb640, 0xc088,	0xb67f, 0xc088,		0x21, 0
	.dw 0xb6c0, 0xc088,	0xb6ff, 0xc088,		0x21, 0
	.dw 0xb740, 0xc088,	0xb77f, 0xc088,		0x21, 0
	.dw 0xb7c0, 0xc088,	0xb7ff, 0xc088,		0x21, 0
	.dw 0xb840, 0xc088,	0xb87f, 0xc088,		0x21, 0
	.dw 0xb8c0, 0xc088,	0xb8ff, 0xc088,		0x21, 0
	.dw 0xb940, 0xc088,	0xb97f, 0xc088,		0x21, 0
	.dw 0xb9c0, 0xc088,	0xdfff, 0xc088,		0x21, 0
	.dw 0xe040, 0xc088,	0xe07f, 0xc088,		0x21, 0
	.dw 0xe0c0, 0xc088,	0xe0ff, 0xc088,		0x21, 0
	.dw 0xe140, 0xc088,	0xe17f, 0xc088,		0x21, 0
	.dw 0xe1c0, 0xc088,	0xe1ff, 0xc088,		0x21, 0
	.dw 0xe240, 0xc088,	0xe27f, 0xc088,		0x21, 0
	.dw 0xe2c0, 0xc088,	0xe2ff, 0xc088,		0x21, 0
	.dw 0xe340, 0xc088,	0xe37f, 0xc088,		0x21, 0
	.dw 0xe3c0, 0xc088,	0xe3ff, 0xc088,		0x21, 0
	.dw 0xe440, 0xc088,	0xe47f, 0xc088,		0x21, 0
	.dw 0xe4c0, 0xc088,	0xe4ff, 0xc088,		0x21, 0
	.dw 0xe540, 0xc088,	0xe57f, 0xc088,		0x21, 0
	.dw 0xe5c0, 0xc088,	0xe5ff, 0xc088,		0x21, 0
	.dw 0xe640, 0xc088,	0xe67f, 0xc088,		0x21, 0
	.dw 0xe6c0, 0xc088,	0xe6ff, 0xc088,		0x21, 0
	.dw 0xe740, 0xc088,	0xe77f, 0xc088,		0x21, 0
	.dw 0xe7c0, 0xc088,	0xe7ff, 0xc088,		0x21, 0
	.dw 0xe840, 0xc088,	0xe87f, 0xc088,		0x21, 0
	.dw 0xe8c0, 0xc088,	0xe8ff, 0xc088,		0x21, 0
	.dw 0xe940, 0xc088,	0xe97f, 0xc088,		0x21, 0
	.dw 0xe9c0, 0xc088,	0xe9ff, 0xc088,		0x21, 0
	.dw 0xea40, 0xc088,	0xea7f, 0xc088,		0x21, 0
	.dw 0xeac0, 0xc088,	0xeaff, 0xc088,		0x21, 0
	.dw 0xeb40, 0xc088,	0xeb7f, 0xc088,		0x21, 0
	.dw 0xebc0, 0xc088,	0xebff, 0xc088,		0x21, 0
	.dw 0xec40, 0xc088,	0xec7f, 0xc088,		0x21, 0
	.dw 0xecc0, 0xc088,	0xecff, 0xc088,		0x21, 0
	.dw 0xed40, 0xc088,	0xed7f, 0xc088,		0x21, 0
	.dw 0xedc0, 0xc088,	0xedff, 0xc088,		0x21, 0
	.dw 0xee40, 0xc088,	0xee7f, 0xc088,		0x21, 0
	.dw 0xeec0, 0xc088,	0xeeff, 0xc088,		0x21, 0
	.dw 0xef40, 0xc088,	0xef7f, 0xc088,		0x21, 0
	.dw 0xefc0, 0xc088,	0xefff, 0xc088,		0x21, 0
	.dw 0xf040, 0xc088,	0xf07f, 0xc088,		0x21, 0
	.dw 0xf0c0, 0xc088,	0xf0ff, 0xc088,		0x21, 0
	.dw 0xf140, 0xc088,	0xf17f, 0xc088,		0x21, 0
	.dw 0xf1c0, 0xc088,	0xf1ff, 0xc088,		0x21, 0
	.dw 0xf240, 0xc088,	0xf27f, 0xc088,		0x21, 0
	.dw 0xf2c0, 0xc088,	0xf2ff, 0xc088,		0x21, 0
	.dw 0xf340, 0xc088,	0xf37f, 0xc088,		0x21, 0
	.dw 0xf3c0, 0xc088,	0xf3ff, 0xc088,		0x21, 0
	.dw 0xf440, 0xc088,	0xf47f, 0xc088,		0x21, 0
	.dw 0xf4c0, 0xc088,	0xf4ff, 0xc088,		0x21, 0
	.dw 0xf540, 0xc088,	0xf57f, 0xc088,		0x21, 0
	.dw 0xf5c0, 0xc088,	0xf5ff, 0xc088,		0x21, 0
	.dw 0xf640, 0xc088,	0xf67f, 0xc088,		0x21, 0
	.dw 0xf6c0, 0xc088,	0xf6ff, 0xc088,		0x21, 0
	.dw 0xf740, 0xc088,	0xf77f, 0xc088,		0x21, 0
	.dw 0xf7c0, 0xc088,	0xf7ff, 0xc088,		0x21, 0
	.dw 0xf840, 0xc088,	0xf87f, 0xc088,		0x21, 0
	.dw 0xf8c0, 0xc088,	0xf8ff, 0xc088,		0x21, 0
	.dw 0xf940, 0xc088,	0xf97f, 0xc088,		0x21, 0
	.dw 0xf9c0, 0xc088,	0x1fff, 0xc089,		0x21, 0
	.dw 0x2040, 0xc089,	0x207f, 0xc089,		0x21, 0
	.dw 0x20c0, 0xc089,	0x20ff, 0xc089,		0x21, 0
	.dw 0x2140, 0xc089,	0x217f, 0xc089,		0x21, 0
	.dw 0x21c0, 0xc089,	0x21ff, 0xc089,		0x21, 0
	.dw 0x2240, 0xc089,	0x227f, 0xc089,		0x21, 0
	.dw 0x22c0, 0xc089,	0x22ff, 0xc089,		0x21, 0
	.dw 0x2340, 0xc089,	0x237f, 0xc089,		0x21, 0
	.dw 0x23c0, 0xc089,	0x23ff, 0xc089,		0x21, 0
	.dw 0x2440, 0xc089,	0x247f, 0xc089,		0x21, 0
	.dw 0x24c0, 0xc089,	0x24ff, 0xc089,		0x21, 0
	.dw 0x2540, 0xc089,	0x257f, 0xc089,		0x21, 0
	.dw 0x25c0, 0xc089,	0x25ff, 0xc089,		0x21, 0
	.dw 0x2640, 0xc089,	0x267f, 0xc089,		0x21, 0
	.dw 0x26c0, 0xc089,	0x26ff, 0xc089,		0x21, 0
	.dw 0x2740, 0xc089,	0x277f, 0xc089,		0x21, 0
	.dw 0x27c0, 0xc089,	0x27ff, 0xc089,		0x21, 0
	.dw 0x2840, 0xc089,	0x287f, 0xc089,		0x21, 0
	.dw 0x28c0, 0xc089,	0x28ff, 0xc089,		0x21, 0
	.dw 0x2940, 0xc089,	0x297f, 0xc089,		0x21, 0
	.dw 0x29c0, 0xc089,	0x29ff, 0xc089,		0x21, 0
	.dw 0x2a40, 0xc089,	0x2a7f, 0xc089,		0x21, 0
	.dw 0x2ac0, 0xc089,	0x2aff, 0xc089,		0x21, 0
	.dw 0x2b40, 0xc089,	0x2b7f, 0xc089,		0x21, 0
	.dw 0x2bc0, 0xc089,	0x2bff, 0xc089,		0x21, 0
	.dw 0x2c40, 0xc089,	0x2c7f, 0xc089,		0x21, 0
	.dw 0x2cc0, 0xc089,	0x2cff, 0xc089,		0x21, 0
	.dw 0x2d40, 0xc089,	0x2d7f, 0xc089,		0x21, 0
	.dw 0x2dc0, 0xc089,	0x2dff, 0xc089,		0x21, 0
	.dw 0x2e40, 0xc089,	0x2e7f, 0xc089,		0x21, 0
	.dw 0x2ec0, 0xc089,	0x2eff, 0xc089,		0x21, 0
	.dw 0x2f40, 0xc089,	0x2f7f, 0xc089,		0x21, 0
	.dw 0x2fc0, 0xc089,	0x2fff, 0xc089,		0x21, 0
	.dw 0x3040, 0xc089,	0x307f, 0xc089,		0x21, 0
	.dw 0x30c0, 0xc089,	0x30ff, 0xc089,		0x21, 0
	.dw 0x3140, 0xc089,	0x317f, 0xc089,		0x21, 0
	.dw 0x31c0, 0xc089,	0x31ff, 0xc089,		0x21, 0
	.dw 0x3240, 0xc089,	0x327f, 0xc089,		0x21, 0
	.dw 0x32c0, 0xc089,	0x32ff, 0xc089,		0x21, 0
	.dw 0x3340, 0xc089,	0x337f, 0xc089,		0x21, 0
	.dw 0x33c0, 0xc089,	0x33ff, 0xc089,		0x21, 0
	.dw 0x3440, 0xc089,	0x347f, 0xc089,		0x21, 0
	.dw 0x34c0, 0xc089,	0x34ff, 0xc089,		0x21, 0
	.dw 0x3540, 0xc089,	0x357f, 0xc089,		0x21, 0
	.dw 0x35c0, 0xc089,	0x35ff, 0xc089,		0x21, 0
	.dw 0x3640, 0xc089,	0x367f, 0xc089,		0x21, 0
	.dw 0x36c0, 0xc089,	0x36ff, 0xc089,		0x21, 0
	.dw 0x3740, 0xc089,	0x377f, 0xc089,		0x21, 0
	.dw 0x37c0, 0xc089,	0x37ff, 0xc089,		0x21, 0
	.dw 0x3840, 0xc089,	0x387f, 0xc089,		0x21, 0
	.dw 0x38c0, 0xc089,	0x38ff, 0xc089,		0x21, 0
	.dw 0x3940, 0xc089,	0x397f, 0xc089,		0x21, 0
	.dw 0x39c0, 0xc089,	0x5fff, 0xc089,		0x21, 0
	.dw 0x6040, 0xc089,	0x607f, 0xc089,		0x21, 0
	.dw 0x60c0, 0xc089,	0x60ff, 0xc089,		0x21, 0
	.dw 0x6140, 0xc089,	0x617f, 0xc089,		0x21, 0
	.dw 0x61c0, 0xc089,	0x61ff, 0xc089,		0x21, 0
	.dw 0x6240, 0xc089,	0x627f, 0xc089,		0x21, 0
	.dw 0x62c0, 0xc089,	0x62ff, 0xc089,		0x21, 0
	.dw 0x6340, 0xc089,	0x637f, 0xc089,		0x21, 0
	.dw 0x63c0, 0xc089,	0x63ff, 0xc089,		0x21, 0
	.dw 0x6440, 0xc089,	0x647f, 0xc089,		0x21, 0
	.dw 0x64c0, 0xc089,	0x64ff, 0xc089,		0x21, 0
	.dw 0x6540, 0xc089,	0x657f, 0xc089,		0x21, 0
	.dw 0x65c0, 0xc089,	0x65ff, 0xc089,		0x21, 0
	.dw 0x6640, 0xc089,	0x667f, 0xc089,		0x21, 0
	.dw 0x66c0, 0xc089,	0x66ff, 0xc089,		0x21, 0
	.dw 0x6740, 0xc089,	0x677f, 0xc089,		0x21, 0
	.dw 0x67c0, 0xc089,	0x67ff, 0xc089,		0x21, 0
	.dw 0x6840, 0xc089,	0x687f, 0xc089,		0x21, 0
	.dw 0x68c0, 0xc089,	0x68ff, 0xc089,		0x21, 0
	.dw 0x6940, 0xc089,	0x697f, 0xc089,		0x21, 0
	.dw 0x69c0, 0xc089,	0x69ff, 0xc089,		0x21, 0
	.dw 0x6a40, 0xc089,	0x6a7f, 0xc089,		0x21, 0
	.dw 0x6ac0, 0xc089,	0x6aff, 0xc089,		0x21, 0
	.dw 0x6b40, 0xc089,	0x6b7f, 0xc089,		0x21, 0
	.dw 0x6bc0, 0xc089,	0x6bff, 0xc089,		0x21, 0
	.dw 0x6c40, 0xc089,	0x6c7f, 0xc089,		0x21, 0
	.dw 0x6cc0, 0xc089,	0x6cff, 0xc089,		0x21, 0
	.dw 0x6d40, 0xc089,	0x6d7f, 0xc089,		0x21, 0
	.dw 0x6dc0, 0xc089,	0x6dff, 0xc089,		0x21, 0
	.dw 0x6e40, 0xc089,	0x6e7f, 0xc089,		0x21, 0
	.dw 0x6ec0, 0xc089,	0x6eff, 0xc089,		0x21, 0
	.dw 0x6f40, 0xc089,	0x6f7f, 0xc089,		0x21, 0
	.dw 0x6fc0, 0xc089,	0x6fff, 0xc089,		0x21, 0
	.dw 0x7040, 0xc089,	0x707f, 0xc089,		0x21, 0
	.dw 0x70c0, 0xc089,	0x70ff, 0xc089,		0x21, 0
	.dw 0x7140, 0xc089,	0x717f, 0xc089,		0x21, 0
	.dw 0x71c0, 0xc089,	0x71ff, 0xc089,		0x21, 0
	.dw 0x7240, 0xc089,	0x727f, 0xc089,		0x21, 0
	.dw 0x72c0, 0xc089,	0x72ff, 0xc089,		0x21, 0
	.dw 0x7340, 0xc089,	0x737f, 0xc089,		0x21, 0
	.dw 0x73c0, 0xc089,	0x73ff, 0xc089,		0x21, 0
	.dw 0x7440, 0xc089,	0x747f, 0xc089,		0x21, 0
	.dw 0x74c0, 0xc089,	0x74ff, 0xc089,		0x21, 0
	.dw 0x7540, 0xc089,	0x757f, 0xc089,		0x21, 0
	.dw 0x75c0, 0xc089,	0x75ff, 0xc089,		0x21, 0
	.dw 0x7640, 0xc089,	0x767f, 0xc089,		0x21, 0
	.dw 0x76c0, 0xc089,	0x76ff, 0xc089,		0x21, 0
	.dw 0x7740, 0xc089,	0x777f, 0xc089,		0x21, 0
	.dw 0x77c0, 0xc089,	0x77ff, 0xc089,		0x21, 0
	.dw 0x7840, 0xc089,	0x787f, 0xc089,		0x21, 0
	.dw 0x78c0, 0xc089,	0x78ff, 0xc089,		0x21, 0
	.dw 0x7940, 0xc089,	0x797f, 0xc089,		0x21, 0
	.dw 0x79c0, 0xc089,	0x9fff, 0xc089,		0x21, 0
	.dw 0xa040, 0xc089,	0xa07f, 0xc089,		0x21, 0
	.dw 0xa0c0, 0xc089,	0xa0ff, 0xc089,		0x21, 0
	.dw 0xa140, 0xc089,	0xa17f, 0xc089,		0x21, 0
	.dw 0xa1c0, 0xc089,	0xa1ff, 0xc089,		0x21, 0
	.dw 0xa240, 0xc089,	0xa27f, 0xc089,		0x21, 0
	.dw 0xa2c0, 0xc089,	0xa2ff, 0xc089,		0x21, 0
	.dw 0xa340, 0xc089,	0xa37f, 0xc089,		0x21, 0
	.dw 0xa3c0, 0xc089,	0xa3ff, 0xc089,		0x21, 0
	.dw 0xa440, 0xc089,	0xa47f, 0xc089,		0x21, 0
	.dw 0xa4c0, 0xc089,	0xa4ff, 0xc089,		0x21, 0
	.dw 0xa540, 0xc089,	0xa57f, 0xc089,		0x21, 0
	.dw 0xa5c0, 0xc089,	0xa5ff, 0xc089,		0x21, 0
	.dw 0xa640, 0xc089,	0xa67f, 0xc089,		0x21, 0
	.dw 0xa6c0, 0xc089,	0xa6ff, 0xc089,		0x21, 0
	.dw 0xa740, 0xc089,	0xa77f, 0xc089,		0x21, 0
	.dw 0xa7c0, 0xc089,	0xa7ff, 0xc089,		0x21, 0
	.dw 0xa840, 0xc089,	0xa87f, 0xc089,		0x21, 0
	.dw 0xa8c0, 0xc089,	0xa8ff, 0xc089,		0x21, 0
	.dw 0xa940, 0xc089,	0xa97f, 0xc089,		0x21, 0
	.dw 0xa9c0, 0xc089,	0xa9ff, 0xc089,		0x21, 0
	.dw 0xaa40, 0xc089,	0xaa7f, 0xc089,		0x21, 0
	.dw 0xaac0, 0xc089,	0xaaff, 0xc089,		0x21, 0
	.dw 0xab40, 0xc089,	0xab7f, 0xc089,		0x21, 0
	.dw 0xabc0, 0xc089,	0xabff, 0xc089,		0x21, 0
	.dw 0xac40, 0xc089,	0xac7f, 0xc089,		0x21, 0
	.dw 0xacc0, 0xc089,	0xacff, 0xc089,		0x21, 0
	.dw 0xad40, 0xc089,	0xad7f, 0xc089,		0x21, 0
	.dw 0xadc0, 0xc089,	0xadff, 0xc089,		0x21, 0
	.dw 0xae40, 0xc089,	0xae7f, 0xc089,		0x21, 0
	.dw 0xaec0, 0xc089,	0xaeff, 0xc089,		0x21, 0
	.dw 0xaf40, 0xc089,	0xaf7f, 0xc089,		0x21, 0
	.dw 0xafc0, 0xc089,	0xafff, 0xc089,		0x21, 0
	.dw 0xb040, 0xc089,	0xb07f, 0xc089,		0x21, 0
	.dw 0xb0c0, 0xc089,	0xb0ff, 0xc089,		0x21, 0
	.dw 0xb140, 0xc089,	0xb17f, 0xc089,		0x21, 0
	.dw 0xb1c0, 0xc089,	0xb1ff, 0xc089,		0x21, 0
	.dw 0xb240, 0xc089,	0xb27f, 0xc089,		0x21, 0
	.dw 0xb2c0, 0xc089,	0xb2ff, 0xc089,		0x21, 0
	.dw 0xb340, 0xc089,	0xb37f, 0xc089,		0x21, 0
	.dw 0xb3c0, 0xc089,	0xb3ff, 0xc089,		0x21, 0
	.dw 0xb440, 0xc089,	0xb47f, 0xc089,		0x21, 0
	.dw 0xb4c0, 0xc089,	0xb4ff, 0xc089,		0x21, 0
	.dw 0xb540, 0xc089,	0xb57f, 0xc089,		0x21, 0
	.dw 0xb5c0, 0xc089,	0xb5ff, 0xc089,		0x21, 0
	.dw 0xb640, 0xc089,	0xb67f, 0xc089,		0x21, 0
	.dw 0xb6c0, 0xc089,	0xb6ff, 0xc089,		0x21, 0
	.dw 0xb740, 0xc089,	0xb77f, 0xc089,		0x21, 0
	.dw 0xb7c0, 0xc089,	0xb7ff, 0xc089,		0x21, 0
	.dw 0xb840, 0xc089,	0xb87f, 0xc089,		0x21, 0
	.dw 0xb8c0, 0xc089,	0xb8ff, 0xc089,		0x21, 0
	.dw 0xb940, 0xc089,	0xb97f, 0xc089,		0x21, 0
	.dw 0xb9c0, 0xc089,	0xdfff, 0xc089,		0x21, 0
	.dw 0xe040, 0xc089,	0xe07f, 0xc089,		0x21, 0
	.dw 0xe0c0, 0xc089,	0xe0ff, 0xc089,		0x21, 0
	.dw 0xe140, 0xc089,	0xe17f, 0xc089,		0x21, 0
	.dw 0xe1c0, 0xc089,	0xe1ff, 0xc089,		0x21, 0
	.dw 0xe240, 0xc089,	0xe27f, 0xc089,		0x21, 0
	.dw 0xe2c0, 0xc089,	0xe2ff, 0xc089,		0x21, 0
	.dw 0xe340, 0xc089,	0xe37f, 0xc089,		0x21, 0
	.dw 0xe3c0, 0xc089,	0xe3ff, 0xc089,		0x21, 0
	.dw 0xe440, 0xc089,	0xe47f, 0xc089,		0x21, 0
	.dw 0xe4c0, 0xc089,	0xe4ff, 0xc089,		0x21, 0
	.dw 0xe540, 0xc089,	0xe57f, 0xc089,		0x21, 0
	.dw 0xe5c0, 0xc089,	0xe5ff, 0xc089,		0x21, 0
	.dw 0xe640, 0xc089,	0xe67f, 0xc089,		0x21, 0
	.dw 0xe6c0, 0xc089,	0xe6ff, 0xc089,		0x21, 0
	.dw 0xe740, 0xc089,	0xe77f, 0xc089,		0x21, 0
	.dw 0xe7c0, 0xc089,	0xe7ff, 0xc089,		0x21, 0
	.dw 0xe840, 0xc089,	0xe87f, 0xc089,		0x21, 0
	.dw 0xe8c0, 0xc089,	0xe8ff, 0xc089,		0x21, 0
	.dw 0xe940, 0xc089,	0xe97f, 0xc089,		0x21, 0
	.dw 0xe9c0, 0xc089,	0xe9ff, 0xc089,		0x21, 0
	.dw 0xea40, 0xc089,	0xea7f, 0xc089,		0x21, 0
	.dw 0xeac0, 0xc089,	0xeaff, 0xc089,		0x21, 0
	.dw 0xeb40, 0xc089,	0xeb7f, 0xc089,		0x21, 0
	.dw 0xebc0, 0xc089,	0xebff, 0xc089,		0x21, 0
	.dw 0xec40, 0xc089,	0xec7f, 0xc089,		0x21, 0
	.dw 0xecc0, 0xc089,	0xecff, 0xc089,		0x21, 0
	.dw 0xed40, 0xc089,	0xed7f, 0xc089,		0x21, 0
	.dw 0xedc0, 0xc089,	0xedff, 0xc089,		0x21, 0
	.dw 0xee40, 0xc089,	0xee7f, 0xc089,		0x21, 0
	.dw 0xeec0, 0xc089,	0xeeff, 0xc089,		0x21, 0
	.dw 0xef40, 0xc089,	0xef7f, 0xc089,		0x21, 0
	.dw 0xefc0, 0xc089,	0xefff, 0xc089,		0x21, 0
	.dw 0xf040, 0xc089,	0xf07f, 0xc089,		0x21, 0
	.dw 0xf0c0, 0xc089,	0xf0ff, 0xc089,		0x21, 0
	.dw 0xf140, 0xc089,	0xf17f, 0xc089,		0x21, 0
	.dw 0xf1c0, 0xc089,	0xf1ff, 0xc089,		0x21, 0
	.dw 0xf240, 0xc089,	0xf27f, 0xc089,		0x21, 0
	.dw 0xf2c0, 0xc089,	0xf2ff, 0xc089,		0x21, 0
	.dw 0xf340, 0xc089,	0xf37f, 0xc089,		0x21, 0
	.dw 0xf3c0, 0xc089,	0xf3ff, 0xc089,		0x21, 0
	.dw 0xf440, 0xc089,	0xf47f, 0xc089,		0x21, 0
	.dw 0xf4c0, 0xc089,	0xf4ff, 0xc089,		0x21, 0
	.dw 0xf540, 0xc089,	0xf57f, 0xc089,		0x21, 0
	.dw 0xf5c0, 0xc089,	0xf5ff, 0xc089,		0x21, 0
	.dw 0xf640, 0xc089,	0xf67f, 0xc089,		0x21, 0
	.dw 0xf6c0, 0xc089,	0xf6ff, 0xc089,		0x21, 0
	.dw 0xf740, 0xc089,	0xf77f, 0xc089,		0x21, 0
	.dw 0xf7c0, 0xc089,	0xf7ff, 0xc089,		0x21, 0
	.dw 0xf840, 0xc089,	0xf87f, 0xc089,		0x21, 0
	.dw 0xf8c0, 0xc089,	0xf8ff, 0xc089,		0x21, 0
	.dw 0xf940, 0xc089,	0xf97f, 0xc089,		0x21, 0
	.dw 0xf9c0, 0xc089,	0x1fff, 0xc08a,		0x21, 0
	.dw 0x2040, 0xc08a,	0x207f, 0xc08a,		0x21, 0
	.dw 0x20c0, 0xc08a,	0x20ff, 0xc08a,		0x21, 0
	.dw 0x2140, 0xc08a,	0x217f, 0xc08a,		0x21, 0
	.dw 0x21c0, 0xc08a,	0x21ff, 0xc08a,		0x21, 0
	.dw 0x2240, 0xc08a,	0x227f, 0xc08a,		0x21, 0
	.dw 0x22c0, 0xc08a,	0x22ff, 0xc08a,		0x21, 0
	.dw 0x2340, 0xc08a,	0x237f, 0xc08a,		0x21, 0
	.dw 0x23c0, 0xc08a,	0x23ff, 0xc08a,		0x21, 0
	.dw 0x2440, 0xc08a,	0x247f, 0xc08a,		0x21, 0
	.dw 0x24c0, 0xc08a,	0x24ff, 0xc08a,		0x21, 0
	.dw 0x2540, 0xc08a,	0x257f, 0xc08a,		0x21, 0
	.dw 0x25c0, 0xc08a,	0x25ff, 0xc08a,		0x21, 0
	.dw 0x2640, 0xc08a,	0x267f, 0xc08a,		0x21, 0
	.dw 0x26c0, 0xc08a,	0x26ff, 0xc08a,		0x21, 0
	.dw 0x2740, 0xc08a,	0x277f, 0xc08a,		0x21, 0
	.dw 0x27c0, 0xc08a,	0x27ff, 0xc08a,		0x21, 0
	.dw 0x2840, 0xc08a,	0x287f, 0xc08a,		0x21, 0
	.dw 0x28c0, 0xc08a,	0x28ff, 0xc08a,		0x21, 0
	.dw 0x2940, 0xc08a,	0x297f, 0xc08a,		0x21, 0
	.dw 0x29c0, 0xc08a,	0x29ff, 0xc08a,		0x21, 0
	.dw 0x2a40, 0xc08a,	0x2a7f, 0xc08a,		0x21, 0
	.dw 0x2ac0, 0xc08a,	0x2aff, 0xc08a,		0x21, 0
	.dw 0x2b40, 0xc08a,	0x2b7f, 0xc08a,		0x21, 0
	.dw 0x2bc0, 0xc08a,	0x2bff, 0xc08a,		0x21, 0
	.dw 0x2c40, 0xc08a,	0x2c7f, 0xc08a,		0x21, 0
	.dw 0x2cc0, 0xc08a,	0x2cff, 0xc08a,		0x21, 0
	.dw 0x2d40, 0xc08a,	0x2d7f, 0xc08a,		0x21, 0
	.dw 0x2dc0, 0xc08a,	0x2dff, 0xc08a,		0x21, 0
	.dw 0x2e40, 0xc08a,	0x2e7f, 0xc08a,		0x21, 0
	.dw 0x2ec0, 0xc08a,	0x2eff, 0xc08a,		0x21, 0
	.dw 0x2f40, 0xc08a,	0x2f7f, 0xc08a,		0x21, 0
	.dw 0x2fc0, 0xc08a,	0x2fff, 0xc08a,		0x21, 0
	.dw 0x3040, 0xc08a,	0x307f, 0xc08a,		0x21, 0
	.dw 0x30c0, 0xc08a,	0x30ff, 0xc08a,		0x21, 0
	.dw 0x3140, 0xc08a,	0x317f, 0xc08a,		0x21, 0
	.dw 0x31c0, 0xc08a,	0x31ff, 0xc08a,		0x21, 0
	.dw 0x3240, 0xc08a,	0x327f, 0xc08a,		0x21, 0
	.dw 0x32c0, 0xc08a,	0x32ff, 0xc08a,		0x21, 0
	.dw 0x3340, 0xc08a,	0x337f, 0xc08a,		0x21, 0
	.dw 0x33c0, 0xc08a,	0x33ff, 0xc08a,		0x21, 0
	.dw 0x3440, 0xc08a,	0x347f, 0xc08a,		0x21, 0
	.dw 0x34c0, 0xc08a,	0x34ff, 0xc08a,		0x21, 0
	.dw 0x3540, 0xc08a,	0x357f, 0xc08a,		0x21, 0
	.dw 0x35c0, 0xc08a,	0x35ff, 0xc08a,		0x21, 0
	.dw 0x3640, 0xc08a,	0x367f, 0xc08a,		0x21, 0
	.dw 0x36c0, 0xc08a,	0x36ff, 0xc08a,		0x21, 0
	.dw 0x3740, 0xc08a,	0x377f, 0xc08a,		0x21, 0
	.dw 0x37c0, 0xc08a,	0x37ff, 0xc08a,		0x21, 0
	.dw 0x3840, 0xc08a,	0x387f, 0xc08a,		0x21, 0
	.dw 0x38c0, 0xc08a,	0x38ff, 0xc08a,		0x21, 0
	.dw 0x3940, 0xc08a,	0x397f, 0xc08a,		0x21, 0
	.dw 0x39c0, 0xc08a,	0x5fff, 0xc08a,		0x21, 0
	.dw 0x6040, 0xc08a,	0x607f, 0xc08a,		0x21, 0
	.dw 0x60c0, 0xc08a,	0x60ff, 0xc08a,		0x21, 0
	.dw 0x6140, 0xc08a,	0x617f, 0xc08a,		0x21, 0
	.dw 0x61c0, 0xc08a,	0x61ff, 0xc08a,		0x21, 0
	.dw 0x6240, 0xc08a,	0x627f, 0xc08a,		0x21, 0
	.dw 0x62c0, 0xc08a,	0x62ff, 0xc08a,		0x21, 0
	.dw 0x6340, 0xc08a,	0x637f, 0xc08a,		0x21, 0
	.dw 0x63c0, 0xc08a,	0x63ff, 0xc08a,		0x21, 0
	.dw 0x6440, 0xc08a,	0x647f, 0xc08a,		0x21, 0
	.dw 0x64c0, 0xc08a,	0x64ff, 0xc08a,		0x21, 0
	.dw 0x6540, 0xc08a,	0x657f, 0xc08a,		0x21, 0
	.dw 0x65c0, 0xc08a,	0x65ff, 0xc08a,		0x21, 0
	.dw 0x6640, 0xc08a,	0x667f, 0xc08a,		0x21, 0
	.dw 0x66c0, 0xc08a,	0x66ff, 0xc08a,		0x21, 0
	.dw 0x6740, 0xc08a,	0x677f, 0xc08a,		0x21, 0
	.dw 0x67c0, 0xc08a,	0x67ff, 0xc08a,		0x21, 0
	.dw 0x6840, 0xc08a,	0x687f, 0xc08a,		0x21, 0
	.dw 0x68c0, 0xc08a,	0x68ff, 0xc08a,		0x21, 0
	.dw 0x6940, 0xc08a,	0x697f, 0xc08a,		0x21, 0
	.dw 0x69c0, 0xc08a,	0x69ff, 0xc08a,		0x21, 0
	.dw 0x6a40, 0xc08a,	0x6a7f, 0xc08a,		0x21, 0
	.dw 0x6ac0, 0xc08a,	0x6aff, 0xc08a,		0x21, 0
	.dw 0x6b40, 0xc08a,	0x6b7f, 0xc08a,		0x21, 0
	.dw 0x6bc0, 0xc08a,	0x6bff, 0xc08a,		0x21, 0
	.dw 0x6c40, 0xc08a,	0x6c7f, 0xc08a,		0x21, 0
	.dw 0x6cc0, 0xc08a,	0x6cff, 0xc08a,		0x21, 0
	.dw 0x6d40, 0xc08a,	0x6d7f, 0xc08a,		0x21, 0
	.dw 0x6dc0, 0xc08a,	0x6dff, 0xc08a,		0x21, 0
	.dw 0x6e40, 0xc08a,	0x6e7f, 0xc08a,		0x21, 0
	.dw 0x6ec0, 0xc08a,	0x6eff, 0xc08a,		0x21, 0
	.dw 0x6f40, 0xc08a,	0x6f7f, 0xc08a,		0x21, 0
	.dw 0x6fc0, 0xc08a,	0x6fff, 0xc08a,		0x21, 0
	.dw 0x7040, 0xc08a,	0x707f, 0xc08a,		0x21, 0
	.dw 0x70c0, 0xc08a,	0x70ff, 0xc08a,		0x21, 0
	.dw 0x7140, 0xc08a,	0x717f, 0xc08a,		0x21, 0
	.dw 0x71c0, 0xc08a,	0x71ff, 0xc08a,		0x21, 0
	.dw 0x7240, 0xc08a,	0x727f, 0xc08a,		0x21, 0
	.dw 0x72c0, 0xc08a,	0x72ff, 0xc08a,		0x21, 0
	.dw 0x7340, 0xc08a,	0x737f, 0xc08a,		0x21, 0
	.dw 0x73c0, 0xc08a,	0x73ff, 0xc08a,		0x21, 0
	.dw 0x7440, 0xc08a,	0x747f, 0xc08a,		0x21, 0
	.dw 0x74c0, 0xc08a,	0x74ff, 0xc08a,		0x21, 0
	.dw 0x7540, 0xc08a,	0x757f, 0xc08a,		0x21, 0
	.dw 0x75c0, 0xc08a,	0x75ff, 0xc08a,		0x21, 0
	.dw 0x7640, 0xc08a,	0x767f, 0xc08a,		0x21, 0
	.dw 0x76c0, 0xc08a,	0x76ff, 0xc08a,		0x21, 0
	.dw 0x7740, 0xc08a,	0x777f, 0xc08a,		0x21, 0
	.dw 0x77c0, 0xc08a,	0x77ff, 0xc08a,		0x21, 0
	.dw 0x7840, 0xc08a,	0x787f, 0xc08a,		0x21, 0
	.dw 0x78c0, 0xc08a,	0x78ff, 0xc08a,		0x21, 0
	.dw 0x7940, 0xc08a,	0x797f, 0xc08a,		0x21, 0
	.dw 0x79c0, 0xc08a,	0x9fff, 0xc08a,		0x21, 0
	.dw 0xa040, 0xc08a,	0xa07f, 0xc08a,		0x21, 0
	.dw 0xa0c0, 0xc08a,	0xa0ff, 0xc08a,		0x21, 0
	.dw 0xa140, 0xc08a,	0xa17f, 0xc08a,		0x21, 0
	.dw 0xa1c0, 0xc08a,	0xa1ff, 0xc08a,		0x21, 0
	.dw 0xa240, 0xc08a,	0xa27f, 0xc08a,		0x21, 0
	.dw 0xa2c0, 0xc08a,	0xa2ff, 0xc08a,		0x21, 0
	.dw 0xa340, 0xc08a,	0xa37f, 0xc08a,		0x21, 0
	.dw 0xa3c0, 0xc08a,	0xa3ff, 0xc08a,		0x21, 0
	.dw 0xa440, 0xc08a,	0xa47f, 0xc08a,		0x21, 0
	.dw 0xa4c0, 0xc08a,	0xa4ff, 0xc08a,		0x21, 0
	.dw 0xa540, 0xc08a,	0xa57f, 0xc08a,		0x21, 0
	.dw 0xa5c0, 0xc08a,	0xa5ff, 0xc08a,		0x21, 0
	.dw 0xa640, 0xc08a,	0xa67f, 0xc08a,		0x21, 0
	.dw 0xa6c0, 0xc08a,	0xa6ff, 0xc08a,		0x21, 0
	.dw 0xa740, 0xc08a,	0xa77f, 0xc08a,		0x21, 0
	.dw 0xa7c0, 0xc08a,	0xa7ff, 0xc08a,		0x21, 0
	.dw 0xa840, 0xc08a,	0xa87f, 0xc08a,		0x21, 0
	.dw 0xa8c0, 0xc08a,	0xa8ff, 0xc08a,		0x21, 0
	.dw 0xa940, 0xc08a,	0xa97f, 0xc08a,		0x21, 0
	.dw 0xa9c0, 0xc08a,	0xa9ff, 0xc08a,		0x21, 0
	.dw 0xaa40, 0xc08a,	0xaa7f, 0xc08a,		0x21, 0
	.dw 0xaac0, 0xc08a,	0xaaff, 0xc08a,		0x21, 0
	.dw 0xab40, 0xc08a,	0xab7f, 0xc08a,		0x21, 0
	.dw 0xabc0, 0xc08a,	0xabff, 0xc08a,		0x21, 0
	.dw 0xac40, 0xc08a,	0xac7f, 0xc08a,		0x21, 0
	.dw 0xacc0, 0xc08a,	0xacff, 0xc08a,		0x21, 0
	.dw 0xad40, 0xc08a,	0xad7f, 0xc08a,		0x21, 0
	.dw 0xadc0, 0xc08a,	0xadff, 0xc08a,		0x21, 0
	.dw 0xae40, 0xc08a,	0xae7f, 0xc08a,		0x21, 0
	.dw 0xaec0, 0xc08a,	0xaeff, 0xc08a,		0x21, 0
	.dw 0xaf40, 0xc08a,	0xaf7f, 0xc08a,		0x21, 0
	.dw 0xafc0, 0xc08a,	0xafff, 0xc08a,		0x21, 0
	.dw 0xb040, 0xc08a,	0xb07f, 0xc08a,		0x21, 0
	.dw 0xb0c0, 0xc08a,	0xb0ff, 0xc08a,		0x21, 0
	.dw 0xb140, 0xc08a,	0xb17f, 0xc08a,		0x21, 0
	.dw 0xb1c0, 0xc08a,	0xb1ff, 0xc08a,		0x21, 0
	.dw 0xb240, 0xc08a,	0xb27f, 0xc08a,		0x21, 0
	.dw 0xb2c0, 0xc08a,	0xb2ff, 0xc08a,		0x21, 0
	.dw 0xb340, 0xc08a,	0xb37f, 0xc08a,		0x21, 0
	.dw 0xb3c0, 0xc08a,	0xb3ff, 0xc08a,		0x21, 0
	.dw 0xb440, 0xc08a,	0xb47f, 0xc08a,		0x21, 0
	.dw 0xb4c0, 0xc08a,	0xb4ff, 0xc08a,		0x21, 0
	.dw 0xb540, 0xc08a,	0xb57f, 0xc08a,		0x21, 0
	.dw 0xb5c0, 0xc08a,	0xb5ff, 0xc08a,		0x21, 0
	.dw 0xb640, 0xc08a,	0xb67f, 0xc08a,		0x21, 0
	.dw 0xb6c0, 0xc08a,	0xb6ff, 0xc08a,		0x21, 0
	.dw 0xb740, 0xc08a,	0xb77f, 0xc08a,		0x21, 0
	.dw 0xb7c0, 0xc08a,	0xb7ff, 0xc08a,		0x21, 0
	.dw 0xb840, 0xc08a,	0xb87f, 0xc08a,		0x21, 0
	.dw 0xb8c0, 0xc08a,	0xb8ff, 0xc08a,		0x21, 0
	.dw 0xb940, 0xc08a,	0xb97f, 0xc08a,		0x21, 0
	.dw 0xb9c0, 0xc08a,	0xdfff, 0xc08a,		0x21, 0
	.dw 0xe040, 0xc08a,	0xe07f, 0xc08a,		0x21, 0
	.dw 0xe0c0, 0xc08a,	0xe0ff, 0xc08a,		0x21, 0
	.dw 0xe140, 0xc08a,	0xe17f, 0xc08a,		0x21, 0
	.dw 0xe1c0, 0xc08a,	0xe1ff, 0xc08a,		0x21, 0
	.dw 0xe240, 0xc08a,	0xe27f, 0xc08a,		0x21, 0
	.dw 0xe2c0, 0xc08a,	0xe2ff, 0xc08a,		0x21, 0
	.dw 0xe340, 0xc08a,	0xe37f, 0xc08a,		0x21, 0
	.dw 0xe3c0, 0xc08a,	0xe3ff, 0xc08a,		0x21, 0
	.dw 0xe440, 0xc08a,	0xe47f, 0xc08a,		0x21, 0
	.dw 0xe4c0, 0xc08a,	0xe4ff, 0xc08a,		0x21, 0
	.dw 0xe540, 0xc08a,	0xe57f, 0xc08a,		0x21, 0
	.dw 0xe5c0, 0xc08a,	0xe5ff, 0xc08a,		0x21, 0
	.dw 0xe640, 0xc08a,	0xe67f, 0xc08a,		0x21, 0
	.dw 0xe6c0, 0xc08a,	0xe6ff, 0xc08a,		0x21, 0
	.dw 0xe740, 0xc08a,	0xe77f, 0xc08a,		0x21, 0
	.dw 0xe7c0, 0xc08a,	0xe7ff, 0xc08a,		0x21, 0
	.dw 0xe840, 0xc08a,	0xe87f, 0xc08a,		0x21, 0
	.dw 0xe8c0, 0xc08a,	0xe8ff, 0xc08a,		0x21, 0
	.dw 0xe940, 0xc08a,	0xe97f, 0xc08a,		0x21, 0
	.dw 0xe9c0, 0xc08a,	0xe9ff, 0xc08a,		0x21, 0
	.dw 0xea40, 0xc08a,	0xea7f, 0xc08a,		0x21, 0
	.dw 0xeac0, 0xc08a,	0xeaff, 0xc08a,		0x21, 0
	.dw 0xeb40, 0xc08a,	0xeb7f, 0xc08a,		0x21, 0
	.dw 0xebc0, 0xc08a,	0xebff, 0xc08a,		0x21, 0
	.dw 0xec40, 0xc08a,	0xec7f, 0xc08a,		0x21, 0
	.dw 0xecc0, 0xc08a,	0xecff, 0xc08a,		0x21, 0
	.dw 0xed40, 0xc08a,	0xed7f, 0xc08a,		0x21, 0
	.dw 0xedc0, 0xc08a,	0xedff, 0xc08a,		0x21, 0
	.dw 0xee40, 0xc08a,	0xee7f, 0xc08a,		0x21, 0
	.dw 0xeec0, 0xc08a,	0xeeff, 0xc08a,		0x21, 0
	.dw 0xef40, 0xc08a,	0xef7f, 0xc08a,		0x21, 0
	.dw 0xefc0, 0xc08a,	0xefff, 0xc08a,		0x21, 0
	.dw 0xf040, 0xc08a,	0xf07f, 0xc08a,		0x21, 0
	.dw 0xf0c0, 0xc08a,	0xf0ff, 0xc08a,		0x21, 0
	.dw 0xf140, 0xc08a,	0xf17f, 0xc08a,		0x21, 0
	.dw 0xf1c0, 0xc08a,	0xf1ff, 0xc08a,		0x21, 0
	.dw 0xf240, 0xc08a,	0xf27f, 0xc08a,		0x21, 0
	.dw 0xf2c0, 0xc08a,	0xf2ff, 0xc08a,		0x21, 0
	.dw 0xf340, 0xc08a,	0xf37f, 0xc08a,		0x21, 0
	.dw 0xf3c0, 0xc08a,	0xf3ff, 0xc08a,		0x21, 0
	.dw 0xf440, 0xc08a,	0xf47f, 0xc08a,		0x21, 0
	.dw 0xf4c0, 0xc08a,	0xf4ff, 0xc08a,		0x21, 0
	.dw 0xf540, 0xc08a,	0xf57f, 0xc08a,		0x21, 0
	.dw 0xf5c0, 0xc08a,	0xf5ff, 0xc08a,		0x21, 0
	.dw 0xf640, 0xc08a,	0xf67f, 0xc08a,		0x21, 0
	.dw 0xf6c0, 0xc08a,	0xf6ff, 0xc08a,		0x21, 0
	.dw 0xf740, 0xc08a,	0xf77f, 0xc08a,		0x21, 0
	.dw 0xf7c0, 0xc08a,	0xf7ff, 0xc08a,		0x21, 0
	.dw 0xf840, 0xc08a,	0xf87f, 0xc08a,		0x21, 0
	.dw 0xf8c0, 0xc08a,	0xf8ff, 0xc08a,		0x21, 0
	.dw 0xf940, 0xc08a,	0xf97f, 0xc08a,		0x21, 0
	.dw 0xf9c0, 0xc08a,	0x1fff, 0xc08b,		0x21, 0
	.dw 0x2040, 0xc08b,	0x207f, 0xc08b,		0x21, 0
	.dw 0x20c0, 0xc08b,	0x20ff, 0xc08b,		0x21, 0
	.dw 0x2140, 0xc08b,	0x217f, 0xc08b,		0x21, 0
	.dw 0x21c0, 0xc08b,	0x21ff, 0xc08b,		0x21, 0
	.dw 0x2240, 0xc08b,	0x227f, 0xc08b,		0x21, 0
	.dw 0x22c0, 0xc08b,	0x22ff, 0xc08b,		0x21, 0
	.dw 0x2340, 0xc08b,	0x237f, 0xc08b,		0x21, 0
	.dw 0x23c0, 0xc08b,	0x23ff, 0xc08b,		0x21, 0
	.dw 0x2440, 0xc08b,	0x247f, 0xc08b,		0x21, 0
	.dw 0x24c0, 0xc08b,	0x24ff, 0xc08b,		0x21, 0
	.dw 0x2540, 0xc08b,	0x257f, 0xc08b,		0x21, 0
	.dw 0x25c0, 0xc08b,	0x25ff, 0xc08b,		0x21, 0
	.dw 0x2640, 0xc08b,	0x267f, 0xc08b,		0x21, 0
	.dw 0x26c0, 0xc08b,	0x26ff, 0xc08b,		0x21, 0
	.dw 0x2740, 0xc08b,	0x277f, 0xc08b,		0x21, 0
	.dw 0x27c0, 0xc08b,	0x27ff, 0xc08b,		0x21, 0
	.dw 0x2840, 0xc08b,	0x287f, 0xc08b,		0x21, 0
	.dw 0x28c0, 0xc08b,	0x28ff, 0xc08b,		0x21, 0
	.dw 0x2940, 0xc08b,	0x297f, 0xc08b,		0x21, 0
	.dw 0x29c0, 0xc08b,	0x29ff, 0xc08b,		0x21, 0
	.dw 0x2a40, 0xc08b,	0x2a7f, 0xc08b,		0x21, 0
	.dw 0x2ac0, 0xc08b,	0x2aff, 0xc08b,		0x21, 0
	.dw 0x2b40, 0xc08b,	0x2b7f, 0xc08b,		0x21, 0
	.dw 0x2bc0, 0xc08b,	0x2bff, 0xc08b,		0x21, 0
	.dw 0x2c40, 0xc08b,	0x2c7f, 0xc08b,		0x21, 0
	.dw 0x2cc0, 0xc08b,	0x2cff, 0xc08b,		0x21, 0
	.dw 0x2d40, 0xc08b,	0x2d7f, 0xc08b,		0x21, 0
	.dw 0x2dc0, 0xc08b,	0x2dff, 0xc08b,		0x21, 0
	.dw 0x2e40, 0xc08b,	0x2e7f, 0xc08b,		0x21, 0
	.dw 0x2ec0, 0xc08b,	0x2eff, 0xc08b,		0x21, 0
	.dw 0x2f40, 0xc08b,	0x2f7f, 0xc08b,		0x21, 0
	.dw 0x2fc0, 0xc08b,	0x2fff, 0xc08b,		0x21, 0
	.dw 0x3040, 0xc08b,	0x307f, 0xc08b,		0x21, 0
	.dw 0x30c0, 0xc08b,	0x30ff, 0xc08b,		0x21, 0
	.dw 0x3140, 0xc08b,	0x317f, 0xc08b,		0x21, 0
	.dw 0x31c0, 0xc08b,	0x31ff, 0xc08b,		0x21, 0
	.dw 0x3240, 0xc08b,	0x327f, 0xc08b,		0x21, 0
	.dw 0x32c0, 0xc08b,	0x32ff, 0xc08b,		0x21, 0
	.dw 0x3340, 0xc08b,	0x337f, 0xc08b,		0x21, 0
	.dw 0x33c0, 0xc08b,	0x33ff, 0xc08b,		0x21, 0
	.dw 0x3440, 0xc08b,	0x347f, 0xc08b,		0x21, 0
	.dw 0x34c0, 0xc08b,	0x34ff, 0xc08b,		0x21, 0
	.dw 0x3540, 0xc08b,	0x357f, 0xc08b,		0x21, 0
	.dw 0x35c0, 0xc08b,	0x35ff, 0xc08b,		0x21, 0
	.dw 0x3640, 0xc08b,	0x367f, 0xc08b,		0x21, 0
	.dw 0x36c0, 0xc08b,	0x36ff, 0xc08b,		0x21, 0
	.dw 0x3740, 0xc08b,	0x377f, 0xc08b,		0x21, 0
	.dw 0x37c0, 0xc08b,	0x37ff, 0xc08b,		0x21, 0
	.dw 0x3840, 0xc08b,	0x387f, 0xc08b,		0x21, 0
	.dw 0x38c0, 0xc08b,	0x38ff, 0xc08b,		0x21, 0
	.dw 0x3940, 0xc08b,	0x397f, 0xc08b,		0x21, 0
	.dw 0x39c0, 0xc08b,	0xffff, 0xc08b,		0x21, 0
	.dw 0x0040, 0xc08c,	0x007f, 0xc08c,		0x21, 0
	.dw 0x00c0, 0xc08c,	0x00ff, 0xc08c,		0x21, 0
	.dw 0x0140, 0xc08c,	0x017f, 0xc08c,		0x21, 0
	.dw 0x01c0, 0xc08c,	0x01ff, 0xc08c,		0x21, 0
	.dw 0x0240, 0xc08c,	0x027f, 0xc08c,		0x21, 0
	.dw 0x02c0, 0xc08c,	0x02ff, 0xc08c,		0x21, 0
	.dw 0x0340, 0xc08c,	0x037f, 0xc08c,		0x21, 0
	.dw 0x03c0, 0xc08c,	0x03ff, 0xc08c,		0x21, 0
	.dw 0x0440, 0xc08c,	0x047f, 0xc08c,		0x21, 0
	.dw 0x04c0, 0xc08c,	0x04ff, 0xc08c,		0x21, 0
	.dw 0x0540, 0xc08c,	0x057f, 0xc08c,		0x21, 0
	.dw 0x05c0, 0xc08c,	0x05ff, 0xc08c,		0x21, 0
	.dw 0x0640, 0xc08c,	0x067f, 0xc08c,		0x21, 0
	.dw 0x06c0, 0xc08c,	0x06ff, 0xc08c,		0x21, 0
	.dw 0x0740, 0xc08c,	0x077f, 0xc08c,		0x21, 0
	.dw 0x07c0, 0xc08c,	0x07ff, 0xc08c,		0x21, 0
	.dw 0x0840, 0xc08c,	0x087f, 0xc08c,		0x21, 0
	.dw 0x08c0, 0xc08c,	0x08ff, 0xc08c,		0x21, 0
	.dw 0x0940, 0xc08c,	0x097f, 0xc08c,		0x21, 0
	.dw 0x09c0, 0xc08c,	0x09ff, 0xc08c,		0x21, 0
	.dw 0x0a40, 0xc08c,	0x0a7f, 0xc08c,		0x21, 0
	.dw 0x0ac0, 0xc08c,	0x0aff, 0xc08c,		0x21, 0
	.dw 0x0b40, 0xc08c,	0x0b7f, 0xc08c,		0x21, 0
	.dw 0x0bc0, 0xc08c,	0x0bff, 0xc08c,		0x21, 0
	.dw 0x0c40, 0xc08c,	0x0c7f, 0xc08c,		0x21, 0
	.dw 0x0cc0, 0xc08c,	0x0cff, 0xc08c,		0x21, 0
	.dw 0x0d40, 0xc08c,	0x0d7f, 0xc08c,		0x21, 0
	.dw 0x0dc0, 0xc08c,	0x0dff, 0xc08c,		0x21, 0
	.dw 0x0e40, 0xc08c,	0x0e7f, 0xc08c,		0x21, 0
	.dw 0x0ec0, 0xc08c,	0x0eff, 0xc08c,		0x21, 0
	.dw 0x0f40, 0xc08c,	0x0f7f, 0xc08c,		0x21, 0
	.dw 0x0fc0, 0xc08c,	0x0fff, 0xc08c,		0x21, 0
	.dw 0x1040, 0xc08c,	0x107f, 0xc08c,		0x21, 0
	.dw 0x10c0, 0xc08c,	0x10ff, 0xc08c,		0x21, 0
	.dw 0x1140, 0xc08c,	0x117f, 0xc08c,		0x21, 0
	.dw 0x11c0, 0xc08c,	0x11ff, 0xc08c,		0x21, 0
	.dw 0x1240, 0xc08c,	0x127f, 0xc08c,		0x21, 0
	.dw 0x12c0, 0xc08c,	0x12ff, 0xc08c,		0x21, 0
	.dw 0x1340, 0xc08c,	0x137f, 0xc08c,		0x21, 0
	.dw 0x13c0, 0xc08c,	0x13ff, 0xc08c,		0x21, 0
	.dw 0x1440, 0xc08c,	0x147f, 0xc08c,		0x21, 0
	.dw 0x14c0, 0xc08c,	0x14ff, 0xc08c,		0x21, 0
	.dw 0x1540, 0xc08c,	0x157f, 0xc08c,		0x21, 0
	.dw 0x15c0, 0xc08c,	0x15ff, 0xc08c,		0x21, 0
	.dw 0x1640, 0xc08c,	0x167f, 0xc08c,		0x21, 0
	.dw 0x16c0, 0xc08c,	0x16ff, 0xc08c,		0x21, 0
	.dw 0x1740, 0xc08c,	0x177f, 0xc08c,		0x21, 0
	.dw 0x17c0, 0xc08c,	0x17ff, 0xc08c,		0x21, 0
	.dw 0x1840, 0xc08c,	0x187f, 0xc08c,		0x21, 0
	.dw 0x18c0, 0xc08c,	0x18ff, 0xc08c,		0x21, 0
	.dw 0x1940, 0xc08c,	0x197f, 0xc08c,		0x21, 0
	.dw 0x19c0, 0xc08c,	0x1fff, 0xc08c,		0x21, 0
	.dw 0x2040, 0xc08c,	0x207f, 0xc08c,		0x21, 0
	.dw 0x20c0, 0xc08c,	0x20ff, 0xc08c,		0x21, 0
	.dw 0x2140, 0xc08c,	0x217f, 0xc08c,		0x21, 0
	.dw 0x21c0, 0xc08c,	0x21ff, 0xc08c,		0x21, 0
	.dw 0x2240, 0xc08c,	0x227f, 0xc08c,		0x21, 0
	.dw 0x22c0, 0xc08c,	0x22ff, 0xc08c,		0x21, 0
	.dw 0x2340, 0xc08c,	0x237f, 0xc08c,		0x21, 0
	.dw 0x23c0, 0xc08c,	0x23ff, 0xc08c,		0x21, 0
	.dw 0x2440, 0xc08c,	0x247f, 0xc08c,		0x21, 0
	.dw 0x24c0, 0xc08c,	0x24ff, 0xc08c,		0x21, 0
	.dw 0x2540, 0xc08c,	0x257f, 0xc08c,		0x21, 0
	.dw 0x25c0, 0xc08c,	0x25ff, 0xc08c,		0x21, 0
	.dw 0x2640, 0xc08c,	0x267f, 0xc08c,		0x21, 0
	.dw 0x26c0, 0xc08c,	0x26ff, 0xc08c,		0x21, 0
	.dw 0x2740, 0xc08c,	0x277f, 0xc08c,		0x21, 0
	.dw 0x27c0, 0xc08c,	0x27ff, 0xc08c,		0x21, 0
	.dw 0x2840, 0xc08c,	0x287f, 0xc08c,		0x21, 0
	.dw 0x28c0, 0xc08c,	0x28ff, 0xc08c,		0x21, 0
	.dw 0x2940, 0xc08c,	0x297f, 0xc08c,		0x21, 0
	.dw 0x29c0, 0xc08c,	0x29ff, 0xc08c,		0x21, 0
	.dw 0x2a40, 0xc08c,	0x2a7f, 0xc08c,		0x21, 0
	.dw 0x2ac0, 0xc08c,	0x2aff, 0xc08c,		0x21, 0
	.dw 0x2b40, 0xc08c,	0x2b7f, 0xc08c,		0x21, 0
	.dw 0x2bc0, 0xc08c,	0x2bff, 0xc08c,		0x21, 0
	.dw 0x2c40, 0xc08c,	0x2c7f, 0xc08c,		0x21, 0
	.dw 0x2cc0, 0xc08c,	0x2cff, 0xc08c,		0x21, 0
	.dw 0x2d40, 0xc08c,	0x2d7f, 0xc08c,		0x21, 0
	.dw 0x2dc0, 0xc08c,	0x2dff, 0xc08c,		0x21, 0
	.dw 0x2e40, 0xc08c,	0x2e7f, 0xc08c,		0x21, 0
	.dw 0x2ec0, 0xc08c,	0x2eff, 0xc08c,		0x21, 0
	.dw 0x2f40, 0xc08c,	0x2f7f, 0xc08c,		0x21, 0
	.dw 0x2fc0, 0xc08c,	0x2fff, 0xc08c,		0x21, 0
	.dw 0x3040, 0xc08c,	0x307f, 0xc08c,		0x21, 0
	.dw 0x30c0, 0xc08c,	0x30ff, 0xc08c,		0x21, 0
	.dw 0x3140, 0xc08c,	0x317f, 0xc08c,		0x21, 0
	.dw 0x31c0, 0xc08c,	0x31ff, 0xc08c,		0x21, 0
	.dw 0x3240, 0xc08c,	0x327f, 0xc08c,		0x21, 0
	.dw 0x32c0, 0xc08c,	0x32ff, 0xc08c,		0x21, 0
	.dw 0x3340, 0xc08c,	0x337f, 0xc08c,		0x21, 0
	.dw 0x33c0, 0xc08c,	0x33ff, 0xc08c,		0x21, 0
	.dw 0x3440, 0xc08c,	0x347f, 0xc08c,		0x21, 0
	.dw 0x34c0, 0xc08c,	0x34ff, 0xc08c,		0x21, 0
	.dw 0x3540, 0xc08c,	0x357f, 0xc08c,		0x21, 0
	.dw 0x35c0, 0xc08c,	0x35ff, 0xc08c,		0x21, 0
	.dw 0x3640, 0xc08c,	0x367f, 0xc08c,		0x21, 0
	.dw 0x36c0, 0xc08c,	0x36ff, 0xc08c,		0x21, 0
	.dw 0x3740, 0xc08c,	0x377f, 0xc08c,		0x21, 0
	.dw 0x37c0, 0xc08c,	0x37ff, 0xc08c,		0x21, 0
	.dw 0x3840, 0xc08c,	0x387f, 0xc08c,		0x21, 0
	.dw 0x38c0, 0xc08c,	0x38ff, 0xc08c,		0x21, 0
	.dw 0x3940, 0xc08c,	0x397f, 0xc08c,		0x21, 0
	.dw 0x39c0, 0xc08c,	0x3fff, 0xc08c,		0x21, 0
	.dw 0x4040, 0xc08c,	0x407f, 0xc08c,		0x21, 0
	.dw 0x40c0, 0xc08c,	0x40ff, 0xc08c,		0x21, 0
	.dw 0x4140, 0xc08c,	0x417f, 0xc08c,		0x21, 0
	.dw 0x41c0, 0xc08c,	0x41ff, 0xc08c,		0x21, 0
	.dw 0x4240, 0xc08c,	0x427f, 0xc08c,		0x21, 0
	.dw 0x42c0, 0xc08c,	0x42ff, 0xc08c,		0x21, 0
	.dw 0x4340, 0xc08c,	0x437f, 0xc08c,		0x21, 0
	.dw 0x43c0, 0xc08c,	0x43ff, 0xc08c,		0x21, 0
	.dw 0x4440, 0xc08c,	0x447f, 0xc08c,		0x21, 0
	.dw 0x44c0, 0xc08c,	0x44ff, 0xc08c,		0x21, 0
	.dw 0x4540, 0xc08c,	0x457f, 0xc08c,		0x21, 0
	.dw 0x45c0, 0xc08c,	0x45ff, 0xc08c,		0x21, 0
	.dw 0x4640, 0xc08c,	0x467f, 0xc08c,		0x21, 0
	.dw 0x46c0, 0xc08c,	0x46ff, 0xc08c,		0x21, 0
	.dw 0x4740, 0xc08c,	0x477f, 0xc08c,		0x21, 0
	.dw 0x47c0, 0xc08c,	0x47ff, 0xc08c,		0x21, 0
	.dw 0x4840, 0xc08c,	0x487f, 0xc08c,		0x21, 0
	.dw 0x48c0, 0xc08c,	0x48ff, 0xc08c,		0x21, 0
	.dw 0x4940, 0xc08c,	0x497f, 0xc08c,		0x21, 0
	.dw 0x49c0, 0xc08c,	0x49ff, 0xc08c,		0x21, 0
	.dw 0x4a40, 0xc08c,	0x4a7f, 0xc08c,		0x21, 0
	.dw 0x4ac0, 0xc08c,	0x4aff, 0xc08c,		0x21, 0
	.dw 0x4b40, 0xc08c,	0x4b7f, 0xc08c,		0x21, 0
	.dw 0x4bc0, 0xc08c,	0x4bff, 0xc08c,		0x21, 0
	.dw 0x4c40, 0xc08c,	0x4c7f, 0xc08c,		0x21, 0
	.dw 0x4cc0, 0xc08c,	0x4cff, 0xc08c,		0x21, 0
	.dw 0x4d40, 0xc08c,	0x4d7f, 0xc08c,		0x21, 0
	.dw 0x4dc0, 0xc08c,	0x4dff, 0xc08c,		0x21, 0
	.dw 0x4e40, 0xc08c,	0x4e7f, 0xc08c,		0x21, 0
	.dw 0x4ec0, 0xc08c,	0x4eff, 0xc08c,		0x21, 0
	.dw 0x4f40, 0xc08c,	0x4f7f, 0xc08c,		0x21, 0
	.dw 0x4fc0, 0xc08c,	0x4fff, 0xc08c,		0x21, 0
	.dw 0x5040, 0xc08c,	0x507f, 0xc08c,		0x21, 0
	.dw 0x50c0, 0xc08c,	0x50ff, 0xc08c,		0x21, 0
	.dw 0x5140, 0xc08c,	0x517f, 0xc08c,		0x21, 0
	.dw 0x51c0, 0xc08c,	0x51ff, 0xc08c,		0x21, 0
	.dw 0x5240, 0xc08c,	0x527f, 0xc08c,		0x21, 0
	.dw 0x52c0, 0xc08c,	0x52ff, 0xc08c,		0x21, 0
	.dw 0x5340, 0xc08c,	0x537f, 0xc08c,		0x21, 0
	.dw 0x53c0, 0xc08c,	0x53ff, 0xc08c,		0x21, 0
	.dw 0x5440, 0xc08c,	0x547f, 0xc08c,		0x21, 0
	.dw 0x54c0, 0xc08c,	0x54ff, 0xc08c,		0x21, 0
	.dw 0x5540, 0xc08c,	0x557f, 0xc08c,		0x21, 0
	.dw 0x55c0, 0xc08c,	0x55ff, 0xc08c,		0x21, 0
	.dw 0x5640, 0xc08c,	0x567f, 0xc08c,		0x21, 0
	.dw 0x56c0, 0xc08c,	0x56ff, 0xc08c,		0x21, 0
	.dw 0x5740, 0xc08c,	0x577f, 0xc08c,		0x21, 0
	.dw 0x57c0, 0xc08c,	0x57ff, 0xc08c,		0x21, 0
	.dw 0x5840, 0xc08c,	0x587f, 0xc08c,		0x21, 0
	.dw 0x58c0, 0xc08c,	0x58ff, 0xc08c,		0x21, 0
	.dw 0x5940, 0xc08c,	0x597f, 0xc08c,		0x21, 0
	.dw 0x59c0, 0xc08c,	0x5fff, 0xc08c,		0x21, 0
	.dw 0x6040, 0xc08c,	0x607f, 0xc08c,		0x21, 0
	.dw 0x60c0, 0xc08c,	0x60ff, 0xc08c,		0x21, 0
	.dw 0x6140, 0xc08c,	0x617f, 0xc08c,		0x21, 0
	.dw 0x61c0, 0xc08c,	0x61ff, 0xc08c,		0x21, 0
	.dw 0x6240, 0xc08c,	0x627f, 0xc08c,		0x21, 0
	.dw 0x62c0, 0xc08c,	0x62ff, 0xc08c,		0x21, 0
	.dw 0x6340, 0xc08c,	0x637f, 0xc08c,		0x21, 0
	.dw 0x63c0, 0xc08c,	0x63ff, 0xc08c,		0x21, 0
	.dw 0x6440, 0xc08c,	0x647f, 0xc08c,		0x21, 0
	.dw 0x64c0, 0xc08c,	0x64ff, 0xc08c,		0x21, 0
	.dw 0x6540, 0xc08c,	0x657f, 0xc08c,		0x21, 0
	.dw 0x65c0, 0xc08c,	0x65ff, 0xc08c,		0x21, 0
	.dw 0x6640, 0xc08c,	0x667f, 0xc08c,		0x21, 0
	.dw 0x66c0, 0xc08c,	0x66ff, 0xc08c,		0x21, 0
	.dw 0x6740, 0xc08c,	0x677f, 0xc08c,		0x21, 0
	.dw 0x67c0, 0xc08c,	0x67ff, 0xc08c,		0x21, 0
	.dw 0x6840, 0xc08c,	0x687f, 0xc08c,		0x21, 0
	.dw 0x68c0, 0xc08c,	0x68ff, 0xc08c,		0x21, 0
	.dw 0x6940, 0xc08c,	0x697f, 0xc08c,		0x21, 0
	.dw 0x69c0, 0xc08c,	0x69ff, 0xc08c,		0x21, 0
	.dw 0x6a40, 0xc08c,	0x6a7f, 0xc08c,		0x21, 0
	.dw 0x6ac0, 0xc08c,	0x6aff, 0xc08c,		0x21, 0
	.dw 0x6b40, 0xc08c,	0x6b7f, 0xc08c,		0x21, 0
	.dw 0x6bc0, 0xc08c,	0x6bff, 0xc08c,		0x21, 0
	.dw 0x6c40, 0xc08c,	0x6c7f, 0xc08c,		0x21, 0
	.dw 0x6cc0, 0xc08c,	0x6cff, 0xc08c,		0x21, 0
	.dw 0x6d40, 0xc08c,	0x6d7f, 0xc08c,		0x21, 0
	.dw 0x6dc0, 0xc08c,	0x6dff, 0xc08c,		0x21, 0
	.dw 0x6e40, 0xc08c,	0x6e7f, 0xc08c,		0x21, 0
	.dw 0x6ec0, 0xc08c,	0x6eff, 0xc08c,		0x21, 0
	.dw 0x6f40, 0xc08c,	0x6f7f, 0xc08c,		0x21, 0
	.dw 0x6fc0, 0xc08c,	0x6fff, 0xc08c,		0x21, 0
	.dw 0x7040, 0xc08c,	0x707f, 0xc08c,		0x21, 0
	.dw 0x70c0, 0xc08c,	0x70ff, 0xc08c,		0x21, 0
	.dw 0x7140, 0xc08c,	0x717f, 0xc08c,		0x21, 0
	.dw 0x71c0, 0xc08c,	0x71ff, 0xc08c,		0x21, 0
	.dw 0x7240, 0xc08c,	0x727f, 0xc08c,		0x21, 0
	.dw 0x72c0, 0xc08c,	0x72ff, 0xc08c,		0x21, 0
	.dw 0x7340, 0xc08c,	0x737f, 0xc08c,		0x21, 0
	.dw 0x73c0, 0xc08c,	0x73ff, 0xc08c,		0x21, 0
	.dw 0x7440, 0xc08c,	0x747f, 0xc08c,		0x21, 0
	.dw 0x74c0, 0xc08c,	0x74ff, 0xc08c,		0x21, 0
	.dw 0x7540, 0xc08c,	0x757f, 0xc08c,		0x21, 0
	.dw 0x75c0, 0xc08c,	0x75ff, 0xc08c,		0x21, 0
	.dw 0x7640, 0xc08c,	0x767f, 0xc08c,		0x21, 0
	.dw 0x76c0, 0xc08c,	0x76ff, 0xc08c,		0x21, 0
	.dw 0x7740, 0xc08c,	0x777f, 0xc08c,		0x21, 0
	.dw 0x77c0, 0xc08c,	0x77ff, 0xc08c,		0x21, 0
	.dw 0x7840, 0xc08c,	0x787f, 0xc08c,		0x21, 0
	.dw 0x78c0, 0xc08c,	0x78ff, 0xc08c,		0x21, 0
	.dw 0x7940, 0xc08c,	0x797f, 0xc08c,		0x21, 0
	.dw 0x79c0, 0xc08c,	0x7fff, 0xc08c,		0x21, 0
	.dw 0x8040, 0xc08c,	0x807f, 0xc08c,		0x21, 0
	.dw 0x80c0, 0xc08c,	0x80ff, 0xc08c,		0x21, 0
	.dw 0x8140, 0xc08c,	0x817f, 0xc08c,		0x21, 0
	.dw 0x81c0, 0xc08c,	0x81ff, 0xc08c,		0x21, 0
	.dw 0x8240, 0xc08c,	0x827f, 0xc08c,		0x21, 0
	.dw 0x82c0, 0xc08c,	0x82ff, 0xc08c,		0x21, 0
	.dw 0x8340, 0xc08c,	0x837f, 0xc08c,		0x21, 0
	.dw 0x83c0, 0xc08c,	0x83ff, 0xc08c,		0x21, 0
	.dw 0x8440, 0xc08c,	0x847f, 0xc08c,		0x21, 0
	.dw 0x84c0, 0xc08c,	0x84ff, 0xc08c,		0x21, 0
	.dw 0x8540, 0xc08c,	0x857f, 0xc08c,		0x21, 0
	.dw 0x85c0, 0xc08c,	0x85ff, 0xc08c,		0x21, 0
	.dw 0x8640, 0xc08c,	0x867f, 0xc08c,		0x21, 0
	.dw 0x86c0, 0xc08c,	0x86ff, 0xc08c,		0x21, 0
	.dw 0x8740, 0xc08c,	0x877f, 0xc08c,		0x21, 0
	.dw 0x87c0, 0xc08c,	0x87ff, 0xc08c,		0x21, 0
	.dw 0x8840, 0xc08c,	0x887f, 0xc08c,		0x21, 0
	.dw 0x88c0, 0xc08c,	0x88ff, 0xc08c,		0x21, 0
	.dw 0x8940, 0xc08c,	0x897f, 0xc08c,		0x21, 0
	.dw 0x89c0, 0xc08c,	0x89ff, 0xc08c,		0x21, 0
	.dw 0x8a40, 0xc08c,	0x8a7f, 0xc08c,		0x21, 0
	.dw 0x8ac0, 0xc08c,	0x8aff, 0xc08c,		0x21, 0
	.dw 0x8b40, 0xc08c,	0x8b7f, 0xc08c,		0x21, 0
	.dw 0x8bc0, 0xc08c,	0x8bff, 0xc08c,		0x21, 0
	.dw 0x8c40, 0xc08c,	0x8c7f, 0xc08c,		0x21, 0
	.dw 0x8cc0, 0xc08c,	0x8cff, 0xc08c,		0x21, 0
	.dw 0x8d40, 0xc08c,	0x8d7f, 0xc08c,		0x21, 0
	.dw 0x8dc0, 0xc08c,	0x8dff, 0xc08c,		0x21, 0
	.dw 0x8e40, 0xc08c,	0x8e7f, 0xc08c,		0x21, 0
	.dw 0x8ec0, 0xc08c,	0x8eff, 0xc08c,		0x21, 0
	.dw 0x8f40, 0xc08c,	0x8f7f, 0xc08c,		0x21, 0
	.dw 0x8fc0, 0xc08c,	0x8fff, 0xc08c,		0x21, 0
	.dw 0x9040, 0xc08c,	0x907f, 0xc08c,		0x21, 0
	.dw 0x90c0, 0xc08c,	0x90ff, 0xc08c,		0x21, 0
	.dw 0x9140, 0xc08c,	0x917f, 0xc08c,		0x21, 0
	.dw 0x91c0, 0xc08c,	0x91ff, 0xc08c,		0x21, 0
	.dw 0x9240, 0xc08c,	0x927f, 0xc08c,		0x21, 0
	.dw 0x92c0, 0xc08c,	0x92ff, 0xc08c,		0x21, 0
	.dw 0x9340, 0xc08c,	0x937f, 0xc08c,		0x21, 0
	.dw 0x93c0, 0xc08c,	0x93ff, 0xc08c,		0x21, 0
	.dw 0x9440, 0xc08c,	0x947f, 0xc08c,		0x21, 0
	.dw 0x94c0, 0xc08c,	0x94ff, 0xc08c,		0x21, 0
	.dw 0x9540, 0xc08c,	0x957f, 0xc08c,		0x21, 0
	.dw 0x95c0, 0xc08c,	0x95ff, 0xc08c,		0x21, 0
	.dw 0x9640, 0xc08c,	0x967f, 0xc08c,		0x21, 0
	.dw 0x96c0, 0xc08c,	0x96ff, 0xc08c,		0x21, 0
	.dw 0x9740, 0xc08c,	0x977f, 0xc08c,		0x21, 0
	.dw 0x97c0, 0xc08c,	0x97ff, 0xc08c,		0x21, 0
	.dw 0x9840, 0xc08c,	0x987f, 0xc08c,		0x21, 0
	.dw 0x98c0, 0xc08c,	0x98ff, 0xc08c,		0x21, 0
	.dw 0x9940, 0xc08c,	0x997f, 0xc08c,		0x21, 0
	.dw 0x99c0, 0xc08c,	0x9fff, 0xc08c,		0x21, 0
	.dw 0xa040, 0xc08c,	0xa07f, 0xc08c,		0x21, 0
	.dw 0xa0c0, 0xc08c,	0xa0ff, 0xc08c,		0x21, 0
	.dw 0xa140, 0xc08c,	0xa17f, 0xc08c,		0x21, 0
	.dw 0xa1c0, 0xc08c,	0xa1ff, 0xc08c,		0x21, 0
	.dw 0xa240, 0xc08c,	0xa27f, 0xc08c,		0x21, 0
	.dw 0xa2c0, 0xc08c,	0xa2ff, 0xc08c,		0x21, 0
	.dw 0xa340, 0xc08c,	0xa37f, 0xc08c,		0x21, 0
	.dw 0xa3c0, 0xc08c,	0xa3ff, 0xc08c,		0x21, 0
	.dw 0xa440, 0xc08c,	0xa47f, 0xc08c,		0x21, 0
	.dw 0xa4c0, 0xc08c,	0xa4ff, 0xc08c,		0x21, 0
	.dw 0xa540, 0xc08c,	0xa57f, 0xc08c,		0x21, 0
	.dw 0xa5c0, 0xc08c,	0xa5ff, 0xc08c,		0x21, 0
	.dw 0xa640, 0xc08c,	0xa67f, 0xc08c,		0x21, 0
	.dw 0xa6c0, 0xc08c,	0xa6ff, 0xc08c,		0x21, 0
	.dw 0xa740, 0xc08c,	0xa77f, 0xc08c,		0x21, 0
	.dw 0xa7c0, 0xc08c,	0xa7ff, 0xc08c,		0x21, 0
	.dw 0xa840, 0xc08c,	0xa87f, 0xc08c,		0x21, 0
	.dw 0xa8c0, 0xc08c,	0xa8ff, 0xc08c,		0x21, 0
	.dw 0xa940, 0xc08c,	0xa97f, 0xc08c,		0x21, 0
	.dw 0xa9c0, 0xc08c,	0xa9ff, 0xc08c,		0x21, 0
	.dw 0xaa40, 0xc08c,	0xaa7f, 0xc08c,		0x21, 0
	.dw 0xaac0, 0xc08c,	0xaaff, 0xc08c,		0x21, 0
	.dw 0xab40, 0xc08c,	0xab7f, 0xc08c,		0x21, 0
	.dw 0xabc0, 0xc08c,	0xabff, 0xc08c,		0x21, 0
	.dw 0xac40, 0xc08c,	0xac7f, 0xc08c,		0x21, 0
	.dw 0xacc0, 0xc08c,	0xacff, 0xc08c,		0x21, 0
	.dw 0xad40, 0xc08c,	0xad7f, 0xc08c,		0x21, 0
	.dw 0xadc0, 0xc08c,	0xadff, 0xc08c,		0x21, 0
	.dw 0xae40, 0xc08c,	0xae7f, 0xc08c,		0x21, 0
	.dw 0xaec0, 0xc08c,	0xaeff, 0xc08c,		0x21, 0
	.dw 0xaf40, 0xc08c,	0xaf7f, 0xc08c,		0x21, 0
	.dw 0xafc0, 0xc08c,	0xafff, 0xc08c,		0x21, 0
	.dw 0xb040, 0xc08c,	0xb07f, 0xc08c,		0x21, 0
	.dw 0xb0c0, 0xc08c,	0xb0ff, 0xc08c,		0x21, 0
	.dw 0xb140, 0xc08c,	0xb17f, 0xc08c,		0x21, 0
	.dw 0xb1c0, 0xc08c,	0xb1ff, 0xc08c,		0x21, 0
	.dw 0xb240, 0xc08c,	0xb27f, 0xc08c,		0x21, 0
	.dw 0xb2c0, 0xc08c,	0xb2ff, 0xc08c,		0x21, 0
	.dw 0xb340, 0xc08c,	0xb37f, 0xc08c,		0x21, 0
	.dw 0xb3c0, 0xc08c,	0xb3ff, 0xc08c,		0x21, 0
	.dw 0xb440, 0xc08c,	0xb47f, 0xc08c,		0x21, 0
	.dw 0xb4c0, 0xc08c,	0xb4ff, 0xc08c,		0x21, 0
	.dw 0xb540, 0xc08c,	0xb57f, 0xc08c,		0x21, 0
	.dw 0xb5c0, 0xc08c,	0xb5ff, 0xc08c,		0x21, 0
	.dw 0xb640, 0xc08c,	0xb67f, 0xc08c,		0x21, 0
	.dw 0xb6c0, 0xc08c,	0xb6ff, 0xc08c,		0x21, 0
	.dw 0xb740, 0xc08c,	0xb77f, 0xc08c,		0x21, 0
	.dw 0xb7c0, 0xc08c,	0xb7ff, 0xc08c,		0x21, 0
	.dw 0xb840, 0xc08c,	0xb87f, 0xc08c,		0x21, 0
	.dw 0xb8c0, 0xc08c,	0xb8ff, 0xc08c,		0x21, 0
	.dw 0xb940, 0xc08c,	0xb97f, 0xc08c,		0x21, 0
	.dw 0xb9c0, 0xc08c,	0xbfff, 0xc08c,		0x21, 0
	.dw 0xc040, 0xc08c,	0xc07f, 0xc08c,		0x21, 0
	.dw 0xc0c0, 0xc08c,	0xc0ff, 0xc08c,		0x21, 0
	.dw 0xc140, 0xc08c,	0xc17f, 0xc08c,		0x21, 0
	.dw 0xc1c0, 0xc08c,	0xc1ff, 0xc08c,		0x21, 0
	.dw 0xc240, 0xc08c,	0xc27f, 0xc08c,		0x21, 0
	.dw 0xc2c0, 0xc08c,	0xc2ff, 0xc08c,		0x21, 0
	.dw 0xc340, 0xc08c,	0xc37f, 0xc08c,		0x21, 0
	.dw 0xc3c0, 0xc08c,	0xc3ff, 0xc08c,		0x21, 0
	.dw 0xc440, 0xc08c,	0xc47f, 0xc08c,		0x21, 0
	.dw 0xc4c0, 0xc08c,	0xc4ff, 0xc08c,		0x21, 0
	.dw 0xc540, 0xc08c,	0xc57f, 0xc08c,		0x21, 0
	.dw 0xc5c0, 0xc08c,	0xc5ff, 0xc08c,		0x21, 0
	.dw 0xc640, 0xc08c,	0xc67f, 0xc08c,		0x21, 0
	.dw 0xc6c0, 0xc08c,	0xc6ff, 0xc08c,		0x21, 0
	.dw 0xc740, 0xc08c,	0xc77f, 0xc08c,		0x21, 0
	.dw 0xc7c0, 0xc08c,	0xc7ff, 0xc08c,		0x21, 0
	.dw 0xc840, 0xc08c,	0xc87f, 0xc08c,		0x21, 0
	.dw 0xc8c0, 0xc08c,	0xc8ff, 0xc08c,		0x21, 0
	.dw 0xc940, 0xc08c,	0xc97f, 0xc08c,		0x21, 0
	.dw 0xc9c0, 0xc08c,	0xc9ff, 0xc08c,		0x21, 0
	.dw 0xca40, 0xc08c,	0xca7f, 0xc08c,		0x21, 0
	.dw 0xcac0, 0xc08c,	0xcaff, 0xc08c,		0x21, 0
	.dw 0xcb40, 0xc08c,	0xcb7f, 0xc08c,		0x21, 0
	.dw 0xcbc0, 0xc08c,	0xcbff, 0xc08c,		0x21, 0
	.dw 0xcc40, 0xc08c,	0xcc7f, 0xc08c,		0x21, 0
	.dw 0xccc0, 0xc08c,	0xccff, 0xc08c,		0x21, 0
	.dw 0xcd40, 0xc08c,	0xcd7f, 0xc08c,		0x21, 0
	.dw 0xcdc0, 0xc08c,	0xcdff, 0xc08c,		0x21, 0
	.dw 0xce40, 0xc08c,	0xce7f, 0xc08c,		0x21, 0
	.dw 0xcec0, 0xc08c,	0xceff, 0xc08c,		0x21, 0
	.dw 0xcf40, 0xc08c,	0xcf7f, 0xc08c,		0x21, 0
	.dw 0xcfc0, 0xc08c,	0xcfff, 0xc08c,		0x21, 0
	.dw 0xd040, 0xc08c,	0xd07f, 0xc08c,		0x21, 0
	.dw 0xd0c0, 0xc08c,	0xd0ff, 0xc08c,		0x21, 0
	.dw 0xd140, 0xc08c,	0xd17f, 0xc08c,		0x21, 0
	.dw 0xd1c0, 0xc08c,	0xd1ff, 0xc08c,		0x21, 0
	.dw 0xd240, 0xc08c,	0xd27f, 0xc08c,		0x21, 0
	.dw 0xd2c0, 0xc08c,	0xd2ff, 0xc08c,		0x21, 0
	.dw 0xd340, 0xc08c,	0xd37f, 0xc08c,		0x21, 0
	.dw 0xd3c0, 0xc08c,	0xd3ff, 0xc08c,		0x21, 0
	.dw 0xd440, 0xc08c,	0xd47f, 0xc08c,		0x21, 0
	.dw 0xd4c0, 0xc08c,	0xd4ff, 0xc08c,		0x21, 0
	.dw 0xd540, 0xc08c,	0xd57f, 0xc08c,		0x21, 0
	.dw 0xd5c0, 0xc08c,	0xd5ff, 0xc08c,		0x21, 0
	.dw 0xd640, 0xc08c,	0xd67f, 0xc08c,		0x21, 0
	.dw 0xd6c0, 0xc08c,	0xd6ff, 0xc08c,		0x21, 0
	.dw 0xd740, 0xc08c,	0xd77f, 0xc08c,		0x21, 0
	.dw 0xd7c0, 0xc08c,	0xd7ff, 0xc08c,		0x21, 0
	.dw 0xd840, 0xc08c,	0xd87f, 0xc08c,		0x21, 0
	.dw 0xd8c0, 0xc08c,	0xd8ff, 0xc08c,		0x21, 0
	.dw 0xd940, 0xc08c,	0xd97f, 0xc08c,		0x21, 0
	.dw 0xd9c0, 0xc08c,	0xdfff, 0xc08c,		0x21, 0
	.dw 0xe040, 0xc08c,	0xe07f, 0xc08c,		0x21, 0
	.dw 0xe0c0, 0xc08c,	0xe0ff, 0xc08c,		0x21, 0
	.dw 0xe140, 0xc08c,	0xe17f, 0xc08c,		0x21, 0
	.dw 0xe1c0, 0xc08c,	0xe1ff, 0xc08c,		0x21, 0
	.dw 0xe240, 0xc08c,	0xe27f, 0xc08c,		0x21, 0
	.dw 0xe2c0, 0xc08c,	0xe2ff, 0xc08c,		0x21, 0
	.dw 0xe340, 0xc08c,	0xe37f, 0xc08c,		0x21, 0
	.dw 0xe3c0, 0xc08c,	0xe3ff, 0xc08c,		0x21, 0
	.dw 0xe440, 0xc08c,	0xe47f, 0xc08c,		0x21, 0
	.dw 0xe4c0, 0xc08c,	0xe4ff, 0xc08c,		0x21, 0
	.dw 0xe540, 0xc08c,	0xe57f, 0xc08c,		0x21, 0
	.dw 0xe5c0, 0xc08c,	0xe5ff, 0xc08c,		0x21, 0
	.dw 0xe640, 0xc08c,	0xe67f, 0xc08c,		0x21, 0
	.dw 0xe6c0, 0xc08c,	0xe6ff, 0xc08c,		0x21, 0
	.dw 0xe740, 0xc08c,	0xe77f, 0xc08c,		0x21, 0
	.dw 0xe7c0, 0xc08c,	0xe7ff, 0xc08c,		0x21, 0
	.dw 0xe840, 0xc08c,	0xe87f, 0xc08c,		0x21, 0
	.dw 0xe8c0, 0xc08c,	0xe8ff, 0xc08c,		0x21, 0
	.dw 0xe940, 0xc08c,	0xe97f, 0xc08c,		0x21, 0
	.dw 0xe9c0, 0xc08c,	0xe9ff, 0xc08c,		0x21, 0
	.dw 0xea40, 0xc08c,	0xea7f, 0xc08c,		0x21, 0
	.dw 0xeac0, 0xc08c,	0xeaff, 0xc08c,		0x21, 0
	.dw 0xeb40, 0xc08c,	0xeb7f, 0xc08c,		0x21, 0
	.dw 0xebc0, 0xc08c,	0xebff, 0xc08c,		0x21, 0
	.dw 0xec40, 0xc08c,	0xec7f, 0xc08c,		0x21, 0
	.dw 0xecc0, 0xc08c,	0xecff, 0xc08c,		0x21, 0
	.dw 0xed40, 0xc08c,	0xed7f, 0xc08c,		0x21, 0
	.dw 0xedc0, 0xc08c,	0xedff, 0xc08c,		0x21, 0
	.dw 0xee40, 0xc08c,	0xee7f, 0xc08c,		0x21, 0
	.dw 0xeec0, 0xc08c,	0xeeff, 0xc08c,		0x21, 0
	.dw 0xef40, 0xc08c,	0xef7f, 0xc08c,		0x21, 0
	.dw 0xefc0, 0xc08c,	0xefff, 0xc08c,		0x21, 0
	.dw 0xf040, 0xc08c,	0xf07f, 0xc08c,		0x21, 0
	.dw 0xf0c0, 0xc08c,	0xf0ff, 0xc08c,		0x21, 0
	.dw 0xf140, 0xc08c,	0xf17f, 0xc08c,		0x21, 0
	.dw 0xf1c0, 0xc08c,	0xf1ff, 0xc08c,		0x21, 0
	.dw 0xf240, 0xc08c,	0xf27f, 0xc08c,		0x21, 0
	.dw 0xf2c0, 0xc08c,	0xf2ff, 0xc08c,		0x21, 0
	.dw 0xf340, 0xc08c,	0xf37f, 0xc08c,		0x21, 0
	.dw 0xf3c0, 0xc08c,	0xf3ff, 0xc08c,		0x21, 0
	.dw 0xf440, 0xc08c,	0xf47f, 0xc08c,		0x21, 0
	.dw 0xf4c0, 0xc08c,	0xf4ff, 0xc08c,		0x21, 0
	.dw 0xf540, 0xc08c,	0xf57f, 0xc08c,		0x21, 0
	.dw 0xf5c0, 0xc08c,	0xf5ff, 0xc08c,		0x21, 0
	.dw 0xf640, 0xc08c,	0xf67f, 0xc08c,		0x21, 0
	.dw 0xf6c0, 0xc08c,	0xf6ff, 0xc08c,		0x21, 0
	.dw 0xf740, 0xc08c,	0xf77f, 0xc08c,		0x21, 0
	.dw 0xf7c0, 0xc08c,	0xf7ff, 0xc08c,		0x21, 0
	.dw 0xf840, 0xc08c,	0xf87f, 0xc08c,		0x21, 0
	.dw 0xf8c0, 0xc08c,	0xf8ff, 0xc08c,		0x21, 0
	.dw 0xf940, 0xc08c,	0xf97f, 0xc08c,		0x21, 0
	.dw 0xf9c0, 0xc08c,	0xffff, 0xc08c,		0x21, 0
	.dw 0x0040, 0xc08d,	0x007f, 0xc08d,		0x21, 0
	.dw 0x00c0, 0xc08d,	0x00ff, 0xc08d,		0x21, 0
	.dw 0x0140, 0xc08d,	0x017f, 0xc08d,		0x21, 0
	.dw 0x01c0, 0xc08d,	0x01ff, 0xc08d,		0x21, 0
	.dw 0x0240, 0xc08d,	0x027f, 0xc08d,		0x21, 0
	.dw 0x02c0, 0xc08d,	0x02ff, 0xc08d,		0x21, 0
	.dw 0x0340, 0xc08d,	0x037f, 0xc08d,		0x21, 0
	.dw 0x03c0, 0xc08d,	0x03ff, 0xc08d,		0x21, 0
	.dw 0x0440, 0xc08d,	0x047f, 0xc08d,		0x21, 0
	.dw 0x04c0, 0xc08d,	0x04ff, 0xc08d,		0x21, 0
	.dw 0x0540, 0xc08d,	0x057f, 0xc08d,		0x21, 0
	.dw 0x05c0, 0xc08d,	0x05ff, 0xc08d,		0x21, 0
	.dw 0x0640, 0xc08d,	0x067f, 0xc08d,		0x21, 0
	.dw 0x06c0, 0xc08d,	0x06ff, 0xc08d,		0x21, 0
	.dw 0x0740, 0xc08d,	0x077f, 0xc08d,		0x21, 0
	.dw 0x07c0, 0xc08d,	0x07ff, 0xc08d,		0x21, 0
	.dw 0x0840, 0xc08d,	0x087f, 0xc08d,		0x21, 0
	.dw 0x08c0, 0xc08d,	0x08ff, 0xc08d,		0x21, 0
	.dw 0x0940, 0xc08d,	0x097f, 0xc08d,		0x21, 0
	.dw 0x09c0, 0xc08d,	0x09ff, 0xc08d,		0x21, 0
	.dw 0x0a40, 0xc08d,	0x0a7f, 0xc08d,		0x21, 0
	.dw 0x0ac0, 0xc08d,	0x0aff, 0xc08d,		0x21, 0
	.dw 0x0b40, 0xc08d,	0x0b7f, 0xc08d,		0x21, 0
	.dw 0x0bc0, 0xc08d,	0x0bff, 0xc08d,		0x21, 0
	.dw 0x0c40, 0xc08d,	0x0c7f, 0xc08d,		0x21, 0
	.dw 0x0cc0, 0xc08d,	0x0cff, 0xc08d,		0x21, 0
	.dw 0x0d40, 0xc08d,	0x0d7f, 0xc08d,		0x21, 0
	.dw 0x0dc0, 0xc08d,	0x0dff, 0xc08d,		0x21, 0
	.dw 0x0e40, 0xc08d,	0x0e7f, 0xc08d,		0x21, 0
	.dw 0x0ec0, 0xc08d,	0x0eff, 0xc08d,		0x21, 0
	.dw 0x0f40, 0xc08d,	0x0f7f, 0xc08d,		0x21, 0
	.dw 0x0fc0, 0xc08d,	0x0fff, 0xc08d,		0x21, 0
	.dw 0x1040, 0xc08d,	0x107f, 0xc08d,		0x21, 0
	.dw 0x10c0, 0xc08d,	0x10ff, 0xc08d,		0x21, 0
	.dw 0x1140, 0xc08d,	0x117f, 0xc08d,		0x21, 0
	.dw 0x11c0, 0xc08d,	0x11ff, 0xc08d,		0x21, 0
	.dw 0x1240, 0xc08d,	0x127f, 0xc08d,		0x21, 0
	.dw 0x12c0, 0xc08d,	0x12ff, 0xc08d,		0x21, 0
	.dw 0x1340, 0xc08d,	0x137f, 0xc08d,		0x21, 0
	.dw 0x13c0, 0xc08d,	0x13ff, 0xc08d,		0x21, 0
	.dw 0x1440, 0xc08d,	0x147f, 0xc08d,		0x21, 0
	.dw 0x14c0, 0xc08d,	0x14ff, 0xc08d,		0x21, 0
	.dw 0x1540, 0xc08d,	0x157f, 0xc08d,		0x21, 0
	.dw 0x15c0, 0xc08d,	0x15ff, 0xc08d,		0x21, 0
	.dw 0x1640, 0xc08d,	0x167f, 0xc08d,		0x21, 0
	.dw 0x16c0, 0xc08d,	0x16ff, 0xc08d,		0x21, 0
	.dw 0x1740, 0xc08d,	0x177f, 0xc08d,		0x21, 0
	.dw 0x17c0, 0xc08d,	0x17ff, 0xc08d,		0x21, 0
	.dw 0x1840, 0xc08d,	0x187f, 0xc08d,		0x21, 0
	.dw 0x18c0, 0xc08d,	0x18ff, 0xc08d,		0x21, 0
	.dw 0x1940, 0xc08d,	0x197f, 0xc08d,		0x21, 0
	.dw 0x19c0, 0xc08d,	0x1fff, 0xc08d,		0x21, 0
	.dw 0x2040, 0xc08d,	0x207f, 0xc08d,		0x21, 0
	.dw 0x20c0, 0xc08d,	0x20ff, 0xc08d,		0x21, 0
	.dw 0x2140, 0xc08d,	0x217f, 0xc08d,		0x21, 0
	.dw 0x21c0, 0xc08d,	0x21ff, 0xc08d,		0x21, 0
	.dw 0x2240, 0xc08d,	0x227f, 0xc08d,		0x21, 0
	.dw 0x22c0, 0xc08d,	0x22ff, 0xc08d,		0x21, 0
	.dw 0x2340, 0xc08d,	0x237f, 0xc08d,		0x21, 0
	.dw 0x23c0, 0xc08d,	0x23ff, 0xc08d,		0x21, 0
	.dw 0x2440, 0xc08d,	0x247f, 0xc08d,		0x21, 0
	.dw 0x24c0, 0xc08d,	0x24ff, 0xc08d,		0x21, 0
	.dw 0x2540, 0xc08d,	0x257f, 0xc08d,		0x21, 0
	.dw 0x25c0, 0xc08d,	0x25ff, 0xc08d,		0x21, 0
	.dw 0x2640, 0xc08d,	0x267f, 0xc08d,		0x21, 0
	.dw 0x26c0, 0xc08d,	0x26ff, 0xc08d,		0x21, 0
	.dw 0x2740, 0xc08d,	0x277f, 0xc08d,		0x21, 0
	.dw 0x27c0, 0xc08d,	0x27ff, 0xc08d,		0x21, 0
	.dw 0x2840, 0xc08d,	0x287f, 0xc08d,		0x21, 0
	.dw 0x28c0, 0xc08d,	0x28ff, 0xc08d,		0x21, 0
	.dw 0x2940, 0xc08d,	0x297f, 0xc08d,		0x21, 0
	.dw 0x29c0, 0xc08d,	0x29ff, 0xc08d,		0x21, 0
	.dw 0x2a40, 0xc08d,	0x2a7f, 0xc08d,		0x21, 0
	.dw 0x2ac0, 0xc08d,	0x2aff, 0xc08d,		0x21, 0
	.dw 0x2b40, 0xc08d,	0x2b7f, 0xc08d,		0x21, 0
	.dw 0x2bc0, 0xc08d,	0x2bff, 0xc08d,		0x21, 0
	.dw 0x2c40, 0xc08d,	0x2c7f, 0xc08d,		0x21, 0
	.dw 0x2cc0, 0xc08d,	0x2cff, 0xc08d,		0x21, 0
	.dw 0x2d40, 0xc08d,	0x2d7f, 0xc08d,		0x21, 0
	.dw 0x2dc0, 0xc08d,	0x2dff, 0xc08d,		0x21, 0
	.dw 0x2e40, 0xc08d,	0x2e7f, 0xc08d,		0x21, 0
	.dw 0x2ec0, 0xc08d,	0x2eff, 0xc08d,		0x21, 0
	.dw 0x2f40, 0xc08d,	0x2f7f, 0xc08d,		0x21, 0
	.dw 0x2fc0, 0xc08d,	0x2fff, 0xc08d,		0x21, 0
	.dw 0x3040, 0xc08d,	0x307f, 0xc08d,		0x21, 0
	.dw 0x30c0, 0xc08d,	0x30ff, 0xc08d,		0x21, 0
	.dw 0x3140, 0xc08d,	0x317f, 0xc08d,		0x21, 0
	.dw 0x31c0, 0xc08d,	0x31ff, 0xc08d,		0x21, 0
	.dw 0x3240, 0xc08d,	0x327f, 0xc08d,		0x21, 0
	.dw 0x32c0, 0xc08d,	0x32ff, 0xc08d,		0x21, 0
	.dw 0x3340, 0xc08d,	0x337f, 0xc08d,		0x21, 0
	.dw 0x33c0, 0xc08d,	0x33ff, 0xc08d,		0x21, 0
	.dw 0x3440, 0xc08d,	0x347f, 0xc08d,		0x21, 0
	.dw 0x34c0, 0xc08d,	0x34ff, 0xc08d,		0x21, 0
	.dw 0x3540, 0xc08d,	0x357f, 0xc08d,		0x21, 0
	.dw 0x35c0, 0xc08d,	0x35ff, 0xc08d,		0x21, 0
	.dw 0x3640, 0xc08d,	0x367f, 0xc08d,		0x21, 0
	.dw 0x36c0, 0xc08d,	0x36ff, 0xc08d,		0x21, 0
	.dw 0x3740, 0xc08d,	0x377f, 0xc08d,		0x21, 0
	.dw 0x37c0, 0xc08d,	0x37ff, 0xc08d,		0x21, 0
	.dw 0x3840, 0xc08d,	0x387f, 0xc08d,		0x21, 0
	.dw 0x38c0, 0xc08d,	0x38ff, 0xc08d,		0x21, 0
	.dw 0x3940, 0xc08d,	0x397f, 0xc08d,		0x21, 0
	.dw 0x39c0, 0xc08d,	0x3fff, 0xc08d,		0x21, 0
	.dw 0x4040, 0xc08d,	0x407f, 0xc08d,		0x21, 0
	.dw 0x40c0, 0xc08d,	0x40ff, 0xc08d,		0x21, 0
	.dw 0x4140, 0xc08d,	0x417f, 0xc08d,		0x21, 0
	.dw 0x41c0, 0xc08d,	0x41ff, 0xc08d,		0x21, 0
	.dw 0x4240, 0xc08d,	0x427f, 0xc08d,		0x21, 0
	.dw 0x42c0, 0xc08d,	0x42ff, 0xc08d,		0x21, 0
	.dw 0x4340, 0xc08d,	0x437f, 0xc08d,		0x21, 0
	.dw 0x43c0, 0xc08d,	0x43ff, 0xc08d,		0x21, 0
	.dw 0x4440, 0xc08d,	0x447f, 0xc08d,		0x21, 0
	.dw 0x44c0, 0xc08d,	0x44ff, 0xc08d,		0x21, 0
	.dw 0x4540, 0xc08d,	0x457f, 0xc08d,		0x21, 0
	.dw 0x45c0, 0xc08d,	0x45ff, 0xc08d,		0x21, 0
	.dw 0x4640, 0xc08d,	0x467f, 0xc08d,		0x21, 0
	.dw 0x46c0, 0xc08d,	0x46ff, 0xc08d,		0x21, 0
	.dw 0x4740, 0xc08d,	0x477f, 0xc08d,		0x21, 0
	.dw 0x47c0, 0xc08d,	0x47ff, 0xc08d,		0x21, 0
	.dw 0x4840, 0xc08d,	0x487f, 0xc08d,		0x21, 0
	.dw 0x48c0, 0xc08d,	0x48ff, 0xc08d,		0x21, 0
	.dw 0x4940, 0xc08d,	0x497f, 0xc08d,		0x21, 0
	.dw 0x49c0, 0xc08d,	0x49ff, 0xc08d,		0x21, 0
	.dw 0x4a40, 0xc08d,	0x4a7f, 0xc08d,		0x21, 0
	.dw 0x4ac0, 0xc08d,	0x4aff, 0xc08d,		0x21, 0
	.dw 0x4b40, 0xc08d,	0x4b7f, 0xc08d,		0x21, 0
	.dw 0x4bc0, 0xc08d,	0x4bff, 0xc08d,		0x21, 0
	.dw 0x4c40, 0xc08d,	0x4c7f, 0xc08d,		0x21, 0
	.dw 0x4cc0, 0xc08d,	0x4cff, 0xc08d,		0x21, 0
	.dw 0x4d40, 0xc08d,	0x4d7f, 0xc08d,		0x21, 0
	.dw 0x4dc0, 0xc08d,	0x4dff, 0xc08d,		0x21, 0
	.dw 0x4e40, 0xc08d,	0x4e7f, 0xc08d,		0x21, 0
	.dw 0x4ec0, 0xc08d,	0x4eff, 0xc08d,		0x21, 0
	.dw 0x4f40, 0xc08d,	0x4f7f, 0xc08d,		0x21, 0
	.dw 0x4fc0, 0xc08d,	0x4fff, 0xc08d,		0x21, 0
	.dw 0x5040, 0xc08d,	0x507f, 0xc08d,		0x21, 0
	.dw 0x50c0, 0xc08d,	0x50ff, 0xc08d,		0x21, 0
	.dw 0x5140, 0xc08d,	0x517f, 0xc08d,		0x21, 0
	.dw 0x51c0, 0xc08d,	0x51ff, 0xc08d,		0x21, 0
	.dw 0x5240, 0xc08d,	0x527f, 0xc08d,		0x21, 0
	.dw 0x52c0, 0xc08d,	0x52ff, 0xc08d,		0x21, 0
	.dw 0x5340, 0xc08d,	0x537f, 0xc08d,		0x21, 0
	.dw 0x53c0, 0xc08d,	0x53ff, 0xc08d,		0x21, 0
	.dw 0x5440, 0xc08d,	0x547f, 0xc08d,		0x21, 0
	.dw 0x54c0, 0xc08d,	0x54ff, 0xc08d,		0x21, 0
	.dw 0x5540, 0xc08d,	0x557f, 0xc08d,		0x21, 0
	.dw 0x55c0, 0xc08d,	0x55ff, 0xc08d,		0x21, 0
	.dw 0x5640, 0xc08d,	0x567f, 0xc08d,		0x21, 0
	.dw 0x56c0, 0xc08d,	0x56ff, 0xc08d,		0x21, 0
	.dw 0x5740, 0xc08d,	0x577f, 0xc08d,		0x21, 0
	.dw 0x57c0, 0xc08d,	0x57ff, 0xc08d,		0x21, 0
	.dw 0x5840, 0xc08d,	0x587f, 0xc08d,		0x21, 0
	.dw 0x58c0, 0xc08d,	0x58ff, 0xc08d,		0x21, 0
	.dw 0x5940, 0xc08d,	0x597f, 0xc08d,		0x21, 0
	.dw 0x59c0, 0xc08d,	0x5fff, 0xc08d,		0x21, 0
	.dw 0x6040, 0xc08d,	0x607f, 0xc08d,		0x21, 0
	.dw 0x60c0, 0xc08d,	0x60ff, 0xc08d,		0x21, 0
	.dw 0x6140, 0xc08d,	0x617f, 0xc08d,		0x21, 0
	.dw 0x61c0, 0xc08d,	0x61ff, 0xc08d,		0x21, 0
	.dw 0x6240, 0xc08d,	0x627f, 0xc08d,		0x21, 0
	.dw 0x62c0, 0xc08d,	0x62ff, 0xc08d,		0x21, 0
	.dw 0x6340, 0xc08d,	0x637f, 0xc08d,		0x21, 0
	.dw 0x63c0, 0xc08d,	0x63ff, 0xc08d,		0x21, 0
	.dw 0x6440, 0xc08d,	0x647f, 0xc08d,		0x21, 0
	.dw 0x64c0, 0xc08d,	0x64ff, 0xc08d,		0x21, 0
	.dw 0x6540, 0xc08d,	0x657f, 0xc08d,		0x21, 0
	.dw 0x65c0, 0xc08d,	0x65ff, 0xc08d,		0x21, 0
	.dw 0x6640, 0xc08d,	0x667f, 0xc08d,		0x21, 0
	.dw 0x66c0, 0xc08d,	0x66ff, 0xc08d,		0x21, 0
	.dw 0x6740, 0xc08d,	0x677f, 0xc08d,		0x21, 0
	.dw 0x67c0, 0xc08d,	0x67ff, 0xc08d,		0x21, 0
	.dw 0x6840, 0xc08d,	0x687f, 0xc08d,		0x21, 0
	.dw 0x68c0, 0xc08d,	0x68ff, 0xc08d,		0x21, 0
	.dw 0x6940, 0xc08d,	0x697f, 0xc08d,		0x21, 0
	.dw 0x69c0, 0xc08d,	0x69ff, 0xc08d,		0x21, 0
	.dw 0x6a40, 0xc08d,	0x6a7f, 0xc08d,		0x21, 0
	.dw 0x6ac0, 0xc08d,	0x6aff, 0xc08d,		0x21, 0
	.dw 0x6b40, 0xc08d,	0x6b7f, 0xc08d,		0x21, 0
	.dw 0x6bc0, 0xc08d,	0x6bff, 0xc08d,		0x21, 0
	.dw 0x6c40, 0xc08d,	0x6c7f, 0xc08d,		0x21, 0
	.dw 0x6cc0, 0xc08d,	0x6cff, 0xc08d,		0x21, 0
	.dw 0x6d40, 0xc08d,	0x6d7f, 0xc08d,		0x21, 0
	.dw 0x6dc0, 0xc08d,	0x6dff, 0xc08d,		0x21, 0
	.dw 0x6e40, 0xc08d,	0x6e7f, 0xc08d,		0x21, 0
	.dw 0x6ec0, 0xc08d,	0x6eff, 0xc08d,		0x21, 0
	.dw 0x6f40, 0xc08d,	0x6f7f, 0xc08d,		0x21, 0
	.dw 0x6fc0, 0xc08d,	0x6fff, 0xc08d,		0x21, 0
	.dw 0x7040, 0xc08d,	0x707f, 0xc08d,		0x21, 0
	.dw 0x70c0, 0xc08d,	0x70ff, 0xc08d,		0x21, 0
	.dw 0x7140, 0xc08d,	0x717f, 0xc08d,		0x21, 0
	.dw 0x71c0, 0xc08d,	0x71ff, 0xc08d,		0x21, 0
	.dw 0x7240, 0xc08d,	0x727f, 0xc08d,		0x21, 0
	.dw 0x72c0, 0xc08d,	0x72ff, 0xc08d,		0x21, 0
	.dw 0x7340, 0xc08d,	0x737f, 0xc08d,		0x21, 0
	.dw 0x73c0, 0xc08d,	0x73ff, 0xc08d,		0x21, 0
	.dw 0x7440, 0xc08d,	0x747f, 0xc08d,		0x21, 0
	.dw 0x74c0, 0xc08d,	0x74ff, 0xc08d,		0x21, 0
	.dw 0x7540, 0xc08d,	0x757f, 0xc08d,		0x21, 0
	.dw 0x75c0, 0xc08d,	0x75ff, 0xc08d,		0x21, 0
	.dw 0x7640, 0xc08d,	0x767f, 0xc08d,		0x21, 0
	.dw 0x76c0, 0xc08d,	0x76ff, 0xc08d,		0x21, 0
	.dw 0x7740, 0xc08d,	0x777f, 0xc08d,		0x21, 0
	.dw 0x77c0, 0xc08d,	0x77ff, 0xc08d,		0x21, 0
	.dw 0x7840, 0xc08d,	0x787f, 0xc08d,		0x21, 0
	.dw 0x78c0, 0xc08d,	0x78ff, 0xc08d,		0x21, 0
	.dw 0x7940, 0xc08d,	0x797f, 0xc08d,		0x21, 0
	.dw 0x79c0, 0xc08d,	0x7fff, 0xc08d,		0x21, 0
	.dw 0x8040, 0xc08d,	0x807f, 0xc08d,		0x21, 0
	.dw 0x80c0, 0xc08d,	0x80ff, 0xc08d,		0x21, 0
	.dw 0x8140, 0xc08d,	0x817f, 0xc08d,		0x21, 0
	.dw 0x81c0, 0xc08d,	0x81ff, 0xc08d,		0x21, 0
	.dw 0x8240, 0xc08d,	0x827f, 0xc08d,		0x21, 0
	.dw 0x82c0, 0xc08d,	0x82ff, 0xc08d,		0x21, 0
	.dw 0x8340, 0xc08d,	0x837f, 0xc08d,		0x21, 0
	.dw 0x83c0, 0xc08d,	0x83ff, 0xc08d,		0x21, 0
	.dw 0x8440, 0xc08d,	0x847f, 0xc08d,		0x21, 0
	.dw 0x84c0, 0xc08d,	0x84ff, 0xc08d,		0x21, 0
	.dw 0x8540, 0xc08d,	0x857f, 0xc08d,		0x21, 0
	.dw 0x85c0, 0xc08d,	0x85ff, 0xc08d,		0x21, 0
	.dw 0x8640, 0xc08d,	0x867f, 0xc08d,		0x21, 0
	.dw 0x86c0, 0xc08d,	0x86ff, 0xc08d,		0x21, 0
	.dw 0x8740, 0xc08d,	0x877f, 0xc08d,		0x21, 0
	.dw 0x87c0, 0xc08d,	0x87ff, 0xc08d,		0x21, 0
	.dw 0x8840, 0xc08d,	0x887f, 0xc08d,		0x21, 0
	.dw 0x88c0, 0xc08d,	0x88ff, 0xc08d,		0x21, 0
	.dw 0x8940, 0xc08d,	0x897f, 0xc08d,		0x21, 0
	.dw 0x89c0, 0xc08d,	0x89ff, 0xc08d,		0x21, 0
	.dw 0x8a40, 0xc08d,	0x8a7f, 0xc08d,		0x21, 0
	.dw 0x8ac0, 0xc08d,	0x8aff, 0xc08d,		0x21, 0
	.dw 0x8b40, 0xc08d,	0x8b7f, 0xc08d,		0x21, 0
	.dw 0x8bc0, 0xc08d,	0x8bff, 0xc08d,		0x21, 0
	.dw 0x8c40, 0xc08d,	0x8c7f, 0xc08d,		0x21, 0
	.dw 0x8cc0, 0xc08d,	0x8cff, 0xc08d,		0x21, 0
	.dw 0x8d40, 0xc08d,	0x8d7f, 0xc08d,		0x21, 0
	.dw 0x8dc0, 0xc08d,	0x8dff, 0xc08d,		0x21, 0
	.dw 0x8e40, 0xc08d,	0x8e7f, 0xc08d,		0x21, 0
	.dw 0x8ec0, 0xc08d,	0x8eff, 0xc08d,		0x21, 0
	.dw 0x8f40, 0xc08d,	0x8f7f, 0xc08d,		0x21, 0
	.dw 0x8fc0, 0xc08d,	0x8fff, 0xc08d,		0x21, 0
	.dw 0x9040, 0xc08d,	0x907f, 0xc08d,		0x21, 0
	.dw 0x90c0, 0xc08d,	0x90ff, 0xc08d,		0x21, 0
	.dw 0x9140, 0xc08d,	0x917f, 0xc08d,		0x21, 0
	.dw 0x91c0, 0xc08d,	0x91ff, 0xc08d,		0x21, 0
	.dw 0x9240, 0xc08d,	0x927f, 0xc08d,		0x21, 0
	.dw 0x92c0, 0xc08d,	0x92ff, 0xc08d,		0x21, 0
	.dw 0x9340, 0xc08d,	0x937f, 0xc08d,		0x21, 0
	.dw 0x93c0, 0xc08d,	0x93ff, 0xc08d,		0x21, 0
	.dw 0x9440, 0xc08d,	0x947f, 0xc08d,		0x21, 0
	.dw 0x94c0, 0xc08d,	0x94ff, 0xc08d,		0x21, 0
	.dw 0x9540, 0xc08d,	0x957f, 0xc08d,		0x21, 0
	.dw 0x95c0, 0xc08d,	0x95ff, 0xc08d,		0x21, 0
	.dw 0x9640, 0xc08d,	0x967f, 0xc08d,		0x21, 0
	.dw 0x96c0, 0xc08d,	0x96ff, 0xc08d,		0x21, 0
	.dw 0x9740, 0xc08d,	0x977f, 0xc08d,		0x21, 0
	.dw 0x97c0, 0xc08d,	0x97ff, 0xc08d,		0x21, 0
	.dw 0x9840, 0xc08d,	0x987f, 0xc08d,		0x21, 0
	.dw 0x98c0, 0xc08d,	0x98ff, 0xc08d,		0x21, 0
	.dw 0x9940, 0xc08d,	0x997f, 0xc08d,		0x21, 0
	.dw 0x99c0, 0xc08d,	0x9fff, 0xc08d,		0x21, 0
	.dw 0xa040, 0xc08d,	0xa07f, 0xc08d,		0x21, 0
	.dw 0xa0c0, 0xc08d,	0xa0ff, 0xc08d,		0x21, 0
	.dw 0xa140, 0xc08d,	0xa17f, 0xc08d,		0x21, 0
	.dw 0xa1c0, 0xc08d,	0xa1ff, 0xc08d,		0x21, 0
	.dw 0xa240, 0xc08d,	0xa27f, 0xc08d,		0x21, 0
	.dw 0xa2c0, 0xc08d,	0xa2ff, 0xc08d,		0x21, 0
	.dw 0xa340, 0xc08d,	0xa37f, 0xc08d,		0x21, 0
	.dw 0xa3c0, 0xc08d,	0xa3ff, 0xc08d,		0x21, 0
	.dw 0xa440, 0xc08d,	0xa47f, 0xc08d,		0x21, 0
	.dw 0xa4c0, 0xc08d,	0xa4ff, 0xc08d,		0x21, 0
	.dw 0xa540, 0xc08d,	0xa57f, 0xc08d,		0x21, 0
	.dw 0xa5c0, 0xc08d,	0xa5ff, 0xc08d,		0x21, 0
	.dw 0xa640, 0xc08d,	0xa67f, 0xc08d,		0x21, 0
	.dw 0xa6c0, 0xc08d,	0xa6ff, 0xc08d,		0x21, 0
	.dw 0xa740, 0xc08d,	0xa77f, 0xc08d,		0x21, 0
	.dw 0xa7c0, 0xc08d,	0xa7ff, 0xc08d,		0x21, 0
	.dw 0xa840, 0xc08d,	0xa87f, 0xc08d,		0x21, 0
	.dw 0xa8c0, 0xc08d,	0xa8ff, 0xc08d,		0x21, 0
	.dw 0xa940, 0xc08d,	0xa97f, 0xc08d,		0x21, 0
	.dw 0xa9c0, 0xc08d,	0xa9ff, 0xc08d,		0x21, 0
	.dw 0xaa40, 0xc08d,	0xaa7f, 0xc08d,		0x21, 0
	.dw 0xaac0, 0xc08d,	0xaaff, 0xc08d,		0x21, 0
	.dw 0xab40, 0xc08d,	0xab7f, 0xc08d,		0x21, 0
	.dw 0xabc0, 0xc08d,	0xabff, 0xc08d,		0x21, 0
	.dw 0xac40, 0xc08d,	0xac7f, 0xc08d,		0x21, 0
	.dw 0xacc0, 0xc08d,	0xacff, 0xc08d,		0x21, 0
	.dw 0xad40, 0xc08d,	0xad7f, 0xc08d,		0x21, 0
	.dw 0xadc0, 0xc08d,	0xadff, 0xc08d,		0x21, 0
	.dw 0xae40, 0xc08d,	0xae7f, 0xc08d,		0x21, 0
	.dw 0xaec0, 0xc08d,	0xaeff, 0xc08d,		0x21, 0
	.dw 0xaf40, 0xc08d,	0xaf7f, 0xc08d,		0x21, 0
	.dw 0xafc0, 0xc08d,	0xafff, 0xc08d,		0x21, 0
	.dw 0xb040, 0xc08d,	0xb07f, 0xc08d,		0x21, 0
	.dw 0xb0c0, 0xc08d,	0xb0ff, 0xc08d,		0x21, 0
	.dw 0xb140, 0xc08d,	0xb17f, 0xc08d,		0x21, 0
	.dw 0xb1c0, 0xc08d,	0xb1ff, 0xc08d,		0x21, 0
	.dw 0xb240, 0xc08d,	0xb27f, 0xc08d,		0x21, 0
	.dw 0xb2c0, 0xc08d,	0xb2ff, 0xc08d,		0x21, 0
	.dw 0xb340, 0xc08d,	0xb37f, 0xc08d,		0x21, 0
	.dw 0xb3c0, 0xc08d,	0xb3ff, 0xc08d,		0x21, 0
	.dw 0xb440, 0xc08d,	0xb47f, 0xc08d,		0x21, 0
	.dw 0xb4c0, 0xc08d,	0xb4ff, 0xc08d,		0x21, 0
	.dw 0xb540, 0xc08d,	0xb57f, 0xc08d,		0x21, 0
	.dw 0xb5c0, 0xc08d,	0xb5ff, 0xc08d,		0x21, 0
	.dw 0xb640, 0xc08d,	0xb67f, 0xc08d,		0x21, 0
	.dw 0xb6c0, 0xc08d,	0xb6ff, 0xc08d,		0x21, 0
	.dw 0xb740, 0xc08d,	0xb77f, 0xc08d,		0x21, 0
	.dw 0xb7c0, 0xc08d,	0xb7ff, 0xc08d,		0x21, 0
	.dw 0xb840, 0xc08d,	0xb87f, 0xc08d,		0x21, 0
	.dw 0xb8c0, 0xc08d,	0xb8ff, 0xc08d,		0x21, 0
	.dw 0xb940, 0xc08d,	0xb97f, 0xc08d,		0x21, 0
	.dw 0xb9c0, 0xc08d,	0xbfff, 0xc08d,		0x21, 0
	.dw 0xc040, 0xc08d,	0xc07f, 0xc08d,		0x21, 0
	.dw 0xc0c0, 0xc08d,	0xc0ff, 0xc08d,		0x21, 0
	.dw 0xc140, 0xc08d,	0xc17f, 0xc08d,		0x21, 0
	.dw 0xc1c0, 0xc08d,	0xc1ff, 0xc08d,		0x21, 0
	.dw 0xc240, 0xc08d,	0xc27f, 0xc08d,		0x21, 0
	.dw 0xc2c0, 0xc08d,	0xc2ff, 0xc08d,		0x21, 0
	.dw 0xc340, 0xc08d,	0xc37f, 0xc08d,		0x21, 0
	.dw 0xc3c0, 0xc08d,	0xc3ff, 0xc08d,		0x21, 0
	.dw 0xc440, 0xc08d,	0xc47f, 0xc08d,		0x21, 0
	.dw 0xc4c0, 0xc08d,	0xc4ff, 0xc08d,		0x21, 0
	.dw 0xc540, 0xc08d,	0xc57f, 0xc08d,		0x21, 0
	.dw 0xc5c0, 0xc08d,	0xc5ff, 0xc08d,		0x21, 0
	.dw 0xc640, 0xc08d,	0xc67f, 0xc08d,		0x21, 0
	.dw 0xc6c0, 0xc08d,	0xc6ff, 0xc08d,		0x21, 0
	.dw 0xc740, 0xc08d,	0xc77f, 0xc08d,		0x21, 0
	.dw 0xc7c0, 0xc08d,	0xc7ff, 0xc08d,		0x21, 0
	.dw 0xc840, 0xc08d,	0xc87f, 0xc08d,		0x21, 0
	.dw 0xc8c0, 0xc08d,	0xc8ff, 0xc08d,		0x21, 0
	.dw 0xc940, 0xc08d,	0xc97f, 0xc08d,		0x21, 0
	.dw 0xc9c0, 0xc08d,	0xc9ff, 0xc08d,		0x21, 0
	.dw 0xca40, 0xc08d,	0xca7f, 0xc08d,		0x21, 0
	.dw 0xcac0, 0xc08d,	0xcaff, 0xc08d,		0x21, 0
	.dw 0xcb40, 0xc08d,	0xcb7f, 0xc08d,		0x21, 0
	.dw 0xcbc0, 0xc08d,	0xcbff, 0xc08d,		0x21, 0
	.dw 0xcc40, 0xc08d,	0xcc7f, 0xc08d,		0x21, 0
	.dw 0xccc0, 0xc08d,	0xccff, 0xc08d,		0x21, 0
	.dw 0xcd40, 0xc08d,	0xcd7f, 0xc08d,		0x21, 0
	.dw 0xcdc0, 0xc08d,	0xcdff, 0xc08d,		0x21, 0
	.dw 0xce40, 0xc08d,	0xce7f, 0xc08d,		0x21, 0
	.dw 0xcec0, 0xc08d,	0xceff, 0xc08d,		0x21, 0
	.dw 0xcf40, 0xc08d,	0xcf7f, 0xc08d,		0x21, 0
	.dw 0xcfc0, 0xc08d,	0xcfff, 0xc08d,		0x21, 0
	.dw 0xd040, 0xc08d,	0xd07f, 0xc08d,		0x21, 0
	.dw 0xd0c0, 0xc08d,	0xd0ff, 0xc08d,		0x21, 0
	.dw 0xd140, 0xc08d,	0xd17f, 0xc08d,		0x21, 0
	.dw 0xd1c0, 0xc08d,	0xd1ff, 0xc08d,		0x21, 0
	.dw 0xd240, 0xc08d,	0xd27f, 0xc08d,		0x21, 0
	.dw 0xd2c0, 0xc08d,	0xd2ff, 0xc08d,		0x21, 0
	.dw 0xd340, 0xc08d,	0xd37f, 0xc08d,		0x21, 0
	.dw 0xd3c0, 0xc08d,	0xd3ff, 0xc08d,		0x21, 0
	.dw 0xd440, 0xc08d,	0xd47f, 0xc08d,		0x21, 0
	.dw 0xd4c0, 0xc08d,	0xd4ff, 0xc08d,		0x21, 0
	.dw 0xd540, 0xc08d,	0xd57f, 0xc08d,		0x21, 0
	.dw 0xd5c0, 0xc08d,	0xd5ff, 0xc08d,		0x21, 0
	.dw 0xd640, 0xc08d,	0xd67f, 0xc08d,		0x21, 0
	.dw 0xd6c0, 0xc08d,	0xd6ff, 0xc08d,		0x21, 0
	.dw 0xd740, 0xc08d,	0xd77f, 0xc08d,		0x21, 0
	.dw 0xd7c0, 0xc08d,	0xd7ff, 0xc08d,		0x21, 0
	.dw 0xd840, 0xc08d,	0xd87f, 0xc08d,		0x21, 0
	.dw 0xd8c0, 0xc08d,	0xd8ff, 0xc08d,		0x21, 0
	.dw 0xd940, 0xc08d,	0xd97f, 0xc08d,		0x21, 0
	.dw 0xd9c0, 0xc08d,	0xdfff, 0xc08d,		0x21, 0
	.dw 0xe040, 0xc08d,	0xe07f, 0xc08d,		0x21, 0
	.dw 0xe0c0, 0xc08d,	0xe0ff, 0xc08d,		0x21, 0
	.dw 0xe140, 0xc08d,	0xe17f, 0xc08d,		0x21, 0
	.dw 0xe1c0, 0xc08d,	0xe1ff, 0xc08d,		0x21, 0
	.dw 0xe240, 0xc08d,	0xe27f, 0xc08d,		0x21, 0
	.dw 0xe2c0, 0xc08d,	0xe2ff, 0xc08d,		0x21, 0
	.dw 0xe340, 0xc08d,	0xe37f, 0xc08d,		0x21, 0
	.dw 0xe3c0, 0xc08d,	0xe3ff, 0xc08d,		0x21, 0
	.dw 0xe440, 0xc08d,	0xe47f, 0xc08d,		0x21, 0
	.dw 0xe4c0, 0xc08d,	0xe4ff, 0xc08d,		0x21, 0
	.dw 0xe540, 0xc08d,	0xe57f, 0xc08d,		0x21, 0
	.dw 0xe5c0, 0xc08d,	0xe5ff, 0xc08d,		0x21, 0
	.dw 0xe640, 0xc08d,	0xe67f, 0xc08d,		0x21, 0
	.dw 0xe6c0, 0xc08d,	0xe6ff, 0xc08d,		0x21, 0
	.dw 0xe740, 0xc08d,	0xe77f, 0xc08d,		0x21, 0
	.dw 0xe7c0, 0xc08d,	0xe7ff, 0xc08d,		0x21, 0
	.dw 0xe840, 0xc08d,	0xe87f, 0xc08d,		0x21, 0
	.dw 0xe8c0, 0xc08d,	0xe8ff, 0xc08d,		0x21, 0
	.dw 0xe940, 0xc08d,	0xe97f, 0xc08d,		0x21, 0
	.dw 0xe9c0, 0xc08d,	0xe9ff, 0xc08d,		0x21, 0
	.dw 0xea40, 0xc08d,	0xea7f, 0xc08d,		0x21, 0
	.dw 0xeac0, 0xc08d,	0xeaff, 0xc08d,		0x21, 0
	.dw 0xeb40, 0xc08d,	0xeb7f, 0xc08d,		0x21, 0
	.dw 0xebc0, 0xc08d,	0xebff, 0xc08d,		0x21, 0
	.dw 0xec40, 0xc08d,	0xec7f, 0xc08d,		0x21, 0
	.dw 0xecc0, 0xc08d,	0xecff, 0xc08d,		0x21, 0
	.dw 0xed40, 0xc08d,	0xed7f, 0xc08d,		0x21, 0
	.dw 0xedc0, 0xc08d,	0xedff, 0xc08d,		0x21, 0
	.dw 0xee40, 0xc08d,	0xee7f, 0xc08d,		0x21, 0
	.dw 0xeec0, 0xc08d,	0xeeff, 0xc08d,		0x21, 0
	.dw 0xef40, 0xc08d,	0xef7f, 0xc08d,		0x21, 0
	.dw 0xefc0, 0xc08d,	0xefff, 0xc08d,		0x21, 0
	.dw 0xf040, 0xc08d,	0xf07f, 0xc08d,		0x21, 0
	.dw 0xf0c0, 0xc08d,	0xf0ff, 0xc08d,		0x21, 0
	.dw 0xf140, 0xc08d,	0xf17f, 0xc08d,		0x21, 0
	.dw 0xf1c0, 0xc08d,	0xf1ff, 0xc08d,		0x21, 0
	.dw 0xf240, 0xc08d,	0xf27f, 0xc08d,		0x21, 0
	.dw 0xf2c0, 0xc08d,	0xf2ff, 0xc08d,		0x21, 0
	.dw 0xf340, 0xc08d,	0xf37f, 0xc08d,		0x21, 0
	.dw 0xf3c0, 0xc08d,	0xf3ff, 0xc08d,		0x21, 0
	.dw 0xf440, 0xc08d,	0xf47f, 0xc08d,		0x21, 0
	.dw 0xf4c0, 0xc08d,	0xf4ff, 0xc08d,		0x21, 0
	.dw 0xf540, 0xc08d,	0xf57f, 0xc08d,		0x21, 0
	.dw 0xf5c0, 0xc08d,	0xf5ff, 0xc08d,		0x21, 0
	.dw 0xf640, 0xc08d,	0xf67f, 0xc08d,		0x21, 0
	.dw 0xf6c0, 0xc08d,	0xf6ff, 0xc08d,		0x21, 0
	.dw 0xf740, 0xc08d,	0xf77f, 0xc08d,		0x21, 0
	.dw 0xf7c0, 0xc08d,	0xf7ff, 0xc08d,		0x21, 0
	.dw 0xf840, 0xc08d,	0xf87f, 0xc08d,		0x21, 0
	.dw 0xf8c0, 0xc08d,	0xf8ff, 0xc08d,		0x21, 0
	.dw 0xf940, 0xc08d,	0xf97f, 0xc08d,		0x21, 0
	.dw 0xf9c0, 0xc08d,	0xffff, 0xc08d,		0x21, 0
	.dw 0x0040, 0xc08e,	0x007f, 0xc08e,		0x21, 0
	.dw 0x00c0, 0xc08e,	0x00ff, 0xc08e,		0x21, 0
	.dw 0x0140, 0xc08e,	0x017f, 0xc08e,		0x21, 0
	.dw 0x01c0, 0xc08e,	0x01ff, 0xc08e,		0x21, 0
	.dw 0x0240, 0xc08e,	0x027f, 0xc08e,		0x21, 0
	.dw 0x02c0, 0xc08e,	0x02ff, 0xc08e,		0x21, 0
	.dw 0x0340, 0xc08e,	0x037f, 0xc08e,		0x21, 0
	.dw 0x03c0, 0xc08e,	0x03ff, 0xc08e,		0x21, 0
	.dw 0x0440, 0xc08e,	0x047f, 0xc08e,		0x21, 0
	.dw 0x04c0, 0xc08e,	0x04ff, 0xc08e,		0x21, 0
	.dw 0x0540, 0xc08e,	0x057f, 0xc08e,		0x21, 0
	.dw 0x05c0, 0xc08e,	0x05ff, 0xc08e,		0x21, 0
	.dw 0x0640, 0xc08e,	0x067f, 0xc08e,		0x21, 0
	.dw 0x06c0, 0xc08e,	0x06ff, 0xc08e,		0x21, 0
	.dw 0x0740, 0xc08e,	0x077f, 0xc08e,		0x21, 0
	.dw 0x07c0, 0xc08e,	0x07ff, 0xc08e,		0x21, 0
	.dw 0x0840, 0xc08e,	0x087f, 0xc08e,		0x21, 0
	.dw 0x08c0, 0xc08e,	0x08ff, 0xc08e,		0x21, 0
	.dw 0x0940, 0xc08e,	0x097f, 0xc08e,		0x21, 0
	.dw 0x09c0, 0xc08e,	0x09ff, 0xc08e,		0x21, 0
	.dw 0x0a40, 0xc08e,	0x0a7f, 0xc08e,		0x21, 0
	.dw 0x0ac0, 0xc08e,	0x0aff, 0xc08e,		0x21, 0
	.dw 0x0b40, 0xc08e,	0x0b7f, 0xc08e,		0x21, 0
	.dw 0x0bc0, 0xc08e,	0x0bff, 0xc08e,		0x21, 0
	.dw 0x0c40, 0xc08e,	0x0c7f, 0xc08e,		0x21, 0
	.dw 0x0cc0, 0xc08e,	0x0cff, 0xc08e,		0x21, 0
	.dw 0x0d40, 0xc08e,	0x0d7f, 0xc08e,		0x21, 0
	.dw 0x0dc0, 0xc08e,	0x0dff, 0xc08e,		0x21, 0
	.dw 0x0e40, 0xc08e,	0x0e7f, 0xc08e,		0x21, 0
	.dw 0x0ec0, 0xc08e,	0x0eff, 0xc08e,		0x21, 0
	.dw 0x0f40, 0xc08e,	0x0f7f, 0xc08e,		0x21, 0
	.dw 0x0fc0, 0xc08e,	0x0fff, 0xc08e,		0x21, 0
	.dw 0x1040, 0xc08e,	0x107f, 0xc08e,		0x21, 0
	.dw 0x10c0, 0xc08e,	0x10ff, 0xc08e,		0x21, 0
	.dw 0x1140, 0xc08e,	0x117f, 0xc08e,		0x21, 0
	.dw 0x11c0, 0xc08e,	0x11ff, 0xc08e,		0x21, 0
	.dw 0x1240, 0xc08e,	0x127f, 0xc08e,		0x21, 0
	.dw 0x12c0, 0xc08e,	0x12ff, 0xc08e,		0x21, 0
	.dw 0x1340, 0xc08e,	0x137f, 0xc08e,		0x21, 0
	.dw 0x13c0, 0xc08e,	0x13ff, 0xc08e,		0x21, 0
	.dw 0x1440, 0xc08e,	0x147f, 0xc08e,		0x21, 0
	.dw 0x14c0, 0xc08e,	0x14ff, 0xc08e,		0x21, 0
	.dw 0x1540, 0xc08e,	0x157f, 0xc08e,		0x21, 0
	.dw 0x15c0, 0xc08e,	0x15ff, 0xc08e,		0x21, 0
	.dw 0x1640, 0xc08e,	0x167f, 0xc08e,		0x21, 0
	.dw 0x16c0, 0xc08e,	0x16ff, 0xc08e,		0x21, 0
	.dw 0x1740, 0xc08e,	0x177f, 0xc08e,		0x21, 0
	.dw 0x17c0, 0xc08e,	0x17ff, 0xc08e,		0x21, 0
	.dw 0x1840, 0xc08e,	0x187f, 0xc08e,		0x21, 0
	.dw 0x18c0, 0xc08e,	0x18ff, 0xc08e,		0x21, 0
	.dw 0x1940, 0xc08e,	0x197f, 0xc08e,		0x21, 0
	.dw 0x19c0, 0xc08e,	0x1fff, 0xc08e,		0x21, 0
	.dw 0x2040, 0xc08e,	0x207f, 0xc08e,		0x21, 0
	.dw 0x20c0, 0xc08e,	0x20ff, 0xc08e,		0x21, 0
	.dw 0x2140, 0xc08e,	0x217f, 0xc08e,		0x21, 0
	.dw 0x21c0, 0xc08e,	0x21ff, 0xc08e,		0x21, 0
	.dw 0x2240, 0xc08e,	0x227f, 0xc08e,		0x21, 0
	.dw 0x22c0, 0xc08e,	0x22ff, 0xc08e,		0x21, 0
	.dw 0x2340, 0xc08e,	0x237f, 0xc08e,		0x21, 0
	.dw 0x23c0, 0xc08e,	0x23ff, 0xc08e,		0x21, 0
	.dw 0x2440, 0xc08e,	0x247f, 0xc08e,		0x21, 0
	.dw 0x24c0, 0xc08e,	0x24ff, 0xc08e,		0x21, 0
	.dw 0x2540, 0xc08e,	0x257f, 0xc08e,		0x21, 0
	.dw 0x25c0, 0xc08e,	0x25ff, 0xc08e,		0x21, 0
	.dw 0x2640, 0xc08e,	0x267f, 0xc08e,		0x21, 0
	.dw 0x26c0, 0xc08e,	0x26ff, 0xc08e,		0x21, 0
	.dw 0x2740, 0xc08e,	0x277f, 0xc08e,		0x21, 0
	.dw 0x27c0, 0xc08e,	0x27ff, 0xc08e,		0x21, 0
	.dw 0x2840, 0xc08e,	0x287f, 0xc08e,		0x21, 0
	.dw 0x28c0, 0xc08e,	0x28ff, 0xc08e,		0x21, 0
	.dw 0x2940, 0xc08e,	0x297f, 0xc08e,		0x21, 0
	.dw 0x29c0, 0xc08e,	0x29ff, 0xc08e,		0x21, 0
	.dw 0x2a40, 0xc08e,	0x2a7f, 0xc08e,		0x21, 0
	.dw 0x2ac0, 0xc08e,	0x2aff, 0xc08e,		0x21, 0
	.dw 0x2b40, 0xc08e,	0x2b7f, 0xc08e,		0x21, 0
	.dw 0x2bc0, 0xc08e,	0x2bff, 0xc08e,		0x21, 0
	.dw 0x2c40, 0xc08e,	0x2c7f, 0xc08e,		0x21, 0
	.dw 0x2cc0, 0xc08e,	0x2cff, 0xc08e,		0x21, 0
	.dw 0x2d40, 0xc08e,	0x2d7f, 0xc08e,		0x21, 0
	.dw 0x2dc0, 0xc08e,	0x2dff, 0xc08e,		0x21, 0
	.dw 0x2e40, 0xc08e,	0x2e7f, 0xc08e,		0x21, 0
	.dw 0x2ec0, 0xc08e,	0x2eff, 0xc08e,		0x21, 0
	.dw 0x2f40, 0xc08e,	0x2f7f, 0xc08e,		0x21, 0
	.dw 0x2fc0, 0xc08e,	0x2fff, 0xc08e,		0x21, 0
	.dw 0x3040, 0xc08e,	0x307f, 0xc08e,		0x21, 0
	.dw 0x30c0, 0xc08e,	0x30ff, 0xc08e,		0x21, 0
	.dw 0x3140, 0xc08e,	0x317f, 0xc08e,		0x21, 0
	.dw 0x31c0, 0xc08e,	0x31ff, 0xc08e,		0x21, 0
	.dw 0x3240, 0xc08e,	0x327f, 0xc08e,		0x21, 0
	.dw 0x32c0, 0xc08e,	0x32ff, 0xc08e,		0x21, 0
	.dw 0x3340, 0xc08e,	0x337f, 0xc08e,		0x21, 0
	.dw 0x33c0, 0xc08e,	0x33ff, 0xc08e,		0x21, 0
	.dw 0x3440, 0xc08e,	0x347f, 0xc08e,		0x21, 0
	.dw 0x34c0, 0xc08e,	0x34ff, 0xc08e,		0x21, 0
	.dw 0x3540, 0xc08e,	0x357f, 0xc08e,		0x21, 0
	.dw 0x35c0, 0xc08e,	0x35ff, 0xc08e,		0x21, 0
	.dw 0x3640, 0xc08e,	0x367f, 0xc08e,		0x21, 0
	.dw 0x36c0, 0xc08e,	0x36ff, 0xc08e,		0x21, 0
	.dw 0x3740, 0xc08e,	0x377f, 0xc08e,		0x21, 0
	.dw 0x37c0, 0xc08e,	0x37ff, 0xc08e,		0x21, 0
	.dw 0x3840, 0xc08e,	0x387f, 0xc08e,		0x21, 0
	.dw 0x38c0, 0xc08e,	0x38ff, 0xc08e,		0x21, 0
	.dw 0x3940, 0xc08e,	0x397f, 0xc08e,		0x21, 0
	.dw 0x39c0, 0xc08e,	0x3fff, 0xc08e,		0x21, 0
	.dw 0x4040, 0xc08e,	0x407f, 0xc08e,		0x21, 0
	.dw 0x40c0, 0xc08e,	0x40ff, 0xc08e,		0x21, 0
	.dw 0x4140, 0xc08e,	0x417f, 0xc08e,		0x21, 0
	.dw 0x41c0, 0xc08e,	0x41ff, 0xc08e,		0x21, 0
	.dw 0x4240, 0xc08e,	0x427f, 0xc08e,		0x21, 0
	.dw 0x42c0, 0xc08e,	0x42ff, 0xc08e,		0x21, 0
	.dw 0x4340, 0xc08e,	0x437f, 0xc08e,		0x21, 0
	.dw 0x43c0, 0xc08e,	0x43ff, 0xc08e,		0x21, 0
	.dw 0x4440, 0xc08e,	0x447f, 0xc08e,		0x21, 0
	.dw 0x44c0, 0xc08e,	0x44ff, 0xc08e,		0x21, 0
	.dw 0x4540, 0xc08e,	0x457f, 0xc08e,		0x21, 0
	.dw 0x45c0, 0xc08e,	0x45ff, 0xc08e,		0x21, 0
	.dw 0x4640, 0xc08e,	0x467f, 0xc08e,		0x21, 0
	.dw 0x46c0, 0xc08e,	0x46ff, 0xc08e,		0x21, 0
	.dw 0x4740, 0xc08e,	0x477f, 0xc08e,		0x21, 0
	.dw 0x47c0, 0xc08e,	0x47ff, 0xc08e,		0x21, 0
	.dw 0x4840, 0xc08e,	0x487f, 0xc08e,		0x21, 0
	.dw 0x48c0, 0xc08e,	0x48ff, 0xc08e,		0x21, 0
	.dw 0x4940, 0xc08e,	0x497f, 0xc08e,		0x21, 0
	.dw 0x49c0, 0xc08e,	0x49ff, 0xc08e,		0x21, 0
	.dw 0x4a40, 0xc08e,	0x4a7f, 0xc08e,		0x21, 0
	.dw 0x4ac0, 0xc08e,	0x4aff, 0xc08e,		0x21, 0
	.dw 0x4b40, 0xc08e,	0x4b7f, 0xc08e,		0x21, 0
	.dw 0x4bc0, 0xc08e,	0x4bff, 0xc08e,		0x21, 0
	.dw 0x4c40, 0xc08e,	0x4c7f, 0xc08e,		0x21, 0
	.dw 0x4cc0, 0xc08e,	0x4cff, 0xc08e,		0x21, 0
	.dw 0x4d40, 0xc08e,	0x4d7f, 0xc08e,		0x21, 0
	.dw 0x4dc0, 0xc08e,	0x4dff, 0xc08e,		0x21, 0
	.dw 0x4e40, 0xc08e,	0x4e7f, 0xc08e,		0x21, 0
	.dw 0x4ec0, 0xc08e,	0x4eff, 0xc08e,		0x21, 0
	.dw 0x4f40, 0xc08e,	0x4f7f, 0xc08e,		0x21, 0
	.dw 0x4fc0, 0xc08e,	0x4fff, 0xc08e,		0x21, 0
	.dw 0x5040, 0xc08e,	0x507f, 0xc08e,		0x21, 0
	.dw 0x50c0, 0xc08e,	0x50ff, 0xc08e,		0x21, 0
	.dw 0x5140, 0xc08e,	0x517f, 0xc08e,		0x21, 0
	.dw 0x51c0, 0xc08e,	0x51ff, 0xc08e,		0x21, 0
	.dw 0x5240, 0xc08e,	0x527f, 0xc08e,		0x21, 0
	.dw 0x52c0, 0xc08e,	0x52ff, 0xc08e,		0x21, 0
	.dw 0x5340, 0xc08e,	0x537f, 0xc08e,		0x21, 0
	.dw 0x53c0, 0xc08e,	0x53ff, 0xc08e,		0x21, 0
	.dw 0x5440, 0xc08e,	0x547f, 0xc08e,		0x21, 0
	.dw 0x54c0, 0xc08e,	0x54ff, 0xc08e,		0x21, 0
	.dw 0x5540, 0xc08e,	0x557f, 0xc08e,		0x21, 0
	.dw 0x55c0, 0xc08e,	0x55ff, 0xc08e,		0x21, 0
	.dw 0x5640, 0xc08e,	0x567f, 0xc08e,		0x21, 0
	.dw 0x56c0, 0xc08e,	0x56ff, 0xc08e,		0x21, 0
	.dw 0x5740, 0xc08e,	0x577f, 0xc08e,		0x21, 0
	.dw 0x57c0, 0xc08e,	0x57ff, 0xc08e,		0x21, 0
	.dw 0x5840, 0xc08e,	0x587f, 0xc08e,		0x21, 0
	.dw 0x58c0, 0xc08e,	0x58ff, 0xc08e,		0x21, 0
	.dw 0x5940, 0xc08e,	0x597f, 0xc08e,		0x21, 0
	.dw 0x59c0, 0xc08e,	0x5fff, 0xc08e,		0x21, 0
	.dw 0x6040, 0xc08e,	0x607f, 0xc08e,		0x21, 0
	.dw 0x60c0, 0xc08e,	0x60ff, 0xc08e,		0x21, 0
	.dw 0x6140, 0xc08e,	0x617f, 0xc08e,		0x21, 0
	.dw 0x61c0, 0xc08e,	0x61ff, 0xc08e,		0x21, 0
	.dw 0x6240, 0xc08e,	0x627f, 0xc08e,		0x21, 0
	.dw 0x62c0, 0xc08e,	0x62ff, 0xc08e,		0x21, 0
	.dw 0x6340, 0xc08e,	0x637f, 0xc08e,		0x21, 0
	.dw 0x63c0, 0xc08e,	0x63ff, 0xc08e,		0x21, 0
	.dw 0x6440, 0xc08e,	0x647f, 0xc08e,		0x21, 0
	.dw 0x64c0, 0xc08e,	0x64ff, 0xc08e,		0x21, 0
	.dw 0x6540, 0xc08e,	0x657f, 0xc08e,		0x21, 0
	.dw 0x65c0, 0xc08e,	0x65ff, 0xc08e,		0x21, 0
	.dw 0x6640, 0xc08e,	0x667f, 0xc08e,		0x21, 0
	.dw 0x66c0, 0xc08e,	0x66ff, 0xc08e,		0x21, 0
	.dw 0x6740, 0xc08e,	0x677f, 0xc08e,		0x21, 0
	.dw 0x67c0, 0xc08e,	0x67ff, 0xc08e,		0x21, 0
	.dw 0x6840, 0xc08e,	0x687f, 0xc08e,		0x21, 0
	.dw 0x68c0, 0xc08e,	0x68ff, 0xc08e,		0x21, 0
	.dw 0x6940, 0xc08e,	0x697f, 0xc08e,		0x21, 0
	.dw 0x69c0, 0xc08e,	0x69ff, 0xc08e,		0x21, 0
	.dw 0x6a40, 0xc08e,	0x6a7f, 0xc08e,		0x21, 0
	.dw 0x6ac0, 0xc08e,	0x6aff, 0xc08e,		0x21, 0
	.dw 0x6b40, 0xc08e,	0x6b7f, 0xc08e,		0x21, 0
	.dw 0x6bc0, 0xc08e,	0x6bff, 0xc08e,		0x21, 0
	.dw 0x6c40, 0xc08e,	0x6c7f, 0xc08e,		0x21, 0
	.dw 0x6cc0, 0xc08e,	0x6cff, 0xc08e,		0x21, 0
	.dw 0x6d40, 0xc08e,	0x6d7f, 0xc08e,		0x21, 0
	.dw 0x6dc0, 0xc08e,	0x6dff, 0xc08e,		0x21, 0
	.dw 0x6e40, 0xc08e,	0x6e7f, 0xc08e,		0x21, 0
	.dw 0x6ec0, 0xc08e,	0x6eff, 0xc08e,		0x21, 0
	.dw 0x6f40, 0xc08e,	0x6f7f, 0xc08e,		0x21, 0
	.dw 0x6fc0, 0xc08e,	0x6fff, 0xc08e,		0x21, 0
	.dw 0x7040, 0xc08e,	0x707f, 0xc08e,		0x21, 0
	.dw 0x70c0, 0xc08e,	0x70ff, 0xc08e,		0x21, 0
	.dw 0x7140, 0xc08e,	0x717f, 0xc08e,		0x21, 0
	.dw 0x71c0, 0xc08e,	0x71ff, 0xc08e,		0x21, 0
	.dw 0x7240, 0xc08e,	0x727f, 0xc08e,		0x21, 0
	.dw 0x72c0, 0xc08e,	0x72ff, 0xc08e,		0x21, 0
	.dw 0x7340, 0xc08e,	0x737f, 0xc08e,		0x21, 0
	.dw 0x73c0, 0xc08e,	0x73ff, 0xc08e,		0x21, 0
	.dw 0x7440, 0xc08e,	0x747f, 0xc08e,		0x21, 0
	.dw 0x74c0, 0xc08e,	0x74ff, 0xc08e,		0x21, 0
	.dw 0x7540, 0xc08e,	0x757f, 0xc08e,		0x21, 0
	.dw 0x75c0, 0xc08e,	0x75ff, 0xc08e,		0x21, 0
	.dw 0x7640, 0xc08e,	0x767f, 0xc08e,		0x21, 0
	.dw 0x76c0, 0xc08e,	0x76ff, 0xc08e,		0x21, 0
	.dw 0x7740, 0xc08e,	0x777f, 0xc08e,		0x21, 0
	.dw 0x77c0, 0xc08e,	0x77ff, 0xc08e,		0x21, 0
	.dw 0x7840, 0xc08e,	0x787f, 0xc08e,		0x21, 0
	.dw 0x78c0, 0xc08e,	0x78ff, 0xc08e,		0x21, 0
	.dw 0x7940, 0xc08e,	0x797f, 0xc08e,		0x21, 0
	.dw 0x79c0, 0xc08e,	0x7fff, 0xc08e,		0x21, 0
	.dw 0x8040, 0xc08e,	0x807f, 0xc08e,		0x21, 0
	.dw 0x80c0, 0xc08e,	0x80ff, 0xc08e,		0x21, 0
	.dw 0x8140, 0xc08e,	0x817f, 0xc08e,		0x21, 0
	.dw 0x81c0, 0xc08e,	0x81ff, 0xc08e,		0x21, 0
	.dw 0x8240, 0xc08e,	0x827f, 0xc08e,		0x21, 0
	.dw 0x82c0, 0xc08e,	0x82ff, 0xc08e,		0x21, 0
	.dw 0x8340, 0xc08e,	0x837f, 0xc08e,		0x21, 0
	.dw 0x83c0, 0xc08e,	0x83ff, 0xc08e,		0x21, 0
	.dw 0x8440, 0xc08e,	0x847f, 0xc08e,		0x21, 0
	.dw 0x84c0, 0xc08e,	0x84ff, 0xc08e,		0x21, 0
	.dw 0x8540, 0xc08e,	0x857f, 0xc08e,		0x21, 0
	.dw 0x85c0, 0xc08e,	0x85ff, 0xc08e,		0x21, 0
	.dw 0x8640, 0xc08e,	0x867f, 0xc08e,		0x21, 0
	.dw 0x86c0, 0xc08e,	0x86ff, 0xc08e,		0x21, 0
	.dw 0x8740, 0xc08e,	0x877f, 0xc08e,		0x21, 0
	.dw 0x87c0, 0xc08e,	0x87ff, 0xc08e,		0x21, 0
	.dw 0x8840, 0xc08e,	0x887f, 0xc08e,		0x21, 0
	.dw 0x88c0, 0xc08e,	0x88ff, 0xc08e,		0x21, 0
	.dw 0x8940, 0xc08e,	0x897f, 0xc08e,		0x21, 0
	.dw 0x89c0, 0xc08e,	0x89ff, 0xc08e,		0x21, 0
	.dw 0x8a40, 0xc08e,	0x8a7f, 0xc08e,		0x21, 0
	.dw 0x8ac0, 0xc08e,	0x8aff, 0xc08e,		0x21, 0
	.dw 0x8b40, 0xc08e,	0x8b7f, 0xc08e,		0x21, 0
	.dw 0x8bc0, 0xc08e,	0x8bff, 0xc08e,		0x21, 0
	.dw 0x8c40, 0xc08e,	0x8c7f, 0xc08e,		0x21, 0
	.dw 0x8cc0, 0xc08e,	0x8cff, 0xc08e,		0x21, 0
	.dw 0x8d40, 0xc08e,	0x8d7f, 0xc08e,		0x21, 0
	.dw 0x8dc0, 0xc08e,	0x8dff, 0xc08e,		0x21, 0
	.dw 0x8e40, 0xc08e,	0x8e7f, 0xc08e,		0x21, 0
	.dw 0x8ec0, 0xc08e,	0x8eff, 0xc08e,		0x21, 0
	.dw 0x8f40, 0xc08e,	0x8f7f, 0xc08e,		0x21, 0
	.dw 0x8fc0, 0xc08e,	0x8fff, 0xc08e,		0x21, 0
	.dw 0x9040, 0xc08e,	0x907f, 0xc08e,		0x21, 0
	.dw 0x90c0, 0xc08e,	0x90ff, 0xc08e,		0x21, 0
	.dw 0x9140, 0xc08e,	0x917f, 0xc08e,		0x21, 0
	.dw 0x91c0, 0xc08e,	0x91ff, 0xc08e,		0x21, 0
	.dw 0x9240, 0xc08e,	0x927f, 0xc08e,		0x21, 0
	.dw 0x92c0, 0xc08e,	0x92ff, 0xc08e,		0x21, 0
	.dw 0x9340, 0xc08e,	0x937f, 0xc08e,		0x21, 0
	.dw 0x93c0, 0xc08e,	0x93ff, 0xc08e,		0x21, 0
	.dw 0x9440, 0xc08e,	0x947f, 0xc08e,		0x21, 0
	.dw 0x94c0, 0xc08e,	0x94ff, 0xc08e,		0x21, 0
	.dw 0x9540, 0xc08e,	0x957f, 0xc08e,		0x21, 0
	.dw 0x95c0, 0xc08e,	0x95ff, 0xc08e,		0x21, 0
	.dw 0x9640, 0xc08e,	0x967f, 0xc08e,		0x21, 0
	.dw 0x96c0, 0xc08e,	0x96ff, 0xc08e,		0x21, 0
	.dw 0x9740, 0xc08e,	0x977f, 0xc08e,		0x21, 0
	.dw 0x97c0, 0xc08e,	0x97ff, 0xc08e,		0x21, 0
	.dw 0x9840, 0xc08e,	0x987f, 0xc08e,		0x21, 0
	.dw 0x98c0, 0xc08e,	0x98ff, 0xc08e,		0x21, 0
	.dw 0x9940, 0xc08e,	0x997f, 0xc08e,		0x21, 0
	.dw 0x99c0, 0xc08e,	0x9fff, 0xc08e,		0x21, 0
	.dw 0xa040, 0xc08e,	0xa07f, 0xc08e,		0x21, 0
	.dw 0xa0c0, 0xc08e,	0xa0ff, 0xc08e,		0x21, 0
	.dw 0xa140, 0xc08e,	0xa17f, 0xc08e,		0x21, 0
	.dw 0xa1c0, 0xc08e,	0xa1ff, 0xc08e,		0x21, 0
	.dw 0xa240, 0xc08e,	0xa27f, 0xc08e,		0x21, 0
	.dw 0xa2c0, 0xc08e,	0xa2ff, 0xc08e,		0x21, 0
	.dw 0xa340, 0xc08e,	0xa37f, 0xc08e,		0x21, 0
	.dw 0xa3c0, 0xc08e,	0xa3ff, 0xc08e,		0x21, 0
	.dw 0xa440, 0xc08e,	0xa47f, 0xc08e,		0x21, 0
	.dw 0xa4c0, 0xc08e,	0xa4ff, 0xc08e,		0x21, 0
	.dw 0xa540, 0xc08e,	0xa57f, 0xc08e,		0x21, 0
	.dw 0xa5c0, 0xc08e,	0xa5ff, 0xc08e,		0x21, 0
	.dw 0xa640, 0xc08e,	0xa67f, 0xc08e,		0x21, 0
	.dw 0xa6c0, 0xc08e,	0xa6ff, 0xc08e,		0x21, 0
	.dw 0xa740, 0xc08e,	0xa77f, 0xc08e,		0x21, 0
	.dw 0xa7c0, 0xc08e,	0xa7ff, 0xc08e,		0x21, 0
	.dw 0xa840, 0xc08e,	0xa87f, 0xc08e,		0x21, 0
	.dw 0xa8c0, 0xc08e,	0xa8ff, 0xc08e,		0x21, 0
	.dw 0xa940, 0xc08e,	0xa97f, 0xc08e,		0x21, 0
	.dw 0xa9c0, 0xc08e,	0xa9ff, 0xc08e,		0x21, 0
	.dw 0xaa40, 0xc08e,	0xaa7f, 0xc08e,		0x21, 0
	.dw 0xaac0, 0xc08e,	0xaaff, 0xc08e,		0x21, 0
	.dw 0xab40, 0xc08e,	0xab7f, 0xc08e,		0x21, 0
	.dw 0xabc0, 0xc08e,	0xabff, 0xc08e,		0x21, 0
	.dw 0xac40, 0xc08e,	0xac7f, 0xc08e,		0x21, 0
	.dw 0xacc0, 0xc08e,	0xacff, 0xc08e,		0x21, 0
	.dw 0xad40, 0xc08e,	0xad7f, 0xc08e,		0x21, 0
	.dw 0xadc0, 0xc08e,	0xadff, 0xc08e,		0x21, 0
	.dw 0xae40, 0xc08e,	0xae7f, 0xc08e,		0x21, 0
	.dw 0xaec0, 0xc08e,	0xaeff, 0xc08e,		0x21, 0
	.dw 0xaf40, 0xc08e,	0xaf7f, 0xc08e,		0x21, 0
	.dw 0xafc0, 0xc08e,	0xafff, 0xc08e,		0x21, 0
	.dw 0xb040, 0xc08e,	0xb07f, 0xc08e,		0x21, 0
	.dw 0xb0c0, 0xc08e,	0xb0ff, 0xc08e,		0x21, 0
	.dw 0xb140, 0xc08e,	0xb17f, 0xc08e,		0x21, 0
	.dw 0xb1c0, 0xc08e,	0xb1ff, 0xc08e,		0x21, 0
	.dw 0xb240, 0xc08e,	0xb27f, 0xc08e,		0x21, 0
	.dw 0xb2c0, 0xc08e,	0xb2ff, 0xc08e,		0x21, 0
	.dw 0xb340, 0xc08e,	0xb37f, 0xc08e,		0x21, 0
	.dw 0xb3c0, 0xc08e,	0xb3ff, 0xc08e,		0x21, 0
	.dw 0xb440, 0xc08e,	0xb47f, 0xc08e,		0x21, 0
	.dw 0xb4c0, 0xc08e,	0xb4ff, 0xc08e,		0x21, 0
	.dw 0xb540, 0xc08e,	0xb57f, 0xc08e,		0x21, 0
	.dw 0xb5c0, 0xc08e,	0xb5ff, 0xc08e,		0x21, 0
	.dw 0xb640, 0xc08e,	0xb67f, 0xc08e,		0x21, 0
	.dw 0xb6c0, 0xc08e,	0xb6ff, 0xc08e,		0x21, 0
	.dw 0xb740, 0xc08e,	0xb77f, 0xc08e,		0x21, 0
	.dw 0xb7c0, 0xc08e,	0xb7ff, 0xc08e,		0x21, 0
	.dw 0xb840, 0xc08e,	0xb87f, 0xc08e,		0x21, 0
	.dw 0xb8c0, 0xc08e,	0xb8ff, 0xc08e,		0x21, 0
	.dw 0xb940, 0xc08e,	0xb97f, 0xc08e,		0x21, 0
	.dw 0xb9c0, 0xc08e,	0xbfff, 0xc08e,		0x21, 0
	.dw 0xc040, 0xc08e,	0xc07f, 0xc08e,		0x21, 0
	.dw 0xc0c0, 0xc08e,	0xc0ff, 0xc08e,		0x21, 0
	.dw 0xc140, 0xc08e,	0xc17f, 0xc08e,		0x21, 0
	.dw 0xc1c0, 0xc08e,	0xc1ff, 0xc08e,		0x21, 0
	.dw 0xc240, 0xc08e,	0xc27f, 0xc08e,		0x21, 0
	.dw 0xc2c0, 0xc08e,	0xc2ff, 0xc08e,		0x21, 0
	.dw 0xc340, 0xc08e,	0xc37f, 0xc08e,		0x21, 0
	.dw 0xc3c0, 0xc08e,	0xc3ff, 0xc08e,		0x21, 0
	.dw 0xc440, 0xc08e,	0xc47f, 0xc08e,		0x21, 0
	.dw 0xc4c0, 0xc08e,	0xc4ff, 0xc08e,		0x21, 0
	.dw 0xc540, 0xc08e,	0xc57f, 0xc08e,		0x21, 0
	.dw 0xc5c0, 0xc08e,	0xc5ff, 0xc08e,		0x21, 0
	.dw 0xc640, 0xc08e,	0xc67f, 0xc08e,		0x21, 0
	.dw 0xc6c0, 0xc08e,	0xc6ff, 0xc08e,		0x21, 0
	.dw 0xc740, 0xc08e,	0xc77f, 0xc08e,		0x21, 0
	.dw 0xc7c0, 0xc08e,	0xc7ff, 0xc08e,		0x21, 0
	.dw 0xc840, 0xc08e,	0xc87f, 0xc08e,		0x21, 0
	.dw 0xc8c0, 0xc08e,	0xc8ff, 0xc08e,		0x21, 0
	.dw 0xc940, 0xc08e,	0xc97f, 0xc08e,		0x21, 0
	.dw 0xc9c0, 0xc08e,	0xc9ff, 0xc08e,		0x21, 0
	.dw 0xca40, 0xc08e,	0xca7f, 0xc08e,		0x21, 0
	.dw 0xcac0, 0xc08e,	0xcaff, 0xc08e,		0x21, 0
	.dw 0xcb40, 0xc08e,	0xcb7f, 0xc08e,		0x21, 0
	.dw 0xcbc0, 0xc08e,	0xcbff, 0xc08e,		0x21, 0
	.dw 0xcc40, 0xc08e,	0xcc7f, 0xc08e,		0x21, 0
	.dw 0xccc0, 0xc08e,	0xccff, 0xc08e,		0x21, 0
	.dw 0xcd40, 0xc08e,	0xcd7f, 0xc08e,		0x21, 0
	.dw 0xcdc0, 0xc08e,	0xcdff, 0xc08e,		0x21, 0
	.dw 0xce40, 0xc08e,	0xce7f, 0xc08e,		0x21, 0
	.dw 0xcec0, 0xc08e,	0xceff, 0xc08e,		0x21, 0
	.dw 0xcf40, 0xc08e,	0xcf7f, 0xc08e,		0x21, 0
	.dw 0xcfc0, 0xc08e,	0xcfff, 0xc08e,		0x21, 0
	.dw 0xd040, 0xc08e,	0xd07f, 0xc08e,		0x21, 0
	.dw 0xd0c0, 0xc08e,	0xd0ff, 0xc08e,		0x21, 0
	.dw 0xd140, 0xc08e,	0xd17f, 0xc08e,		0x21, 0
	.dw 0xd1c0, 0xc08e,	0xd1ff, 0xc08e,		0x21, 0
	.dw 0xd240, 0xc08e,	0xd27f, 0xc08e,		0x21, 0
	.dw 0xd2c0, 0xc08e,	0xd2ff, 0xc08e,		0x21, 0
	.dw 0xd340, 0xc08e,	0xd37f, 0xc08e,		0x21, 0
	.dw 0xd3c0, 0xc08e,	0xd3ff, 0xc08e,		0x21, 0
	.dw 0xd440, 0xc08e,	0xd47f, 0xc08e,		0x21, 0
	.dw 0xd4c0, 0xc08e,	0xd4ff, 0xc08e,		0x21, 0
	.dw 0xd540, 0xc08e,	0xd57f, 0xc08e,		0x21, 0
	.dw 0xd5c0, 0xc08e,	0xd5ff, 0xc08e,		0x21, 0
	.dw 0xd640, 0xc08e,	0xd67f, 0xc08e,		0x21, 0
	.dw 0xd6c0, 0xc08e,	0xd6ff, 0xc08e,		0x21, 0
	.dw 0xd740, 0xc08e,	0xd77f, 0xc08e,		0x21, 0
	.dw 0xd7c0, 0xc08e,	0xd7ff, 0xc08e,		0x21, 0
	.dw 0xd840, 0xc08e,	0xd87f, 0xc08e,		0x21, 0
	.dw 0xd8c0, 0xc08e,	0xd8ff, 0xc08e,		0x21, 0
	.dw 0xd940, 0xc08e,	0xd97f, 0xc08e,		0x21, 0
	.dw 0xd9c0, 0xc08e,	0xdfff, 0xc08e,		0x21, 0
	.dw 0xe040, 0xc08e,	0xe07f, 0xc08e,		0x21, 0
	.dw 0xe0c0, 0xc08e,	0xe0ff, 0xc08e,		0x21, 0
	.dw 0xe140, 0xc08e,	0xe17f, 0xc08e,		0x21, 0
	.dw 0xe1c0, 0xc08e,	0xe1ff, 0xc08e,		0x21, 0
	.dw 0xe240, 0xc08e,	0xe27f, 0xc08e,		0x21, 0
	.dw 0xe2c0, 0xc08e,	0xe2ff, 0xc08e,		0x21, 0
	.dw 0xe340, 0xc08e,	0xe37f, 0xc08e,		0x21, 0
	.dw 0xe3c0, 0xc08e,	0xe3ff, 0xc08e,		0x21, 0
	.dw 0xe440, 0xc08e,	0xe47f, 0xc08e,		0x21, 0
	.dw 0xe4c0, 0xc08e,	0xe4ff, 0xc08e,		0x21, 0
	.dw 0xe540, 0xc08e,	0xe57f, 0xc08e,		0x21, 0
	.dw 0xe5c0, 0xc08e,	0xe5ff, 0xc08e,		0x21, 0
	.dw 0xe640, 0xc08e,	0xe67f, 0xc08e,		0x21, 0
	.dw 0xe6c0, 0xc08e,	0xe6ff, 0xc08e,		0x21, 0
	.dw 0xe740, 0xc08e,	0xe77f, 0xc08e,		0x21, 0
	.dw 0xe7c0, 0xc08e,	0xe7ff, 0xc08e,		0x21, 0
	.dw 0xe840, 0xc08e,	0xe87f, 0xc08e,		0x21, 0
	.dw 0xe8c0, 0xc08e,	0xe8ff, 0xc08e,		0x21, 0
	.dw 0xe940, 0xc08e,	0xe97f, 0xc08e,		0x21, 0
	.dw 0xe9c0, 0xc08e,	0xe9ff, 0xc08e,		0x21, 0
	.dw 0xea40, 0xc08e,	0xea7f, 0xc08e,		0x21, 0
	.dw 0xeac0, 0xc08e,	0xeaff, 0xc08e,		0x21, 0
	.dw 0xeb40, 0xc08e,	0xeb7f, 0xc08e,		0x21, 0
	.dw 0xebc0, 0xc08e,	0xebff, 0xc08e,		0x21, 0
	.dw 0xec40, 0xc08e,	0xec7f, 0xc08e,		0x21, 0
	.dw 0xecc0, 0xc08e,	0xecff, 0xc08e,		0x21, 0
	.dw 0xed40, 0xc08e,	0xed7f, 0xc08e,		0x21, 0
	.dw 0xedc0, 0xc08e,	0xedff, 0xc08e,		0x21, 0
	.dw 0xee40, 0xc08e,	0xee7f, 0xc08e,		0x21, 0
	.dw 0xeec0, 0xc08e,	0xeeff, 0xc08e,		0x21, 0
	.dw 0xef40, 0xc08e,	0xef7f, 0xc08e,		0x21, 0
	.dw 0xefc0, 0xc08e,	0xefff, 0xc08e,		0x21, 0
	.dw 0xf040, 0xc08e,	0xf07f, 0xc08e,		0x21, 0
	.dw 0xf0c0, 0xc08e,	0xf0ff, 0xc08e,		0x21, 0
	.dw 0xf140, 0xc08e,	0xf17f, 0xc08e,		0x21, 0
	.dw 0xf1c0, 0xc08e,	0xf1ff, 0xc08e,		0x21, 0
	.dw 0xf240, 0xc08e,	0xf27f, 0xc08e,		0x21, 0
	.dw 0xf2c0, 0xc08e,	0xf2ff, 0xc08e,		0x21, 0
	.dw 0xf340, 0xc08e,	0xf37f, 0xc08e,		0x21, 0
	.dw 0xf3c0, 0xc08e,	0xf3ff, 0xc08e,		0x21, 0
	.dw 0xf440, 0xc08e,	0xf47f, 0xc08e,		0x21, 0
	.dw 0xf4c0, 0xc08e,	0xf4ff, 0xc08e,		0x21, 0
	.dw 0xf540, 0xc08e,	0xf57f, 0xc08e,		0x21, 0
	.dw 0xf5c0, 0xc08e,	0xf5ff, 0xc08e,		0x21, 0
	.dw 0xf640, 0xc08e,	0xf67f, 0xc08e,		0x21, 0
	.dw 0xf6c0, 0xc08e,	0xf6ff, 0xc08e,		0x21, 0
	.dw 0xf740, 0xc08e,	0xf77f, 0xc08e,		0x21, 0
	.dw 0xf7c0, 0xc08e,	0xf7ff, 0xc08e,		0x21, 0
	.dw 0xf840, 0xc08e,	0xf87f, 0xc08e,		0x21, 0
	.dw 0xf8c0, 0xc08e,	0xf8ff, 0xc08e,		0x21, 0
	.dw 0xf940, 0xc08e,	0xf97f, 0xc08e,		0x21, 0
	.dw 0xf9c0, 0xc08e,	0xffff, 0xc08e,		0x21, 0
	.dw 0x0040, 0xc08f,	0x007f, 0xc08f,		0x21, 0
	.dw 0x00c0, 0xc08f,	0x00ff, 0xc08f,		0x21, 0
	.dw 0x0140, 0xc08f,	0x017f, 0xc08f,		0x21, 0
	.dw 0x01c0, 0xc08f,	0x01ff, 0xc08f,		0x21, 0
	.dw 0x0240, 0xc08f,	0x027f, 0xc08f,		0x21, 0
	.dw 0x02c0, 0xc08f,	0x02ff, 0xc08f,		0x21, 0
	.dw 0x0340, 0xc08f,	0x037f, 0xc08f,		0x21, 0
	.dw 0x03c0, 0xc08f,	0x03ff, 0xc08f,		0x21, 0
	.dw 0x0440, 0xc08f,	0x047f, 0xc08f,		0x21, 0
	.dw 0x04c0, 0xc08f,	0x04ff, 0xc08f,		0x21, 0
	.dw 0x0540, 0xc08f,	0x057f, 0xc08f,		0x21, 0
	.dw 0x05c0, 0xc08f,	0x05ff, 0xc08f,		0x21, 0
	.dw 0x0640, 0xc08f,	0x067f, 0xc08f,		0x21, 0
	.dw 0x06c0, 0xc08f,	0x06ff, 0xc08f,		0x21, 0
	.dw 0x0740, 0xc08f,	0x077f, 0xc08f,		0x21, 0
	.dw 0x07c0, 0xc08f,	0x07ff, 0xc08f,		0x21, 0
	.dw 0x0840, 0xc08f,	0x087f, 0xc08f,		0x21, 0
	.dw 0x08c0, 0xc08f,	0x08ff, 0xc08f,		0x21, 0
	.dw 0x0940, 0xc08f,	0x097f, 0xc08f,		0x21, 0
	.dw 0x09c0, 0xc08f,	0x09ff, 0xc08f,		0x21, 0
	.dw 0x0a40, 0xc08f,	0x0a7f, 0xc08f,		0x21, 0
	.dw 0x0ac0, 0xc08f,	0x0aff, 0xc08f,		0x21, 0
	.dw 0x0b40, 0xc08f,	0x0b7f, 0xc08f,		0x21, 0
	.dw 0x0bc0, 0xc08f,	0x0bff, 0xc08f,		0x21, 0
	.dw 0x0c40, 0xc08f,	0x0c7f, 0xc08f,		0x21, 0
	.dw 0x0cc0, 0xc08f,	0x0cff, 0xc08f,		0x21, 0
	.dw 0x0d40, 0xc08f,	0x0d7f, 0xc08f,		0x21, 0
	.dw 0x0dc0, 0xc08f,	0x0dff, 0xc08f,		0x21, 0
	.dw 0x0e40, 0xc08f,	0x0e7f, 0xc08f,		0x21, 0
	.dw 0x0ec0, 0xc08f,	0x0eff, 0xc08f,		0x21, 0
	.dw 0x0f40, 0xc08f,	0x0f7f, 0xc08f,		0x21, 0
	.dw 0x0fc0, 0xc08f,	0x0fff, 0xc08f,		0x21, 0
	.dw 0x1040, 0xc08f,	0x107f, 0xc08f,		0x21, 0
	.dw 0x10c0, 0xc08f,	0x10ff, 0xc08f,		0x21, 0
	.dw 0x1140, 0xc08f,	0x117f, 0xc08f,		0x21, 0
	.dw 0x11c0, 0xc08f,	0x11ff, 0xc08f,		0x21, 0
	.dw 0x1240, 0xc08f,	0x127f, 0xc08f,		0x21, 0
	.dw 0x12c0, 0xc08f,	0x12ff, 0xc08f,		0x21, 0
	.dw 0x1340, 0xc08f,	0x137f, 0xc08f,		0x21, 0
	.dw 0x13c0, 0xc08f,	0x13ff, 0xc08f,		0x21, 0
	.dw 0x1440, 0xc08f,	0x147f, 0xc08f,		0x21, 0
	.dw 0x14c0, 0xc08f,	0x14ff, 0xc08f,		0x21, 0
	.dw 0x1540, 0xc08f,	0x157f, 0xc08f,		0x21, 0
	.dw 0x15c0, 0xc08f,	0x15ff, 0xc08f,		0x21, 0
	.dw 0x1640, 0xc08f,	0x167f, 0xc08f,		0x21, 0
	.dw 0x16c0, 0xc08f,	0x16ff, 0xc08f,		0x21, 0
	.dw 0x1740, 0xc08f,	0x177f, 0xc08f,		0x21, 0
	.dw 0x17c0, 0xc08f,	0x17ff, 0xc08f,		0x21, 0
	.dw 0x1840, 0xc08f,	0x187f, 0xc08f,		0x21, 0
	.dw 0x18c0, 0xc08f,	0x18ff, 0xc08f,		0x21, 0
	.dw 0x1940, 0xc08f,	0x197f, 0xc08f,		0x21, 0
	.dw 0x19c0, 0xc08f,	0x1fff, 0xc08f,		0x21, 0
	.dw 0x2040, 0xc08f,	0x207f, 0xc08f,		0x21, 0
	.dw 0x20c0, 0xc08f,	0x20ff, 0xc08f,		0x21, 0
	.dw 0x2140, 0xc08f,	0x217f, 0xc08f,		0x21, 0
	.dw 0x21c0, 0xc08f,	0x21ff, 0xc08f,		0x21, 0
	.dw 0x2240, 0xc08f,	0x227f, 0xc08f,		0x21, 0
	.dw 0x22c0, 0xc08f,	0x22ff, 0xc08f,		0x21, 0
	.dw 0x2340, 0xc08f,	0x237f, 0xc08f,		0x21, 0
	.dw 0x23c0, 0xc08f,	0x23ff, 0xc08f,		0x21, 0
	.dw 0x2440, 0xc08f,	0x247f, 0xc08f,		0x21, 0
	.dw 0x24c0, 0xc08f,	0x24ff, 0xc08f,		0x21, 0
	.dw 0x2540, 0xc08f,	0x257f, 0xc08f,		0x21, 0
	.dw 0x25c0, 0xc08f,	0x25ff, 0xc08f,		0x21, 0
	.dw 0x2640, 0xc08f,	0x267f, 0xc08f,		0x21, 0
	.dw 0x26c0, 0xc08f,	0x26ff, 0xc08f,		0x21, 0
	.dw 0x2740, 0xc08f,	0x277f, 0xc08f,		0x21, 0
	.dw 0x27c0, 0xc08f,	0x27ff, 0xc08f,		0x21, 0
	.dw 0x2840, 0xc08f,	0x287f, 0xc08f,		0x21, 0
	.dw 0x28c0, 0xc08f,	0x28ff, 0xc08f,		0x21, 0
	.dw 0x2940, 0xc08f,	0x297f, 0xc08f,		0x21, 0
	.dw 0x29c0, 0xc08f,	0x29ff, 0xc08f,		0x21, 0
	.dw 0x2a40, 0xc08f,	0x2a7f, 0xc08f,		0x21, 0
	.dw 0x2ac0, 0xc08f,	0x2aff, 0xc08f,		0x21, 0
	.dw 0x2b40, 0xc08f,	0x2b7f, 0xc08f,		0x21, 0
	.dw 0x2bc0, 0xc08f,	0x2bff, 0xc08f,		0x21, 0
	.dw 0x2c40, 0xc08f,	0x2c7f, 0xc08f,		0x21, 0
	.dw 0x2cc0, 0xc08f,	0x2cff, 0xc08f,		0x21, 0
	.dw 0x2d40, 0xc08f,	0x2d7f, 0xc08f,		0x21, 0
	.dw 0x2dc0, 0xc08f,	0x2dff, 0xc08f,		0x21, 0
	.dw 0x2e40, 0xc08f,	0x2e7f, 0xc08f,		0x21, 0
	.dw 0x2ec0, 0xc08f,	0x2eff, 0xc08f,		0x21, 0
	.dw 0x2f40, 0xc08f,	0x2f7f, 0xc08f,		0x21, 0
	.dw 0x2fc0, 0xc08f,	0x2fff, 0xc08f,		0x21, 0
	.dw 0x3040, 0xc08f,	0x307f, 0xc08f,		0x21, 0
	.dw 0x30c0, 0xc08f,	0x30ff, 0xc08f,		0x21, 0
	.dw 0x3140, 0xc08f,	0x317f, 0xc08f,		0x21, 0
	.dw 0x31c0, 0xc08f,	0x31ff, 0xc08f,		0x21, 0
	.dw 0x3240, 0xc08f,	0x327f, 0xc08f,		0x21, 0
	.dw 0x32c0, 0xc08f,	0x32ff, 0xc08f,		0x21, 0
	.dw 0x3340, 0xc08f,	0x337f, 0xc08f,		0x21, 0
	.dw 0x33c0, 0xc08f,	0x33ff, 0xc08f,		0x21, 0
	.dw 0x3440, 0xc08f,	0x347f, 0xc08f,		0x21, 0
	.dw 0x34c0, 0xc08f,	0x34ff, 0xc08f,		0x21, 0
	.dw 0x3540, 0xc08f,	0x357f, 0xc08f,		0x21, 0
	.dw 0x35c0, 0xc08f,	0x35ff, 0xc08f,		0x21, 0
	.dw 0x3640, 0xc08f,	0x367f, 0xc08f,		0x21, 0
	.dw 0x36c0, 0xc08f,	0x36ff, 0xc08f,		0x21, 0
	.dw 0x3740, 0xc08f,	0x377f, 0xc08f,		0x21, 0
	.dw 0x37c0, 0xc08f,	0x37ff, 0xc08f,		0x21, 0
	.dw 0x3840, 0xc08f,	0x387f, 0xc08f,		0x21, 0
	.dw 0x38c0, 0xc08f,	0x38ff, 0xc08f,		0x21, 0
	.dw 0x3940, 0xc08f,	0x397f, 0xc08f,		0x21, 0
	.dw 0x39c0, 0xc08f,	0xffff, 0xc08f,		0x21, 0
	.dw 0x1a00, 0xc090,	0x1fff, 0xc090,		0x21, 0
	.dw 0x3a00, 0xc090,	0x3fff, 0xc090,		0x21, 0
	.dw 0x5a00, 0xc090,	0x5fff, 0xc090,		0x21, 0
	.dw 0x7a00, 0xc090,	0x7fff, 0xc090,		0x21, 0
	.dw 0x9a00, 0xc090,	0x9fff, 0xc090,		0x21, 0
	.dw 0xba00, 0xc090,	0xbfff, 0xc090,		0x21, 0
	.dw 0xda00, 0xc090,	0xdfff, 0xc090,		0x21, 0
	.dw 0xfa00, 0xc090,	0xffff, 0xc090,		0x21, 0
	.dw 0x1a00, 0xc091,	0x1fff, 0xc091,		0x21, 0
	.dw 0x3a00, 0xc091,	0x3fff, 0xc091,		0x21, 0
	.dw 0x5a00, 0xc091,	0x5fff, 0xc091,		0x21, 0
	.dw 0x7a00, 0xc091,	0x7fff, 0xc091,		0x21, 0
	.dw 0x9a00, 0xc091,	0x9fff, 0xc091,		0x21, 0
	.dw 0xba00, 0xc091,	0xbfff, 0xc091,		0x21, 0
	.dw 0xda00, 0xc091,	0xdfff, 0xc091,		0x21, 0
	.dw 0xfa00, 0xc091,	0xffff, 0xc091,		0x21, 0
	.dw 0x1a00, 0xc092,	0x1fff, 0xc092,		0x21, 0
	.dw 0x3a00, 0xc092,	0x3fff, 0xc092,		0x21, 0
	.dw 0x5a00, 0xc092,	0x5fff, 0xc092,		0x21, 0
	.dw 0x7a00, 0xc092,	0x7fff, 0xc092,		0x21, 0
	.dw 0x9a00, 0xc092,	0x9fff, 0xc092,		0x21, 0
	.dw 0xba00, 0xc092,	0xbfff, 0xc092,		0x21, 0
	.dw 0xda00, 0xc092,	0xdfff, 0xc092,		0x21, 0
	.dw 0xfa00, 0xc092,	0xffff, 0xc093,		0x21, 0
	.dw 0x1a00, 0xc094,	0x1fff, 0xc094,		0x21, 0
	.dw 0x3a00, 0xc094,	0x3fff, 0xc094,		0x21, 0
	.dw 0x5a00, 0xc094,	0x5fff, 0xc094,		0x21, 0
	.dw 0x7a00, 0xc094,	0x7fff, 0xc094,		0x21, 0
	.dw 0x9a00, 0xc094,	0x9fff, 0xc094,		0x21, 0
	.dw 0xba00, 0xc094,	0xbfff, 0xc094,		0x21, 0
	.dw 0xda00, 0xc094,	0xdfff, 0xc094,		0x21, 0
	.dw 0xfa00, 0xc094,	0xffff, 0xc094,		0x21, 0
	.dw 0x1a00, 0xc095,	0x1fff, 0xc095,		0x21, 0
	.dw 0x3a00, 0xc095,	0x3fff, 0xc095,		0x21, 0
	.dw 0x5a00, 0xc095,	0x5fff, 0xc095,		0x21, 0
	.dw 0x7a00, 0xc095,	0x7fff, 0xc095,		0x21, 0
	.dw 0x9a00, 0xc095,	0x9fff, 0xc095,		0x21, 0
	.dw 0xba00, 0xc095,	0xbfff, 0xc095,		0x21, 0
	.dw 0xda00, 0xc095,	0xdfff, 0xc095,		0x21, 0
	.dw 0xfa00, 0xc095,	0xffff, 0xc095,		0x21, 0
	.dw 0x1a00, 0xc096,	0x1fff, 0xc096,		0x21, 0
	.dw 0x3a00, 0xc096,	0x3fff, 0xc096,		0x21, 0
	.dw 0x5a00, 0xc096,	0x5fff, 0xc096,		0x21, 0
	.dw 0x7a00, 0xc096,	0x7fff, 0xc096,		0x21, 0
	.dw 0x9a00, 0xc096,	0x9fff, 0xc096,		0x21, 0
	.dw 0xba00, 0xc096,	0xbfff, 0xc096,		0x21, 0
	.dw 0xda00, 0xc096,	0xdfff, 0xc096,		0x21, 0
	.dw 0xfa00, 0xc096,	0xffff, 0xc096,		0x21, 0
	.dw 0x1a00, 0xc097,	0x1fff, 0xc097,		0x21, 0
	.dw 0x3a00, 0xc097,	0x1fff, 0xc098,		0x21, 0
	.dw 0x2040, 0xc098,	0x207f, 0xc098,		0x21, 0
	.dw 0x20c0, 0xc098,	0x20ff, 0xc098,		0x21, 0
	.dw 0x2140, 0xc098,	0x217f, 0xc098,		0x21, 0
	.dw 0x21c0, 0xc098,	0x21ff, 0xc098,		0x21, 0
	.dw 0x2240, 0xc098,	0x227f, 0xc098,		0x21, 0
	.dw 0x22c0, 0xc098,	0x22ff, 0xc098,		0x21, 0
	.dw 0x2340, 0xc098,	0x237f, 0xc098,		0x21, 0
	.dw 0x23c0, 0xc098,	0x23ff, 0xc098,		0x21, 0
	.dw 0x2440, 0xc098,	0x247f, 0xc098,		0x21, 0
	.dw 0x24c0, 0xc098,	0x24ff, 0xc098,		0x21, 0
	.dw 0x2540, 0xc098,	0x257f, 0xc098,		0x21, 0
	.dw 0x25c0, 0xc098,	0x25ff, 0xc098,		0x21, 0
	.dw 0x2640, 0xc098,	0x267f, 0xc098,		0x21, 0
	.dw 0x26c0, 0xc098,	0x26ff, 0xc098,		0x21, 0
	.dw 0x2740, 0xc098,	0x277f, 0xc098,		0x21, 0
	.dw 0x27c0, 0xc098,	0x27ff, 0xc098,		0x21, 0
	.dw 0x2840, 0xc098,	0x287f, 0xc098,		0x21, 0
	.dw 0x28c0, 0xc098,	0x28ff, 0xc098,		0x21, 0
	.dw 0x2940, 0xc098,	0x297f, 0xc098,		0x21, 0
	.dw 0x29c0, 0xc098,	0x29ff, 0xc098,		0x21, 0
	.dw 0x2a40, 0xc098,	0x2a7f, 0xc098,		0x21, 0
	.dw 0x2ac0, 0xc098,	0x2aff, 0xc098,		0x21, 0
	.dw 0x2b40, 0xc098,	0x2b7f, 0xc098,		0x21, 0
	.dw 0x2bc0, 0xc098,	0x2bff, 0xc098,		0x21, 0
	.dw 0x2c40, 0xc098,	0x2c7f, 0xc098,		0x21, 0
	.dw 0x2cc0, 0xc098,	0x2cff, 0xc098,		0x21, 0
	.dw 0x2d40, 0xc098,	0x2d7f, 0xc098,		0x21, 0
	.dw 0x2dc0, 0xc098,	0x2dff, 0xc098,		0x21, 0
	.dw 0x2e40, 0xc098,	0x2e7f, 0xc098,		0x21, 0
	.dw 0x2ec0, 0xc098,	0x2eff, 0xc098,		0x21, 0
	.dw 0x2f40, 0xc098,	0x2f7f, 0xc098,		0x21, 0
	.dw 0x2fc0, 0xc098,	0x2fff, 0xc098,		0x21, 0
	.dw 0x3040, 0xc098,	0x307f, 0xc098,		0x21, 0
	.dw 0x30c0, 0xc098,	0x30ff, 0xc098,		0x21, 0
	.dw 0x3140, 0xc098,	0x317f, 0xc098,		0x21, 0
	.dw 0x31c0, 0xc098,	0x31ff, 0xc098,		0x21, 0
	.dw 0x3240, 0xc098,	0x327f, 0xc098,		0x21, 0
	.dw 0x32c0, 0xc098,	0x32ff, 0xc098,		0x21, 0
	.dw 0x3340, 0xc098,	0x337f, 0xc098,		0x21, 0
	.dw 0x33c0, 0xc098,	0x33ff, 0xc098,		0x21, 0
	.dw 0x3440, 0xc098,	0x347f, 0xc098,		0x21, 0
	.dw 0x34c0, 0xc098,	0x34ff, 0xc098,		0x21, 0
	.dw 0x3540, 0xc098,	0x357f, 0xc098,		0x21, 0
	.dw 0x35c0, 0xc098,	0x35ff, 0xc098,		0x21, 0
	.dw 0x3640, 0xc098,	0x367f, 0xc098,		0x21, 0
	.dw 0x36c0, 0xc098,	0x36ff, 0xc098,		0x21, 0
	.dw 0x3740, 0xc098,	0x377f, 0xc098,		0x21, 0
	.dw 0x37c0, 0xc098,	0x37ff, 0xc098,		0x21, 0
	.dw 0x3840, 0xc098,	0x387f, 0xc098,		0x21, 0
	.dw 0x38c0, 0xc098,	0x38ff, 0xc098,		0x21, 0
	.dw 0x3940, 0xc098,	0x397f, 0xc098,		0x21, 0
	.dw 0x39c0, 0xc098,	0x5fff, 0xc098,		0x21, 0
	.dw 0x6040, 0xc098,	0x607f, 0xc098,		0x21, 0
	.dw 0x60c0, 0xc098,	0x60ff, 0xc098,		0x21, 0
	.dw 0x6140, 0xc098,	0x617f, 0xc098,		0x21, 0
	.dw 0x61c0, 0xc098,	0x61ff, 0xc098,		0x21, 0
	.dw 0x6240, 0xc098,	0x627f, 0xc098,		0x21, 0
	.dw 0x62c0, 0xc098,	0x62ff, 0xc098,		0x21, 0
	.dw 0x6340, 0xc098,	0x637f, 0xc098,		0x21, 0
	.dw 0x63c0, 0xc098,	0x63ff, 0xc098,		0x21, 0
	.dw 0x6440, 0xc098,	0x647f, 0xc098,		0x21, 0
	.dw 0x64c0, 0xc098,	0x64ff, 0xc098,		0x21, 0
	.dw 0x6540, 0xc098,	0x657f, 0xc098,		0x21, 0
	.dw 0x65c0, 0xc098,	0x65ff, 0xc098,		0x21, 0
	.dw 0x6640, 0xc098,	0x667f, 0xc098,		0x21, 0
	.dw 0x66c0, 0xc098,	0x66ff, 0xc098,		0x21, 0
	.dw 0x6740, 0xc098,	0x677f, 0xc098,		0x21, 0
	.dw 0x67c0, 0xc098,	0x67ff, 0xc098,		0x21, 0
	.dw 0x6840, 0xc098,	0x687f, 0xc098,		0x21, 0
	.dw 0x68c0, 0xc098,	0x68ff, 0xc098,		0x21, 0
	.dw 0x6940, 0xc098,	0x697f, 0xc098,		0x21, 0
	.dw 0x69c0, 0xc098,	0x69ff, 0xc098,		0x21, 0
	.dw 0x6a40, 0xc098,	0x6a7f, 0xc098,		0x21, 0
	.dw 0x6ac0, 0xc098,	0x6aff, 0xc098,		0x21, 0
	.dw 0x6b40, 0xc098,	0x6b7f, 0xc098,		0x21, 0
	.dw 0x6bc0, 0xc098,	0x6bff, 0xc098,		0x21, 0
	.dw 0x6c40, 0xc098,	0x6c7f, 0xc098,		0x21, 0
	.dw 0x6cc0, 0xc098,	0x6cff, 0xc098,		0x21, 0
	.dw 0x6d40, 0xc098,	0x6d7f, 0xc098,		0x21, 0
	.dw 0x6dc0, 0xc098,	0x6dff, 0xc098,		0x21, 0
	.dw 0x6e40, 0xc098,	0x6e7f, 0xc098,		0x21, 0
	.dw 0x6ec0, 0xc098,	0x6eff, 0xc098,		0x21, 0
	.dw 0x6f40, 0xc098,	0x6f7f, 0xc098,		0x21, 0
	.dw 0x6fc0, 0xc098,	0x6fff, 0xc098,		0x21, 0
	.dw 0x7040, 0xc098,	0x707f, 0xc098,		0x21, 0
	.dw 0x70c0, 0xc098,	0x70ff, 0xc098,		0x21, 0
	.dw 0x7140, 0xc098,	0x717f, 0xc098,		0x21, 0
	.dw 0x71c0, 0xc098,	0x71ff, 0xc098,		0x21, 0
	.dw 0x7240, 0xc098,	0x727f, 0xc098,		0x21, 0
	.dw 0x72c0, 0xc098,	0x72ff, 0xc098,		0x21, 0
	.dw 0x7340, 0xc098,	0x737f, 0xc098,		0x21, 0
	.dw 0x73c0, 0xc098,	0x73ff, 0xc098,		0x21, 0
	.dw 0x7440, 0xc098,	0x747f, 0xc098,		0x21, 0
	.dw 0x74c0, 0xc098,	0x74ff, 0xc098,		0x21, 0
	.dw 0x7540, 0xc098,	0x757f, 0xc098,		0x21, 0
	.dw 0x75c0, 0xc098,	0x75ff, 0xc098,		0x21, 0
	.dw 0x7640, 0xc098,	0x767f, 0xc098,		0x21, 0
	.dw 0x76c0, 0xc098,	0x76ff, 0xc098,		0x21, 0
	.dw 0x7740, 0xc098,	0x777f, 0xc098,		0x21, 0
	.dw 0x77c0, 0xc098,	0x77ff, 0xc098,		0x21, 0
	.dw 0x7840, 0xc098,	0x787f, 0xc098,		0x21, 0
	.dw 0x78c0, 0xc098,	0x78ff, 0xc098,		0x21, 0
	.dw 0x7940, 0xc098,	0x797f, 0xc098,		0x21, 0
	.dw 0x79c0, 0xc098,	0x9fff, 0xc098,		0x21, 0
	.dw 0xa040, 0xc098,	0xa07f, 0xc098,		0x21, 0
	.dw 0xa0c0, 0xc098,	0xa0ff, 0xc098,		0x21, 0
	.dw 0xa140, 0xc098,	0xa17f, 0xc098,		0x21, 0
	.dw 0xa1c0, 0xc098,	0xa1ff, 0xc098,		0x21, 0
	.dw 0xa240, 0xc098,	0xa27f, 0xc098,		0x21, 0
	.dw 0xa2c0, 0xc098,	0xa2ff, 0xc098,		0x21, 0
	.dw 0xa340, 0xc098,	0xa37f, 0xc098,		0x21, 0
	.dw 0xa3c0, 0xc098,	0xa3ff, 0xc098,		0x21, 0
	.dw 0xa440, 0xc098,	0xa47f, 0xc098,		0x21, 0
	.dw 0xa4c0, 0xc098,	0xa4ff, 0xc098,		0x21, 0
	.dw 0xa540, 0xc098,	0xa57f, 0xc098,		0x21, 0
	.dw 0xa5c0, 0xc098,	0xa5ff, 0xc098,		0x21, 0
	.dw 0xa640, 0xc098,	0xa67f, 0xc098,		0x21, 0
	.dw 0xa6c0, 0xc098,	0xa6ff, 0xc098,		0x21, 0
	.dw 0xa740, 0xc098,	0xa77f, 0xc098,		0x21, 0
	.dw 0xa7c0, 0xc098,	0xa7ff, 0xc098,		0x21, 0
	.dw 0xa840, 0xc098,	0xa87f, 0xc098,		0x21, 0
	.dw 0xa8c0, 0xc098,	0xa8ff, 0xc098,		0x21, 0
	.dw 0xa940, 0xc098,	0xa97f, 0xc098,		0x21, 0
	.dw 0xa9c0, 0xc098,	0xa9ff, 0xc098,		0x21, 0
	.dw 0xaa40, 0xc098,	0xaa7f, 0xc098,		0x21, 0
	.dw 0xaac0, 0xc098,	0xaaff, 0xc098,		0x21, 0
	.dw 0xab40, 0xc098,	0xab7f, 0xc098,		0x21, 0
	.dw 0xabc0, 0xc098,	0xabff, 0xc098,		0x21, 0
	.dw 0xac40, 0xc098,	0xac7f, 0xc098,		0x21, 0
	.dw 0xacc0, 0xc098,	0xacff, 0xc098,		0x21, 0
	.dw 0xad40, 0xc098,	0xad7f, 0xc098,		0x21, 0
	.dw 0xadc0, 0xc098,	0xadff, 0xc098,		0x21, 0
	.dw 0xae40, 0xc098,	0xae7f, 0xc098,		0x21, 0
	.dw 0xaec0, 0xc098,	0xaeff, 0xc098,		0x21, 0
	.dw 0xaf40, 0xc098,	0xaf7f, 0xc098,		0x21, 0
	.dw 0xafc0, 0xc098,	0xafff, 0xc098,		0x21, 0
	.dw 0xb040, 0xc098,	0xb07f, 0xc098,		0x21, 0
	.dw 0xb0c0, 0xc098,	0xb0ff, 0xc098,		0x21, 0
	.dw 0xb140, 0xc098,	0xb17f, 0xc098,		0x21, 0
	.dw 0xb1c0, 0xc098,	0xb1ff, 0xc098,		0x21, 0
	.dw 0xb240, 0xc098,	0xb27f, 0xc098,		0x21, 0
	.dw 0xb2c0, 0xc098,	0xb2ff, 0xc098,		0x21, 0
	.dw 0xb340, 0xc098,	0xb37f, 0xc098,		0x21, 0
	.dw 0xb3c0, 0xc098,	0xb3ff, 0xc098,		0x21, 0
	.dw 0xb440, 0xc098,	0xb47f, 0xc098,		0x21, 0
	.dw 0xb4c0, 0xc098,	0xb4ff, 0xc098,		0x21, 0
	.dw 0xb540, 0xc098,	0xb57f, 0xc098,		0x21, 0
	.dw 0xb5c0, 0xc098,	0xb5ff, 0xc098,		0x21, 0
	.dw 0xb640, 0xc098,	0xb67f, 0xc098,		0x21, 0
	.dw 0xb6c0, 0xc098,	0xb6ff, 0xc098,		0x21, 0
	.dw 0xb740, 0xc098,	0xb77f, 0xc098,		0x21, 0
	.dw 0xb7c0, 0xc098,	0xb7ff, 0xc098,		0x21, 0
	.dw 0xb840, 0xc098,	0xb87f, 0xc098,		0x21, 0
	.dw 0xb8c0, 0xc098,	0xb8ff, 0xc098,		0x21, 0
	.dw 0xb940, 0xc098,	0xb97f, 0xc098,		0x21, 0
	.dw 0xb9c0, 0xc098,	0xdfff, 0xc098,		0x21, 0
	.dw 0xe040, 0xc098,	0xe07f, 0xc098,		0x21, 0
	.dw 0xe0c0, 0xc098,	0xe0ff, 0xc098,		0x21, 0
	.dw 0xe140, 0xc098,	0xe17f, 0xc098,		0x21, 0
	.dw 0xe1c0, 0xc098,	0xe1ff, 0xc098,		0x21, 0
	.dw 0xe240, 0xc098,	0xe27f, 0xc098,		0x21, 0
	.dw 0xe2c0, 0xc098,	0xe2ff, 0xc098,		0x21, 0
	.dw 0xe340, 0xc098,	0xe37f, 0xc098,		0x21, 0
	.dw 0xe3c0, 0xc098,	0xe3ff, 0xc098,		0x21, 0
	.dw 0xe440, 0xc098,	0xe47f, 0xc098,		0x21, 0
	.dw 0xe4c0, 0xc098,	0xe4ff, 0xc098,		0x21, 0
	.dw 0xe540, 0xc098,	0xe57f, 0xc098,		0x21, 0
	.dw 0xe5c0, 0xc098,	0xe5ff, 0xc098,		0x21, 0
	.dw 0xe640, 0xc098,	0xe67f, 0xc098,		0x21, 0
	.dw 0xe6c0, 0xc098,	0xe6ff, 0xc098,		0x21, 0
	.dw 0xe740, 0xc098,	0xe77f, 0xc098,		0x21, 0
	.dw 0xe7c0, 0xc098,	0xe7ff, 0xc098,		0x21, 0
	.dw 0xe840, 0xc098,	0xe87f, 0xc098,		0x21, 0
	.dw 0xe8c0, 0xc098,	0xe8ff, 0xc098,		0x21, 0
	.dw 0xe940, 0xc098,	0xe97f, 0xc098,		0x21, 0
	.dw 0xe9c0, 0xc098,	0xe9ff, 0xc098,		0x21, 0
	.dw 0xea40, 0xc098,	0xea7f, 0xc098,		0x21, 0
	.dw 0xeac0, 0xc098,	0xeaff, 0xc098,		0x21, 0
	.dw 0xeb40, 0xc098,	0xeb7f, 0xc098,		0x21, 0
	.dw 0xebc0, 0xc098,	0xebff, 0xc098,		0x21, 0
	.dw 0xec40, 0xc098,	0xec7f, 0xc098,		0x21, 0
	.dw 0xecc0, 0xc098,	0xecff, 0xc098,		0x21, 0
	.dw 0xed40, 0xc098,	0xed7f, 0xc098,		0x21, 0
	.dw 0xedc0, 0xc098,	0xedff, 0xc098,		0x21, 0
	.dw 0xee40, 0xc098,	0xee7f, 0xc098,		0x21, 0
	.dw 0xeec0, 0xc098,	0xeeff, 0xc098,		0x21, 0
	.dw 0xef40, 0xc098,	0xef7f, 0xc098,		0x21, 0
	.dw 0xefc0, 0xc098,	0xefff, 0xc098,		0x21, 0
	.dw 0xf040, 0xc098,	0xf07f, 0xc098,		0x21, 0
	.dw 0xf0c0, 0xc098,	0xf0ff, 0xc098,		0x21, 0
	.dw 0xf140, 0xc098,	0xf17f, 0xc098,		0x21, 0
	.dw 0xf1c0, 0xc098,	0xf1ff, 0xc098,		0x21, 0
	.dw 0xf240, 0xc098,	0xf27f, 0xc098,		0x21, 0
	.dw 0xf2c0, 0xc098,	0xf2ff, 0xc098,		0x21, 0
	.dw 0xf340, 0xc098,	0xf37f, 0xc098,		0x21, 0
	.dw 0xf3c0, 0xc098,	0xf3ff, 0xc098,		0x21, 0
	.dw 0xf440, 0xc098,	0xf47f, 0xc098,		0x21, 0
	.dw 0xf4c0, 0xc098,	0xf4ff, 0xc098,		0x21, 0
	.dw 0xf540, 0xc098,	0xf57f, 0xc098,		0x21, 0
	.dw 0xf5c0, 0xc098,	0xf5ff, 0xc098,		0x21, 0
	.dw 0xf640, 0xc098,	0xf67f, 0xc098,		0x21, 0
	.dw 0xf6c0, 0xc098,	0xf6ff, 0xc098,		0x21, 0
	.dw 0xf740, 0xc098,	0xf77f, 0xc098,		0x21, 0
	.dw 0xf7c0, 0xc098,	0xf7ff, 0xc098,		0x21, 0
	.dw 0xf840, 0xc098,	0xf87f, 0xc098,		0x21, 0
	.dw 0xf8c0, 0xc098,	0xf8ff, 0xc098,		0x21, 0
	.dw 0xf940, 0xc098,	0xf97f, 0xc098,		0x21, 0
	.dw 0xf9c0, 0xc098,	0x1fff, 0xc099,		0x21, 0
	.dw 0x2040, 0xc099,	0x207f, 0xc099,		0x21, 0
	.dw 0x20c0, 0xc099,	0x20ff, 0xc099,		0x21, 0
	.dw 0x2140, 0xc099,	0x217f, 0xc099,		0x21, 0
	.dw 0x21c0, 0xc099,	0x21ff, 0xc099,		0x21, 0
	.dw 0x2240, 0xc099,	0x227f, 0xc099,		0x21, 0
	.dw 0x22c0, 0xc099,	0x22ff, 0xc099,		0x21, 0
	.dw 0x2340, 0xc099,	0x237f, 0xc099,		0x21, 0
	.dw 0x23c0, 0xc099,	0x23ff, 0xc099,		0x21, 0
	.dw 0x2440, 0xc099,	0x247f, 0xc099,		0x21, 0
	.dw 0x24c0, 0xc099,	0x24ff, 0xc099,		0x21, 0
	.dw 0x2540, 0xc099,	0x257f, 0xc099,		0x21, 0
	.dw 0x25c0, 0xc099,	0x25ff, 0xc099,		0x21, 0
	.dw 0x2640, 0xc099,	0x267f, 0xc099,		0x21, 0
	.dw 0x26c0, 0xc099,	0x26ff, 0xc099,		0x21, 0
	.dw 0x2740, 0xc099,	0x277f, 0xc099,		0x21, 0
	.dw 0x27c0, 0xc099,	0x27ff, 0xc099,		0x21, 0
	.dw 0x2840, 0xc099,	0x287f, 0xc099,		0x21, 0
	.dw 0x28c0, 0xc099,	0x28ff, 0xc099,		0x21, 0
	.dw 0x2940, 0xc099,	0x297f, 0xc099,		0x21, 0
	.dw 0x29c0, 0xc099,	0x29ff, 0xc099,		0x21, 0
	.dw 0x2a40, 0xc099,	0x2a7f, 0xc099,		0x21, 0
	.dw 0x2ac0, 0xc099,	0x2aff, 0xc099,		0x21, 0
	.dw 0x2b40, 0xc099,	0x2b7f, 0xc099,		0x21, 0
	.dw 0x2bc0, 0xc099,	0x2bff, 0xc099,		0x21, 0
	.dw 0x2c40, 0xc099,	0x2c7f, 0xc099,		0x21, 0
	.dw 0x2cc0, 0xc099,	0x2cff, 0xc099,		0x21, 0
	.dw 0x2d40, 0xc099,	0x2d7f, 0xc099,		0x21, 0
	.dw 0x2dc0, 0xc099,	0x2dff, 0xc099,		0x21, 0
	.dw 0x2e40, 0xc099,	0x2e7f, 0xc099,		0x21, 0
	.dw 0x2ec0, 0xc099,	0x2eff, 0xc099,		0x21, 0
	.dw 0x2f40, 0xc099,	0x2f7f, 0xc099,		0x21, 0
	.dw 0x2fc0, 0xc099,	0x2fff, 0xc099,		0x21, 0
	.dw 0x3040, 0xc099,	0x307f, 0xc099,		0x21, 0
	.dw 0x30c0, 0xc099,	0x30ff, 0xc099,		0x21, 0
	.dw 0x3140, 0xc099,	0x317f, 0xc099,		0x21, 0
	.dw 0x31c0, 0xc099,	0x31ff, 0xc099,		0x21, 0
	.dw 0x3240, 0xc099,	0x327f, 0xc099,		0x21, 0
	.dw 0x32c0, 0xc099,	0x32ff, 0xc099,		0x21, 0
	.dw 0x3340, 0xc099,	0x337f, 0xc099,		0x21, 0
	.dw 0x33c0, 0xc099,	0x33ff, 0xc099,		0x21, 0
	.dw 0x3440, 0xc099,	0x347f, 0xc099,		0x21, 0
	.dw 0x34c0, 0xc099,	0x34ff, 0xc099,		0x21, 0
	.dw 0x3540, 0xc099,	0x357f, 0xc099,		0x21, 0
	.dw 0x35c0, 0xc099,	0x35ff, 0xc099,		0x21, 0
	.dw 0x3640, 0xc099,	0x367f, 0xc099,		0x21, 0
	.dw 0x36c0, 0xc099,	0x36ff, 0xc099,		0x21, 0
	.dw 0x3740, 0xc099,	0x377f, 0xc099,		0x21, 0
	.dw 0x37c0, 0xc099,	0x37ff, 0xc099,		0x21, 0
	.dw 0x3840, 0xc099,	0x387f, 0xc099,		0x21, 0
	.dw 0x38c0, 0xc099,	0x38ff, 0xc099,		0x21, 0
	.dw 0x3940, 0xc099,	0x397f, 0xc099,		0x21, 0
	.dw 0x39c0, 0xc099,	0x5fff, 0xc099,		0x21, 0
	.dw 0x6040, 0xc099,	0x607f, 0xc099,		0x21, 0
	.dw 0x60c0, 0xc099,	0x60ff, 0xc099,		0x21, 0
	.dw 0x6140, 0xc099,	0x617f, 0xc099,		0x21, 0
	.dw 0x61c0, 0xc099,	0x61ff, 0xc099,		0x21, 0
	.dw 0x6240, 0xc099,	0x627f, 0xc099,		0x21, 0
	.dw 0x62c0, 0xc099,	0x62ff, 0xc099,		0x21, 0
	.dw 0x6340, 0xc099,	0x637f, 0xc099,		0x21, 0
	.dw 0x63c0, 0xc099,	0x63ff, 0xc099,		0x21, 0
	.dw 0x6440, 0xc099,	0x647f, 0xc099,		0x21, 0
	.dw 0x64c0, 0xc099,	0x64ff, 0xc099,		0x21, 0
	.dw 0x6540, 0xc099,	0x657f, 0xc099,		0x21, 0
	.dw 0x65c0, 0xc099,	0x65ff, 0xc099,		0x21, 0
	.dw 0x6640, 0xc099,	0x667f, 0xc099,		0x21, 0
	.dw 0x66c0, 0xc099,	0x66ff, 0xc099,		0x21, 0
	.dw 0x6740, 0xc099,	0x677f, 0xc099,		0x21, 0
	.dw 0x67c0, 0xc099,	0x67ff, 0xc099,		0x21, 0
	.dw 0x6840, 0xc099,	0x687f, 0xc099,		0x21, 0
	.dw 0x68c0, 0xc099,	0x68ff, 0xc099,		0x21, 0
	.dw 0x6940, 0xc099,	0x697f, 0xc099,		0x21, 0
	.dw 0x69c0, 0xc099,	0x69ff, 0xc099,		0x21, 0
	.dw 0x6a40, 0xc099,	0x6a7f, 0xc099,		0x21, 0
	.dw 0x6ac0, 0xc099,	0x6aff, 0xc099,		0x21, 0
	.dw 0x6b40, 0xc099,	0x6b7f, 0xc099,		0x21, 0
	.dw 0x6bc0, 0xc099,	0x6bff, 0xc099,		0x21, 0
	.dw 0x6c40, 0xc099,	0x6c7f, 0xc099,		0x21, 0
	.dw 0x6cc0, 0xc099,	0x6cff, 0xc099,		0x21, 0
	.dw 0x6d40, 0xc099,	0x6d7f, 0xc099,		0x21, 0
	.dw 0x6dc0, 0xc099,	0x6dff, 0xc099,		0x21, 0
	.dw 0x6e40, 0xc099,	0x6e7f, 0xc099,		0x21, 0
	.dw 0x6ec0, 0xc099,	0x6eff, 0xc099,		0x21, 0
	.dw 0x6f40, 0xc099,	0x6f7f, 0xc099,		0x21, 0
	.dw 0x6fc0, 0xc099,	0x6fff, 0xc099,		0x21, 0
	.dw 0x7040, 0xc099,	0x707f, 0xc099,		0x21, 0
	.dw 0x70c0, 0xc099,	0x70ff, 0xc099,		0x21, 0
	.dw 0x7140, 0xc099,	0x717f, 0xc099,		0x21, 0
	.dw 0x71c0, 0xc099,	0x71ff, 0xc099,		0x21, 0
	.dw 0x7240, 0xc099,	0x727f, 0xc099,		0x21, 0
	.dw 0x72c0, 0xc099,	0x72ff, 0xc099,		0x21, 0
	.dw 0x7340, 0xc099,	0x737f, 0xc099,		0x21, 0
	.dw 0x73c0, 0xc099,	0x73ff, 0xc099,		0x21, 0
	.dw 0x7440, 0xc099,	0x747f, 0xc099,		0x21, 0
	.dw 0x74c0, 0xc099,	0x74ff, 0xc099,		0x21, 0
	.dw 0x7540, 0xc099,	0x757f, 0xc099,		0x21, 0
	.dw 0x75c0, 0xc099,	0x75ff, 0xc099,		0x21, 0
	.dw 0x7640, 0xc099,	0x767f, 0xc099,		0x21, 0
	.dw 0x76c0, 0xc099,	0x76ff, 0xc099,		0x21, 0
	.dw 0x7740, 0xc099,	0x777f, 0xc099,		0x21, 0
	.dw 0x77c0, 0xc099,	0x77ff, 0xc099,		0x21, 0
	.dw 0x7840, 0xc099,	0x787f, 0xc099,		0x21, 0
	.dw 0x78c0, 0xc099,	0x78ff, 0xc099,		0x21, 0
	.dw 0x7940, 0xc099,	0x797f, 0xc099,		0x21, 0
	.dw 0x79c0, 0xc099,	0x9fff, 0xc099,		0x21, 0
	.dw 0xa040, 0xc099,	0xa07f, 0xc099,		0x21, 0
	.dw 0xa0c0, 0xc099,	0xa0ff, 0xc099,		0x21, 0
	.dw 0xa140, 0xc099,	0xa17f, 0xc099,		0x21, 0
	.dw 0xa1c0, 0xc099,	0xa1ff, 0xc099,		0x21, 0
	.dw 0xa240, 0xc099,	0xa27f, 0xc099,		0x21, 0
	.dw 0xa2c0, 0xc099,	0xa2ff, 0xc099,		0x21, 0
	.dw 0xa340, 0xc099,	0xa37f, 0xc099,		0x21, 0
	.dw 0xa3c0, 0xc099,	0xa3ff, 0xc099,		0x21, 0
	.dw 0xa440, 0xc099,	0xa47f, 0xc099,		0x21, 0
	.dw 0xa4c0, 0xc099,	0xa4ff, 0xc099,		0x21, 0
	.dw 0xa540, 0xc099,	0xa57f, 0xc099,		0x21, 0
	.dw 0xa5c0, 0xc099,	0xa5ff, 0xc099,		0x21, 0
	.dw 0xa640, 0xc099,	0xa67f, 0xc099,		0x21, 0
	.dw 0xa6c0, 0xc099,	0xa6ff, 0xc099,		0x21, 0
	.dw 0xa740, 0xc099,	0xa77f, 0xc099,		0x21, 0
	.dw 0xa7c0, 0xc099,	0xa7ff, 0xc099,		0x21, 0
	.dw 0xa840, 0xc099,	0xa87f, 0xc099,		0x21, 0
	.dw 0xa8c0, 0xc099,	0xa8ff, 0xc099,		0x21, 0
	.dw 0xa940, 0xc099,	0xa97f, 0xc099,		0x21, 0
	.dw 0xa9c0, 0xc099,	0xa9ff, 0xc099,		0x21, 0
	.dw 0xaa40, 0xc099,	0xaa7f, 0xc099,		0x21, 0
	.dw 0xaac0, 0xc099,	0xaaff, 0xc099,		0x21, 0
	.dw 0xab40, 0xc099,	0xab7f, 0xc099,		0x21, 0
	.dw 0xabc0, 0xc099,	0xabff, 0xc099,		0x21, 0
	.dw 0xac40, 0xc099,	0xac7f, 0xc099,		0x21, 0
	.dw 0xacc0, 0xc099,	0xacff, 0xc099,		0x21, 0
	.dw 0xad40, 0xc099,	0xad7f, 0xc099,		0x21, 0
	.dw 0xadc0, 0xc099,	0xadff, 0xc099,		0x21, 0
	.dw 0xae40, 0xc099,	0xae7f, 0xc099,		0x21, 0
	.dw 0xaec0, 0xc099,	0xaeff, 0xc099,		0x21, 0
	.dw 0xaf40, 0xc099,	0xaf7f, 0xc099,		0x21, 0
	.dw 0xafc0, 0xc099,	0xafff, 0xc099,		0x21, 0
	.dw 0xb040, 0xc099,	0xb07f, 0xc099,		0x21, 0
	.dw 0xb0c0, 0xc099,	0xb0ff, 0xc099,		0x21, 0
	.dw 0xb140, 0xc099,	0xb17f, 0xc099,		0x21, 0
	.dw 0xb1c0, 0xc099,	0xb1ff, 0xc099,		0x21, 0
	.dw 0xb240, 0xc099,	0xb27f, 0xc099,		0x21, 0
	.dw 0xb2c0, 0xc099,	0xb2ff, 0xc099,		0x21, 0
	.dw 0xb340, 0xc099,	0xb37f, 0xc099,		0x21, 0
	.dw 0xb3c0, 0xc099,	0xb3ff, 0xc099,		0x21, 0
	.dw 0xb440, 0xc099,	0xb47f, 0xc099,		0x21, 0
	.dw 0xb4c0, 0xc099,	0xb4ff, 0xc099,		0x21, 0
	.dw 0xb540, 0xc099,	0xb57f, 0xc099,		0x21, 0
	.dw 0xb5c0, 0xc099,	0xb5ff, 0xc099,		0x21, 0
	.dw 0xb640, 0xc099,	0xb67f, 0xc099,		0x21, 0
	.dw 0xb6c0, 0xc099,	0xb6ff, 0xc099,		0x21, 0
	.dw 0xb740, 0xc099,	0xb77f, 0xc099,		0x21, 0
	.dw 0xb7c0, 0xc099,	0xb7ff, 0xc099,		0x21, 0
	.dw 0xb840, 0xc099,	0xb87f, 0xc099,		0x21, 0
	.dw 0xb8c0, 0xc099,	0xb8ff, 0xc099,		0x21, 0
	.dw 0xb940, 0xc099,	0xb97f, 0xc099,		0x21, 0
	.dw 0xb9c0, 0xc099,	0xdfff, 0xc099,		0x21, 0
	.dw 0xe040, 0xc099,	0xe07f, 0xc099,		0x21, 0
	.dw 0xe0c0, 0xc099,	0xe0ff, 0xc099,		0x21, 0
	.dw 0xe140, 0xc099,	0xe17f, 0xc099,		0x21, 0
	.dw 0xe1c0, 0xc099,	0xe1ff, 0xc099,		0x21, 0
	.dw 0xe240, 0xc099,	0xe27f, 0xc099,		0x21, 0
	.dw 0xe2c0, 0xc099,	0xe2ff, 0xc099,		0x21, 0
	.dw 0xe340, 0xc099,	0xe37f, 0xc099,		0x21, 0
	.dw 0xe3c0, 0xc099,	0xe3ff, 0xc099,		0x21, 0
	.dw 0xe440, 0xc099,	0xe47f, 0xc099,		0x21, 0
	.dw 0xe4c0, 0xc099,	0xe4ff, 0xc099,		0x21, 0
	.dw 0xe540, 0xc099,	0xe57f, 0xc099,		0x21, 0
	.dw 0xe5c0, 0xc099,	0xe5ff, 0xc099,		0x21, 0
	.dw 0xe640, 0xc099,	0xe67f, 0xc099,		0x21, 0
	.dw 0xe6c0, 0xc099,	0xe6ff, 0xc099,		0x21, 0
	.dw 0xe740, 0xc099,	0xe77f, 0xc099,		0x21, 0
	.dw 0xe7c0, 0xc099,	0xe7ff, 0xc099,		0x21, 0
	.dw 0xe840, 0xc099,	0xe87f, 0xc099,		0x21, 0
	.dw 0xe8c0, 0xc099,	0xe8ff, 0xc099,		0x21, 0
	.dw 0xe940, 0xc099,	0xe97f, 0xc099,		0x21, 0
	.dw 0xe9c0, 0xc099,	0xe9ff, 0xc099,		0x21, 0
	.dw 0xea40, 0xc099,	0xea7f, 0xc099,		0x21, 0
	.dw 0xeac0, 0xc099,	0xeaff, 0xc099,		0x21, 0
	.dw 0xeb40, 0xc099,	0xeb7f, 0xc099,		0x21, 0
	.dw 0xebc0, 0xc099,	0xebff, 0xc099,		0x21, 0
	.dw 0xec40, 0xc099,	0xec7f, 0xc099,		0x21, 0
	.dw 0xecc0, 0xc099,	0xecff, 0xc099,		0x21, 0
	.dw 0xed40, 0xc099,	0xed7f, 0xc099,		0x21, 0
	.dw 0xedc0, 0xc099,	0xedff, 0xc099,		0x21, 0
	.dw 0xee40, 0xc099,	0xee7f, 0xc099,		0x21, 0
	.dw 0xeec0, 0xc099,	0xeeff, 0xc099,		0x21, 0
	.dw 0xef40, 0xc099,	0xef7f, 0xc099,		0x21, 0
	.dw 0xefc0, 0xc099,	0xefff, 0xc099,		0x21, 0
	.dw 0xf040, 0xc099,	0xf07f, 0xc099,		0x21, 0
	.dw 0xf0c0, 0xc099,	0xf0ff, 0xc099,		0x21, 0
	.dw 0xf140, 0xc099,	0xf17f, 0xc099,		0x21, 0
	.dw 0xf1c0, 0xc099,	0xf1ff, 0xc099,		0x21, 0
	.dw 0xf240, 0xc099,	0xf27f, 0xc099,		0x21, 0
	.dw 0xf2c0, 0xc099,	0xf2ff, 0xc099,		0x21, 0
	.dw 0xf340, 0xc099,	0xf37f, 0xc099,		0x21, 0
	.dw 0xf3c0, 0xc099,	0xf3ff, 0xc099,		0x21, 0
	.dw 0xf440, 0xc099,	0xf47f, 0xc099,		0x21, 0
	.dw 0xf4c0, 0xc099,	0xf4ff, 0xc099,		0x21, 0
	.dw 0xf540, 0xc099,	0xf57f, 0xc099,		0x21, 0
	.dw 0xf5c0, 0xc099,	0xf5ff, 0xc099,		0x21, 0
	.dw 0xf640, 0xc099,	0xf67f, 0xc099,		0x21, 0
	.dw 0xf6c0, 0xc099,	0xf6ff, 0xc099,		0x21, 0
	.dw 0xf740, 0xc099,	0xf77f, 0xc099,		0x21, 0
	.dw 0xf7c0, 0xc099,	0xf7ff, 0xc099,		0x21, 0
	.dw 0xf840, 0xc099,	0xf87f, 0xc099,		0x21, 0
	.dw 0xf8c0, 0xc099,	0xf8ff, 0xc099,		0x21, 0
	.dw 0xf940, 0xc099,	0xf97f, 0xc099,		0x21, 0
	.dw 0xf9c0, 0xc099,	0x1fff, 0xc09a,		0x21, 0
	.dw 0x2040, 0xc09a,	0x207f, 0xc09a,		0x21, 0
	.dw 0x20c0, 0xc09a,	0x20ff, 0xc09a,		0x21, 0
	.dw 0x2140, 0xc09a,	0x217f, 0xc09a,		0x21, 0
	.dw 0x21c0, 0xc09a,	0x21ff, 0xc09a,		0x21, 0
	.dw 0x2240, 0xc09a,	0x227f, 0xc09a,		0x21, 0
	.dw 0x22c0, 0xc09a,	0x22ff, 0xc09a,		0x21, 0
	.dw 0x2340, 0xc09a,	0x237f, 0xc09a,		0x21, 0
	.dw 0x23c0, 0xc09a,	0x23ff, 0xc09a,		0x21, 0
	.dw 0x2440, 0xc09a,	0x247f, 0xc09a,		0x21, 0
	.dw 0x24c0, 0xc09a,	0x24ff, 0xc09a,		0x21, 0
	.dw 0x2540, 0xc09a,	0x257f, 0xc09a,		0x21, 0
	.dw 0x25c0, 0xc09a,	0x25ff, 0xc09a,		0x21, 0
	.dw 0x2640, 0xc09a,	0x267f, 0xc09a,		0x21, 0
	.dw 0x26c0, 0xc09a,	0x26ff, 0xc09a,		0x21, 0
	.dw 0x2740, 0xc09a,	0x277f, 0xc09a,		0x21, 0
	.dw 0x27c0, 0xc09a,	0x27ff, 0xc09a,		0x21, 0
	.dw 0x2840, 0xc09a,	0x287f, 0xc09a,		0x21, 0
	.dw 0x28c0, 0xc09a,	0x28ff, 0xc09a,		0x21, 0
	.dw 0x2940, 0xc09a,	0x297f, 0xc09a,		0x21, 0
	.dw 0x29c0, 0xc09a,	0x29ff, 0xc09a,		0x21, 0
	.dw 0x2a40, 0xc09a,	0x2a7f, 0xc09a,		0x21, 0
	.dw 0x2ac0, 0xc09a,	0x2aff, 0xc09a,		0x21, 0
	.dw 0x2b40, 0xc09a,	0x2b7f, 0xc09a,		0x21, 0
	.dw 0x2bc0, 0xc09a,	0x2bff, 0xc09a,		0x21, 0
	.dw 0x2c40, 0xc09a,	0x2c7f, 0xc09a,		0x21, 0
	.dw 0x2cc0, 0xc09a,	0x2cff, 0xc09a,		0x21, 0
	.dw 0x2d40, 0xc09a,	0x2d7f, 0xc09a,		0x21, 0
	.dw 0x2dc0, 0xc09a,	0x2dff, 0xc09a,		0x21, 0
	.dw 0x2e40, 0xc09a,	0x2e7f, 0xc09a,		0x21, 0
	.dw 0x2ec0, 0xc09a,	0x2eff, 0xc09a,		0x21, 0
	.dw 0x2f40, 0xc09a,	0x2f7f, 0xc09a,		0x21, 0
	.dw 0x2fc0, 0xc09a,	0x2fff, 0xc09a,		0x21, 0
	.dw 0x3040, 0xc09a,	0x307f, 0xc09a,		0x21, 0
	.dw 0x30c0, 0xc09a,	0x30ff, 0xc09a,		0x21, 0
	.dw 0x3140, 0xc09a,	0x317f, 0xc09a,		0x21, 0
	.dw 0x31c0, 0xc09a,	0x31ff, 0xc09a,		0x21, 0
	.dw 0x3240, 0xc09a,	0x327f, 0xc09a,		0x21, 0
	.dw 0x32c0, 0xc09a,	0x32ff, 0xc09a,		0x21, 0
	.dw 0x3340, 0xc09a,	0x337f, 0xc09a,		0x21, 0
	.dw 0x33c0, 0xc09a,	0x33ff, 0xc09a,		0x21, 0
	.dw 0x3440, 0xc09a,	0x347f, 0xc09a,		0x21, 0
	.dw 0x34c0, 0xc09a,	0x34ff, 0xc09a,		0x21, 0
	.dw 0x3540, 0xc09a,	0x357f, 0xc09a,		0x21, 0
	.dw 0x35c0, 0xc09a,	0x35ff, 0xc09a,		0x21, 0
	.dw 0x3640, 0xc09a,	0x367f, 0xc09a,		0x21, 0
	.dw 0x36c0, 0xc09a,	0x36ff, 0xc09a,		0x21, 0
	.dw 0x3740, 0xc09a,	0x377f, 0xc09a,		0x21, 0
	.dw 0x37c0, 0xc09a,	0x37ff, 0xc09a,		0x21, 0
	.dw 0x3840, 0xc09a,	0x387f, 0xc09a,		0x21, 0
	.dw 0x38c0, 0xc09a,	0x38ff, 0xc09a,		0x21, 0
	.dw 0x3940, 0xc09a,	0x397f, 0xc09a,		0x21, 0
	.dw 0x39c0, 0xc09a,	0x5fff, 0xc09a,		0x21, 0
	.dw 0x6040, 0xc09a,	0x607f, 0xc09a,		0x21, 0
	.dw 0x60c0, 0xc09a,	0x60ff, 0xc09a,		0x21, 0
	.dw 0x6140, 0xc09a,	0x617f, 0xc09a,		0x21, 0
	.dw 0x61c0, 0xc09a,	0x61ff, 0xc09a,		0x21, 0
	.dw 0x6240, 0xc09a,	0x627f, 0xc09a,		0x21, 0
	.dw 0x62c0, 0xc09a,	0x62ff, 0xc09a,		0x21, 0
	.dw 0x6340, 0xc09a,	0x637f, 0xc09a,		0x21, 0
	.dw 0x63c0, 0xc09a,	0x63ff, 0xc09a,		0x21, 0
	.dw 0x6440, 0xc09a,	0x647f, 0xc09a,		0x21, 0
	.dw 0x64c0, 0xc09a,	0x64ff, 0xc09a,		0x21, 0
	.dw 0x6540, 0xc09a,	0x657f, 0xc09a,		0x21, 0
	.dw 0x65c0, 0xc09a,	0x65ff, 0xc09a,		0x21, 0
	.dw 0x6640, 0xc09a,	0x667f, 0xc09a,		0x21, 0
	.dw 0x66c0, 0xc09a,	0x66ff, 0xc09a,		0x21, 0
	.dw 0x6740, 0xc09a,	0x677f, 0xc09a,		0x21, 0
	.dw 0x67c0, 0xc09a,	0x67ff, 0xc09a,		0x21, 0
	.dw 0x6840, 0xc09a,	0x687f, 0xc09a,		0x21, 0
	.dw 0x68c0, 0xc09a,	0x68ff, 0xc09a,		0x21, 0
	.dw 0x6940, 0xc09a,	0x697f, 0xc09a,		0x21, 0
	.dw 0x69c0, 0xc09a,	0x69ff, 0xc09a,		0x21, 0
	.dw 0x6a40, 0xc09a,	0x6a7f, 0xc09a,		0x21, 0
	.dw 0x6ac0, 0xc09a,	0x6aff, 0xc09a,		0x21, 0
	.dw 0x6b40, 0xc09a,	0x6b7f, 0xc09a,		0x21, 0
	.dw 0x6bc0, 0xc09a,	0x6bff, 0xc09a,		0x21, 0
	.dw 0x6c40, 0xc09a,	0x6c7f, 0xc09a,		0x21, 0
	.dw 0x6cc0, 0xc09a,	0x6cff, 0xc09a,		0x21, 0
	.dw 0x6d40, 0xc09a,	0x6d7f, 0xc09a,		0x21, 0
	.dw 0x6dc0, 0xc09a,	0x6dff, 0xc09a,		0x21, 0
	.dw 0x6e40, 0xc09a,	0x6e7f, 0xc09a,		0x21, 0
	.dw 0x6ec0, 0xc09a,	0x6eff, 0xc09a,		0x21, 0
	.dw 0x6f40, 0xc09a,	0x6f7f, 0xc09a,		0x21, 0
	.dw 0x6fc0, 0xc09a,	0x6fff, 0xc09a,		0x21, 0
	.dw 0x7040, 0xc09a,	0x707f, 0xc09a,		0x21, 0
	.dw 0x70c0, 0xc09a,	0x70ff, 0xc09a,		0x21, 0
	.dw 0x7140, 0xc09a,	0x717f, 0xc09a,		0x21, 0
	.dw 0x71c0, 0xc09a,	0x71ff, 0xc09a,		0x21, 0
	.dw 0x7240, 0xc09a,	0x727f, 0xc09a,		0x21, 0
	.dw 0x72c0, 0xc09a,	0x72ff, 0xc09a,		0x21, 0
	.dw 0x7340, 0xc09a,	0x737f, 0xc09a,		0x21, 0
	.dw 0x73c0, 0xc09a,	0x73ff, 0xc09a,		0x21, 0
	.dw 0x7440, 0xc09a,	0x747f, 0xc09a,		0x21, 0
	.dw 0x74c0, 0xc09a,	0x74ff, 0xc09a,		0x21, 0
	.dw 0x7540, 0xc09a,	0x757f, 0xc09a,		0x21, 0
	.dw 0x75c0, 0xc09a,	0x75ff, 0xc09a,		0x21, 0
	.dw 0x7640, 0xc09a,	0x767f, 0xc09a,		0x21, 0
	.dw 0x76c0, 0xc09a,	0x76ff, 0xc09a,		0x21, 0
	.dw 0x7740, 0xc09a,	0x777f, 0xc09a,		0x21, 0
	.dw 0x77c0, 0xc09a,	0x77ff, 0xc09a,		0x21, 0
	.dw 0x7840, 0xc09a,	0x787f, 0xc09a,		0x21, 0
	.dw 0x78c0, 0xc09a,	0x78ff, 0xc09a,		0x21, 0
	.dw 0x7940, 0xc09a,	0x797f, 0xc09a,		0x21, 0
	.dw 0x79c0, 0xc09a,	0x9fff, 0xc09a,		0x21, 0
	.dw 0xa040, 0xc09a,	0xa07f, 0xc09a,		0x21, 0
	.dw 0xa0c0, 0xc09a,	0xa0ff, 0xc09a,		0x21, 0
	.dw 0xa140, 0xc09a,	0xa17f, 0xc09a,		0x21, 0
	.dw 0xa1c0, 0xc09a,	0xa1ff, 0xc09a,		0x21, 0
	.dw 0xa240, 0xc09a,	0xa27f, 0xc09a,		0x21, 0
	.dw 0xa2c0, 0xc09a,	0xa2ff, 0xc09a,		0x21, 0
	.dw 0xa340, 0xc09a,	0xa37f, 0xc09a,		0x21, 0
	.dw 0xa3c0, 0xc09a,	0xa3ff, 0xc09a,		0x21, 0
	.dw 0xa440, 0xc09a,	0xa47f, 0xc09a,		0x21, 0
	.dw 0xa4c0, 0xc09a,	0xa4ff, 0xc09a,		0x21, 0
	.dw 0xa540, 0xc09a,	0xa57f, 0xc09a,		0x21, 0
	.dw 0xa5c0, 0xc09a,	0xa5ff, 0xc09a,		0x21, 0
	.dw 0xa640, 0xc09a,	0xa67f, 0xc09a,		0x21, 0
	.dw 0xa6c0, 0xc09a,	0xa6ff, 0xc09a,		0x21, 0
	.dw 0xa740, 0xc09a,	0xa77f, 0xc09a,		0x21, 0
	.dw 0xa7c0, 0xc09a,	0xa7ff, 0xc09a,		0x21, 0
	.dw 0xa840, 0xc09a,	0xa87f, 0xc09a,		0x21, 0
	.dw 0xa8c0, 0xc09a,	0xa8ff, 0xc09a,		0x21, 0
	.dw 0xa940, 0xc09a,	0xa97f, 0xc09a,		0x21, 0
	.dw 0xa9c0, 0xc09a,	0xa9ff, 0xc09a,		0x21, 0
	.dw 0xaa40, 0xc09a,	0xaa7f, 0xc09a,		0x21, 0
	.dw 0xaac0, 0xc09a,	0xaaff, 0xc09a,		0x21, 0
	.dw 0xab40, 0xc09a,	0xab7f, 0xc09a,		0x21, 0
	.dw 0xabc0, 0xc09a,	0xabff, 0xc09a,		0x21, 0
	.dw 0xac40, 0xc09a,	0xac7f, 0xc09a,		0x21, 0
	.dw 0xacc0, 0xc09a,	0xacff, 0xc09a,		0x21, 0
	.dw 0xad40, 0xc09a,	0xad7f, 0xc09a,		0x21, 0
	.dw 0xadc0, 0xc09a,	0xadff, 0xc09a,		0x21, 0
	.dw 0xae40, 0xc09a,	0xae7f, 0xc09a,		0x21, 0
	.dw 0xaec0, 0xc09a,	0xaeff, 0xc09a,		0x21, 0
	.dw 0xaf40, 0xc09a,	0xaf7f, 0xc09a,		0x21, 0
	.dw 0xafc0, 0xc09a,	0xafff, 0xc09a,		0x21, 0
	.dw 0xb040, 0xc09a,	0xb07f, 0xc09a,		0x21, 0
	.dw 0xb0c0, 0xc09a,	0xb0ff, 0xc09a,		0x21, 0
	.dw 0xb140, 0xc09a,	0xb17f, 0xc09a,		0x21, 0
	.dw 0xb1c0, 0xc09a,	0xb1ff, 0xc09a,		0x21, 0
	.dw 0xb240, 0xc09a,	0xb27f, 0xc09a,		0x21, 0
	.dw 0xb2c0, 0xc09a,	0xb2ff, 0xc09a,		0x21, 0
	.dw 0xb340, 0xc09a,	0xb37f, 0xc09a,		0x21, 0
	.dw 0xb3c0, 0xc09a,	0xb3ff, 0xc09a,		0x21, 0
	.dw 0xb440, 0xc09a,	0xb47f, 0xc09a,		0x21, 0
	.dw 0xb4c0, 0xc09a,	0xb4ff, 0xc09a,		0x21, 0
	.dw 0xb540, 0xc09a,	0xb57f, 0xc09a,		0x21, 0
	.dw 0xb5c0, 0xc09a,	0xb5ff, 0xc09a,		0x21, 0
	.dw 0xb640, 0xc09a,	0xb67f, 0xc09a,		0x21, 0
	.dw 0xb6c0, 0xc09a,	0xb6ff, 0xc09a,		0x21, 0
	.dw 0xb740, 0xc09a,	0xb77f, 0xc09a,		0x21, 0
	.dw 0xb7c0, 0xc09a,	0xb7ff, 0xc09a,		0x21, 0
	.dw 0xb840, 0xc09a,	0xb87f, 0xc09a,		0x21, 0
	.dw 0xb8c0, 0xc09a,	0xb8ff, 0xc09a,		0x21, 0
	.dw 0xb940, 0xc09a,	0xb97f, 0xc09a,		0x21, 0
	.dw 0xb9c0, 0xc09a,	0xdfff, 0xc09a,		0x21, 0
	.dw 0xe040, 0xc09a,	0xe07f, 0xc09a,		0x21, 0
	.dw 0xe0c0, 0xc09a,	0xe0ff, 0xc09a,		0x21, 0
	.dw 0xe140, 0xc09a,	0xe17f, 0xc09a,		0x21, 0
	.dw 0xe1c0, 0xc09a,	0xe1ff, 0xc09a,		0x21, 0
	.dw 0xe240, 0xc09a,	0xe27f, 0xc09a,		0x21, 0
	.dw 0xe2c0, 0xc09a,	0xe2ff, 0xc09a,		0x21, 0
	.dw 0xe340, 0xc09a,	0xe37f, 0xc09a,		0x21, 0
	.dw 0xe3c0, 0xc09a,	0xe3ff, 0xc09a,		0x21, 0
	.dw 0xe440, 0xc09a,	0xe47f, 0xc09a,		0x21, 0
	.dw 0xe4c0, 0xc09a,	0xe4ff, 0xc09a,		0x21, 0
	.dw 0xe540, 0xc09a,	0xe57f, 0xc09a,		0x21, 0
	.dw 0xe5c0, 0xc09a,	0xe5ff, 0xc09a,		0x21, 0
	.dw 0xe640, 0xc09a,	0xe67f, 0xc09a,		0x21, 0
	.dw 0xe6c0, 0xc09a,	0xe6ff, 0xc09a,		0x21, 0
	.dw 0xe740, 0xc09a,	0xe77f, 0xc09a,		0x21, 0
	.dw 0xe7c0, 0xc09a,	0xe7ff, 0xc09a,		0x21, 0
	.dw 0xe840, 0xc09a,	0xe87f, 0xc09a,		0x21, 0
	.dw 0xe8c0, 0xc09a,	0xe8ff, 0xc09a,		0x21, 0
	.dw 0xe940, 0xc09a,	0xe97f, 0xc09a,		0x21, 0
	.dw 0xe9c0, 0xc09a,	0xe9ff, 0xc09a,		0x21, 0
	.dw 0xea40, 0xc09a,	0xea7f, 0xc09a,		0x21, 0
	.dw 0xeac0, 0xc09a,	0xeaff, 0xc09a,		0x21, 0
	.dw 0xeb40, 0xc09a,	0xeb7f, 0xc09a,		0x21, 0
	.dw 0xebc0, 0xc09a,	0xebff, 0xc09a,		0x21, 0
	.dw 0xec40, 0xc09a,	0xec7f, 0xc09a,		0x21, 0
	.dw 0xecc0, 0xc09a,	0xecff, 0xc09a,		0x21, 0
	.dw 0xed40, 0xc09a,	0xed7f, 0xc09a,		0x21, 0
	.dw 0xedc0, 0xc09a,	0xedff, 0xc09a,		0x21, 0
	.dw 0xee40, 0xc09a,	0xee7f, 0xc09a,		0x21, 0
	.dw 0xeec0, 0xc09a,	0xeeff, 0xc09a,		0x21, 0
	.dw 0xef40, 0xc09a,	0xef7f, 0xc09a,		0x21, 0
	.dw 0xefc0, 0xc09a,	0xefff, 0xc09a,		0x21, 0
	.dw 0xf040, 0xc09a,	0xf07f, 0xc09a,		0x21, 0
	.dw 0xf0c0, 0xc09a,	0xf0ff, 0xc09a,		0x21, 0
	.dw 0xf140, 0xc09a,	0xf17f, 0xc09a,		0x21, 0
	.dw 0xf1c0, 0xc09a,	0xf1ff, 0xc09a,		0x21, 0
	.dw 0xf240, 0xc09a,	0xf27f, 0xc09a,		0x21, 0
	.dw 0xf2c0, 0xc09a,	0xf2ff, 0xc09a,		0x21, 0
	.dw 0xf340, 0xc09a,	0xf37f, 0xc09a,		0x21, 0
	.dw 0xf3c0, 0xc09a,	0xf3ff, 0xc09a,		0x21, 0
	.dw 0xf440, 0xc09a,	0xf47f, 0xc09a,		0x21, 0
	.dw 0xf4c0, 0xc09a,	0xf4ff, 0xc09a,		0x21, 0
	.dw 0xf540, 0xc09a,	0xf57f, 0xc09a,		0x21, 0
	.dw 0xf5c0, 0xc09a,	0xf5ff, 0xc09a,		0x21, 0
	.dw 0xf640, 0xc09a,	0xf67f, 0xc09a,		0x21, 0
	.dw 0xf6c0, 0xc09a,	0xf6ff, 0xc09a,		0x21, 0
	.dw 0xf740, 0xc09a,	0xf77f, 0xc09a,		0x21, 0
	.dw 0xf7c0, 0xc09a,	0xf7ff, 0xc09a,		0x21, 0
	.dw 0xf840, 0xc09a,	0xf87f, 0xc09a,		0x21, 0
	.dw 0xf8c0, 0xc09a,	0xf8ff, 0xc09a,		0x21, 0
	.dw 0xf940, 0xc09a,	0xf97f, 0xc09a,		0x21, 0
	.dw 0xf9c0, 0xc09a,	0xffff, 0xc09b,		0x21, 0
	.dw 0x0040, 0xc09c,	0x007f, 0xc09c,		0x21, 0
	.dw 0x00c0, 0xc09c,	0x00ff, 0xc09c,		0x21, 0
	.dw 0x0140, 0xc09c,	0x017f, 0xc09c,		0x21, 0
	.dw 0x01c0, 0xc09c,	0x01ff, 0xc09c,		0x21, 0
	.dw 0x0240, 0xc09c,	0x027f, 0xc09c,		0x21, 0
	.dw 0x02c0, 0xc09c,	0x02ff, 0xc09c,		0x21, 0
	.dw 0x0340, 0xc09c,	0x037f, 0xc09c,		0x21, 0
	.dw 0x03c0, 0xc09c,	0x03ff, 0xc09c,		0x21, 0
	.dw 0x0440, 0xc09c,	0x047f, 0xc09c,		0x21, 0
	.dw 0x04c0, 0xc09c,	0x04ff, 0xc09c,		0x21, 0
	.dw 0x0540, 0xc09c,	0x057f, 0xc09c,		0x21, 0
	.dw 0x05c0, 0xc09c,	0x05ff, 0xc09c,		0x21, 0
	.dw 0x0640, 0xc09c,	0x067f, 0xc09c,		0x21, 0
	.dw 0x06c0, 0xc09c,	0x06ff, 0xc09c,		0x21, 0
	.dw 0x0740, 0xc09c,	0x077f, 0xc09c,		0x21, 0
	.dw 0x07c0, 0xc09c,	0x07ff, 0xc09c,		0x21, 0
	.dw 0x0840, 0xc09c,	0x087f, 0xc09c,		0x21, 0
	.dw 0x08c0, 0xc09c,	0x08ff, 0xc09c,		0x21, 0
	.dw 0x0940, 0xc09c,	0x097f, 0xc09c,		0x21, 0
	.dw 0x09c0, 0xc09c,	0x09ff, 0xc09c,		0x21, 0
	.dw 0x0a40, 0xc09c,	0x0a7f, 0xc09c,		0x21, 0
	.dw 0x0ac0, 0xc09c,	0x0aff, 0xc09c,		0x21, 0
	.dw 0x0b40, 0xc09c,	0x0b7f, 0xc09c,		0x21, 0
	.dw 0x0bc0, 0xc09c,	0x0bff, 0xc09c,		0x21, 0
	.dw 0x0c40, 0xc09c,	0x0c7f, 0xc09c,		0x21, 0
	.dw 0x0cc0, 0xc09c,	0x0cff, 0xc09c,		0x21, 0
	.dw 0x0d40, 0xc09c,	0x0d7f, 0xc09c,		0x21, 0
	.dw 0x0dc0, 0xc09c,	0x0dff, 0xc09c,		0x21, 0
	.dw 0x0e40, 0xc09c,	0x0e7f, 0xc09c,		0x21, 0
	.dw 0x0ec0, 0xc09c,	0x0eff, 0xc09c,		0x21, 0
	.dw 0x0f40, 0xc09c,	0x0f7f, 0xc09c,		0x21, 0
	.dw 0x0fc0, 0xc09c,	0x0fff, 0xc09c,		0x21, 0
	.dw 0x1040, 0xc09c,	0x107f, 0xc09c,		0x21, 0
	.dw 0x10c0, 0xc09c,	0x10ff, 0xc09c,		0x21, 0
	.dw 0x1140, 0xc09c,	0x117f, 0xc09c,		0x21, 0
	.dw 0x11c0, 0xc09c,	0x11ff, 0xc09c,		0x21, 0
	.dw 0x1240, 0xc09c,	0x127f, 0xc09c,		0x21, 0
	.dw 0x12c0, 0xc09c,	0x12ff, 0xc09c,		0x21, 0
	.dw 0x1340, 0xc09c,	0x137f, 0xc09c,		0x21, 0
	.dw 0x13c0, 0xc09c,	0x13ff, 0xc09c,		0x21, 0
	.dw 0x1440, 0xc09c,	0x147f, 0xc09c,		0x21, 0
	.dw 0x14c0, 0xc09c,	0x14ff, 0xc09c,		0x21, 0
	.dw 0x1540, 0xc09c,	0x157f, 0xc09c,		0x21, 0
	.dw 0x15c0, 0xc09c,	0x15ff, 0xc09c,		0x21, 0
	.dw 0x1640, 0xc09c,	0x167f, 0xc09c,		0x21, 0
	.dw 0x16c0, 0xc09c,	0x16ff, 0xc09c,		0x21, 0
	.dw 0x1740, 0xc09c,	0x177f, 0xc09c,		0x21, 0
	.dw 0x17c0, 0xc09c,	0x17ff, 0xc09c,		0x21, 0
	.dw 0x1840, 0xc09c,	0x187f, 0xc09c,		0x21, 0
	.dw 0x18c0, 0xc09c,	0x18ff, 0xc09c,		0x21, 0
	.dw 0x1940, 0xc09c,	0x197f, 0xc09c,		0x21, 0
	.dw 0x19c0, 0xc09c,	0x1fff, 0xc09c,		0x21, 0
	.dw 0x2040, 0xc09c,	0x207f, 0xc09c,		0x21, 0
	.dw 0x20c0, 0xc09c,	0x20ff, 0xc09c,		0x21, 0
	.dw 0x2140, 0xc09c,	0x217f, 0xc09c,		0x21, 0
	.dw 0x21c0, 0xc09c,	0x21ff, 0xc09c,		0x21, 0
	.dw 0x2240, 0xc09c,	0x227f, 0xc09c,		0x21, 0
	.dw 0x22c0, 0xc09c,	0x22ff, 0xc09c,		0x21, 0
	.dw 0x2340, 0xc09c,	0x237f, 0xc09c,		0x21, 0
	.dw 0x23c0, 0xc09c,	0x23ff, 0xc09c,		0x21, 0
	.dw 0x2440, 0xc09c,	0x247f, 0xc09c,		0x21, 0
	.dw 0x24c0, 0xc09c,	0x24ff, 0xc09c,		0x21, 0
	.dw 0x2540, 0xc09c,	0x257f, 0xc09c,		0x21, 0
	.dw 0x25c0, 0xc09c,	0x25ff, 0xc09c,		0x21, 0
	.dw 0x2640, 0xc09c,	0x267f, 0xc09c,		0x21, 0
	.dw 0x26c0, 0xc09c,	0x26ff, 0xc09c,		0x21, 0
	.dw 0x2740, 0xc09c,	0x277f, 0xc09c,		0x21, 0
	.dw 0x27c0, 0xc09c,	0x27ff, 0xc09c,		0x21, 0
	.dw 0x2840, 0xc09c,	0x287f, 0xc09c,		0x21, 0
	.dw 0x28c0, 0xc09c,	0x28ff, 0xc09c,		0x21, 0
	.dw 0x2940, 0xc09c,	0x297f, 0xc09c,		0x21, 0
	.dw 0x29c0, 0xc09c,	0x29ff, 0xc09c,		0x21, 0
	.dw 0x2a40, 0xc09c,	0x2a7f, 0xc09c,		0x21, 0
	.dw 0x2ac0, 0xc09c,	0x2aff, 0xc09c,		0x21, 0
	.dw 0x2b40, 0xc09c,	0x2b7f, 0xc09c,		0x21, 0
	.dw 0x2bc0, 0xc09c,	0x2bff, 0xc09c,		0x21, 0
	.dw 0x2c40, 0xc09c,	0x2c7f, 0xc09c,		0x21, 0
	.dw 0x2cc0, 0xc09c,	0x2cff, 0xc09c,		0x21, 0
	.dw 0x2d40, 0xc09c,	0x2d7f, 0xc09c,		0x21, 0
	.dw 0x2dc0, 0xc09c,	0x2dff, 0xc09c,		0x21, 0
	.dw 0x2e40, 0xc09c,	0x2e7f, 0xc09c,		0x21, 0
	.dw 0x2ec0, 0xc09c,	0x2eff, 0xc09c,		0x21, 0
	.dw 0x2f40, 0xc09c,	0x2f7f, 0xc09c,		0x21, 0
	.dw 0x2fc0, 0xc09c,	0x2fff, 0xc09c,		0x21, 0
	.dw 0x3040, 0xc09c,	0x307f, 0xc09c,		0x21, 0
	.dw 0x30c0, 0xc09c,	0x30ff, 0xc09c,		0x21, 0
	.dw 0x3140, 0xc09c,	0x317f, 0xc09c,		0x21, 0
	.dw 0x31c0, 0xc09c,	0x31ff, 0xc09c,		0x21, 0
	.dw 0x3240, 0xc09c,	0x327f, 0xc09c,		0x21, 0
	.dw 0x32c0, 0xc09c,	0x32ff, 0xc09c,		0x21, 0
	.dw 0x3340, 0xc09c,	0x337f, 0xc09c,		0x21, 0
	.dw 0x33c0, 0xc09c,	0x33ff, 0xc09c,		0x21, 0
	.dw 0x3440, 0xc09c,	0x347f, 0xc09c,		0x21, 0
	.dw 0x34c0, 0xc09c,	0x34ff, 0xc09c,		0x21, 0
	.dw 0x3540, 0xc09c,	0x357f, 0xc09c,		0x21, 0
	.dw 0x35c0, 0xc09c,	0x35ff, 0xc09c,		0x21, 0
	.dw 0x3640, 0xc09c,	0x367f, 0xc09c,		0x21, 0
	.dw 0x36c0, 0xc09c,	0x36ff, 0xc09c,		0x21, 0
	.dw 0x3740, 0xc09c,	0x377f, 0xc09c,		0x21, 0
	.dw 0x37c0, 0xc09c,	0x37ff, 0xc09c,		0x21, 0
	.dw 0x3840, 0xc09c,	0x387f, 0xc09c,		0x21, 0
	.dw 0x38c0, 0xc09c,	0x38ff, 0xc09c,		0x21, 0
	.dw 0x3940, 0xc09c,	0x397f, 0xc09c,		0x21, 0
	.dw 0x39c0, 0xc09c,	0x3fff, 0xc09c,		0x21, 0
	.dw 0x4040, 0xc09c,	0x407f, 0xc09c,		0x21, 0
	.dw 0x40c0, 0xc09c,	0x40ff, 0xc09c,		0x21, 0
	.dw 0x4140, 0xc09c,	0x417f, 0xc09c,		0x21, 0
	.dw 0x41c0, 0xc09c,	0x41ff, 0xc09c,		0x21, 0
	.dw 0x4240, 0xc09c,	0x427f, 0xc09c,		0x21, 0
	.dw 0x42c0, 0xc09c,	0x42ff, 0xc09c,		0x21, 0
	.dw 0x4340, 0xc09c,	0x437f, 0xc09c,		0x21, 0
	.dw 0x43c0, 0xc09c,	0x43ff, 0xc09c,		0x21, 0
	.dw 0x4440, 0xc09c,	0x447f, 0xc09c,		0x21, 0
	.dw 0x44c0, 0xc09c,	0x44ff, 0xc09c,		0x21, 0
	.dw 0x4540, 0xc09c,	0x457f, 0xc09c,		0x21, 0
	.dw 0x45c0, 0xc09c,	0x45ff, 0xc09c,		0x21, 0
	.dw 0x4640, 0xc09c,	0x467f, 0xc09c,		0x21, 0
	.dw 0x46c0, 0xc09c,	0x46ff, 0xc09c,		0x21, 0
	.dw 0x4740, 0xc09c,	0x477f, 0xc09c,		0x21, 0
	.dw 0x47c0, 0xc09c,	0x47ff, 0xc09c,		0x21, 0
	.dw 0x4840, 0xc09c,	0x487f, 0xc09c,		0x21, 0
	.dw 0x48c0, 0xc09c,	0x48ff, 0xc09c,		0x21, 0
	.dw 0x4940, 0xc09c,	0x497f, 0xc09c,		0x21, 0
	.dw 0x49c0, 0xc09c,	0x49ff, 0xc09c,		0x21, 0
	.dw 0x4a40, 0xc09c,	0x4a7f, 0xc09c,		0x21, 0
	.dw 0x4ac0, 0xc09c,	0x4aff, 0xc09c,		0x21, 0
	.dw 0x4b40, 0xc09c,	0x4b7f, 0xc09c,		0x21, 0
	.dw 0x4bc0, 0xc09c,	0x4bff, 0xc09c,		0x21, 0
	.dw 0x4c40, 0xc09c,	0x4c7f, 0xc09c,		0x21, 0
	.dw 0x4cc0, 0xc09c,	0x4cff, 0xc09c,		0x21, 0
	.dw 0x4d40, 0xc09c,	0x4d7f, 0xc09c,		0x21, 0
	.dw 0x4dc0, 0xc09c,	0x4dff, 0xc09c,		0x21, 0
	.dw 0x4e40, 0xc09c,	0x4e7f, 0xc09c,		0x21, 0
	.dw 0x4ec0, 0xc09c,	0x4eff, 0xc09c,		0x21, 0
	.dw 0x4f40, 0xc09c,	0x4f7f, 0xc09c,		0x21, 0
	.dw 0x4fc0, 0xc09c,	0x4fff, 0xc09c,		0x21, 0
	.dw 0x5040, 0xc09c,	0x507f, 0xc09c,		0x21, 0
	.dw 0x50c0, 0xc09c,	0x50ff, 0xc09c,		0x21, 0
	.dw 0x5140, 0xc09c,	0x517f, 0xc09c,		0x21, 0
	.dw 0x51c0, 0xc09c,	0x51ff, 0xc09c,		0x21, 0
	.dw 0x5240, 0xc09c,	0x527f, 0xc09c,		0x21, 0
	.dw 0x52c0, 0xc09c,	0x52ff, 0xc09c,		0x21, 0
	.dw 0x5340, 0xc09c,	0x537f, 0xc09c,		0x21, 0
	.dw 0x53c0, 0xc09c,	0x53ff, 0xc09c,		0x21, 0
	.dw 0x5440, 0xc09c,	0x547f, 0xc09c,		0x21, 0
	.dw 0x54c0, 0xc09c,	0x54ff, 0xc09c,		0x21, 0
	.dw 0x5540, 0xc09c,	0x557f, 0xc09c,		0x21, 0
	.dw 0x55c0, 0xc09c,	0x55ff, 0xc09c,		0x21, 0
	.dw 0x5640, 0xc09c,	0x567f, 0xc09c,		0x21, 0
	.dw 0x56c0, 0xc09c,	0x56ff, 0xc09c,		0x21, 0
	.dw 0x5740, 0xc09c,	0x577f, 0xc09c,		0x21, 0
	.dw 0x57c0, 0xc09c,	0x57ff, 0xc09c,		0x21, 0
	.dw 0x5840, 0xc09c,	0x587f, 0xc09c,		0x21, 0
	.dw 0x58c0, 0xc09c,	0x58ff, 0xc09c,		0x21, 0
	.dw 0x5940, 0xc09c,	0x597f, 0xc09c,		0x21, 0
	.dw 0x59c0, 0xc09c,	0x5fff, 0xc09c,		0x21, 0
	.dw 0x6040, 0xc09c,	0x607f, 0xc09c,		0x21, 0
	.dw 0x60c0, 0xc09c,	0x60ff, 0xc09c,		0x21, 0
	.dw 0x6140, 0xc09c,	0x617f, 0xc09c,		0x21, 0
	.dw 0x61c0, 0xc09c,	0x61ff, 0xc09c,		0x21, 0
	.dw 0x6240, 0xc09c,	0x627f, 0xc09c,		0x21, 0
	.dw 0x62c0, 0xc09c,	0x62ff, 0xc09c,		0x21, 0
	.dw 0x6340, 0xc09c,	0x637f, 0xc09c,		0x21, 0
	.dw 0x63c0, 0xc09c,	0x63ff, 0xc09c,		0x21, 0
	.dw 0x6440, 0xc09c,	0x647f, 0xc09c,		0x21, 0
	.dw 0x64c0, 0xc09c,	0x64ff, 0xc09c,		0x21, 0
	.dw 0x6540, 0xc09c,	0x657f, 0xc09c,		0x21, 0
	.dw 0x65c0, 0xc09c,	0x65ff, 0xc09c,		0x21, 0
	.dw 0x6640, 0xc09c,	0x667f, 0xc09c,		0x21, 0
	.dw 0x66c0, 0xc09c,	0x66ff, 0xc09c,		0x21, 0
	.dw 0x6740, 0xc09c,	0x677f, 0xc09c,		0x21, 0
	.dw 0x67c0, 0xc09c,	0x67ff, 0xc09c,		0x21, 0
	.dw 0x6840, 0xc09c,	0x687f, 0xc09c,		0x21, 0
	.dw 0x68c0, 0xc09c,	0x68ff, 0xc09c,		0x21, 0
	.dw 0x6940, 0xc09c,	0x697f, 0xc09c,		0x21, 0
	.dw 0x69c0, 0xc09c,	0x69ff, 0xc09c,		0x21, 0
	.dw 0x6a40, 0xc09c,	0x6a7f, 0xc09c,		0x21, 0
	.dw 0x6ac0, 0xc09c,	0x6aff, 0xc09c,		0x21, 0
	.dw 0x6b40, 0xc09c,	0x6b7f, 0xc09c,		0x21, 0
	.dw 0x6bc0, 0xc09c,	0x6bff, 0xc09c,		0x21, 0
	.dw 0x6c40, 0xc09c,	0x6c7f, 0xc09c,		0x21, 0
	.dw 0x6cc0, 0xc09c,	0x6cff, 0xc09c,		0x21, 0
	.dw 0x6d40, 0xc09c,	0x6d7f, 0xc09c,		0x21, 0
	.dw 0x6dc0, 0xc09c,	0x6dff, 0xc09c,		0x21, 0
	.dw 0x6e40, 0xc09c,	0x6e7f, 0xc09c,		0x21, 0
	.dw 0x6ec0, 0xc09c,	0x6eff, 0xc09c,		0x21, 0
	.dw 0x6f40, 0xc09c,	0x6f7f, 0xc09c,		0x21, 0
	.dw 0x6fc0, 0xc09c,	0x6fff, 0xc09c,		0x21, 0
	.dw 0x7040, 0xc09c,	0x707f, 0xc09c,		0x21, 0
	.dw 0x70c0, 0xc09c,	0x70ff, 0xc09c,		0x21, 0
	.dw 0x7140, 0xc09c,	0x717f, 0xc09c,		0x21, 0
	.dw 0x71c0, 0xc09c,	0x71ff, 0xc09c,		0x21, 0
	.dw 0x7240, 0xc09c,	0x727f, 0xc09c,		0x21, 0
	.dw 0x72c0, 0xc09c,	0x72ff, 0xc09c,		0x21, 0
	.dw 0x7340, 0xc09c,	0x737f, 0xc09c,		0x21, 0
	.dw 0x73c0, 0xc09c,	0x73ff, 0xc09c,		0x21, 0
	.dw 0x7440, 0xc09c,	0x747f, 0xc09c,		0x21, 0
	.dw 0x74c0, 0xc09c,	0x74ff, 0xc09c,		0x21, 0
	.dw 0x7540, 0xc09c,	0x757f, 0xc09c,		0x21, 0
	.dw 0x75c0, 0xc09c,	0x75ff, 0xc09c,		0x21, 0
	.dw 0x7640, 0xc09c,	0x767f, 0xc09c,		0x21, 0
	.dw 0x76c0, 0xc09c,	0x76ff, 0xc09c,		0x21, 0
	.dw 0x7740, 0xc09c,	0x777f, 0xc09c,		0x21, 0
	.dw 0x77c0, 0xc09c,	0x77ff, 0xc09c,		0x21, 0
	.dw 0x7840, 0xc09c,	0x787f, 0xc09c,		0x21, 0
	.dw 0x78c0, 0xc09c,	0x78ff, 0xc09c,		0x21, 0
	.dw 0x7940, 0xc09c,	0x797f, 0xc09c,		0x21, 0
	.dw 0x79c0, 0xc09c,	0x7fff, 0xc09c,		0x21, 0
	.dw 0x8040, 0xc09c,	0x807f, 0xc09c,		0x21, 0
	.dw 0x80c0, 0xc09c,	0x80ff, 0xc09c,		0x21, 0
	.dw 0x8140, 0xc09c,	0x817f, 0xc09c,		0x21, 0
	.dw 0x81c0, 0xc09c,	0x81ff, 0xc09c,		0x21, 0
	.dw 0x8240, 0xc09c,	0x827f, 0xc09c,		0x21, 0
	.dw 0x82c0, 0xc09c,	0x82ff, 0xc09c,		0x21, 0
	.dw 0x8340, 0xc09c,	0x837f, 0xc09c,		0x21, 0
	.dw 0x83c0, 0xc09c,	0x83ff, 0xc09c,		0x21, 0
	.dw 0x8440, 0xc09c,	0x847f, 0xc09c,		0x21, 0
	.dw 0x84c0, 0xc09c,	0x84ff, 0xc09c,		0x21, 0
	.dw 0x8540, 0xc09c,	0x857f, 0xc09c,		0x21, 0
	.dw 0x85c0, 0xc09c,	0x85ff, 0xc09c,		0x21, 0
	.dw 0x8640, 0xc09c,	0x867f, 0xc09c,		0x21, 0
	.dw 0x86c0, 0xc09c,	0x86ff, 0xc09c,		0x21, 0
	.dw 0x8740, 0xc09c,	0x877f, 0xc09c,		0x21, 0
	.dw 0x87c0, 0xc09c,	0x87ff, 0xc09c,		0x21, 0
	.dw 0x8840, 0xc09c,	0x887f, 0xc09c,		0x21, 0
	.dw 0x88c0, 0xc09c,	0x88ff, 0xc09c,		0x21, 0
	.dw 0x8940, 0xc09c,	0x897f, 0xc09c,		0x21, 0
	.dw 0x89c0, 0xc09c,	0x89ff, 0xc09c,		0x21, 0
	.dw 0x8a40, 0xc09c,	0x8a7f, 0xc09c,		0x21, 0
	.dw 0x8ac0, 0xc09c,	0x8aff, 0xc09c,		0x21, 0
	.dw 0x8b40, 0xc09c,	0x8b7f, 0xc09c,		0x21, 0
	.dw 0x8bc0, 0xc09c,	0x8bff, 0xc09c,		0x21, 0
	.dw 0x8c40, 0xc09c,	0x8c7f, 0xc09c,		0x21, 0
	.dw 0x8cc0, 0xc09c,	0x8cff, 0xc09c,		0x21, 0
	.dw 0x8d40, 0xc09c,	0x8d7f, 0xc09c,		0x21, 0
	.dw 0x8dc0, 0xc09c,	0x8dff, 0xc09c,		0x21, 0
	.dw 0x8e40, 0xc09c,	0x8e7f, 0xc09c,		0x21, 0
	.dw 0x8ec0, 0xc09c,	0x8eff, 0xc09c,		0x21, 0
	.dw 0x8f40, 0xc09c,	0x8f7f, 0xc09c,		0x21, 0
	.dw 0x8fc0, 0xc09c,	0x8fff, 0xc09c,		0x21, 0
	.dw 0x9040, 0xc09c,	0x907f, 0xc09c,		0x21, 0
	.dw 0x90c0, 0xc09c,	0x90ff, 0xc09c,		0x21, 0
	.dw 0x9140, 0xc09c,	0x917f, 0xc09c,		0x21, 0
	.dw 0x91c0, 0xc09c,	0x91ff, 0xc09c,		0x21, 0
	.dw 0x9240, 0xc09c,	0x927f, 0xc09c,		0x21, 0
	.dw 0x92c0, 0xc09c,	0x92ff, 0xc09c,		0x21, 0
	.dw 0x9340, 0xc09c,	0x937f, 0xc09c,		0x21, 0
	.dw 0x93c0, 0xc09c,	0x93ff, 0xc09c,		0x21, 0
	.dw 0x9440, 0xc09c,	0x947f, 0xc09c,		0x21, 0
	.dw 0x94c0, 0xc09c,	0x94ff, 0xc09c,		0x21, 0
	.dw 0x9540, 0xc09c,	0x957f, 0xc09c,		0x21, 0
	.dw 0x95c0, 0xc09c,	0x95ff, 0xc09c,		0x21, 0
	.dw 0x9640, 0xc09c,	0x967f, 0xc09c,		0x21, 0
	.dw 0x96c0, 0xc09c,	0x96ff, 0xc09c,		0x21, 0
	.dw 0x9740, 0xc09c,	0x977f, 0xc09c,		0x21, 0
	.dw 0x97c0, 0xc09c,	0x97ff, 0xc09c,		0x21, 0
	.dw 0x9840, 0xc09c,	0x987f, 0xc09c,		0x21, 0
	.dw 0x98c0, 0xc09c,	0x98ff, 0xc09c,		0x21, 0
	.dw 0x9940, 0xc09c,	0x997f, 0xc09c,		0x21, 0
	.dw 0x99c0, 0xc09c,	0x9fff, 0xc09c,		0x21, 0
	.dw 0xa040, 0xc09c,	0xa07f, 0xc09c,		0x21, 0
	.dw 0xa0c0, 0xc09c,	0xa0ff, 0xc09c,		0x21, 0
	.dw 0xa140, 0xc09c,	0xa17f, 0xc09c,		0x21, 0
	.dw 0xa1c0, 0xc09c,	0xa1ff, 0xc09c,		0x21, 0
	.dw 0xa240, 0xc09c,	0xa27f, 0xc09c,		0x21, 0
	.dw 0xa2c0, 0xc09c,	0xa2ff, 0xc09c,		0x21, 0
	.dw 0xa340, 0xc09c,	0xa37f, 0xc09c,		0x21, 0
	.dw 0xa3c0, 0xc09c,	0xa3ff, 0xc09c,		0x21, 0
	.dw 0xa440, 0xc09c,	0xa47f, 0xc09c,		0x21, 0
	.dw 0xa4c0, 0xc09c,	0xa4ff, 0xc09c,		0x21, 0
	.dw 0xa540, 0xc09c,	0xa57f, 0xc09c,		0x21, 0
	.dw 0xa5c0, 0xc09c,	0xa5ff, 0xc09c,		0x21, 0
	.dw 0xa640, 0xc09c,	0xa67f, 0xc09c,		0x21, 0
	.dw 0xa6c0, 0xc09c,	0xa6ff, 0xc09c,		0x21, 0
	.dw 0xa740, 0xc09c,	0xa77f, 0xc09c,		0x21, 0
	.dw 0xa7c0, 0xc09c,	0xa7ff, 0xc09c,		0x21, 0
	.dw 0xa840, 0xc09c,	0xa87f, 0xc09c,		0x21, 0
	.dw 0xa8c0, 0xc09c,	0xa8ff, 0xc09c,		0x21, 0
	.dw 0xa940, 0xc09c,	0xa97f, 0xc09c,		0x21, 0
	.dw 0xa9c0, 0xc09c,	0xa9ff, 0xc09c,		0x21, 0
	.dw 0xaa40, 0xc09c,	0xaa7f, 0xc09c,		0x21, 0
	.dw 0xaac0, 0xc09c,	0xaaff, 0xc09c,		0x21, 0
	.dw 0xab40, 0xc09c,	0xab7f, 0xc09c,		0x21, 0
	.dw 0xabc0, 0xc09c,	0xabff, 0xc09c,		0x21, 0
	.dw 0xac40, 0xc09c,	0xac7f, 0xc09c,		0x21, 0
	.dw 0xacc0, 0xc09c,	0xacff, 0xc09c,		0x21, 0
	.dw 0xad40, 0xc09c,	0xad7f, 0xc09c,		0x21, 0
	.dw 0xadc0, 0xc09c,	0xadff, 0xc09c,		0x21, 0
	.dw 0xae40, 0xc09c,	0xae7f, 0xc09c,		0x21, 0
	.dw 0xaec0, 0xc09c,	0xaeff, 0xc09c,		0x21, 0
	.dw 0xaf40, 0xc09c,	0xaf7f, 0xc09c,		0x21, 0
	.dw 0xafc0, 0xc09c,	0xafff, 0xc09c,		0x21, 0
	.dw 0xb040, 0xc09c,	0xb07f, 0xc09c,		0x21, 0
	.dw 0xb0c0, 0xc09c,	0xb0ff, 0xc09c,		0x21, 0
	.dw 0xb140, 0xc09c,	0xb17f, 0xc09c,		0x21, 0
	.dw 0xb1c0, 0xc09c,	0xb1ff, 0xc09c,		0x21, 0
	.dw 0xb240, 0xc09c,	0xb27f, 0xc09c,		0x21, 0
	.dw 0xb2c0, 0xc09c,	0xb2ff, 0xc09c,		0x21, 0
	.dw 0xb340, 0xc09c,	0xb37f, 0xc09c,		0x21, 0
	.dw 0xb3c0, 0xc09c,	0xb3ff, 0xc09c,		0x21, 0
	.dw 0xb440, 0xc09c,	0xb47f, 0xc09c,		0x21, 0
	.dw 0xb4c0, 0xc09c,	0xb4ff, 0xc09c,		0x21, 0
	.dw 0xb540, 0xc09c,	0xb57f, 0xc09c,		0x21, 0
	.dw 0xb5c0, 0xc09c,	0xb5ff, 0xc09c,		0x21, 0
	.dw 0xb640, 0xc09c,	0xb67f, 0xc09c,		0x21, 0
	.dw 0xb6c0, 0xc09c,	0xb6ff, 0xc09c,		0x21, 0
	.dw 0xb740, 0xc09c,	0xb77f, 0xc09c,		0x21, 0
	.dw 0xb7c0, 0xc09c,	0xb7ff, 0xc09c,		0x21, 0
	.dw 0xb840, 0xc09c,	0xb87f, 0xc09c,		0x21, 0
	.dw 0xb8c0, 0xc09c,	0xb8ff, 0xc09c,		0x21, 0
	.dw 0xb940, 0xc09c,	0xb97f, 0xc09c,		0x21, 0
	.dw 0xb9c0, 0xc09c,	0xbfff, 0xc09c,		0x21, 0
	.dw 0xc040, 0xc09c,	0xc07f, 0xc09c,		0x21, 0
	.dw 0xc0c0, 0xc09c,	0xc0ff, 0xc09c,		0x21, 0
	.dw 0xc140, 0xc09c,	0xc17f, 0xc09c,		0x21, 0
	.dw 0xc1c0, 0xc09c,	0xc1ff, 0xc09c,		0x21, 0
	.dw 0xc240, 0xc09c,	0xc27f, 0xc09c,		0x21, 0
	.dw 0xc2c0, 0xc09c,	0xc2ff, 0xc09c,		0x21, 0
	.dw 0xc340, 0xc09c,	0xc37f, 0xc09c,		0x21, 0
	.dw 0xc3c0, 0xc09c,	0xc3ff, 0xc09c,		0x21, 0
	.dw 0xc440, 0xc09c,	0xc47f, 0xc09c,		0x21, 0
	.dw 0xc4c0, 0xc09c,	0xc4ff, 0xc09c,		0x21, 0
	.dw 0xc540, 0xc09c,	0xc57f, 0xc09c,		0x21, 0
	.dw 0xc5c0, 0xc09c,	0xc5ff, 0xc09c,		0x21, 0
	.dw 0xc640, 0xc09c,	0xc67f, 0xc09c,		0x21, 0
	.dw 0xc6c0, 0xc09c,	0xc6ff, 0xc09c,		0x21, 0
	.dw 0xc740, 0xc09c,	0xc77f, 0xc09c,		0x21, 0
	.dw 0xc7c0, 0xc09c,	0xc7ff, 0xc09c,		0x21, 0
	.dw 0xc840, 0xc09c,	0xc87f, 0xc09c,		0x21, 0
	.dw 0xc8c0, 0xc09c,	0xc8ff, 0xc09c,		0x21, 0
	.dw 0xc940, 0xc09c,	0xc97f, 0xc09c,		0x21, 0
	.dw 0xc9c0, 0xc09c,	0xc9ff, 0xc09c,		0x21, 0
	.dw 0xca40, 0xc09c,	0xca7f, 0xc09c,		0x21, 0
	.dw 0xcac0, 0xc09c,	0xcaff, 0xc09c,		0x21, 0
	.dw 0xcb40, 0xc09c,	0xcb7f, 0xc09c,		0x21, 0
	.dw 0xcbc0, 0xc09c,	0xcbff, 0xc09c,		0x21, 0
	.dw 0xcc40, 0xc09c,	0xcc7f, 0xc09c,		0x21, 0
	.dw 0xccc0, 0xc09c,	0xccff, 0xc09c,		0x21, 0
	.dw 0xcd40, 0xc09c,	0xcd7f, 0xc09c,		0x21, 0
	.dw 0xcdc0, 0xc09c,	0xcdff, 0xc09c,		0x21, 0
	.dw 0xce40, 0xc09c,	0xce7f, 0xc09c,		0x21, 0
	.dw 0xcec0, 0xc09c,	0xceff, 0xc09c,		0x21, 0
	.dw 0xcf40, 0xc09c,	0xcf7f, 0xc09c,		0x21, 0
	.dw 0xcfc0, 0xc09c,	0xcfff, 0xc09c,		0x21, 0
	.dw 0xd040, 0xc09c,	0xd07f, 0xc09c,		0x21, 0
	.dw 0xd0c0, 0xc09c,	0xd0ff, 0xc09c,		0x21, 0
	.dw 0xd140, 0xc09c,	0xd17f, 0xc09c,		0x21, 0
	.dw 0xd1c0, 0xc09c,	0xd1ff, 0xc09c,		0x21, 0
	.dw 0xd240, 0xc09c,	0xd27f, 0xc09c,		0x21, 0
	.dw 0xd2c0, 0xc09c,	0xd2ff, 0xc09c,		0x21, 0
	.dw 0xd340, 0xc09c,	0xd37f, 0xc09c,		0x21, 0
	.dw 0xd3c0, 0xc09c,	0xd3ff, 0xc09c,		0x21, 0
	.dw 0xd440, 0xc09c,	0xd47f, 0xc09c,		0x21, 0
	.dw 0xd4c0, 0xc09c,	0xd4ff, 0xc09c,		0x21, 0
	.dw 0xd540, 0xc09c,	0xd57f, 0xc09c,		0x21, 0
	.dw 0xd5c0, 0xc09c,	0xd5ff, 0xc09c,		0x21, 0
	.dw 0xd640, 0xc09c,	0xd67f, 0xc09c,		0x21, 0
	.dw 0xd6c0, 0xc09c,	0xd6ff, 0xc09c,		0x21, 0
	.dw 0xd740, 0xc09c,	0xd77f, 0xc09c,		0x21, 0
	.dw 0xd7c0, 0xc09c,	0xd7ff, 0xc09c,		0x21, 0
	.dw 0xd840, 0xc09c,	0xd87f, 0xc09c,		0x21, 0
	.dw 0xd8c0, 0xc09c,	0xd8ff, 0xc09c,		0x21, 0
	.dw 0xd940, 0xc09c,	0xd97f, 0xc09c,		0x21, 0
	.dw 0xd9c0, 0xc09c,	0xdfff, 0xc09c,		0x21, 0
	.dw 0xe040, 0xc09c,	0xe07f, 0xc09c,		0x21, 0
	.dw 0xe0c0, 0xc09c,	0xe0ff, 0xc09c,		0x21, 0
	.dw 0xe140, 0xc09c,	0xe17f, 0xc09c,		0x21, 0
	.dw 0xe1c0, 0xc09c,	0xe1ff, 0xc09c,		0x21, 0
	.dw 0xe240, 0xc09c,	0xe27f, 0xc09c,		0x21, 0
	.dw 0xe2c0, 0xc09c,	0xe2ff, 0xc09c,		0x21, 0
	.dw 0xe340, 0xc09c,	0xe37f, 0xc09c,		0x21, 0
	.dw 0xe3c0, 0xc09c,	0xe3ff, 0xc09c,		0x21, 0
	.dw 0xe440, 0xc09c,	0xe47f, 0xc09c,		0x21, 0
	.dw 0xe4c0, 0xc09c,	0xe4ff, 0xc09c,		0x21, 0
	.dw 0xe540, 0xc09c,	0xe57f, 0xc09c,		0x21, 0
	.dw 0xe5c0, 0xc09c,	0xe5ff, 0xc09c,		0x21, 0
	.dw 0xe640, 0xc09c,	0xe67f, 0xc09c,		0x21, 0
	.dw 0xe6c0, 0xc09c,	0xe6ff, 0xc09c,		0x21, 0
	.dw 0xe740, 0xc09c,	0xe77f, 0xc09c,		0x21, 0
	.dw 0xe7c0, 0xc09c,	0xe7ff, 0xc09c,		0x21, 0
	.dw 0xe840, 0xc09c,	0xe87f, 0xc09c,		0x21, 0
	.dw 0xe8c0, 0xc09c,	0xe8ff, 0xc09c,		0x21, 0
	.dw 0xe940, 0xc09c,	0xe97f, 0xc09c,		0x21, 0
	.dw 0xe9c0, 0xc09c,	0xe9ff, 0xc09c,		0x21, 0
	.dw 0xea40, 0xc09c,	0xea7f, 0xc09c,		0x21, 0
	.dw 0xeac0, 0xc09c,	0xeaff, 0xc09c,		0x21, 0
	.dw 0xeb40, 0xc09c,	0xeb7f, 0xc09c,		0x21, 0
	.dw 0xebc0, 0xc09c,	0xebff, 0xc09c,		0x21, 0
	.dw 0xec40, 0xc09c,	0xec7f, 0xc09c,		0x21, 0
	.dw 0xecc0, 0xc09c,	0xecff, 0xc09c,		0x21, 0
	.dw 0xed40, 0xc09c,	0xed7f, 0xc09c,		0x21, 0
	.dw 0xedc0, 0xc09c,	0xedff, 0xc09c,		0x21, 0
	.dw 0xee40, 0xc09c,	0xee7f, 0xc09c,		0x21, 0
	.dw 0xeec0, 0xc09c,	0xeeff, 0xc09c,		0x21, 0
	.dw 0xef40, 0xc09c,	0xef7f, 0xc09c,		0x21, 0
	.dw 0xefc0, 0xc09c,	0xefff, 0xc09c,		0x21, 0
	.dw 0xf040, 0xc09c,	0xf07f, 0xc09c,		0x21, 0
	.dw 0xf0c0, 0xc09c,	0xf0ff, 0xc09c,		0x21, 0
	.dw 0xf140, 0xc09c,	0xf17f, 0xc09c,		0x21, 0
	.dw 0xf1c0, 0xc09c,	0xf1ff, 0xc09c,		0x21, 0
	.dw 0xf240, 0xc09c,	0xf27f, 0xc09c,		0x21, 0
	.dw 0xf2c0, 0xc09c,	0xf2ff, 0xc09c,		0x21, 0
	.dw 0xf340, 0xc09c,	0xf37f, 0xc09c,		0x21, 0
	.dw 0xf3c0, 0xc09c,	0xf3ff, 0xc09c,		0x21, 0
	.dw 0xf440, 0xc09c,	0xf47f, 0xc09c,		0x21, 0
	.dw 0xf4c0, 0xc09c,	0xf4ff, 0xc09c,		0x21, 0
	.dw 0xf540, 0xc09c,	0xf57f, 0xc09c,		0x21, 0
	.dw 0xf5c0, 0xc09c,	0xf5ff, 0xc09c,		0x21, 0
	.dw 0xf640, 0xc09c,	0xf67f, 0xc09c,		0x21, 0
	.dw 0xf6c0, 0xc09c,	0xf6ff, 0xc09c,		0x21, 0
	.dw 0xf740, 0xc09c,	0xf77f, 0xc09c,		0x21, 0
	.dw 0xf7c0, 0xc09c,	0xf7ff, 0xc09c,		0x21, 0
	.dw 0xf840, 0xc09c,	0xf87f, 0xc09c,		0x21, 0
	.dw 0xf8c0, 0xc09c,	0xf8ff, 0xc09c,		0x21, 0
	.dw 0xf940, 0xc09c,	0xf97f, 0xc09c,		0x21, 0
	.dw 0xf9c0, 0xc09c,	0xffff, 0xc09c,		0x21, 0
	.dw 0x0040, 0xc09d,	0x007f, 0xc09d,		0x21, 0
	.dw 0x00c0, 0xc09d,	0x00ff, 0xc09d,		0x21, 0
	.dw 0x0140, 0xc09d,	0x017f, 0xc09d,		0x21, 0
	.dw 0x01c0, 0xc09d,	0x01ff, 0xc09d,		0x21, 0
	.dw 0x0240, 0xc09d,	0x027f, 0xc09d,		0x21, 0
	.dw 0x02c0, 0xc09d,	0x02ff, 0xc09d,		0x21, 0
	.dw 0x0340, 0xc09d,	0x037f, 0xc09d,		0x21, 0
	.dw 0x03c0, 0xc09d,	0x03ff, 0xc09d,		0x21, 0
	.dw 0x0440, 0xc09d,	0x047f, 0xc09d,		0x21, 0
	.dw 0x04c0, 0xc09d,	0x04ff, 0xc09d,		0x21, 0
	.dw 0x0540, 0xc09d,	0x057f, 0xc09d,		0x21, 0
	.dw 0x05c0, 0xc09d,	0x05ff, 0xc09d,		0x21, 0
	.dw 0x0640, 0xc09d,	0x067f, 0xc09d,		0x21, 0
	.dw 0x06c0, 0xc09d,	0x06ff, 0xc09d,		0x21, 0
	.dw 0x0740, 0xc09d,	0x077f, 0xc09d,		0x21, 0
	.dw 0x07c0, 0xc09d,	0x07ff, 0xc09d,		0x21, 0
	.dw 0x0840, 0xc09d,	0x087f, 0xc09d,		0x21, 0
	.dw 0x08c0, 0xc09d,	0x08ff, 0xc09d,		0x21, 0
	.dw 0x0940, 0xc09d,	0x097f, 0xc09d,		0x21, 0
	.dw 0x09c0, 0xc09d,	0x09ff, 0xc09d,		0x21, 0
	.dw 0x0a40, 0xc09d,	0x0a7f, 0xc09d,		0x21, 0
	.dw 0x0ac0, 0xc09d,	0x0aff, 0xc09d,		0x21, 0
	.dw 0x0b40, 0xc09d,	0x0b7f, 0xc09d,		0x21, 0
	.dw 0x0bc0, 0xc09d,	0x0bff, 0xc09d,		0x21, 0
	.dw 0x0c40, 0xc09d,	0x0c7f, 0xc09d,		0x21, 0
	.dw 0x0cc0, 0xc09d,	0x0cff, 0xc09d,		0x21, 0
	.dw 0x0d40, 0xc09d,	0x0d7f, 0xc09d,		0x21, 0
	.dw 0x0dc0, 0xc09d,	0x0dff, 0xc09d,		0x21, 0
	.dw 0x0e40, 0xc09d,	0x0e7f, 0xc09d,		0x21, 0
	.dw 0x0ec0, 0xc09d,	0x0eff, 0xc09d,		0x21, 0
	.dw 0x0f40, 0xc09d,	0x0f7f, 0xc09d,		0x21, 0
	.dw 0x0fc0, 0xc09d,	0x0fff, 0xc09d,		0x21, 0
	.dw 0x1040, 0xc09d,	0x107f, 0xc09d,		0x21, 0
	.dw 0x10c0, 0xc09d,	0x10ff, 0xc09d,		0x21, 0
	.dw 0x1140, 0xc09d,	0x117f, 0xc09d,		0x21, 0
	.dw 0x11c0, 0xc09d,	0x11ff, 0xc09d,		0x21, 0
	.dw 0x1240, 0xc09d,	0x127f, 0xc09d,		0x21, 0
	.dw 0x12c0, 0xc09d,	0x12ff, 0xc09d,		0x21, 0
	.dw 0x1340, 0xc09d,	0x137f, 0xc09d,		0x21, 0
	.dw 0x13c0, 0xc09d,	0x13ff, 0xc09d,		0x21, 0
	.dw 0x1440, 0xc09d,	0x147f, 0xc09d,		0x21, 0
	.dw 0x14c0, 0xc09d,	0x14ff, 0xc09d,		0x21, 0
	.dw 0x1540, 0xc09d,	0x157f, 0xc09d,		0x21, 0
	.dw 0x15c0, 0xc09d,	0x15ff, 0xc09d,		0x21, 0
	.dw 0x1640, 0xc09d,	0x167f, 0xc09d,		0x21, 0
	.dw 0x16c0, 0xc09d,	0x16ff, 0xc09d,		0x21, 0
	.dw 0x1740, 0xc09d,	0x177f, 0xc09d,		0x21, 0
	.dw 0x17c0, 0xc09d,	0x17ff, 0xc09d,		0x21, 0
	.dw 0x1840, 0xc09d,	0x187f, 0xc09d,		0x21, 0
	.dw 0x18c0, 0xc09d,	0x18ff, 0xc09d,		0x21, 0
	.dw 0x1940, 0xc09d,	0x197f, 0xc09d,		0x21, 0
	.dw 0x19c0, 0xc09d,	0x1fff, 0xc09d,		0x21, 0
	.dw 0x2040, 0xc09d,	0x207f, 0xc09d,		0x21, 0
	.dw 0x20c0, 0xc09d,	0x20ff, 0xc09d,		0x21, 0
	.dw 0x2140, 0xc09d,	0x217f, 0xc09d,		0x21, 0
	.dw 0x21c0, 0xc09d,	0x21ff, 0xc09d,		0x21, 0
	.dw 0x2240, 0xc09d,	0x227f, 0xc09d,		0x21, 0
	.dw 0x22c0, 0xc09d,	0x22ff, 0xc09d,		0x21, 0
	.dw 0x2340, 0xc09d,	0x237f, 0xc09d,		0x21, 0
	.dw 0x23c0, 0xc09d,	0x23ff, 0xc09d,		0x21, 0
	.dw 0x2440, 0xc09d,	0x247f, 0xc09d,		0x21, 0
	.dw 0x24c0, 0xc09d,	0x24ff, 0xc09d,		0x21, 0
	.dw 0x2540, 0xc09d,	0x257f, 0xc09d,		0x21, 0
	.dw 0x25c0, 0xc09d,	0x25ff, 0xc09d,		0x21, 0
	.dw 0x2640, 0xc09d,	0x267f, 0xc09d,		0x21, 0
	.dw 0x26c0, 0xc09d,	0x26ff, 0xc09d,		0x21, 0
	.dw 0x2740, 0xc09d,	0x277f, 0xc09d,		0x21, 0
	.dw 0x27c0, 0xc09d,	0x27ff, 0xc09d,		0x21, 0
	.dw 0x2840, 0xc09d,	0x287f, 0xc09d,		0x21, 0
	.dw 0x28c0, 0xc09d,	0x28ff, 0xc09d,		0x21, 0
	.dw 0x2940, 0xc09d,	0x297f, 0xc09d,		0x21, 0
	.dw 0x29c0, 0xc09d,	0x29ff, 0xc09d,		0x21, 0
	.dw 0x2a40, 0xc09d,	0x2a7f, 0xc09d,		0x21, 0
	.dw 0x2ac0, 0xc09d,	0x2aff, 0xc09d,		0x21, 0
	.dw 0x2b40, 0xc09d,	0x2b7f, 0xc09d,		0x21, 0
	.dw 0x2bc0, 0xc09d,	0x2bff, 0xc09d,		0x21, 0
	.dw 0x2c40, 0xc09d,	0x2c7f, 0xc09d,		0x21, 0
	.dw 0x2cc0, 0xc09d,	0x2cff, 0xc09d,		0x21, 0
	.dw 0x2d40, 0xc09d,	0x2d7f, 0xc09d,		0x21, 0
	.dw 0x2dc0, 0xc09d,	0x2dff, 0xc09d,		0x21, 0
	.dw 0x2e40, 0xc09d,	0x2e7f, 0xc09d,		0x21, 0
	.dw 0x2ec0, 0xc09d,	0x2eff, 0xc09d,		0x21, 0
	.dw 0x2f40, 0xc09d,	0x2f7f, 0xc09d,		0x21, 0
	.dw 0x2fc0, 0xc09d,	0x2fff, 0xc09d,		0x21, 0
	.dw 0x3040, 0xc09d,	0x307f, 0xc09d,		0x21, 0
	.dw 0x30c0, 0xc09d,	0x30ff, 0xc09d,		0x21, 0
	.dw 0x3140, 0xc09d,	0x317f, 0xc09d,		0x21, 0
	.dw 0x31c0, 0xc09d,	0x31ff, 0xc09d,		0x21, 0
	.dw 0x3240, 0xc09d,	0x327f, 0xc09d,		0x21, 0
	.dw 0x32c0, 0xc09d,	0x32ff, 0xc09d,		0x21, 0
	.dw 0x3340, 0xc09d,	0x337f, 0xc09d,		0x21, 0
	.dw 0x33c0, 0xc09d,	0x33ff, 0xc09d,		0x21, 0
	.dw 0x3440, 0xc09d,	0x347f, 0xc09d,		0x21, 0
	.dw 0x34c0, 0xc09d,	0x34ff, 0xc09d,		0x21, 0
	.dw 0x3540, 0xc09d,	0x357f, 0xc09d,		0x21, 0
	.dw 0x35c0, 0xc09d,	0x35ff, 0xc09d,		0x21, 0
	.dw 0x3640, 0xc09d,	0x367f, 0xc09d,		0x21, 0
	.dw 0x36c0, 0xc09d,	0x36ff, 0xc09d,		0x21, 0
	.dw 0x3740, 0xc09d,	0x377f, 0xc09d,		0x21, 0
	.dw 0x37c0, 0xc09d,	0x37ff, 0xc09d,		0x21, 0
	.dw 0x3840, 0xc09d,	0x387f, 0xc09d,		0x21, 0
	.dw 0x38c0, 0xc09d,	0x38ff, 0xc09d,		0x21, 0
	.dw 0x3940, 0xc09d,	0x397f, 0xc09d,		0x21, 0
	.dw 0x39c0, 0xc09d,	0x3fff, 0xc09d,		0x21, 0
	.dw 0x4040, 0xc09d,	0x407f, 0xc09d,		0x21, 0
	.dw 0x40c0, 0xc09d,	0x40ff, 0xc09d,		0x21, 0
	.dw 0x4140, 0xc09d,	0x417f, 0xc09d,		0x21, 0
	.dw 0x41c0, 0xc09d,	0x41ff, 0xc09d,		0x21, 0
	.dw 0x4240, 0xc09d,	0x427f, 0xc09d,		0x21, 0
	.dw 0x42c0, 0xc09d,	0x42ff, 0xc09d,		0x21, 0
	.dw 0x4340, 0xc09d,	0x437f, 0xc09d,		0x21, 0
	.dw 0x43c0, 0xc09d,	0x43ff, 0xc09d,		0x21, 0
	.dw 0x4440, 0xc09d,	0x447f, 0xc09d,		0x21, 0
	.dw 0x44c0, 0xc09d,	0x44ff, 0xc09d,		0x21, 0
	.dw 0x4540, 0xc09d,	0x457f, 0xc09d,		0x21, 0
	.dw 0x45c0, 0xc09d,	0x45ff, 0xc09d,		0x21, 0
	.dw 0x4640, 0xc09d,	0x467f, 0xc09d,		0x21, 0
	.dw 0x46c0, 0xc09d,	0x46ff, 0xc09d,		0x21, 0
	.dw 0x4740, 0xc09d,	0x477f, 0xc09d,		0x21, 0
	.dw 0x47c0, 0xc09d,	0x47ff, 0xc09d,		0x21, 0
	.dw 0x4840, 0xc09d,	0x487f, 0xc09d,		0x21, 0
	.dw 0x48c0, 0xc09d,	0x48ff, 0xc09d,		0x21, 0
	.dw 0x4940, 0xc09d,	0x497f, 0xc09d,		0x21, 0
	.dw 0x49c0, 0xc09d,	0x49ff, 0xc09d,		0x21, 0
	.dw 0x4a40, 0xc09d,	0x4a7f, 0xc09d,		0x21, 0
	.dw 0x4ac0, 0xc09d,	0x4aff, 0xc09d,		0x21, 0
	.dw 0x4b40, 0xc09d,	0x4b7f, 0xc09d,		0x21, 0
	.dw 0x4bc0, 0xc09d,	0x4bff, 0xc09d,		0x21, 0
	.dw 0x4c40, 0xc09d,	0x4c7f, 0xc09d,		0x21, 0
	.dw 0x4cc0, 0xc09d,	0x4cff, 0xc09d,		0x21, 0
	.dw 0x4d40, 0xc09d,	0x4d7f, 0xc09d,		0x21, 0
	.dw 0x4dc0, 0xc09d,	0x4dff, 0xc09d,		0x21, 0
	.dw 0x4e40, 0xc09d,	0x4e7f, 0xc09d,		0x21, 0
	.dw 0x4ec0, 0xc09d,	0x4eff, 0xc09d,		0x21, 0
	.dw 0x4f40, 0xc09d,	0x4f7f, 0xc09d,		0x21, 0
	.dw 0x4fc0, 0xc09d,	0x4fff, 0xc09d,		0x21, 0
	.dw 0x5040, 0xc09d,	0x507f, 0xc09d,		0x21, 0
	.dw 0x50c0, 0xc09d,	0x50ff, 0xc09d,		0x21, 0
	.dw 0x5140, 0xc09d,	0x517f, 0xc09d,		0x21, 0
	.dw 0x51c0, 0xc09d,	0x51ff, 0xc09d,		0x21, 0
	.dw 0x5240, 0xc09d,	0x527f, 0xc09d,		0x21, 0
	.dw 0x52c0, 0xc09d,	0x52ff, 0xc09d,		0x21, 0
	.dw 0x5340, 0xc09d,	0x537f, 0xc09d,		0x21, 0
	.dw 0x53c0, 0xc09d,	0x53ff, 0xc09d,		0x21, 0
	.dw 0x5440, 0xc09d,	0x547f, 0xc09d,		0x21, 0
	.dw 0x54c0, 0xc09d,	0x54ff, 0xc09d,		0x21, 0
	.dw 0x5540, 0xc09d,	0x557f, 0xc09d,		0x21, 0
	.dw 0x55c0, 0xc09d,	0x55ff, 0xc09d,		0x21, 0
	.dw 0x5640, 0xc09d,	0x567f, 0xc09d,		0x21, 0
	.dw 0x56c0, 0xc09d,	0x56ff, 0xc09d,		0x21, 0
	.dw 0x5740, 0xc09d,	0x577f, 0xc09d,		0x21, 0
	.dw 0x57c0, 0xc09d,	0x57ff, 0xc09d,		0x21, 0
	.dw 0x5840, 0xc09d,	0x587f, 0xc09d,		0x21, 0
	.dw 0x58c0, 0xc09d,	0x58ff, 0xc09d,		0x21, 0
	.dw 0x5940, 0xc09d,	0x597f, 0xc09d,		0x21, 0
	.dw 0x59c0, 0xc09d,	0x5fff, 0xc09d,		0x21, 0
	.dw 0x6040, 0xc09d,	0x607f, 0xc09d,		0x21, 0
	.dw 0x60c0, 0xc09d,	0x60ff, 0xc09d,		0x21, 0
	.dw 0x6140, 0xc09d,	0x617f, 0xc09d,		0x21, 0
	.dw 0x61c0, 0xc09d,	0x61ff, 0xc09d,		0x21, 0
	.dw 0x6240, 0xc09d,	0x627f, 0xc09d,		0x21, 0
	.dw 0x62c0, 0xc09d,	0x62ff, 0xc09d,		0x21, 0
	.dw 0x6340, 0xc09d,	0x637f, 0xc09d,		0x21, 0
	.dw 0x63c0, 0xc09d,	0x63ff, 0xc09d,		0x21, 0
	.dw 0x6440, 0xc09d,	0x647f, 0xc09d,		0x21, 0
	.dw 0x64c0, 0xc09d,	0x64ff, 0xc09d,		0x21, 0
	.dw 0x6540, 0xc09d,	0x657f, 0xc09d,		0x21, 0
	.dw 0x65c0, 0xc09d,	0x65ff, 0xc09d,		0x21, 0
	.dw 0x6640, 0xc09d,	0x667f, 0xc09d,		0x21, 0
	.dw 0x66c0, 0xc09d,	0x66ff, 0xc09d,		0x21, 0
	.dw 0x6740, 0xc09d,	0x677f, 0xc09d,		0x21, 0
	.dw 0x67c0, 0xc09d,	0x67ff, 0xc09d,		0x21, 0
	.dw 0x6840, 0xc09d,	0x687f, 0xc09d,		0x21, 0
	.dw 0x68c0, 0xc09d,	0x68ff, 0xc09d,		0x21, 0
	.dw 0x6940, 0xc09d,	0x697f, 0xc09d,		0x21, 0
	.dw 0x69c0, 0xc09d,	0x69ff, 0xc09d,		0x21, 0
	.dw 0x6a40, 0xc09d,	0x6a7f, 0xc09d,		0x21, 0
	.dw 0x6ac0, 0xc09d,	0x6aff, 0xc09d,		0x21, 0
	.dw 0x6b40, 0xc09d,	0x6b7f, 0xc09d,		0x21, 0
	.dw 0x6bc0, 0xc09d,	0x6bff, 0xc09d,		0x21, 0
	.dw 0x6c40, 0xc09d,	0x6c7f, 0xc09d,		0x21, 0
	.dw 0x6cc0, 0xc09d,	0x6cff, 0xc09d,		0x21, 0
	.dw 0x6d40, 0xc09d,	0x6d7f, 0xc09d,		0x21, 0
	.dw 0x6dc0, 0xc09d,	0x6dff, 0xc09d,		0x21, 0
	.dw 0x6e40, 0xc09d,	0x6e7f, 0xc09d,		0x21, 0
	.dw 0x6ec0, 0xc09d,	0x6eff, 0xc09d,		0x21, 0
	.dw 0x6f40, 0xc09d,	0x6f7f, 0xc09d,		0x21, 0
	.dw 0x6fc0, 0xc09d,	0x6fff, 0xc09d,		0x21, 0
	.dw 0x7040, 0xc09d,	0x707f, 0xc09d,		0x21, 0
	.dw 0x70c0, 0xc09d,	0x70ff, 0xc09d,		0x21, 0
	.dw 0x7140, 0xc09d,	0x717f, 0xc09d,		0x21, 0
	.dw 0x71c0, 0xc09d,	0x71ff, 0xc09d,		0x21, 0
	.dw 0x7240, 0xc09d,	0x727f, 0xc09d,		0x21, 0
	.dw 0x72c0, 0xc09d,	0x72ff, 0xc09d,		0x21, 0
	.dw 0x7340, 0xc09d,	0x737f, 0xc09d,		0x21, 0
	.dw 0x73c0, 0xc09d,	0x73ff, 0xc09d,		0x21, 0
	.dw 0x7440, 0xc09d,	0x747f, 0xc09d,		0x21, 0
	.dw 0x74c0, 0xc09d,	0x74ff, 0xc09d,		0x21, 0
	.dw 0x7540, 0xc09d,	0x757f, 0xc09d,		0x21, 0
	.dw 0x75c0, 0xc09d,	0x75ff, 0xc09d,		0x21, 0
	.dw 0x7640, 0xc09d,	0x767f, 0xc09d,		0x21, 0
	.dw 0x76c0, 0xc09d,	0x76ff, 0xc09d,		0x21, 0
	.dw 0x7740, 0xc09d,	0x777f, 0xc09d,		0x21, 0
	.dw 0x77c0, 0xc09d,	0x77ff, 0xc09d,		0x21, 0
	.dw 0x7840, 0xc09d,	0x787f, 0xc09d,		0x21, 0
	.dw 0x78c0, 0xc09d,	0x78ff, 0xc09d,		0x21, 0
	.dw 0x7940, 0xc09d,	0x797f, 0xc09d,		0x21, 0
	.dw 0x79c0, 0xc09d,	0x7fff, 0xc09d,		0x21, 0
	.dw 0x8040, 0xc09d,	0x807f, 0xc09d,		0x21, 0
	.dw 0x80c0, 0xc09d,	0x80ff, 0xc09d,		0x21, 0
	.dw 0x8140, 0xc09d,	0x817f, 0xc09d,		0x21, 0
	.dw 0x81c0, 0xc09d,	0x81ff, 0xc09d,		0x21, 0
	.dw 0x8240, 0xc09d,	0x827f, 0xc09d,		0x21, 0
	.dw 0x82c0, 0xc09d,	0x82ff, 0xc09d,		0x21, 0
	.dw 0x8340, 0xc09d,	0x837f, 0xc09d,		0x21, 0
	.dw 0x83c0, 0xc09d,	0x83ff, 0xc09d,		0x21, 0
	.dw 0x8440, 0xc09d,	0x847f, 0xc09d,		0x21, 0
	.dw 0x84c0, 0xc09d,	0x84ff, 0xc09d,		0x21, 0
	.dw 0x8540, 0xc09d,	0x857f, 0xc09d,		0x21, 0
	.dw 0x85c0, 0xc09d,	0x85ff, 0xc09d,		0x21, 0
	.dw 0x8640, 0xc09d,	0x867f, 0xc09d,		0x21, 0
	.dw 0x86c0, 0xc09d,	0x86ff, 0xc09d,		0x21, 0
	.dw 0x8740, 0xc09d,	0x877f, 0xc09d,		0x21, 0
	.dw 0x87c0, 0xc09d,	0x87ff, 0xc09d,		0x21, 0
	.dw 0x8840, 0xc09d,	0x887f, 0xc09d,		0x21, 0
	.dw 0x88c0, 0xc09d,	0x88ff, 0xc09d,		0x21, 0
	.dw 0x8940, 0xc09d,	0x897f, 0xc09d,		0x21, 0
	.dw 0x89c0, 0xc09d,	0x89ff, 0xc09d,		0x21, 0
	.dw 0x8a40, 0xc09d,	0x8a7f, 0xc09d,		0x21, 0
	.dw 0x8ac0, 0xc09d,	0x8aff, 0xc09d,		0x21, 0
	.dw 0x8b40, 0xc09d,	0x8b7f, 0xc09d,		0x21, 0
	.dw 0x8bc0, 0xc09d,	0x8bff, 0xc09d,		0x21, 0
	.dw 0x8c40, 0xc09d,	0x8c7f, 0xc09d,		0x21, 0
	.dw 0x8cc0, 0xc09d,	0x8cff, 0xc09d,		0x21, 0
	.dw 0x8d40, 0xc09d,	0x8d7f, 0xc09d,		0x21, 0
	.dw 0x8dc0, 0xc09d,	0x8dff, 0xc09d,		0x21, 0
	.dw 0x8e40, 0xc09d,	0x8e7f, 0xc09d,		0x21, 0
	.dw 0x8ec0, 0xc09d,	0x8eff, 0xc09d,		0x21, 0
	.dw 0x8f40, 0xc09d,	0x8f7f, 0xc09d,		0x21, 0
	.dw 0x8fc0, 0xc09d,	0x8fff, 0xc09d,		0x21, 0
	.dw 0x9040, 0xc09d,	0x907f, 0xc09d,		0x21, 0
	.dw 0x90c0, 0xc09d,	0x90ff, 0xc09d,		0x21, 0
	.dw 0x9140, 0xc09d,	0x917f, 0xc09d,		0x21, 0
	.dw 0x91c0, 0xc09d,	0x91ff, 0xc09d,		0x21, 0
	.dw 0x9240, 0xc09d,	0x927f, 0xc09d,		0x21, 0
	.dw 0x92c0, 0xc09d,	0x92ff, 0xc09d,		0x21, 0
	.dw 0x9340, 0xc09d,	0x937f, 0xc09d,		0x21, 0
	.dw 0x93c0, 0xc09d,	0x93ff, 0xc09d,		0x21, 0
	.dw 0x9440, 0xc09d,	0x947f, 0xc09d,		0x21, 0
	.dw 0x94c0, 0xc09d,	0x94ff, 0xc09d,		0x21, 0
	.dw 0x9540, 0xc09d,	0x957f, 0xc09d,		0x21, 0
	.dw 0x95c0, 0xc09d,	0x95ff, 0xc09d,		0x21, 0
	.dw 0x9640, 0xc09d,	0x967f, 0xc09d,		0x21, 0
	.dw 0x96c0, 0xc09d,	0x96ff, 0xc09d,		0x21, 0
	.dw 0x9740, 0xc09d,	0x977f, 0xc09d,		0x21, 0
	.dw 0x97c0, 0xc09d,	0x97ff, 0xc09d,		0x21, 0
	.dw 0x9840, 0xc09d,	0x987f, 0xc09d,		0x21, 0
	.dw 0x98c0, 0xc09d,	0x98ff, 0xc09d,		0x21, 0
	.dw 0x9940, 0xc09d,	0x997f, 0xc09d,		0x21, 0
	.dw 0x99c0, 0xc09d,	0x9fff, 0xc09d,		0x21, 0
	.dw 0xa040, 0xc09d,	0xa07f, 0xc09d,		0x21, 0
	.dw 0xa0c0, 0xc09d,	0xa0ff, 0xc09d,		0x21, 0
	.dw 0xa140, 0xc09d,	0xa17f, 0xc09d,		0x21, 0
	.dw 0xa1c0, 0xc09d,	0xa1ff, 0xc09d,		0x21, 0
	.dw 0xa240, 0xc09d,	0xa27f, 0xc09d,		0x21, 0
	.dw 0xa2c0, 0xc09d,	0xa2ff, 0xc09d,		0x21, 0
	.dw 0xa340, 0xc09d,	0xa37f, 0xc09d,		0x21, 0
	.dw 0xa3c0, 0xc09d,	0xa3ff, 0xc09d,		0x21, 0
	.dw 0xa440, 0xc09d,	0xa47f, 0xc09d,		0x21, 0
	.dw 0xa4c0, 0xc09d,	0xa4ff, 0xc09d,		0x21, 0
	.dw 0xa540, 0xc09d,	0xa57f, 0xc09d,		0x21, 0
	.dw 0xa5c0, 0xc09d,	0xa5ff, 0xc09d,		0x21, 0
	.dw 0xa640, 0xc09d,	0xa67f, 0xc09d,		0x21, 0
	.dw 0xa6c0, 0xc09d,	0xa6ff, 0xc09d,		0x21, 0
	.dw 0xa740, 0xc09d,	0xa77f, 0xc09d,		0x21, 0
	.dw 0xa7c0, 0xc09d,	0xa7ff, 0xc09d,		0x21, 0
	.dw 0xa840, 0xc09d,	0xa87f, 0xc09d,		0x21, 0
	.dw 0xa8c0, 0xc09d,	0xa8ff, 0xc09d,		0x21, 0
	.dw 0xa940, 0xc09d,	0xa97f, 0xc09d,		0x21, 0
	.dw 0xa9c0, 0xc09d,	0xa9ff, 0xc09d,		0x21, 0
	.dw 0xaa40, 0xc09d,	0xaa7f, 0xc09d,		0x21, 0
	.dw 0xaac0, 0xc09d,	0xaaff, 0xc09d,		0x21, 0
	.dw 0xab40, 0xc09d,	0xab7f, 0xc09d,		0x21, 0
	.dw 0xabc0, 0xc09d,	0xabff, 0xc09d,		0x21, 0
	.dw 0xac40, 0xc09d,	0xac7f, 0xc09d,		0x21, 0
	.dw 0xacc0, 0xc09d,	0xacff, 0xc09d,		0x21, 0
	.dw 0xad40, 0xc09d,	0xad7f, 0xc09d,		0x21, 0
	.dw 0xadc0, 0xc09d,	0xadff, 0xc09d,		0x21, 0
	.dw 0xae40, 0xc09d,	0xae7f, 0xc09d,		0x21, 0
	.dw 0xaec0, 0xc09d,	0xaeff, 0xc09d,		0x21, 0
	.dw 0xaf40, 0xc09d,	0xaf7f, 0xc09d,		0x21, 0
	.dw 0xafc0, 0xc09d,	0xafff, 0xc09d,		0x21, 0
	.dw 0xb040, 0xc09d,	0xb07f, 0xc09d,		0x21, 0
	.dw 0xb0c0, 0xc09d,	0xb0ff, 0xc09d,		0x21, 0
	.dw 0xb140, 0xc09d,	0xb17f, 0xc09d,		0x21, 0
	.dw 0xb1c0, 0xc09d,	0xb1ff, 0xc09d,		0x21, 0
	.dw 0xb240, 0xc09d,	0xb27f, 0xc09d,		0x21, 0
	.dw 0xb2c0, 0xc09d,	0xb2ff, 0xc09d,		0x21, 0
	.dw 0xb340, 0xc09d,	0xb37f, 0xc09d,		0x21, 0
	.dw 0xb3c0, 0xc09d,	0xb3ff, 0xc09d,		0x21, 0
	.dw 0xb440, 0xc09d,	0xb47f, 0xc09d,		0x21, 0
	.dw 0xb4c0, 0xc09d,	0xb4ff, 0xc09d,		0x21, 0
	.dw 0xb540, 0xc09d,	0xb57f, 0xc09d,		0x21, 0
	.dw 0xb5c0, 0xc09d,	0xb5ff, 0xc09d,		0x21, 0
	.dw 0xb640, 0xc09d,	0xb67f, 0xc09d,		0x21, 0
	.dw 0xb6c0, 0xc09d,	0xb6ff, 0xc09d,		0x21, 0
	.dw 0xb740, 0xc09d,	0xb77f, 0xc09d,		0x21, 0
	.dw 0xb7c0, 0xc09d,	0xb7ff, 0xc09d,		0x21, 0
	.dw 0xb840, 0xc09d,	0xb87f, 0xc09d,		0x21, 0
	.dw 0xb8c0, 0xc09d,	0xb8ff, 0xc09d,		0x21, 0
	.dw 0xb940, 0xc09d,	0xb97f, 0xc09d,		0x21, 0
	.dw 0xb9c0, 0xc09d,	0xbfff, 0xc09d,		0x21, 0
	.dw 0xc040, 0xc09d,	0xc07f, 0xc09d,		0x21, 0
	.dw 0xc0c0, 0xc09d,	0xc0ff, 0xc09d,		0x21, 0
	.dw 0xc140, 0xc09d,	0xc17f, 0xc09d,		0x21, 0
	.dw 0xc1c0, 0xc09d,	0xc1ff, 0xc09d,		0x21, 0
	.dw 0xc240, 0xc09d,	0xc27f, 0xc09d,		0x21, 0
	.dw 0xc2c0, 0xc09d,	0xc2ff, 0xc09d,		0x21, 0
	.dw 0xc340, 0xc09d,	0xc37f, 0xc09d,		0x21, 0
	.dw 0xc3c0, 0xc09d,	0xc3ff, 0xc09d,		0x21, 0
	.dw 0xc440, 0xc09d,	0xc47f, 0xc09d,		0x21, 0
	.dw 0xc4c0, 0xc09d,	0xc4ff, 0xc09d,		0x21, 0
	.dw 0xc540, 0xc09d,	0xc57f, 0xc09d,		0x21, 0
	.dw 0xc5c0, 0xc09d,	0xc5ff, 0xc09d,		0x21, 0
	.dw 0xc640, 0xc09d,	0xc67f, 0xc09d,		0x21, 0
	.dw 0xc6c0, 0xc09d,	0xc6ff, 0xc09d,		0x21, 0
	.dw 0xc740, 0xc09d,	0xc77f, 0xc09d,		0x21, 0
	.dw 0xc7c0, 0xc09d,	0xc7ff, 0xc09d,		0x21, 0
	.dw 0xc840, 0xc09d,	0xc87f, 0xc09d,		0x21, 0
	.dw 0xc8c0, 0xc09d,	0xc8ff, 0xc09d,		0x21, 0
	.dw 0xc940, 0xc09d,	0xc97f, 0xc09d,		0x21, 0
	.dw 0xc9c0, 0xc09d,	0xc9ff, 0xc09d,		0x21, 0
	.dw 0xca40, 0xc09d,	0xca7f, 0xc09d,		0x21, 0
	.dw 0xcac0, 0xc09d,	0xcaff, 0xc09d,		0x21, 0
	.dw 0xcb40, 0xc09d,	0xcb7f, 0xc09d,		0x21, 0
	.dw 0xcbc0, 0xc09d,	0xcbff, 0xc09d,		0x21, 0
	.dw 0xcc40, 0xc09d,	0xcc7f, 0xc09d,		0x21, 0
	.dw 0xccc0, 0xc09d,	0xccff, 0xc09d,		0x21, 0
	.dw 0xcd40, 0xc09d,	0xcd7f, 0xc09d,		0x21, 0
	.dw 0xcdc0, 0xc09d,	0xcdff, 0xc09d,		0x21, 0
	.dw 0xce40, 0xc09d,	0xce7f, 0xc09d,		0x21, 0
	.dw 0xcec0, 0xc09d,	0xceff, 0xc09d,		0x21, 0
	.dw 0xcf40, 0xc09d,	0xcf7f, 0xc09d,		0x21, 0
	.dw 0xcfc0, 0xc09d,	0xcfff, 0xc09d,		0x21, 0
	.dw 0xd040, 0xc09d,	0xd07f, 0xc09d,		0x21, 0
	.dw 0xd0c0, 0xc09d,	0xd0ff, 0xc09d,		0x21, 0
	.dw 0xd140, 0xc09d,	0xd17f, 0xc09d,		0x21, 0
	.dw 0xd1c0, 0xc09d,	0xd1ff, 0xc09d,		0x21, 0
	.dw 0xd240, 0xc09d,	0xd27f, 0xc09d,		0x21, 0
	.dw 0xd2c0, 0xc09d,	0xd2ff, 0xc09d,		0x21, 0
	.dw 0xd340, 0xc09d,	0xd37f, 0xc09d,		0x21, 0
	.dw 0xd3c0, 0xc09d,	0xd3ff, 0xc09d,		0x21, 0
	.dw 0xd440, 0xc09d,	0xd47f, 0xc09d,		0x21, 0
	.dw 0xd4c0, 0xc09d,	0xd4ff, 0xc09d,		0x21, 0
	.dw 0xd540, 0xc09d,	0xd57f, 0xc09d,		0x21, 0
	.dw 0xd5c0, 0xc09d,	0xd5ff, 0xc09d,		0x21, 0
	.dw 0xd640, 0xc09d,	0xd67f, 0xc09d,		0x21, 0
	.dw 0xd6c0, 0xc09d,	0xd6ff, 0xc09d,		0x21, 0
	.dw 0xd740, 0xc09d,	0xd77f, 0xc09d,		0x21, 0
	.dw 0xd7c0, 0xc09d,	0xd7ff, 0xc09d,		0x21, 0
	.dw 0xd840, 0xc09d,	0xd87f, 0xc09d,		0x21, 0
	.dw 0xd8c0, 0xc09d,	0xd8ff, 0xc09d,		0x21, 0
	.dw 0xd940, 0xc09d,	0xd97f, 0xc09d,		0x21, 0
	.dw 0xd9c0, 0xc09d,	0xdfff, 0xc09d,		0x21, 0
	.dw 0xe040, 0xc09d,	0xe07f, 0xc09d,		0x21, 0
	.dw 0xe0c0, 0xc09d,	0xe0ff, 0xc09d,		0x21, 0
	.dw 0xe140, 0xc09d,	0xe17f, 0xc09d,		0x21, 0
	.dw 0xe1c0, 0xc09d,	0xe1ff, 0xc09d,		0x21, 0
	.dw 0xe240, 0xc09d,	0xe27f, 0xc09d,		0x21, 0
	.dw 0xe2c0, 0xc09d,	0xe2ff, 0xc09d,		0x21, 0
	.dw 0xe340, 0xc09d,	0xe37f, 0xc09d,		0x21, 0
	.dw 0xe3c0, 0xc09d,	0xe3ff, 0xc09d,		0x21, 0
	.dw 0xe440, 0xc09d,	0xe47f, 0xc09d,		0x21, 0
	.dw 0xe4c0, 0xc09d,	0xe4ff, 0xc09d,		0x21, 0
	.dw 0xe540, 0xc09d,	0xe57f, 0xc09d,		0x21, 0
	.dw 0xe5c0, 0xc09d,	0xe5ff, 0xc09d,		0x21, 0
	.dw 0xe640, 0xc09d,	0xe67f, 0xc09d,		0x21, 0
	.dw 0xe6c0, 0xc09d,	0xe6ff, 0xc09d,		0x21, 0
	.dw 0xe740, 0xc09d,	0xe77f, 0xc09d,		0x21, 0
	.dw 0xe7c0, 0xc09d,	0xe7ff, 0xc09d,		0x21, 0
	.dw 0xe840, 0xc09d,	0xe87f, 0xc09d,		0x21, 0
	.dw 0xe8c0, 0xc09d,	0xe8ff, 0xc09d,		0x21, 0
	.dw 0xe940, 0xc09d,	0xe97f, 0xc09d,		0x21, 0
	.dw 0xe9c0, 0xc09d,	0xe9ff, 0xc09d,		0x21, 0
	.dw 0xea40, 0xc09d,	0xea7f, 0xc09d,		0x21, 0
	.dw 0xeac0, 0xc09d,	0xeaff, 0xc09d,		0x21, 0
	.dw 0xeb40, 0xc09d,	0xeb7f, 0xc09d,		0x21, 0
	.dw 0xebc0, 0xc09d,	0xebff, 0xc09d,		0x21, 0
	.dw 0xec40, 0xc09d,	0xec7f, 0xc09d,		0x21, 0
	.dw 0xecc0, 0xc09d,	0xecff, 0xc09d,		0x21, 0
	.dw 0xed40, 0xc09d,	0xed7f, 0xc09d,		0x21, 0
	.dw 0xedc0, 0xc09d,	0xedff, 0xc09d,		0x21, 0
	.dw 0xee40, 0xc09d,	0xee7f, 0xc09d,		0x21, 0
	.dw 0xeec0, 0xc09d,	0xeeff, 0xc09d,		0x21, 0
	.dw 0xef40, 0xc09d,	0xef7f, 0xc09d,		0x21, 0
	.dw 0xefc0, 0xc09d,	0xefff, 0xc09d,		0x21, 0
	.dw 0xf040, 0xc09d,	0xf07f, 0xc09d,		0x21, 0
	.dw 0xf0c0, 0xc09d,	0xf0ff, 0xc09d,		0x21, 0
	.dw 0xf140, 0xc09d,	0xf17f, 0xc09d,		0x21, 0
	.dw 0xf1c0, 0xc09d,	0xf1ff, 0xc09d,		0x21, 0
	.dw 0xf240, 0xc09d,	0xf27f, 0xc09d,		0x21, 0
	.dw 0xf2c0, 0xc09d,	0xf2ff, 0xc09d,		0x21, 0
	.dw 0xf340, 0xc09d,	0xf37f, 0xc09d,		0x21, 0
	.dw 0xf3c0, 0xc09d,	0xf3ff, 0xc09d,		0x21, 0
	.dw 0xf440, 0xc09d,	0xf47f, 0xc09d,		0x21, 0
	.dw 0xf4c0, 0xc09d,	0xf4ff, 0xc09d,		0x21, 0
	.dw 0xf540, 0xc09d,	0xf57f, 0xc09d,		0x21, 0
	.dw 0xf5c0, 0xc09d,	0xf5ff, 0xc09d,		0x21, 0
	.dw 0xf640, 0xc09d,	0xf67f, 0xc09d,		0x21, 0
	.dw 0xf6c0, 0xc09d,	0xf6ff, 0xc09d,		0x21, 0
	.dw 0xf740, 0xc09d,	0xf77f, 0xc09d,		0x21, 0
	.dw 0xf7c0, 0xc09d,	0xf7ff, 0xc09d,		0x21, 0
	.dw 0xf840, 0xc09d,	0xf87f, 0xc09d,		0x21, 0
	.dw 0xf8c0, 0xc09d,	0xf8ff, 0xc09d,		0x21, 0
	.dw 0xf940, 0xc09d,	0xf97f, 0xc09d,		0x21, 0
	.dw 0xf9c0, 0xc09d,	0xffff, 0xc09d,		0x21, 0
	.dw 0x0040, 0xc09e,	0x007f, 0xc09e,		0x21, 0
	.dw 0x00c0, 0xc09e,	0x00ff, 0xc09e,		0x21, 0
	.dw 0x0140, 0xc09e,	0x017f, 0xc09e,		0x21, 0
	.dw 0x01c0, 0xc09e,	0x01ff, 0xc09e,		0x21, 0
	.dw 0x0240, 0xc09e,	0x027f, 0xc09e,		0x21, 0
	.dw 0x02c0, 0xc09e,	0x02ff, 0xc09e,		0x21, 0
	.dw 0x0340, 0xc09e,	0x037f, 0xc09e,		0x21, 0
	.dw 0x03c0, 0xc09e,	0x03ff, 0xc09e,		0x21, 0
	.dw 0x0440, 0xc09e,	0x047f, 0xc09e,		0x21, 0
	.dw 0x04c0, 0xc09e,	0x04ff, 0xc09e,		0x21, 0
	.dw 0x0540, 0xc09e,	0x057f, 0xc09e,		0x21, 0
	.dw 0x05c0, 0xc09e,	0x05ff, 0xc09e,		0x21, 0
	.dw 0x0640, 0xc09e,	0x067f, 0xc09e,		0x21, 0
	.dw 0x06c0, 0xc09e,	0x06ff, 0xc09e,		0x21, 0
	.dw 0x0740, 0xc09e,	0x077f, 0xc09e,		0x21, 0
	.dw 0x07c0, 0xc09e,	0x07ff, 0xc09e,		0x21, 0
	.dw 0x0840, 0xc09e,	0x087f, 0xc09e,		0x21, 0
	.dw 0x08c0, 0xc09e,	0x08ff, 0xc09e,		0x21, 0
	.dw 0x0940, 0xc09e,	0x097f, 0xc09e,		0x21, 0
	.dw 0x09c0, 0xc09e,	0x09ff, 0xc09e,		0x21, 0
	.dw 0x0a40, 0xc09e,	0x0a7f, 0xc09e,		0x21, 0
	.dw 0x0ac0, 0xc09e,	0x0aff, 0xc09e,		0x21, 0
	.dw 0x0b40, 0xc09e,	0x0b7f, 0xc09e,		0x21, 0
	.dw 0x0bc0, 0xc09e,	0x0bff, 0xc09e,		0x21, 0
	.dw 0x0c40, 0xc09e,	0x0c7f, 0xc09e,		0x21, 0
	.dw 0x0cc0, 0xc09e,	0x0cff, 0xc09e,		0x21, 0
	.dw 0x0d40, 0xc09e,	0x0d7f, 0xc09e,		0x21, 0
	.dw 0x0dc0, 0xc09e,	0x0dff, 0xc09e,		0x21, 0
	.dw 0x0e40, 0xc09e,	0x0e7f, 0xc09e,		0x21, 0
	.dw 0x0ec0, 0xc09e,	0x0eff, 0xc09e,		0x21, 0
	.dw 0x0f40, 0xc09e,	0x0f7f, 0xc09e,		0x21, 0
	.dw 0x0fc0, 0xc09e,	0x0fff, 0xc09e,		0x21, 0
	.dw 0x1040, 0xc09e,	0x107f, 0xc09e,		0x21, 0
	.dw 0x10c0, 0xc09e,	0x10ff, 0xc09e,		0x21, 0
	.dw 0x1140, 0xc09e,	0x117f, 0xc09e,		0x21, 0
	.dw 0x11c0, 0xc09e,	0x11ff, 0xc09e,		0x21, 0
	.dw 0x1240, 0xc09e,	0x127f, 0xc09e,		0x21, 0
	.dw 0x12c0, 0xc09e,	0x12ff, 0xc09e,		0x21, 0
	.dw 0x1340, 0xc09e,	0x137f, 0xc09e,		0x21, 0
	.dw 0x13c0, 0xc09e,	0x13ff, 0xc09e,		0x21, 0
	.dw 0x1440, 0xc09e,	0x147f, 0xc09e,		0x21, 0
	.dw 0x14c0, 0xc09e,	0x14ff, 0xc09e,		0x21, 0
	.dw 0x1540, 0xc09e,	0x157f, 0xc09e,		0x21, 0
	.dw 0x15c0, 0xc09e,	0x15ff, 0xc09e,		0x21, 0
	.dw 0x1640, 0xc09e,	0x167f, 0xc09e,		0x21, 0
	.dw 0x16c0, 0xc09e,	0x16ff, 0xc09e,		0x21, 0
	.dw 0x1740, 0xc09e,	0x177f, 0xc09e,		0x21, 0
	.dw 0x17c0, 0xc09e,	0x17ff, 0xc09e,		0x21, 0
	.dw 0x1840, 0xc09e,	0x187f, 0xc09e,		0x21, 0
	.dw 0x18c0, 0xc09e,	0x18ff, 0xc09e,		0x21, 0
	.dw 0x1940, 0xc09e,	0x197f, 0xc09e,		0x21, 0
	.dw 0x19c0, 0xc09e,	0x1fff, 0xc09e,		0x21, 0
	.dw 0x2040, 0xc09e,	0x207f, 0xc09e,		0x21, 0
	.dw 0x20c0, 0xc09e,	0x20ff, 0xc09e,		0x21, 0
	.dw 0x2140, 0xc09e,	0x217f, 0xc09e,		0x21, 0
	.dw 0x21c0, 0xc09e,	0x21ff, 0xc09e,		0x21, 0
	.dw 0x2240, 0xc09e,	0x227f, 0xc09e,		0x21, 0
	.dw 0x22c0, 0xc09e,	0x22ff, 0xc09e,		0x21, 0
	.dw 0x2340, 0xc09e,	0x237f, 0xc09e,		0x21, 0
	.dw 0x23c0, 0xc09e,	0x23ff, 0xc09e,		0x21, 0
	.dw 0x2440, 0xc09e,	0x247f, 0xc09e,		0x21, 0
	.dw 0x24c0, 0xc09e,	0x24ff, 0xc09e,		0x21, 0
	.dw 0x2540, 0xc09e,	0x257f, 0xc09e,		0x21, 0
	.dw 0x25c0, 0xc09e,	0x25ff, 0xc09e,		0x21, 0
	.dw 0x2640, 0xc09e,	0x267f, 0xc09e,		0x21, 0
	.dw 0x26c0, 0xc09e,	0x26ff, 0xc09e,		0x21, 0
	.dw 0x2740, 0xc09e,	0x277f, 0xc09e,		0x21, 0
	.dw 0x27c0, 0xc09e,	0x27ff, 0xc09e,		0x21, 0
	.dw 0x2840, 0xc09e,	0x287f, 0xc09e,		0x21, 0
	.dw 0x28c0, 0xc09e,	0x28ff, 0xc09e,		0x21, 0
	.dw 0x2940, 0xc09e,	0x297f, 0xc09e,		0x21, 0
	.dw 0x29c0, 0xc09e,	0x29ff, 0xc09e,		0x21, 0
	.dw 0x2a40, 0xc09e,	0x2a7f, 0xc09e,		0x21, 0
	.dw 0x2ac0, 0xc09e,	0x2aff, 0xc09e,		0x21, 0
	.dw 0x2b40, 0xc09e,	0x2b7f, 0xc09e,		0x21, 0
	.dw 0x2bc0, 0xc09e,	0x2bff, 0xc09e,		0x21, 0
	.dw 0x2c40, 0xc09e,	0x2c7f, 0xc09e,		0x21, 0
	.dw 0x2cc0, 0xc09e,	0x2cff, 0xc09e,		0x21, 0
	.dw 0x2d40, 0xc09e,	0x2d7f, 0xc09e,		0x21, 0
	.dw 0x2dc0, 0xc09e,	0x2dff, 0xc09e,		0x21, 0
	.dw 0x2e40, 0xc09e,	0x2e7f, 0xc09e,		0x21, 0
	.dw 0x2ec0, 0xc09e,	0x2eff, 0xc09e,		0x21, 0
	.dw 0x2f40, 0xc09e,	0x2f7f, 0xc09e,		0x21, 0
	.dw 0x2fc0, 0xc09e,	0x2fff, 0xc09e,		0x21, 0
	.dw 0x3040, 0xc09e,	0x307f, 0xc09e,		0x21, 0
	.dw 0x30c0, 0xc09e,	0x30ff, 0xc09e,		0x21, 0
	.dw 0x3140, 0xc09e,	0x317f, 0xc09e,		0x21, 0
	.dw 0x31c0, 0xc09e,	0x31ff, 0xc09e,		0x21, 0
	.dw 0x3240, 0xc09e,	0x327f, 0xc09e,		0x21, 0
	.dw 0x32c0, 0xc09e,	0x32ff, 0xc09e,		0x21, 0
	.dw 0x3340, 0xc09e,	0x337f, 0xc09e,		0x21, 0
	.dw 0x33c0, 0xc09e,	0x33ff, 0xc09e,		0x21, 0
	.dw 0x3440, 0xc09e,	0x347f, 0xc09e,		0x21, 0
	.dw 0x34c0, 0xc09e,	0x34ff, 0xc09e,		0x21, 0
	.dw 0x3540, 0xc09e,	0x357f, 0xc09e,		0x21, 0
	.dw 0x35c0, 0xc09e,	0x35ff, 0xc09e,		0x21, 0
	.dw 0x3640, 0xc09e,	0x367f, 0xc09e,		0x21, 0
	.dw 0x36c0, 0xc09e,	0x36ff, 0xc09e,		0x21, 0
	.dw 0x3740, 0xc09e,	0x377f, 0xc09e,		0x21, 0
	.dw 0x37c0, 0xc09e,	0x37ff, 0xc09e,		0x21, 0
	.dw 0x3840, 0xc09e,	0x387f, 0xc09e,		0x21, 0
	.dw 0x38c0, 0xc09e,	0x38ff, 0xc09e,		0x21, 0
	.dw 0x3940, 0xc09e,	0x397f, 0xc09e,		0x21, 0
	.dw 0x39c0, 0xc09e,	0x3fff, 0xc09e,		0x21, 0
	.dw 0x4040, 0xc09e,	0x407f, 0xc09e,		0x21, 0
	.dw 0x40c0, 0xc09e,	0x40ff, 0xc09e,		0x21, 0
	.dw 0x4140, 0xc09e,	0x417f, 0xc09e,		0x21, 0
	.dw 0x41c0, 0xc09e,	0x41ff, 0xc09e,		0x21, 0
	.dw 0x4240, 0xc09e,	0x427f, 0xc09e,		0x21, 0
	.dw 0x42c0, 0xc09e,	0x42ff, 0xc09e,		0x21, 0
	.dw 0x4340, 0xc09e,	0x437f, 0xc09e,		0x21, 0
	.dw 0x43c0, 0xc09e,	0x43ff, 0xc09e,		0x21, 0
	.dw 0x4440, 0xc09e,	0x447f, 0xc09e,		0x21, 0
	.dw 0x44c0, 0xc09e,	0x44ff, 0xc09e,		0x21, 0
	.dw 0x4540, 0xc09e,	0x457f, 0xc09e,		0x21, 0
	.dw 0x45c0, 0xc09e,	0x45ff, 0xc09e,		0x21, 0
	.dw 0x4640, 0xc09e,	0x467f, 0xc09e,		0x21, 0
	.dw 0x46c0, 0xc09e,	0x46ff, 0xc09e,		0x21, 0
	.dw 0x4740, 0xc09e,	0x477f, 0xc09e,		0x21, 0
	.dw 0x47c0, 0xc09e,	0x47ff, 0xc09e,		0x21, 0
	.dw 0x4840, 0xc09e,	0x487f, 0xc09e,		0x21, 0
	.dw 0x48c0, 0xc09e,	0x48ff, 0xc09e,		0x21, 0
	.dw 0x4940, 0xc09e,	0x497f, 0xc09e,		0x21, 0
	.dw 0x49c0, 0xc09e,	0x49ff, 0xc09e,		0x21, 0
	.dw 0x4a40, 0xc09e,	0x4a7f, 0xc09e,		0x21, 0
	.dw 0x4ac0, 0xc09e,	0x4aff, 0xc09e,		0x21, 0
	.dw 0x4b40, 0xc09e,	0x4b7f, 0xc09e,		0x21, 0
	.dw 0x4bc0, 0xc09e,	0x4bff, 0xc09e,		0x21, 0
	.dw 0x4c40, 0xc09e,	0x4c7f, 0xc09e,		0x21, 0
	.dw 0x4cc0, 0xc09e,	0x4cff, 0xc09e,		0x21, 0
	.dw 0x4d40, 0xc09e,	0x4d7f, 0xc09e,		0x21, 0
	.dw 0x4dc0, 0xc09e,	0x4dff, 0xc09e,		0x21, 0
	.dw 0x4e40, 0xc09e,	0x4e7f, 0xc09e,		0x21, 0
	.dw 0x4ec0, 0xc09e,	0x4eff, 0xc09e,		0x21, 0
	.dw 0x4f40, 0xc09e,	0x4f7f, 0xc09e,		0x21, 0
	.dw 0x4fc0, 0xc09e,	0x4fff, 0xc09e,		0x21, 0
	.dw 0x5040, 0xc09e,	0x507f, 0xc09e,		0x21, 0
	.dw 0x50c0, 0xc09e,	0x50ff, 0xc09e,		0x21, 0
	.dw 0x5140, 0xc09e,	0x517f, 0xc09e,		0x21, 0
	.dw 0x51c0, 0xc09e,	0x51ff, 0xc09e,		0x21, 0
	.dw 0x5240, 0xc09e,	0x527f, 0xc09e,		0x21, 0
	.dw 0x52c0, 0xc09e,	0x52ff, 0xc09e,		0x21, 0
	.dw 0x5340, 0xc09e,	0x537f, 0xc09e,		0x21, 0
	.dw 0x53c0, 0xc09e,	0x53ff, 0xc09e,		0x21, 0
	.dw 0x5440, 0xc09e,	0x547f, 0xc09e,		0x21, 0
	.dw 0x54c0, 0xc09e,	0x54ff, 0xc09e,		0x21, 0
	.dw 0x5540, 0xc09e,	0x557f, 0xc09e,		0x21, 0
	.dw 0x55c0, 0xc09e,	0x55ff, 0xc09e,		0x21, 0
	.dw 0x5640, 0xc09e,	0x567f, 0xc09e,		0x21, 0
	.dw 0x56c0, 0xc09e,	0x56ff, 0xc09e,		0x21, 0
	.dw 0x5740, 0xc09e,	0x577f, 0xc09e,		0x21, 0
	.dw 0x57c0, 0xc09e,	0x57ff, 0xc09e,		0x21, 0
	.dw 0x5840, 0xc09e,	0x587f, 0xc09e,		0x21, 0
	.dw 0x58c0, 0xc09e,	0x58ff, 0xc09e,		0x21, 0
	.dw 0x5940, 0xc09e,	0x597f, 0xc09e,		0x21, 0
	.dw 0x59c0, 0xc09e,	0x5fff, 0xc09e,		0x21, 0
	.dw 0x6040, 0xc09e,	0x607f, 0xc09e,		0x21, 0
	.dw 0x60c0, 0xc09e,	0x60ff, 0xc09e,		0x21, 0
	.dw 0x6140, 0xc09e,	0x617f, 0xc09e,		0x21, 0
	.dw 0x61c0, 0xc09e,	0x61ff, 0xc09e,		0x21, 0
	.dw 0x6240, 0xc09e,	0x627f, 0xc09e,		0x21, 0
	.dw 0x62c0, 0xc09e,	0x62ff, 0xc09e,		0x21, 0
	.dw 0x6340, 0xc09e,	0x637f, 0xc09e,		0x21, 0
	.dw 0x63c0, 0xc09e,	0x63ff, 0xc09e,		0x21, 0
	.dw 0x6440, 0xc09e,	0x647f, 0xc09e,		0x21, 0
	.dw 0x64c0, 0xc09e,	0x64ff, 0xc09e,		0x21, 0
	.dw 0x6540, 0xc09e,	0x657f, 0xc09e,		0x21, 0
	.dw 0x65c0, 0xc09e,	0x65ff, 0xc09e,		0x21, 0
	.dw 0x6640, 0xc09e,	0x667f, 0xc09e,		0x21, 0
	.dw 0x66c0, 0xc09e,	0x66ff, 0xc09e,		0x21, 0
	.dw 0x6740, 0xc09e,	0x677f, 0xc09e,		0x21, 0
	.dw 0x67c0, 0xc09e,	0x67ff, 0xc09e,		0x21, 0
	.dw 0x6840, 0xc09e,	0x687f, 0xc09e,		0x21, 0
	.dw 0x68c0, 0xc09e,	0x68ff, 0xc09e,		0x21, 0
	.dw 0x6940, 0xc09e,	0x697f, 0xc09e,		0x21, 0
	.dw 0x69c0, 0xc09e,	0x69ff, 0xc09e,		0x21, 0
	.dw 0x6a40, 0xc09e,	0x6a7f, 0xc09e,		0x21, 0
	.dw 0x6ac0, 0xc09e,	0x6aff, 0xc09e,		0x21, 0
	.dw 0x6b40, 0xc09e,	0x6b7f, 0xc09e,		0x21, 0
	.dw 0x6bc0, 0xc09e,	0x6bff, 0xc09e,		0x21, 0
	.dw 0x6c40, 0xc09e,	0x6c7f, 0xc09e,		0x21, 0
	.dw 0x6cc0, 0xc09e,	0x6cff, 0xc09e,		0x21, 0
	.dw 0x6d40, 0xc09e,	0x6d7f, 0xc09e,		0x21, 0
	.dw 0x6dc0, 0xc09e,	0x6dff, 0xc09e,		0x21, 0
	.dw 0x6e40, 0xc09e,	0x6e7f, 0xc09e,		0x21, 0
	.dw 0x6ec0, 0xc09e,	0x6eff, 0xc09e,		0x21, 0
	.dw 0x6f40, 0xc09e,	0x6f7f, 0xc09e,		0x21, 0
	.dw 0x6fc0, 0xc09e,	0x6fff, 0xc09e,		0x21, 0
	.dw 0x7040, 0xc09e,	0x707f, 0xc09e,		0x21, 0
	.dw 0x70c0, 0xc09e,	0x70ff, 0xc09e,		0x21, 0
	.dw 0x7140, 0xc09e,	0x717f, 0xc09e,		0x21, 0
	.dw 0x71c0, 0xc09e,	0x71ff, 0xc09e,		0x21, 0
	.dw 0x7240, 0xc09e,	0x727f, 0xc09e,		0x21, 0
	.dw 0x72c0, 0xc09e,	0x72ff, 0xc09e,		0x21, 0
	.dw 0x7340, 0xc09e,	0x737f, 0xc09e,		0x21, 0
	.dw 0x73c0, 0xc09e,	0x73ff, 0xc09e,		0x21, 0
	.dw 0x7440, 0xc09e,	0x747f, 0xc09e,		0x21, 0
	.dw 0x74c0, 0xc09e,	0x74ff, 0xc09e,		0x21, 0
	.dw 0x7540, 0xc09e,	0x757f, 0xc09e,		0x21, 0
	.dw 0x75c0, 0xc09e,	0x75ff, 0xc09e,		0x21, 0
	.dw 0x7640, 0xc09e,	0x767f, 0xc09e,		0x21, 0
	.dw 0x76c0, 0xc09e,	0x76ff, 0xc09e,		0x21, 0
	.dw 0x7740, 0xc09e,	0x777f, 0xc09e,		0x21, 0
	.dw 0x77c0, 0xc09e,	0x77ff, 0xc09e,		0x21, 0
	.dw 0x7840, 0xc09e,	0x787f, 0xc09e,		0x21, 0
	.dw 0x78c0, 0xc09e,	0x78ff, 0xc09e,		0x21, 0
	.dw 0x7940, 0xc09e,	0x797f, 0xc09e,		0x21, 0
	.dw 0x79c0, 0xc09e,	0x7fff, 0xc09e,		0x21, 0
	.dw 0x8040, 0xc09e,	0x807f, 0xc09e,		0x21, 0
	.dw 0x80c0, 0xc09e,	0x80ff, 0xc09e,		0x21, 0
	.dw 0x8140, 0xc09e,	0x817f, 0xc09e,		0x21, 0
	.dw 0x81c0, 0xc09e,	0x81ff, 0xc09e,		0x21, 0
	.dw 0x8240, 0xc09e,	0x827f, 0xc09e,		0x21, 0
	.dw 0x82c0, 0xc09e,	0x82ff, 0xc09e,		0x21, 0
	.dw 0x8340, 0xc09e,	0x837f, 0xc09e,		0x21, 0
	.dw 0x83c0, 0xc09e,	0x83ff, 0xc09e,		0x21, 0
	.dw 0x8440, 0xc09e,	0x847f, 0xc09e,		0x21, 0
	.dw 0x84c0, 0xc09e,	0x84ff, 0xc09e,		0x21, 0
	.dw 0x8540, 0xc09e,	0x857f, 0xc09e,		0x21, 0
	.dw 0x85c0, 0xc09e,	0x85ff, 0xc09e,		0x21, 0
	.dw 0x8640, 0xc09e,	0x867f, 0xc09e,		0x21, 0
	.dw 0x86c0, 0xc09e,	0x86ff, 0xc09e,		0x21, 0
	.dw 0x8740, 0xc09e,	0x877f, 0xc09e,		0x21, 0
	.dw 0x87c0, 0xc09e,	0x87ff, 0xc09e,		0x21, 0
	.dw 0x8840, 0xc09e,	0x887f, 0xc09e,		0x21, 0
	.dw 0x88c0, 0xc09e,	0x88ff, 0xc09e,		0x21, 0
	.dw 0x8940, 0xc09e,	0x897f, 0xc09e,		0x21, 0
	.dw 0x89c0, 0xc09e,	0x89ff, 0xc09e,		0x21, 0
	.dw 0x8a40, 0xc09e,	0x8a7f, 0xc09e,		0x21, 0
	.dw 0x8ac0, 0xc09e,	0x8aff, 0xc09e,		0x21, 0
	.dw 0x8b40, 0xc09e,	0x8b7f, 0xc09e,		0x21, 0
	.dw 0x8bc0, 0xc09e,	0x8bff, 0xc09e,		0x21, 0
	.dw 0x8c40, 0xc09e,	0x8c7f, 0xc09e,		0x21, 0
	.dw 0x8cc0, 0xc09e,	0x8cff, 0xc09e,		0x21, 0
	.dw 0x8d40, 0xc09e,	0x8d7f, 0xc09e,		0x21, 0
	.dw 0x8dc0, 0xc09e,	0x8dff, 0xc09e,		0x21, 0
	.dw 0x8e40, 0xc09e,	0x8e7f, 0xc09e,		0x21, 0
	.dw 0x8ec0, 0xc09e,	0x8eff, 0xc09e,		0x21, 0
	.dw 0x8f40, 0xc09e,	0x8f7f, 0xc09e,		0x21, 0
	.dw 0x8fc0, 0xc09e,	0x8fff, 0xc09e,		0x21, 0
	.dw 0x9040, 0xc09e,	0x907f, 0xc09e,		0x21, 0
	.dw 0x90c0, 0xc09e,	0x90ff, 0xc09e,		0x21, 0
	.dw 0x9140, 0xc09e,	0x917f, 0xc09e,		0x21, 0
	.dw 0x91c0, 0xc09e,	0x91ff, 0xc09e,		0x21, 0
	.dw 0x9240, 0xc09e,	0x927f, 0xc09e,		0x21, 0
	.dw 0x92c0, 0xc09e,	0x92ff, 0xc09e,		0x21, 0
	.dw 0x9340, 0xc09e,	0x937f, 0xc09e,		0x21, 0
	.dw 0x93c0, 0xc09e,	0x93ff, 0xc09e,		0x21, 0
	.dw 0x9440, 0xc09e,	0x947f, 0xc09e,		0x21, 0
	.dw 0x94c0, 0xc09e,	0x94ff, 0xc09e,		0x21, 0
	.dw 0x9540, 0xc09e,	0x957f, 0xc09e,		0x21, 0
	.dw 0x95c0, 0xc09e,	0x95ff, 0xc09e,		0x21, 0
	.dw 0x9640, 0xc09e,	0x967f, 0xc09e,		0x21, 0
	.dw 0x96c0, 0xc09e,	0x96ff, 0xc09e,		0x21, 0
	.dw 0x9740, 0xc09e,	0x977f, 0xc09e,		0x21, 0
	.dw 0x97c0, 0xc09e,	0x97ff, 0xc09e,		0x21, 0
	.dw 0x9840, 0xc09e,	0x987f, 0xc09e,		0x21, 0
	.dw 0x98c0, 0xc09e,	0x98ff, 0xc09e,		0x21, 0
	.dw 0x9940, 0xc09e,	0x997f, 0xc09e,		0x21, 0
	.dw 0x99c0, 0xc09e,	0x9fff, 0xc09e,		0x21, 0
	.dw 0xa040, 0xc09e,	0xa07f, 0xc09e,		0x21, 0
	.dw 0xa0c0, 0xc09e,	0xa0ff, 0xc09e,		0x21, 0
	.dw 0xa140, 0xc09e,	0xa17f, 0xc09e,		0x21, 0
	.dw 0xa1c0, 0xc09e,	0xa1ff, 0xc09e,		0x21, 0
	.dw 0xa240, 0xc09e,	0xa27f, 0xc09e,		0x21, 0
	.dw 0xa2c0, 0xc09e,	0xa2ff, 0xc09e,		0x21, 0
	.dw 0xa340, 0xc09e,	0xa37f, 0xc09e,		0x21, 0
	.dw 0xa3c0, 0xc09e,	0xa3ff, 0xc09e,		0x21, 0
	.dw 0xa440, 0xc09e,	0xa47f, 0xc09e,		0x21, 0
	.dw 0xa4c0, 0xc09e,	0xa4ff, 0xc09e,		0x21, 0
	.dw 0xa540, 0xc09e,	0xa57f, 0xc09e,		0x21, 0
	.dw 0xa5c0, 0xc09e,	0xa5ff, 0xc09e,		0x21, 0
	.dw 0xa640, 0xc09e,	0xa67f, 0xc09e,		0x21, 0
	.dw 0xa6c0, 0xc09e,	0xa6ff, 0xc09e,		0x21, 0
	.dw 0xa740, 0xc09e,	0xa77f, 0xc09e,		0x21, 0
	.dw 0xa7c0, 0xc09e,	0xa7ff, 0xc09e,		0x21, 0
	.dw 0xa840, 0xc09e,	0xa87f, 0xc09e,		0x21, 0
	.dw 0xa8c0, 0xc09e,	0xa8ff, 0xc09e,		0x21, 0
	.dw 0xa940, 0xc09e,	0xa97f, 0xc09e,		0x21, 0
	.dw 0xa9c0, 0xc09e,	0xa9ff, 0xc09e,		0x21, 0
	.dw 0xaa40, 0xc09e,	0xaa7f, 0xc09e,		0x21, 0
	.dw 0xaac0, 0xc09e,	0xaaff, 0xc09e,		0x21, 0
	.dw 0xab40, 0xc09e,	0xab7f, 0xc09e,		0x21, 0
	.dw 0xabc0, 0xc09e,	0xabff, 0xc09e,		0x21, 0
	.dw 0xac40, 0xc09e,	0xac7f, 0xc09e,		0x21, 0
	.dw 0xacc0, 0xc09e,	0xacff, 0xc09e,		0x21, 0
	.dw 0xad40, 0xc09e,	0xad7f, 0xc09e,		0x21, 0
	.dw 0xadc0, 0xc09e,	0xadff, 0xc09e,		0x21, 0
	.dw 0xae40, 0xc09e,	0xae7f, 0xc09e,		0x21, 0
	.dw 0xaec0, 0xc09e,	0xaeff, 0xc09e,		0x21, 0
	.dw 0xaf40, 0xc09e,	0xaf7f, 0xc09e,		0x21, 0
	.dw 0xafc0, 0xc09e,	0xafff, 0xc09e,		0x21, 0
	.dw 0xb040, 0xc09e,	0xb07f, 0xc09e,		0x21, 0
	.dw 0xb0c0, 0xc09e,	0xb0ff, 0xc09e,		0x21, 0
	.dw 0xb140, 0xc09e,	0xb17f, 0xc09e,		0x21, 0
	.dw 0xb1c0, 0xc09e,	0xb1ff, 0xc09e,		0x21, 0
	.dw 0xb240, 0xc09e,	0xb27f, 0xc09e,		0x21, 0
	.dw 0xb2c0, 0xc09e,	0xb2ff, 0xc09e,		0x21, 0
	.dw 0xb340, 0xc09e,	0xb37f, 0xc09e,		0x21, 0
	.dw 0xb3c0, 0xc09e,	0xb3ff, 0xc09e,		0x21, 0
	.dw 0xb440, 0xc09e,	0xb47f, 0xc09e,		0x21, 0
	.dw 0xb4c0, 0xc09e,	0xb4ff, 0xc09e,		0x21, 0
	.dw 0xb540, 0xc09e,	0xb57f, 0xc09e,		0x21, 0
	.dw 0xb5c0, 0xc09e,	0xb5ff, 0xc09e,		0x21, 0
	.dw 0xb640, 0xc09e,	0xb67f, 0xc09e,		0x21, 0
	.dw 0xb6c0, 0xc09e,	0xb6ff, 0xc09e,		0x21, 0
	.dw 0xb740, 0xc09e,	0xb77f, 0xc09e,		0x21, 0
	.dw 0xb7c0, 0xc09e,	0xb7ff, 0xc09e,		0x21, 0
	.dw 0xb840, 0xc09e,	0xb87f, 0xc09e,		0x21, 0
	.dw 0xb8c0, 0xc09e,	0xb8ff, 0xc09e,		0x21, 0
	.dw 0xb940, 0xc09e,	0xb97f, 0xc09e,		0x21, 0
	.dw 0xb9c0, 0xc09e,	0xbfff, 0xc09e,		0x21, 0
	.dw 0xc040, 0xc09e,	0xc07f, 0xc09e,		0x21, 0
	.dw 0xc0c0, 0xc09e,	0xc0ff, 0xc09e,		0x21, 0
	.dw 0xc140, 0xc09e,	0xc17f, 0xc09e,		0x21, 0
	.dw 0xc1c0, 0xc09e,	0xc1ff, 0xc09e,		0x21, 0
	.dw 0xc240, 0xc09e,	0xc27f, 0xc09e,		0x21, 0
	.dw 0xc2c0, 0xc09e,	0xc2ff, 0xc09e,		0x21, 0
	.dw 0xc340, 0xc09e,	0xc37f, 0xc09e,		0x21, 0
	.dw 0xc3c0, 0xc09e,	0xc3ff, 0xc09e,		0x21, 0
	.dw 0xc440, 0xc09e,	0xc47f, 0xc09e,		0x21, 0
	.dw 0xc4c0, 0xc09e,	0xc4ff, 0xc09e,		0x21, 0
	.dw 0xc540, 0xc09e,	0xc57f, 0xc09e,		0x21, 0
	.dw 0xc5c0, 0xc09e,	0xc5ff, 0xc09e,		0x21, 0
	.dw 0xc640, 0xc09e,	0xc67f, 0xc09e,		0x21, 0
	.dw 0xc6c0, 0xc09e,	0xc6ff, 0xc09e,		0x21, 0
	.dw 0xc740, 0xc09e,	0xc77f, 0xc09e,		0x21, 0
	.dw 0xc7c0, 0xc09e,	0xc7ff, 0xc09e,		0x21, 0
	.dw 0xc840, 0xc09e,	0xc87f, 0xc09e,		0x21, 0
	.dw 0xc8c0, 0xc09e,	0xc8ff, 0xc09e,		0x21, 0
	.dw 0xc940, 0xc09e,	0xc97f, 0xc09e,		0x21, 0
	.dw 0xc9c0, 0xc09e,	0xc9ff, 0xc09e,		0x21, 0
	.dw 0xca40, 0xc09e,	0xca7f, 0xc09e,		0x21, 0
	.dw 0xcac0, 0xc09e,	0xcaff, 0xc09e,		0x21, 0
	.dw 0xcb40, 0xc09e,	0xcb7f, 0xc09e,		0x21, 0
	.dw 0xcbc0, 0xc09e,	0xcbff, 0xc09e,		0x21, 0
	.dw 0xcc40, 0xc09e,	0xcc7f, 0xc09e,		0x21, 0
	.dw 0xccc0, 0xc09e,	0xccff, 0xc09e,		0x21, 0
	.dw 0xcd40, 0xc09e,	0xcd7f, 0xc09e,		0x21, 0
	.dw 0xcdc0, 0xc09e,	0xcdff, 0xc09e,		0x21, 0
	.dw 0xce40, 0xc09e,	0xce7f, 0xc09e,		0x21, 0
	.dw 0xcec0, 0xc09e,	0xceff, 0xc09e,		0x21, 0
	.dw 0xcf40, 0xc09e,	0xcf7f, 0xc09e,		0x21, 0
	.dw 0xcfc0, 0xc09e,	0xcfff, 0xc09e,		0x21, 0
	.dw 0xd040, 0xc09e,	0xd07f, 0xc09e,		0x21, 0
	.dw 0xd0c0, 0xc09e,	0xd0ff, 0xc09e,		0x21, 0
	.dw 0xd140, 0xc09e,	0xd17f, 0xc09e,		0x21, 0
	.dw 0xd1c0, 0xc09e,	0xd1ff, 0xc09e,		0x21, 0
	.dw 0xd240, 0xc09e,	0xd27f, 0xc09e,		0x21, 0
	.dw 0xd2c0, 0xc09e,	0xd2ff, 0xc09e,		0x21, 0
	.dw 0xd340, 0xc09e,	0xd37f, 0xc09e,		0x21, 0
	.dw 0xd3c0, 0xc09e,	0xd3ff, 0xc09e,		0x21, 0
	.dw 0xd440, 0xc09e,	0xd47f, 0xc09e,		0x21, 0
	.dw 0xd4c0, 0xc09e,	0xd4ff, 0xc09e,		0x21, 0
	.dw 0xd540, 0xc09e,	0xd57f, 0xc09e,		0x21, 0
	.dw 0xd5c0, 0xc09e,	0xd5ff, 0xc09e,		0x21, 0
	.dw 0xd640, 0xc09e,	0xd67f, 0xc09e,		0x21, 0
	.dw 0xd6c0, 0xc09e,	0xd6ff, 0xc09e,		0x21, 0
	.dw 0xd740, 0xc09e,	0xd77f, 0xc09e,		0x21, 0
	.dw 0xd7c0, 0xc09e,	0xd7ff, 0xc09e,		0x21, 0
	.dw 0xd840, 0xc09e,	0xd87f, 0xc09e,		0x21, 0
	.dw 0xd8c0, 0xc09e,	0xd8ff, 0xc09e,		0x21, 0
	.dw 0xd940, 0xc09e,	0xd97f, 0xc09e,		0x21, 0
	.dw 0xd9c0, 0xc09e,	0xdfff, 0xc09e,		0x21, 0
	.dw 0xe040, 0xc09e,	0xe07f, 0xc09e,		0x21, 0
	.dw 0xe0c0, 0xc09e,	0xe0ff, 0xc09e,		0x21, 0
	.dw 0xe140, 0xc09e,	0xe17f, 0xc09e,		0x21, 0
	.dw 0xe1c0, 0xc09e,	0xe1ff, 0xc09e,		0x21, 0
	.dw 0xe240, 0xc09e,	0xe27f, 0xc09e,		0x21, 0
	.dw 0xe2c0, 0xc09e,	0xe2ff, 0xc09e,		0x21, 0
	.dw 0xe340, 0xc09e,	0xe37f, 0xc09e,		0x21, 0
	.dw 0xe3c0, 0xc09e,	0xe3ff, 0xc09e,		0x21, 0
	.dw 0xe440, 0xc09e,	0xe47f, 0xc09e,		0x21, 0
	.dw 0xe4c0, 0xc09e,	0xe4ff, 0xc09e,		0x21, 0
	.dw 0xe540, 0xc09e,	0xe57f, 0xc09e,		0x21, 0
	.dw 0xe5c0, 0xc09e,	0xe5ff, 0xc09e,		0x21, 0
	.dw 0xe640, 0xc09e,	0xe67f, 0xc09e,		0x21, 0
	.dw 0xe6c0, 0xc09e,	0xe6ff, 0xc09e,		0x21, 0
	.dw 0xe740, 0xc09e,	0xe77f, 0xc09e,		0x21, 0
	.dw 0xe7c0, 0xc09e,	0xe7ff, 0xc09e,		0x21, 0
	.dw 0xe840, 0xc09e,	0xe87f, 0xc09e,		0x21, 0
	.dw 0xe8c0, 0xc09e,	0xe8ff, 0xc09e,		0x21, 0
	.dw 0xe940, 0xc09e,	0xe97f, 0xc09e,		0x21, 0
	.dw 0xe9c0, 0xc09e,	0xe9ff, 0xc09e,		0x21, 0
	.dw 0xea40, 0xc09e,	0xea7f, 0xc09e,		0x21, 0
	.dw 0xeac0, 0xc09e,	0xeaff, 0xc09e,		0x21, 0
	.dw 0xeb40, 0xc09e,	0xeb7f, 0xc09e,		0x21, 0
	.dw 0xebc0, 0xc09e,	0xebff, 0xc09e,		0x21, 0
	.dw 0xec40, 0xc09e,	0xec7f, 0xc09e,		0x21, 0
	.dw 0xecc0, 0xc09e,	0xecff, 0xc09e,		0x21, 0
	.dw 0xed40, 0xc09e,	0xed7f, 0xc09e,		0x21, 0
	.dw 0xedc0, 0xc09e,	0xedff, 0xc09e,		0x21, 0
	.dw 0xee40, 0xc09e,	0xee7f, 0xc09e,		0x21, 0
	.dw 0xeec0, 0xc09e,	0xeeff, 0xc09e,		0x21, 0
	.dw 0xef40, 0xc09e,	0xef7f, 0xc09e,		0x21, 0
	.dw 0xefc0, 0xc09e,	0xefff, 0xc09e,		0x21, 0
	.dw 0xf040, 0xc09e,	0xf07f, 0xc09e,		0x21, 0
	.dw 0xf0c0, 0xc09e,	0xf0ff, 0xc09e,		0x21, 0
	.dw 0xf140, 0xc09e,	0xf17f, 0xc09e,		0x21, 0
	.dw 0xf1c0, 0xc09e,	0xf1ff, 0xc09e,		0x21, 0
	.dw 0xf240, 0xc09e,	0xf27f, 0xc09e,		0x21, 0
	.dw 0xf2c0, 0xc09e,	0xf2ff, 0xc09e,		0x21, 0
	.dw 0xf340, 0xc09e,	0xf37f, 0xc09e,		0x21, 0
	.dw 0xf3c0, 0xc09e,	0xf3ff, 0xc09e,		0x21, 0
	.dw 0xf440, 0xc09e,	0xf47f, 0xc09e,		0x21, 0
	.dw 0xf4c0, 0xc09e,	0xf4ff, 0xc09e,		0x21, 0
	.dw 0xf540, 0xc09e,	0xf57f, 0xc09e,		0x21, 0
	.dw 0xf5c0, 0xc09e,	0xf5ff, 0xc09e,		0x21, 0
	.dw 0xf640, 0xc09e,	0xf67f, 0xc09e,		0x21, 0
	.dw 0xf6c0, 0xc09e,	0xf6ff, 0xc09e,		0x21, 0
	.dw 0xf740, 0xc09e,	0xf77f, 0xc09e,		0x21, 0
	.dw 0xf7c0, 0xc09e,	0xf7ff, 0xc09e,		0x21, 0
	.dw 0xf840, 0xc09e,	0xf87f, 0xc09e,		0x21, 0
	.dw 0xf8c0, 0xc09e,	0xf8ff, 0xc09e,		0x21, 0
	.dw 0xf940, 0xc09e,	0xf97f, 0xc09e,		0x21, 0
	.dw 0xf9c0, 0xc09e,	0xffff, 0xc09e,		0x21, 0
	.dw 0x0040, 0xc09f,	0x007f, 0xc09f,		0x21, 0
	.dw 0x00c0, 0xc09f,	0x00ff, 0xc09f,		0x21, 0
	.dw 0x0140, 0xc09f,	0x017f, 0xc09f,		0x21, 0
	.dw 0x01c0, 0xc09f,	0x01ff, 0xc09f,		0x21, 0
	.dw 0x0240, 0xc09f,	0x027f, 0xc09f,		0x21, 0
	.dw 0x02c0, 0xc09f,	0x02ff, 0xc09f,		0x21, 0
	.dw 0x0340, 0xc09f,	0x037f, 0xc09f,		0x21, 0
	.dw 0x03c0, 0xc09f,	0x03ff, 0xc09f,		0x21, 0
	.dw 0x0440, 0xc09f,	0x047f, 0xc09f,		0x21, 0
	.dw 0x04c0, 0xc09f,	0x04ff, 0xc09f,		0x21, 0
	.dw 0x0540, 0xc09f,	0x057f, 0xc09f,		0x21, 0
	.dw 0x05c0, 0xc09f,	0x05ff, 0xc09f,		0x21, 0
	.dw 0x0640, 0xc09f,	0x067f, 0xc09f,		0x21, 0
	.dw 0x06c0, 0xc09f,	0x06ff, 0xc09f,		0x21, 0
	.dw 0x0740, 0xc09f,	0x077f, 0xc09f,		0x21, 0
	.dw 0x07c0, 0xc09f,	0x07ff, 0xc09f,		0x21, 0
	.dw 0x0840, 0xc09f,	0x087f, 0xc09f,		0x21, 0
	.dw 0x08c0, 0xc09f,	0x08ff, 0xc09f,		0x21, 0
	.dw 0x0940, 0xc09f,	0x097f, 0xc09f,		0x21, 0
	.dw 0x09c0, 0xc09f,	0x09ff, 0xc09f,		0x21, 0
	.dw 0x0a40, 0xc09f,	0x0a7f, 0xc09f,		0x21, 0
	.dw 0x0ac0, 0xc09f,	0x0aff, 0xc09f,		0x21, 0
	.dw 0x0b40, 0xc09f,	0x0b7f, 0xc09f,		0x21, 0
	.dw 0x0bc0, 0xc09f,	0x0bff, 0xc09f,		0x21, 0
	.dw 0x0c40, 0xc09f,	0x0c7f, 0xc09f,		0x21, 0
	.dw 0x0cc0, 0xc09f,	0x0cff, 0xc09f,		0x21, 0
	.dw 0x0d40, 0xc09f,	0x0d7f, 0xc09f,		0x21, 0
	.dw 0x0dc0, 0xc09f,	0x0dff, 0xc09f,		0x21, 0
	.dw 0x0e40, 0xc09f,	0x0e7f, 0xc09f,		0x21, 0
	.dw 0x0ec0, 0xc09f,	0x0eff, 0xc09f,		0x21, 0
	.dw 0x0f40, 0xc09f,	0x0f7f, 0xc09f,		0x21, 0
	.dw 0x0fc0, 0xc09f,	0x0fff, 0xc09f,		0x21, 0
	.dw 0x1040, 0xc09f,	0x107f, 0xc09f,		0x21, 0
	.dw 0x10c0, 0xc09f,	0x10ff, 0xc09f,		0x21, 0
	.dw 0x1140, 0xc09f,	0x117f, 0xc09f,		0x21, 0
	.dw 0x11c0, 0xc09f,	0x11ff, 0xc09f,		0x21, 0
	.dw 0x1240, 0xc09f,	0x127f, 0xc09f,		0x21, 0
	.dw 0x12c0, 0xc09f,	0x12ff, 0xc09f,		0x21, 0
	.dw 0x1340, 0xc09f,	0x137f, 0xc09f,		0x21, 0
	.dw 0x13c0, 0xc09f,	0x13ff, 0xc09f,		0x21, 0
	.dw 0x1440, 0xc09f,	0x147f, 0xc09f,		0x21, 0
	.dw 0x14c0, 0xc09f,	0x14ff, 0xc09f,		0x21, 0
	.dw 0x1540, 0xc09f,	0x157f, 0xc09f,		0x21, 0
	.dw 0x15c0, 0xc09f,	0x15ff, 0xc09f,		0x21, 0
	.dw 0x1640, 0xc09f,	0x167f, 0xc09f,		0x21, 0
	.dw 0x16c0, 0xc09f,	0x16ff, 0xc09f,		0x21, 0
	.dw 0x1740, 0xc09f,	0x177f, 0xc09f,		0x21, 0
	.dw 0x17c0, 0xc09f,	0x17ff, 0xc09f,		0x21, 0
	.dw 0x1840, 0xc09f,	0x187f, 0xc09f,		0x21, 0
	.dw 0x18c0, 0xc09f,	0x18ff, 0xc09f,		0x21, 0
	.dw 0x1940, 0xc09f,	0x197f, 0xc09f,		0x21, 0
	.dw 0x19c0, 0xc09f,	0x1fff, 0xc09f,		0x21, 0
	.dw 0x2040, 0xc09f,	0x207f, 0xc09f,		0x21, 0
	.dw 0x20c0, 0xc09f,	0x20ff, 0xc09f,		0x21, 0
	.dw 0x2140, 0xc09f,	0x217f, 0xc09f,		0x21, 0
	.dw 0x21c0, 0xc09f,	0x21ff, 0xc09f,		0x21, 0
	.dw 0x2240, 0xc09f,	0x227f, 0xc09f,		0x21, 0
	.dw 0x22c0, 0xc09f,	0x22ff, 0xc09f,		0x21, 0
	.dw 0x2340, 0xc09f,	0x237f, 0xc09f,		0x21, 0
	.dw 0x23c0, 0xc09f,	0x23ff, 0xc09f,		0x21, 0
	.dw 0x2440, 0xc09f,	0x247f, 0xc09f,		0x21, 0
	.dw 0x24c0, 0xc09f,	0x24ff, 0xc09f,		0x21, 0
	.dw 0x2540, 0xc09f,	0x257f, 0xc09f,		0x21, 0
	.dw 0x25c0, 0xc09f,	0x25ff, 0xc09f,		0x21, 0
	.dw 0x2640, 0xc09f,	0x267f, 0xc09f,		0x21, 0
	.dw 0x26c0, 0xc09f,	0x26ff, 0xc09f,		0x21, 0
	.dw 0x2740, 0xc09f,	0x277f, 0xc09f,		0x21, 0
	.dw 0x27c0, 0xc09f,	0x27ff, 0xc09f,		0x21, 0
	.dw 0x2840, 0xc09f,	0x287f, 0xc09f,		0x21, 0
	.dw 0x28c0, 0xc09f,	0x28ff, 0xc09f,		0x21, 0
	.dw 0x2940, 0xc09f,	0x297f, 0xc09f,		0x21, 0
	.dw 0x29c0, 0xc09f,	0x29ff, 0xc09f,		0x21, 0
	.dw 0x2a40, 0xc09f,	0x2a7f, 0xc09f,		0x21, 0
	.dw 0x2ac0, 0xc09f,	0x2aff, 0xc09f,		0x21, 0
	.dw 0x2b40, 0xc09f,	0x2b7f, 0xc09f,		0x21, 0
	.dw 0x2bc0, 0xc09f,	0x2bff, 0xc09f,		0x21, 0
	.dw 0x2c40, 0xc09f,	0x2c7f, 0xc09f,		0x21, 0
	.dw 0x2cc0, 0xc09f,	0x2cff, 0xc09f,		0x21, 0
	.dw 0x2d40, 0xc09f,	0x2d7f, 0xc09f,		0x21, 0
	.dw 0x2dc0, 0xc09f,	0x2dff, 0xc09f,		0x21, 0
	.dw 0x2e40, 0xc09f,	0x2e7f, 0xc09f,		0x21, 0
	.dw 0x2ec0, 0xc09f,	0x2eff, 0xc09f,		0x21, 0
	.dw 0x2f40, 0xc09f,	0x2f7f, 0xc09f,		0x21, 0
	.dw 0x2fc0, 0xc09f,	0x2fff, 0xc09f,		0x21, 0
	.dw 0x3040, 0xc09f,	0x307f, 0xc09f,		0x21, 0
	.dw 0x30c0, 0xc09f,	0x30ff, 0xc09f,		0x21, 0
	.dw 0x3140, 0xc09f,	0x317f, 0xc09f,		0x21, 0
	.dw 0x31c0, 0xc09f,	0x31ff, 0xc09f,		0x21, 0
	.dw 0x3240, 0xc09f,	0x327f, 0xc09f,		0x21, 0
	.dw 0x32c0, 0xc09f,	0x32ff, 0xc09f,		0x21, 0
	.dw 0x3340, 0xc09f,	0x337f, 0xc09f,		0x21, 0
	.dw 0x33c0, 0xc09f,	0x33ff, 0xc09f,		0x21, 0
	.dw 0x3440, 0xc09f,	0x347f, 0xc09f,		0x21, 0
	.dw 0x34c0, 0xc09f,	0x34ff, 0xc09f,		0x21, 0
	.dw 0x3540, 0xc09f,	0x357f, 0xc09f,		0x21, 0
	.dw 0x35c0, 0xc09f,	0x35ff, 0xc09f,		0x21, 0
	.dw 0x3640, 0xc09f,	0x367f, 0xc09f,		0x21, 0
	.dw 0x36c0, 0xc09f,	0x36ff, 0xc09f,		0x21, 0
	.dw 0x3740, 0xc09f,	0x377f, 0xc09f,		0x21, 0
	.dw 0x37c0, 0xc09f,	0x37ff, 0xc09f,		0x21, 0
	.dw 0x3840, 0xc09f,	0x387f, 0xc09f,		0x21, 0
	.dw 0x38c0, 0xc09f,	0x38ff, 0xc09f,		0x21, 0
	.dw 0x3940, 0xc09f,	0x397f, 0xc09f,		0x21, 0
	.dw 0x39c0, 0xc09f,	0x1fff, 0xc0c0,		0x21, 0
	.dw 0x3a00, 0xc0c0,	0x5fff, 0xc0c0,		0x21, 0
	.dw 0x7a00, 0xc0c0,	0x9fff, 0xc0c0,		0x21, 0
	.dw 0xba00, 0xc0c0,	0xdfff, 0xc0c0,		0x21, 0
	.dw 0xfa00, 0xc0c0,	0x1fff, 0xc0c1,		0x21, 0
	.dw 0x3a00, 0xc0c1,	0x5fff, 0xc0c1,		0x21, 0
	.dw 0x7a00, 0xc0c1,	0x9fff, 0xc0c1,		0x21, 0
	.dw 0xba00, 0xc0c1,	0xdfff, 0xc0c1,		0x21, 0
	.dw 0xfa00, 0xc0c1,	0x1fff, 0xc0c2,		0x21, 0
	.dw 0x3a00, 0xc0c2,	0x5fff, 0xc0c2,		0x21, 0
	.dw 0x7a00, 0xc0c2,	0x9fff, 0xc0c2,		0x21, 0
	.dw 0xba00, 0xc0c2,	0xdfff, 0xc0c2,		0x21, 0
	.dw 0xfa00, 0xc0c2,	0x1fff, 0xc0c3,		0x21, 0
	.dw 0x3a00, 0xc0c3,	0xffff, 0xc0c3,		0x21, 0
	.dw 0x1a00, 0xc0c4,	0x1fff, 0xc0c4,		0x21, 0
	.dw 0x3a00, 0xc0c4,	0x3fff, 0xc0c4,		0x21, 0
	.dw 0x5a00, 0xc0c4,	0x5fff, 0xc0c4,		0x21, 0
	.dw 0x7a00, 0xc0c4,	0x7fff, 0xc0c4,		0x21, 0
	.dw 0x9a00, 0xc0c4,	0x9fff, 0xc0c4,		0x21, 0
	.dw 0xba00, 0xc0c4,	0xbfff, 0xc0c4,		0x21, 0
	.dw 0xda00, 0xc0c4,	0xdfff, 0xc0c4,		0x21, 0
	.dw 0xfa00, 0xc0c4,	0xffff, 0xc0c4,		0x21, 0
	.dw 0x1a00, 0xc0c5,	0x1fff, 0xc0c5,		0x21, 0
	.dw 0x3a00, 0xc0c5,	0x3fff, 0xc0c5,		0x21, 0
	.dw 0x5a00, 0xc0c5,	0x5fff, 0xc0c5,		0x21, 0
	.dw 0x7a00, 0xc0c5,	0x7fff, 0xc0c5,		0x21, 0
	.dw 0x9a00, 0xc0c5,	0x9fff, 0xc0c5,		0x21, 0
	.dw 0xba00, 0xc0c5,	0xbfff, 0xc0c5,		0x21, 0
	.dw 0xda00, 0xc0c5,	0xdfff, 0xc0c5,		0x21, 0
	.dw 0xfa00, 0xc0c5,	0xffff, 0xc0c5,		0x21, 0
	.dw 0x1a00, 0xc0c6,	0x1fff, 0xc0c6,		0x21, 0
	.dw 0x3a00, 0xc0c6,	0x3fff, 0xc0c6,		0x21, 0
	.dw 0x5a00, 0xc0c6,	0x5fff, 0xc0c6,		0x21, 0
	.dw 0x7a00, 0xc0c6,	0x7fff, 0xc0c6,		0x21, 0
	.dw 0x9a00, 0xc0c6,	0x9fff, 0xc0c6,		0x21, 0
	.dw 0xba00, 0xc0c6,	0xbfff, 0xc0c6,		0x21, 0
	.dw 0xda00, 0xc0c6,	0xdfff, 0xc0c6,		0x21, 0
	.dw 0xfa00, 0xc0c6,	0xffff, 0xc0c6,		0x21, 0
	.dw 0x1a00, 0xc0c7,	0x1fff, 0xc0c7,		0x21, 0
	.dw 0x3a00, 0xc0c7,	0x1fff, 0xc0d0,		0x21, 0
	.dw 0x3a00, 0xc0d0,	0x5fff, 0xc0d0,		0x21, 0
	.dw 0x7a00, 0xc0d0,	0x9fff, 0xc0d0,		0x21, 0
	.dw 0xba00, 0xc0d0,	0xdfff, 0xc0d0,		0x21, 0
	.dw 0xfa00, 0xc0d0,	0x1fff, 0xc0d1,		0x21, 0
	.dw 0x3a00, 0xc0d1,	0x5fff, 0xc0d1,		0x21, 0
	.dw 0x7a00, 0xc0d1,	0x9fff, 0xc0d1,		0x21, 0
	.dw 0xba00, 0xc0d1,	0xdfff, 0xc0d1,		0x21, 0
	.dw 0xfa00, 0xc0d1,	0x1fff, 0xc0d2,		0x21, 0
	.dw 0x3a00, 0xc0d2,	0x5fff, 0xc0d2,		0x21, 0
	.dw 0x7a00, 0xc0d2,	0x9fff, 0xc0d2,		0x21, 0
	.dw 0xba00, 0xc0d2,	0xdfff, 0xc0d2,		0x21, 0
	.dw 0xfa00, 0xc0d2,	0xffff, 0xc0d3,		0x21, 0
	.dw 0x1a00, 0xc0d4,	0x1fff, 0xc0d4,		0x21, 0
	.dw 0x3a00, 0xc0d4,	0x3fff, 0xc0d4,		0x21, 0
	.dw 0x5a00, 0xc0d4,	0x5fff, 0xc0d4,		0x21, 0
	.dw 0x7a00, 0xc0d4,	0x7fff, 0xc0d4,		0x21, 0
	.dw 0x9a00, 0xc0d4,	0x9fff, 0xc0d4,		0x21, 0
	.dw 0xba00, 0xc0d4,	0xbfff, 0xc0d4,		0x21, 0
	.dw 0xda00, 0xc0d4,	0xdfff, 0xc0d4,		0x21, 0
	.dw 0xfa00, 0xc0d4,	0xffff, 0xc0d4,		0x21, 0
	.dw 0x1a00, 0xc0d5,	0x1fff, 0xc0d5,		0x21, 0
	.dw 0x3a00, 0xc0d5,	0x3fff, 0xc0d5,		0x21, 0
	.dw 0x5a00, 0xc0d5,	0x5fff, 0xc0d5,		0x21, 0
	.dw 0x7a00, 0xc0d5,	0x7fff, 0xc0d5,		0x21, 0
	.dw 0x9a00, 0xc0d5,	0x9fff, 0xc0d5,		0x21, 0
	.dw 0xba00, 0xc0d5,	0xbfff, 0xc0d5,		0x21, 0
	.dw 0xda00, 0xc0d5,	0xdfff, 0xc0d5,		0x21, 0
	.dw 0xfa00, 0xc0d5,	0xffff, 0xc0d5,		0x21, 0
	.dw 0x1a00, 0xc0d6,	0x1fff, 0xc0d6,		0x21, 0
	.dw 0x3a00, 0xc0d6,	0x3fff, 0xc0d6,		0x21, 0
	.dw 0x5a00, 0xc0d6,	0x5fff, 0xc0d6,		0x21, 0
	.dw 0x7a00, 0xc0d6,	0x7fff, 0xc0d6,		0x21, 0
	.dw 0x9a00, 0xc0d6,	0x9fff, 0xc0d6,		0x21, 0
	.dw 0xba00, 0xc0d6,	0xbfff, 0xc0d6,		0x21, 0
	.dw 0xda00, 0xc0d6,	0xdfff, 0xc0d6,		0x21, 0
	.dw 0xfa00, 0xc0d6,	0xffff, 0xc0d6,		0x21, 0
	.dw 0x1a00, 0xc0d7,	0x1fff, 0xc0d7,		0x21, 0
	.dw 0x3a00, 0xc0d7,	0xffff, 0xc0ff,		0x21, 0
	.dw 0x1a00, 0xc100,	0x1fff, 0xc100,		0x21, 0
	.dw 0x3a00, 0xc100,	0x3fff, 0xc100,		0x21, 0
	.dw 0x5a00, 0xc100,	0x5fff, 0xc100,		0x21, 0
	.dw 0x7a00, 0xc100,	0x7fff, 0xc100,		0x21, 0
	.dw 0x9a00, 0xc100,	0x9fff, 0xc100,		0x21, 0
	.dw 0xba00, 0xc100,	0xbfff, 0xc100,		0x21, 0
	.dw 0xda00, 0xc100,	0xdfff, 0xc100,		0x21, 0
	.dw 0xfa00, 0xc100,	0xffff, 0xc100,		0x21, 0
	.dw 0x1a00, 0xc101,	0x1fff, 0xc101,		0x21, 0
	.dw 0x3a00, 0xc101,	0x3fff, 0xc101,		0x21, 0
	.dw 0x5a00, 0xc101,	0x5fff, 0xc101,		0x21, 0
	.dw 0x7a00, 0xc101,	0x7fff, 0xc101,		0x21, 0
	.dw 0x9a00, 0xc101,	0x9fff, 0xc101,		0x21, 0
	.dw 0xba00, 0xc101,	0xbfff, 0xc101,		0x21, 0
	.dw 0xda00, 0xc101,	0xdfff, 0xc101,		0x21, 0
	.dw 0xfa00, 0xc101,	0xffff, 0xc101,		0x21, 0
	.dw 0x1a00, 0xc102,	0x1fff, 0xc102,		0x21, 0
	.dw 0x3a00, 0xc102,	0x3fff, 0xc102,		0x21, 0
	.dw 0x5a00, 0xc102,	0x5fff, 0xc102,		0x21, 0
	.dw 0x7a00, 0xc102,	0x7fff, 0xc102,		0x21, 0
	.dw 0x9a00, 0xc102,	0x9fff, 0xc102,		0x21, 0
	.dw 0xba00, 0xc102,	0xbfff, 0xc102,		0x21, 0
	.dw 0xda00, 0xc102,	0xdfff, 0xc102,		0x21, 0
	.dw 0xfa00, 0xc102,	0xffff, 0xc102,		0x21, 0
	.dw 0x1a00, 0xc103,	0x1fff, 0xc103,		0x21, 0
	.dw 0x3a00, 0xc103,	0xffff, 0xc103,		0x21, 0
	.dw 0x1a00, 0xc104,	0x1fff, 0xc104,		0x21, 0
	.dw 0x3a00, 0xc104,	0x3fff, 0xc104,		0x21, 0
	.dw 0x5a00, 0xc104,	0x5fff, 0xc104,		0x21, 0
	.dw 0x7a00, 0xc104,	0x7fff, 0xc104,		0x21, 0
	.dw 0x9a00, 0xc104,	0x9fff, 0xc104,		0x21, 0
	.dw 0xba00, 0xc104,	0xbfff, 0xc104,		0x21, 0
	.dw 0xda00, 0xc104,	0xdfff, 0xc104,		0x21, 0
	.dw 0xfa00, 0xc104,	0xffff, 0xc104,		0x21, 0
	.dw 0x1a00, 0xc105,	0x1fff, 0xc105,		0x21, 0
	.dw 0x3a00, 0xc105,	0x3fff, 0xc105,		0x21, 0
	.dw 0x5a00, 0xc105,	0x5fff, 0xc105,		0x21, 0
	.dw 0x7a00, 0xc105,	0x7fff, 0xc105,		0x21, 0
	.dw 0x9a00, 0xc105,	0x9fff, 0xc105,		0x21, 0
	.dw 0xba00, 0xc105,	0xbfff, 0xc105,		0x21, 0
	.dw 0xda00, 0xc105,	0xdfff, 0xc105,		0x21, 0
	.dw 0xfa00, 0xc105,	0xffff, 0xc105,		0x21, 0
	.dw 0x1a00, 0xc106,	0x1fff, 0xc106,		0x21, 0
	.dw 0x3a00, 0xc106,	0x3fff, 0xc106,		0x21, 0
	.dw 0x5a00, 0xc106,	0x5fff, 0xc106,		0x21, 0
	.dw 0x7a00, 0xc106,	0x7fff, 0xc106,		0x21, 0
	.dw 0x9a00, 0xc106,	0x9fff, 0xc106,		0x21, 0
	.dw 0xba00, 0xc106,	0xbfff, 0xc106,		0x21, 0
	.dw 0xda00, 0xc106,	0xdfff, 0xc106,		0x21, 0
	.dw 0xfa00, 0xc106,	0xffff, 0xc106,		0x21, 0
	.dw 0x1a00, 0xc107,	0x1fff, 0xc107,		0x21, 0
	.dw 0x3a00, 0xc107,	0x1fff, 0xc108,		0x21, 0
	.dw 0x2040, 0xc108,	0x207f, 0xc108,		0x21, 0
	.dw 0x20c0, 0xc108,	0x20ff, 0xc108,		0x21, 0
	.dw 0x2140, 0xc108,	0x217f, 0xc108,		0x21, 0
	.dw 0x21c0, 0xc108,	0x21ff, 0xc108,		0x21, 0
	.dw 0x2240, 0xc108,	0x227f, 0xc108,		0x21, 0
	.dw 0x22c0, 0xc108,	0x22ff, 0xc108,		0x21, 0
	.dw 0x2340, 0xc108,	0x237f, 0xc108,		0x21, 0
	.dw 0x23c0, 0xc108,	0x23ff, 0xc108,		0x21, 0
	.dw 0x2440, 0xc108,	0x247f, 0xc108,		0x21, 0
	.dw 0x24c0, 0xc108,	0x24ff, 0xc108,		0x21, 0
	.dw 0x2540, 0xc108,	0x257f, 0xc108,		0x21, 0
	.dw 0x25c0, 0xc108,	0x25ff, 0xc108,		0x21, 0
	.dw 0x2640, 0xc108,	0x267f, 0xc108,		0x21, 0
	.dw 0x26c0, 0xc108,	0x26ff, 0xc108,		0x21, 0
	.dw 0x2740, 0xc108,	0x277f, 0xc108,		0x21, 0
	.dw 0x27c0, 0xc108,	0x27ff, 0xc108,		0x21, 0
	.dw 0x2840, 0xc108,	0x287f, 0xc108,		0x21, 0
	.dw 0x28c0, 0xc108,	0x28ff, 0xc108,		0x21, 0
	.dw 0x2940, 0xc108,	0x297f, 0xc108,		0x21, 0
	.dw 0x29c0, 0xc108,	0x29ff, 0xc108,		0x21, 0
	.dw 0x2a40, 0xc108,	0x2a7f, 0xc108,		0x21, 0
	.dw 0x2ac0, 0xc108,	0x2aff, 0xc108,		0x21, 0
	.dw 0x2b40, 0xc108,	0x2b7f, 0xc108,		0x21, 0
	.dw 0x2bc0, 0xc108,	0x2bff, 0xc108,		0x21, 0
	.dw 0x2c40, 0xc108,	0x2c7f, 0xc108,		0x21, 0
	.dw 0x2cc0, 0xc108,	0x2cff, 0xc108,		0x21, 0
	.dw 0x2d40, 0xc108,	0x2d7f, 0xc108,		0x21, 0
	.dw 0x2dc0, 0xc108,	0x2dff, 0xc108,		0x21, 0
	.dw 0x2e40, 0xc108,	0x2e7f, 0xc108,		0x21, 0
	.dw 0x2ec0, 0xc108,	0x2eff, 0xc108,		0x21, 0
	.dw 0x2f40, 0xc108,	0x2f7f, 0xc108,		0x21, 0
	.dw 0x2fc0, 0xc108,	0x2fff, 0xc108,		0x21, 0
	.dw 0x3040, 0xc108,	0x307f, 0xc108,		0x21, 0
	.dw 0x30c0, 0xc108,	0x30ff, 0xc108,		0x21, 0
	.dw 0x3140, 0xc108,	0x317f, 0xc108,		0x21, 0
	.dw 0x31c0, 0xc108,	0x31ff, 0xc108,		0x21, 0
	.dw 0x3240, 0xc108,	0x327f, 0xc108,		0x21, 0
	.dw 0x32c0, 0xc108,	0x32ff, 0xc108,		0x21, 0
	.dw 0x3340, 0xc108,	0x337f, 0xc108,		0x21, 0
	.dw 0x33c0, 0xc108,	0x33ff, 0xc108,		0x21, 0
	.dw 0x3440, 0xc108,	0x347f, 0xc108,		0x21, 0
	.dw 0x34c0, 0xc108,	0x34ff, 0xc108,		0x21, 0
	.dw 0x3540, 0xc108,	0x357f, 0xc108,		0x21, 0
	.dw 0x35c0, 0xc108,	0x35ff, 0xc108,		0x21, 0
	.dw 0x3640, 0xc108,	0x367f, 0xc108,		0x21, 0
	.dw 0x36c0, 0xc108,	0x36ff, 0xc108,		0x21, 0
	.dw 0x3740, 0xc108,	0x377f, 0xc108,		0x21, 0
	.dw 0x37c0, 0xc108,	0x37ff, 0xc108,		0x21, 0
	.dw 0x3840, 0xc108,	0x387f, 0xc108,		0x21, 0
	.dw 0x38c0, 0xc108,	0x38ff, 0xc108,		0x21, 0
	.dw 0x3940, 0xc108,	0x397f, 0xc108,		0x21, 0
	.dw 0x39c0, 0xc108,	0x5fff, 0xc108,		0x21, 0
	.dw 0x6040, 0xc108,	0x607f, 0xc108,		0x21, 0
	.dw 0x60c0, 0xc108,	0x60ff, 0xc108,		0x21, 0
	.dw 0x6140, 0xc108,	0x617f, 0xc108,		0x21, 0
	.dw 0x61c0, 0xc108,	0x61ff, 0xc108,		0x21, 0
	.dw 0x6240, 0xc108,	0x627f, 0xc108,		0x21, 0
	.dw 0x62c0, 0xc108,	0x62ff, 0xc108,		0x21, 0
	.dw 0x6340, 0xc108,	0x637f, 0xc108,		0x21, 0
	.dw 0x63c0, 0xc108,	0x63ff, 0xc108,		0x21, 0
	.dw 0x6440, 0xc108,	0x647f, 0xc108,		0x21, 0
	.dw 0x64c0, 0xc108,	0x64ff, 0xc108,		0x21, 0
	.dw 0x6540, 0xc108,	0x657f, 0xc108,		0x21, 0
	.dw 0x65c0, 0xc108,	0x65ff, 0xc108,		0x21, 0
	.dw 0x6640, 0xc108,	0x667f, 0xc108,		0x21, 0
	.dw 0x66c0, 0xc108,	0x66ff, 0xc108,		0x21, 0
	.dw 0x6740, 0xc108,	0x677f, 0xc108,		0x21, 0
	.dw 0x67c0, 0xc108,	0x67ff, 0xc108,		0x21, 0
	.dw 0x6840, 0xc108,	0x687f, 0xc108,		0x21, 0
	.dw 0x68c0, 0xc108,	0x68ff, 0xc108,		0x21, 0
	.dw 0x6940, 0xc108,	0x697f, 0xc108,		0x21, 0
	.dw 0x69c0, 0xc108,	0x69ff, 0xc108,		0x21, 0
	.dw 0x6a40, 0xc108,	0x6a7f, 0xc108,		0x21, 0
	.dw 0x6ac0, 0xc108,	0x6aff, 0xc108,		0x21, 0
	.dw 0x6b40, 0xc108,	0x6b7f, 0xc108,		0x21, 0
	.dw 0x6bc0, 0xc108,	0x6bff, 0xc108,		0x21, 0
	.dw 0x6c40, 0xc108,	0x6c7f, 0xc108,		0x21, 0
	.dw 0x6cc0, 0xc108,	0x6cff, 0xc108,		0x21, 0
	.dw 0x6d40, 0xc108,	0x6d7f, 0xc108,		0x21, 0
	.dw 0x6dc0, 0xc108,	0x6dff, 0xc108,		0x21, 0
	.dw 0x6e40, 0xc108,	0x6e7f, 0xc108,		0x21, 0
	.dw 0x6ec0, 0xc108,	0x6eff, 0xc108,		0x21, 0
	.dw 0x6f40, 0xc108,	0x6f7f, 0xc108,		0x21, 0
	.dw 0x6fc0, 0xc108,	0x6fff, 0xc108,		0x21, 0
	.dw 0x7040, 0xc108,	0x707f, 0xc108,		0x21, 0
	.dw 0x70c0, 0xc108,	0x70ff, 0xc108,		0x21, 0
	.dw 0x7140, 0xc108,	0x717f, 0xc108,		0x21, 0
	.dw 0x71c0, 0xc108,	0x71ff, 0xc108,		0x21, 0
	.dw 0x7240, 0xc108,	0x727f, 0xc108,		0x21, 0
	.dw 0x72c0, 0xc108,	0x72ff, 0xc108,		0x21, 0
	.dw 0x7340, 0xc108,	0x737f, 0xc108,		0x21, 0
	.dw 0x73c0, 0xc108,	0x73ff, 0xc108,		0x21, 0
	.dw 0x7440, 0xc108,	0x747f, 0xc108,		0x21, 0
	.dw 0x74c0, 0xc108,	0x74ff, 0xc108,		0x21, 0
	.dw 0x7540, 0xc108,	0x757f, 0xc108,		0x21, 0
	.dw 0x75c0, 0xc108,	0x75ff, 0xc108,		0x21, 0
	.dw 0x7640, 0xc108,	0x767f, 0xc108,		0x21, 0
	.dw 0x76c0, 0xc108,	0x76ff, 0xc108,		0x21, 0
	.dw 0x7740, 0xc108,	0x777f, 0xc108,		0x21, 0
	.dw 0x77c0, 0xc108,	0x77ff, 0xc108,		0x21, 0
	.dw 0x7840, 0xc108,	0x787f, 0xc108,		0x21, 0
	.dw 0x78c0, 0xc108,	0x78ff, 0xc108,		0x21, 0
	.dw 0x7940, 0xc108,	0x797f, 0xc108,		0x21, 0
	.dw 0x79c0, 0xc108,	0x9fff, 0xc108,		0x21, 0
	.dw 0xa040, 0xc108,	0xa07f, 0xc108,		0x21, 0
	.dw 0xa0c0, 0xc108,	0xa0ff, 0xc108,		0x21, 0
	.dw 0xa140, 0xc108,	0xa17f, 0xc108,		0x21, 0
	.dw 0xa1c0, 0xc108,	0xa1ff, 0xc108,		0x21, 0
	.dw 0xa240, 0xc108,	0xa27f, 0xc108,		0x21, 0
	.dw 0xa2c0, 0xc108,	0xa2ff, 0xc108,		0x21, 0
	.dw 0xa340, 0xc108,	0xa37f, 0xc108,		0x21, 0
	.dw 0xa3c0, 0xc108,	0xa3ff, 0xc108,		0x21, 0
	.dw 0xa440, 0xc108,	0xa47f, 0xc108,		0x21, 0
	.dw 0xa4c0, 0xc108,	0xa4ff, 0xc108,		0x21, 0
	.dw 0xa540, 0xc108,	0xa57f, 0xc108,		0x21, 0
	.dw 0xa5c0, 0xc108,	0xa5ff, 0xc108,		0x21, 0
	.dw 0xa640, 0xc108,	0xa67f, 0xc108,		0x21, 0
	.dw 0xa6c0, 0xc108,	0xa6ff, 0xc108,		0x21, 0
	.dw 0xa740, 0xc108,	0xa77f, 0xc108,		0x21, 0
	.dw 0xa7c0, 0xc108,	0xa7ff, 0xc108,		0x21, 0
	.dw 0xa840, 0xc108,	0xa87f, 0xc108,		0x21, 0
	.dw 0xa8c0, 0xc108,	0xa8ff, 0xc108,		0x21, 0
	.dw 0xa940, 0xc108,	0xa97f, 0xc108,		0x21, 0
	.dw 0xa9c0, 0xc108,	0xa9ff, 0xc108,		0x21, 0
	.dw 0xaa40, 0xc108,	0xaa7f, 0xc108,		0x21, 0
	.dw 0xaac0, 0xc108,	0xaaff, 0xc108,		0x21, 0
	.dw 0xab40, 0xc108,	0xab7f, 0xc108,		0x21, 0
	.dw 0xabc0, 0xc108,	0xabff, 0xc108,		0x21, 0
	.dw 0xac40, 0xc108,	0xac7f, 0xc108,		0x21, 0
	.dw 0xacc0, 0xc108,	0xacff, 0xc108,		0x21, 0
	.dw 0xad40, 0xc108,	0xad7f, 0xc108,		0x21, 0
	.dw 0xadc0, 0xc108,	0xadff, 0xc108,		0x21, 0
	.dw 0xae40, 0xc108,	0xae7f, 0xc108,		0x21, 0
	.dw 0xaec0, 0xc108,	0xaeff, 0xc108,		0x21, 0
	.dw 0xaf40, 0xc108,	0xaf7f, 0xc108,		0x21, 0
	.dw 0xafc0, 0xc108,	0xafff, 0xc108,		0x21, 0
	.dw 0xb040, 0xc108,	0xb07f, 0xc108,		0x21, 0
	.dw 0xb0c0, 0xc108,	0xb0ff, 0xc108,		0x21, 0
	.dw 0xb140, 0xc108,	0xb17f, 0xc108,		0x21, 0
	.dw 0xb1c0, 0xc108,	0xb1ff, 0xc108,		0x21, 0
	.dw 0xb240, 0xc108,	0xb27f, 0xc108,		0x21, 0
	.dw 0xb2c0, 0xc108,	0xb2ff, 0xc108,		0x21, 0
	.dw 0xb340, 0xc108,	0xb37f, 0xc108,		0x21, 0
	.dw 0xb3c0, 0xc108,	0xb3ff, 0xc108,		0x21, 0
	.dw 0xb440, 0xc108,	0xb47f, 0xc108,		0x21, 0
	.dw 0xb4c0, 0xc108,	0xb4ff, 0xc108,		0x21, 0
	.dw 0xb540, 0xc108,	0xb57f, 0xc108,		0x21, 0
	.dw 0xb5c0, 0xc108,	0xb5ff, 0xc108,		0x21, 0
	.dw 0xb640, 0xc108,	0xb67f, 0xc108,		0x21, 0
	.dw 0xb6c0, 0xc108,	0xb6ff, 0xc108,		0x21, 0
	.dw 0xb740, 0xc108,	0xb77f, 0xc108,		0x21, 0
	.dw 0xb7c0, 0xc108,	0xb7ff, 0xc108,		0x21, 0
	.dw 0xb840, 0xc108,	0xb87f, 0xc108,		0x21, 0
	.dw 0xb8c0, 0xc108,	0xb8ff, 0xc108,		0x21, 0
	.dw 0xb940, 0xc108,	0xb97f, 0xc108,		0x21, 0
	.dw 0xb9c0, 0xc108,	0xdfff, 0xc108,		0x21, 0
	.dw 0xe040, 0xc108,	0xe07f, 0xc108,		0x21, 0
	.dw 0xe0c0, 0xc108,	0xe0ff, 0xc108,		0x21, 0
	.dw 0xe140, 0xc108,	0xe17f, 0xc108,		0x21, 0
	.dw 0xe1c0, 0xc108,	0xe1ff, 0xc108,		0x21, 0
	.dw 0xe240, 0xc108,	0xe27f, 0xc108,		0x21, 0
	.dw 0xe2c0, 0xc108,	0xe2ff, 0xc108,		0x21, 0
	.dw 0xe340, 0xc108,	0xe37f, 0xc108,		0x21, 0
	.dw 0xe3c0, 0xc108,	0xe3ff, 0xc108,		0x21, 0
	.dw 0xe440, 0xc108,	0xe47f, 0xc108,		0x21, 0
	.dw 0xe4c0, 0xc108,	0xe4ff, 0xc108,		0x21, 0
	.dw 0xe540, 0xc108,	0xe57f, 0xc108,		0x21, 0
	.dw 0xe5c0, 0xc108,	0xe5ff, 0xc108,		0x21, 0
	.dw 0xe640, 0xc108,	0xe67f, 0xc108,		0x21, 0
	.dw 0xe6c0, 0xc108,	0xe6ff, 0xc108,		0x21, 0
	.dw 0xe740, 0xc108,	0xe77f, 0xc108,		0x21, 0
	.dw 0xe7c0, 0xc108,	0xe7ff, 0xc108,		0x21, 0
	.dw 0xe840, 0xc108,	0xe87f, 0xc108,		0x21, 0
	.dw 0xe8c0, 0xc108,	0xe8ff, 0xc108,		0x21, 0
	.dw 0xe940, 0xc108,	0xe97f, 0xc108,		0x21, 0
	.dw 0xe9c0, 0xc108,	0xe9ff, 0xc108,		0x21, 0
	.dw 0xea40, 0xc108,	0xea7f, 0xc108,		0x21, 0
	.dw 0xeac0, 0xc108,	0xeaff, 0xc108,		0x21, 0
	.dw 0xeb40, 0xc108,	0xeb7f, 0xc108,		0x21, 0
	.dw 0xebc0, 0xc108,	0xebff, 0xc108,		0x21, 0
	.dw 0xec40, 0xc108,	0xec7f, 0xc108,		0x21, 0
	.dw 0xecc0, 0xc108,	0xecff, 0xc108,		0x21, 0
	.dw 0xed40, 0xc108,	0xed7f, 0xc108,		0x21, 0
	.dw 0xedc0, 0xc108,	0xedff, 0xc108,		0x21, 0
	.dw 0xee40, 0xc108,	0xee7f, 0xc108,		0x21, 0
	.dw 0xeec0, 0xc108,	0xeeff, 0xc108,		0x21, 0
	.dw 0xef40, 0xc108,	0xef7f, 0xc108,		0x21, 0
	.dw 0xefc0, 0xc108,	0xefff, 0xc108,		0x21, 0
	.dw 0xf040, 0xc108,	0xf07f, 0xc108,		0x21, 0
	.dw 0xf0c0, 0xc108,	0xf0ff, 0xc108,		0x21, 0
	.dw 0xf140, 0xc108,	0xf17f, 0xc108,		0x21, 0
	.dw 0xf1c0, 0xc108,	0xf1ff, 0xc108,		0x21, 0
	.dw 0xf240, 0xc108,	0xf27f, 0xc108,		0x21, 0
	.dw 0xf2c0, 0xc108,	0xf2ff, 0xc108,		0x21, 0
	.dw 0xf340, 0xc108,	0xf37f, 0xc108,		0x21, 0
	.dw 0xf3c0, 0xc108,	0xf3ff, 0xc108,		0x21, 0
	.dw 0xf440, 0xc108,	0xf47f, 0xc108,		0x21, 0
	.dw 0xf4c0, 0xc108,	0xf4ff, 0xc108,		0x21, 0
	.dw 0xf540, 0xc108,	0xf57f, 0xc108,		0x21, 0
	.dw 0xf5c0, 0xc108,	0xf5ff, 0xc108,		0x21, 0
	.dw 0xf640, 0xc108,	0xf67f, 0xc108,		0x21, 0
	.dw 0xf6c0, 0xc108,	0xf6ff, 0xc108,		0x21, 0
	.dw 0xf740, 0xc108,	0xf77f, 0xc108,		0x21, 0
	.dw 0xf7c0, 0xc108,	0xf7ff, 0xc108,		0x21, 0
	.dw 0xf840, 0xc108,	0xf87f, 0xc108,		0x21, 0
	.dw 0xf8c0, 0xc108,	0xf8ff, 0xc108,		0x21, 0
	.dw 0xf940, 0xc108,	0xf97f, 0xc108,		0x21, 0
	.dw 0xf9c0, 0xc108,	0x1fff, 0xc109,		0x21, 0
	.dw 0x2040, 0xc109,	0x207f, 0xc109,		0x21, 0
	.dw 0x20c0, 0xc109,	0x20ff, 0xc109,		0x21, 0
	.dw 0x2140, 0xc109,	0x217f, 0xc109,		0x21, 0
	.dw 0x21c0, 0xc109,	0x21ff, 0xc109,		0x21, 0
	.dw 0x2240, 0xc109,	0x227f, 0xc109,		0x21, 0
	.dw 0x22c0, 0xc109,	0x22ff, 0xc109,		0x21, 0
	.dw 0x2340, 0xc109,	0x237f, 0xc109,		0x21, 0
	.dw 0x23c0, 0xc109,	0x23ff, 0xc109,		0x21, 0
	.dw 0x2440, 0xc109,	0x247f, 0xc109,		0x21, 0
	.dw 0x24c0, 0xc109,	0x24ff, 0xc109,		0x21, 0
	.dw 0x2540, 0xc109,	0x257f, 0xc109,		0x21, 0
	.dw 0x25c0, 0xc109,	0x25ff, 0xc109,		0x21, 0
	.dw 0x2640, 0xc109,	0x267f, 0xc109,		0x21, 0
	.dw 0x26c0, 0xc109,	0x26ff, 0xc109,		0x21, 0
	.dw 0x2740, 0xc109,	0x277f, 0xc109,		0x21, 0
	.dw 0x27c0, 0xc109,	0x27ff, 0xc109,		0x21, 0
	.dw 0x2840, 0xc109,	0x287f, 0xc109,		0x21, 0
	.dw 0x28c0, 0xc109,	0x28ff, 0xc109,		0x21, 0
	.dw 0x2940, 0xc109,	0x297f, 0xc109,		0x21, 0
	.dw 0x29c0, 0xc109,	0x29ff, 0xc109,		0x21, 0
	.dw 0x2a40, 0xc109,	0x2a7f, 0xc109,		0x21, 0
	.dw 0x2ac0, 0xc109,	0x2aff, 0xc109,		0x21, 0
	.dw 0x2b40, 0xc109,	0x2b7f, 0xc109,		0x21, 0
	.dw 0x2bc0, 0xc109,	0x2bff, 0xc109,		0x21, 0
	.dw 0x2c40, 0xc109,	0x2c7f, 0xc109,		0x21, 0
	.dw 0x2cc0, 0xc109,	0x2cff, 0xc109,		0x21, 0
	.dw 0x2d40, 0xc109,	0x2d7f, 0xc109,		0x21, 0
	.dw 0x2dc0, 0xc109,	0x2dff, 0xc109,		0x21, 0
	.dw 0x2e40, 0xc109,	0x2e7f, 0xc109,		0x21, 0
	.dw 0x2ec0, 0xc109,	0x2eff, 0xc109,		0x21, 0
	.dw 0x2f40, 0xc109,	0x2f7f, 0xc109,		0x21, 0
	.dw 0x2fc0, 0xc109,	0x2fff, 0xc109,		0x21, 0
	.dw 0x3040, 0xc109,	0x307f, 0xc109,		0x21, 0
	.dw 0x30c0, 0xc109,	0x30ff, 0xc109,		0x21, 0
	.dw 0x3140, 0xc109,	0x317f, 0xc109,		0x21, 0
	.dw 0x31c0, 0xc109,	0x31ff, 0xc109,		0x21, 0
	.dw 0x3240, 0xc109,	0x327f, 0xc109,		0x21, 0
	.dw 0x32c0, 0xc109,	0x32ff, 0xc109,		0x21, 0
	.dw 0x3340, 0xc109,	0x337f, 0xc109,		0x21, 0
	.dw 0x33c0, 0xc109,	0x33ff, 0xc109,		0x21, 0
	.dw 0x3440, 0xc109,	0x347f, 0xc109,		0x21, 0
	.dw 0x34c0, 0xc109,	0x34ff, 0xc109,		0x21, 0
	.dw 0x3540, 0xc109,	0x357f, 0xc109,		0x21, 0
	.dw 0x35c0, 0xc109,	0x35ff, 0xc109,		0x21, 0
	.dw 0x3640, 0xc109,	0x367f, 0xc109,		0x21, 0
	.dw 0x36c0, 0xc109,	0x36ff, 0xc109,		0x21, 0
	.dw 0x3740, 0xc109,	0x377f, 0xc109,		0x21, 0
	.dw 0x37c0, 0xc109,	0x37ff, 0xc109,		0x21, 0
	.dw 0x3840, 0xc109,	0x387f, 0xc109,		0x21, 0
	.dw 0x38c0, 0xc109,	0x38ff, 0xc109,		0x21, 0
	.dw 0x3940, 0xc109,	0x397f, 0xc109,		0x21, 0
	.dw 0x39c0, 0xc109,	0x5fff, 0xc109,		0x21, 0
	.dw 0x6040, 0xc109,	0x607f, 0xc109,		0x21, 0
	.dw 0x60c0, 0xc109,	0x60ff, 0xc109,		0x21, 0
	.dw 0x6140, 0xc109,	0x617f, 0xc109,		0x21, 0
	.dw 0x61c0, 0xc109,	0x61ff, 0xc109,		0x21, 0
	.dw 0x6240, 0xc109,	0x627f, 0xc109,		0x21, 0
	.dw 0x62c0, 0xc109,	0x62ff, 0xc109,		0x21, 0
	.dw 0x6340, 0xc109,	0x637f, 0xc109,		0x21, 0
	.dw 0x63c0, 0xc109,	0x63ff, 0xc109,		0x21, 0
	.dw 0x6440, 0xc109,	0x647f, 0xc109,		0x21, 0
	.dw 0x64c0, 0xc109,	0x64ff, 0xc109,		0x21, 0
	.dw 0x6540, 0xc109,	0x657f, 0xc109,		0x21, 0
	.dw 0x65c0, 0xc109,	0x65ff, 0xc109,		0x21, 0
	.dw 0x6640, 0xc109,	0x667f, 0xc109,		0x21, 0
	.dw 0x66c0, 0xc109,	0x66ff, 0xc109,		0x21, 0
	.dw 0x6740, 0xc109,	0x677f, 0xc109,		0x21, 0
	.dw 0x67c0, 0xc109,	0x67ff, 0xc109,		0x21, 0
	.dw 0x6840, 0xc109,	0x687f, 0xc109,		0x21, 0
	.dw 0x68c0, 0xc109,	0x68ff, 0xc109,		0x21, 0
	.dw 0x6940, 0xc109,	0x697f, 0xc109,		0x21, 0
	.dw 0x69c0, 0xc109,	0x69ff, 0xc109,		0x21, 0
	.dw 0x6a40, 0xc109,	0x6a7f, 0xc109,		0x21, 0
	.dw 0x6ac0, 0xc109,	0x6aff, 0xc109,		0x21, 0
	.dw 0x6b40, 0xc109,	0x6b7f, 0xc109,		0x21, 0
	.dw 0x6bc0, 0xc109,	0x6bff, 0xc109,		0x21, 0
	.dw 0x6c40, 0xc109,	0x6c7f, 0xc109,		0x21, 0
	.dw 0x6cc0, 0xc109,	0x6cff, 0xc109,		0x21, 0
	.dw 0x6d40, 0xc109,	0x6d7f, 0xc109,		0x21, 0
	.dw 0x6dc0, 0xc109,	0x6dff, 0xc109,		0x21, 0
	.dw 0x6e40, 0xc109,	0x6e7f, 0xc109,		0x21, 0
	.dw 0x6ec0, 0xc109,	0x6eff, 0xc109,		0x21, 0
	.dw 0x6f40, 0xc109,	0x6f7f, 0xc109,		0x21, 0
	.dw 0x6fc0, 0xc109,	0x6fff, 0xc109,		0x21, 0
	.dw 0x7040, 0xc109,	0x707f, 0xc109,		0x21, 0
	.dw 0x70c0, 0xc109,	0x70ff, 0xc109,		0x21, 0
	.dw 0x7140, 0xc109,	0x717f, 0xc109,		0x21, 0
	.dw 0x71c0, 0xc109,	0x71ff, 0xc109,		0x21, 0
	.dw 0x7240, 0xc109,	0x727f, 0xc109,		0x21, 0
	.dw 0x72c0, 0xc109,	0x72ff, 0xc109,		0x21, 0
	.dw 0x7340, 0xc109,	0x737f, 0xc109,		0x21, 0
	.dw 0x73c0, 0xc109,	0x73ff, 0xc109,		0x21, 0
	.dw 0x7440, 0xc109,	0x747f, 0xc109,		0x21, 0
	.dw 0x74c0, 0xc109,	0x74ff, 0xc109,		0x21, 0
	.dw 0x7540, 0xc109,	0x757f, 0xc109,		0x21, 0
	.dw 0x75c0, 0xc109,	0x75ff, 0xc109,		0x21, 0
	.dw 0x7640, 0xc109,	0x767f, 0xc109,		0x21, 0
	.dw 0x76c0, 0xc109,	0x76ff, 0xc109,		0x21, 0
	.dw 0x7740, 0xc109,	0x777f, 0xc109,		0x21, 0
	.dw 0x77c0, 0xc109,	0x77ff, 0xc109,		0x21, 0
	.dw 0x7840, 0xc109,	0x787f, 0xc109,		0x21, 0
	.dw 0x78c0, 0xc109,	0x78ff, 0xc109,		0x21, 0
	.dw 0x7940, 0xc109,	0x797f, 0xc109,		0x21, 0
	.dw 0x79c0, 0xc109,	0x9fff, 0xc109,		0x21, 0
	.dw 0xa040, 0xc109,	0xa07f, 0xc109,		0x21, 0
	.dw 0xa0c0, 0xc109,	0xa0ff, 0xc109,		0x21, 0
	.dw 0xa140, 0xc109,	0xa17f, 0xc109,		0x21, 0
	.dw 0xa1c0, 0xc109,	0xa1ff, 0xc109,		0x21, 0
	.dw 0xa240, 0xc109,	0xa27f, 0xc109,		0x21, 0
	.dw 0xa2c0, 0xc109,	0xa2ff, 0xc109,		0x21, 0
	.dw 0xa340, 0xc109,	0xa37f, 0xc109,		0x21, 0
	.dw 0xa3c0, 0xc109,	0xa3ff, 0xc109,		0x21, 0
	.dw 0xa440, 0xc109,	0xa47f, 0xc109,		0x21, 0
	.dw 0xa4c0, 0xc109,	0xa4ff, 0xc109,		0x21, 0
	.dw 0xa540, 0xc109,	0xa57f, 0xc109,		0x21, 0
	.dw 0xa5c0, 0xc109,	0xa5ff, 0xc109,		0x21, 0
	.dw 0xa640, 0xc109,	0xa67f, 0xc109,		0x21, 0
	.dw 0xa6c0, 0xc109,	0xa6ff, 0xc109,		0x21, 0
	.dw 0xa740, 0xc109,	0xa77f, 0xc109,		0x21, 0
	.dw 0xa7c0, 0xc109,	0xa7ff, 0xc109,		0x21, 0
	.dw 0xa840, 0xc109,	0xa87f, 0xc109,		0x21, 0
	.dw 0xa8c0, 0xc109,	0xa8ff, 0xc109,		0x21, 0
	.dw 0xa940, 0xc109,	0xa97f, 0xc109,		0x21, 0
	.dw 0xa9c0, 0xc109,	0xa9ff, 0xc109,		0x21, 0
	.dw 0xaa40, 0xc109,	0xaa7f, 0xc109,		0x21, 0
	.dw 0xaac0, 0xc109,	0xaaff, 0xc109,		0x21, 0
	.dw 0xab40, 0xc109,	0xab7f, 0xc109,		0x21, 0
	.dw 0xabc0, 0xc109,	0xabff, 0xc109,		0x21, 0
	.dw 0xac40, 0xc109,	0xac7f, 0xc109,		0x21, 0
	.dw 0xacc0, 0xc109,	0xacff, 0xc109,		0x21, 0
	.dw 0xad40, 0xc109,	0xad7f, 0xc109,		0x21, 0
	.dw 0xadc0, 0xc109,	0xadff, 0xc109,		0x21, 0
	.dw 0xae40, 0xc109,	0xae7f, 0xc109,		0x21, 0
	.dw 0xaec0, 0xc109,	0xaeff, 0xc109,		0x21, 0
	.dw 0xaf40, 0xc109,	0xaf7f, 0xc109,		0x21, 0
	.dw 0xafc0, 0xc109,	0xafff, 0xc109,		0x21, 0
	.dw 0xb040, 0xc109,	0xb07f, 0xc109,		0x21, 0
	.dw 0xb0c0, 0xc109,	0xb0ff, 0xc109,		0x21, 0
	.dw 0xb140, 0xc109,	0xb17f, 0xc109,		0x21, 0
	.dw 0xb1c0, 0xc109,	0xb1ff, 0xc109,		0x21, 0
	.dw 0xb240, 0xc109,	0xb27f, 0xc109,		0x21, 0
	.dw 0xb2c0, 0xc109,	0xb2ff, 0xc109,		0x21, 0
	.dw 0xb340, 0xc109,	0xb37f, 0xc109,		0x21, 0
	.dw 0xb3c0, 0xc109,	0xb3ff, 0xc109,		0x21, 0
	.dw 0xb440, 0xc109,	0xb47f, 0xc109,		0x21, 0
	.dw 0xb4c0, 0xc109,	0xb4ff, 0xc109,		0x21, 0
	.dw 0xb540, 0xc109,	0xb57f, 0xc109,		0x21, 0
	.dw 0xb5c0, 0xc109,	0xb5ff, 0xc109,		0x21, 0
	.dw 0xb640, 0xc109,	0xb67f, 0xc109,		0x21, 0
	.dw 0xb6c0, 0xc109,	0xb6ff, 0xc109,		0x21, 0
	.dw 0xb740, 0xc109,	0xb77f, 0xc109,		0x21, 0
	.dw 0xb7c0, 0xc109,	0xb7ff, 0xc109,		0x21, 0
	.dw 0xb840, 0xc109,	0xb87f, 0xc109,		0x21, 0
	.dw 0xb8c0, 0xc109,	0xb8ff, 0xc109,		0x21, 0
	.dw 0xb940, 0xc109,	0xb97f, 0xc109,		0x21, 0
	.dw 0xb9c0, 0xc109,	0xdfff, 0xc109,		0x21, 0
	.dw 0xe040, 0xc109,	0xe07f, 0xc109,		0x21, 0
	.dw 0xe0c0, 0xc109,	0xe0ff, 0xc109,		0x21, 0
	.dw 0xe140, 0xc109,	0xe17f, 0xc109,		0x21, 0
	.dw 0xe1c0, 0xc109,	0xe1ff, 0xc109,		0x21, 0
	.dw 0xe240, 0xc109,	0xe27f, 0xc109,		0x21, 0
	.dw 0xe2c0, 0xc109,	0xe2ff, 0xc109,		0x21, 0
	.dw 0xe340, 0xc109,	0xe37f, 0xc109,		0x21, 0
	.dw 0xe3c0, 0xc109,	0xe3ff, 0xc109,		0x21, 0
	.dw 0xe440, 0xc109,	0xe47f, 0xc109,		0x21, 0
	.dw 0xe4c0, 0xc109,	0xe4ff, 0xc109,		0x21, 0
	.dw 0xe540, 0xc109,	0xe57f, 0xc109,		0x21, 0
	.dw 0xe5c0, 0xc109,	0xe5ff, 0xc109,		0x21, 0
	.dw 0xe640, 0xc109,	0xe67f, 0xc109,		0x21, 0
	.dw 0xe6c0, 0xc109,	0xe6ff, 0xc109,		0x21, 0
	.dw 0xe740, 0xc109,	0xe77f, 0xc109,		0x21, 0
	.dw 0xe7c0, 0xc109,	0xe7ff, 0xc109,		0x21, 0
	.dw 0xe840, 0xc109,	0xe87f, 0xc109,		0x21, 0
	.dw 0xe8c0, 0xc109,	0xe8ff, 0xc109,		0x21, 0
	.dw 0xe940, 0xc109,	0xe97f, 0xc109,		0x21, 0
	.dw 0xe9c0, 0xc109,	0xe9ff, 0xc109,		0x21, 0
	.dw 0xea40, 0xc109,	0xea7f, 0xc109,		0x21, 0
	.dw 0xeac0, 0xc109,	0xeaff, 0xc109,		0x21, 0
	.dw 0xeb40, 0xc109,	0xeb7f, 0xc109,		0x21, 0
	.dw 0xebc0, 0xc109,	0xebff, 0xc109,		0x21, 0
	.dw 0xec40, 0xc109,	0xec7f, 0xc109,		0x21, 0
	.dw 0xecc0, 0xc109,	0xecff, 0xc109,		0x21, 0
	.dw 0xed40, 0xc109,	0xed7f, 0xc109,		0x21, 0
	.dw 0xedc0, 0xc109,	0xedff, 0xc109,		0x21, 0
	.dw 0xee40, 0xc109,	0xee7f, 0xc109,		0x21, 0
	.dw 0xeec0, 0xc109,	0xeeff, 0xc109,		0x21, 0
	.dw 0xef40, 0xc109,	0xef7f, 0xc109,		0x21, 0
	.dw 0xefc0, 0xc109,	0xefff, 0xc109,		0x21, 0
	.dw 0xf040, 0xc109,	0xf07f, 0xc109,		0x21, 0
	.dw 0xf0c0, 0xc109,	0xf0ff, 0xc109,		0x21, 0
	.dw 0xf140, 0xc109,	0xf17f, 0xc109,		0x21, 0
	.dw 0xf1c0, 0xc109,	0xf1ff, 0xc109,		0x21, 0
	.dw 0xf240, 0xc109,	0xf27f, 0xc109,		0x21, 0
	.dw 0xf2c0, 0xc109,	0xf2ff, 0xc109,		0x21, 0
	.dw 0xf340, 0xc109,	0xf37f, 0xc109,		0x21, 0
	.dw 0xf3c0, 0xc109,	0xf3ff, 0xc109,		0x21, 0
	.dw 0xf440, 0xc109,	0xf47f, 0xc109,		0x21, 0
	.dw 0xf4c0, 0xc109,	0xf4ff, 0xc109,		0x21, 0
	.dw 0xf540, 0xc109,	0xf57f, 0xc109,		0x21, 0
	.dw 0xf5c0, 0xc109,	0xf5ff, 0xc109,		0x21, 0
	.dw 0xf640, 0xc109,	0xf67f, 0xc109,		0x21, 0
	.dw 0xf6c0, 0xc109,	0xf6ff, 0xc109,		0x21, 0
	.dw 0xf740, 0xc109,	0xf77f, 0xc109,		0x21, 0
	.dw 0xf7c0, 0xc109,	0xf7ff, 0xc109,		0x21, 0
	.dw 0xf840, 0xc109,	0xf87f, 0xc109,		0x21, 0
	.dw 0xf8c0, 0xc109,	0xf8ff, 0xc109,		0x21, 0
	.dw 0xf940, 0xc109,	0xf97f, 0xc109,		0x21, 0
	.dw 0xf9c0, 0xc109,	0x1fff, 0xc10a,		0x21, 0
	.dw 0x2040, 0xc10a,	0x207f, 0xc10a,		0x21, 0
	.dw 0x20c0, 0xc10a,	0x20ff, 0xc10a,		0x21, 0
	.dw 0x2140, 0xc10a,	0x217f, 0xc10a,		0x21, 0
	.dw 0x21c0, 0xc10a,	0x21ff, 0xc10a,		0x21, 0
	.dw 0x2240, 0xc10a,	0x227f, 0xc10a,		0x21, 0
	.dw 0x22c0, 0xc10a,	0x22ff, 0xc10a,		0x21, 0
	.dw 0x2340, 0xc10a,	0x237f, 0xc10a,		0x21, 0
	.dw 0x23c0, 0xc10a,	0x23ff, 0xc10a,		0x21, 0
	.dw 0x2440, 0xc10a,	0x247f, 0xc10a,		0x21, 0
	.dw 0x24c0, 0xc10a,	0x24ff, 0xc10a,		0x21, 0
	.dw 0x2540, 0xc10a,	0x257f, 0xc10a,		0x21, 0
	.dw 0x25c0, 0xc10a,	0x25ff, 0xc10a,		0x21, 0
	.dw 0x2640, 0xc10a,	0x267f, 0xc10a,		0x21, 0
	.dw 0x26c0, 0xc10a,	0x26ff, 0xc10a,		0x21, 0
	.dw 0x2740, 0xc10a,	0x277f, 0xc10a,		0x21, 0
	.dw 0x27c0, 0xc10a,	0x27ff, 0xc10a,		0x21, 0
	.dw 0x2840, 0xc10a,	0x287f, 0xc10a,		0x21, 0
	.dw 0x28c0, 0xc10a,	0x28ff, 0xc10a,		0x21, 0
	.dw 0x2940, 0xc10a,	0x297f, 0xc10a,		0x21, 0
	.dw 0x29c0, 0xc10a,	0x29ff, 0xc10a,		0x21, 0
	.dw 0x2a40, 0xc10a,	0x2a7f, 0xc10a,		0x21, 0
	.dw 0x2ac0, 0xc10a,	0x2aff, 0xc10a,		0x21, 0
	.dw 0x2b40, 0xc10a,	0x2b7f, 0xc10a,		0x21, 0
	.dw 0x2bc0, 0xc10a,	0x2bff, 0xc10a,		0x21, 0
	.dw 0x2c40, 0xc10a,	0x2c7f, 0xc10a,		0x21, 0
	.dw 0x2cc0, 0xc10a,	0x2cff, 0xc10a,		0x21, 0
	.dw 0x2d40, 0xc10a,	0x2d7f, 0xc10a,		0x21, 0
	.dw 0x2dc0, 0xc10a,	0x2dff, 0xc10a,		0x21, 0
	.dw 0x2e40, 0xc10a,	0x2e7f, 0xc10a,		0x21, 0
	.dw 0x2ec0, 0xc10a,	0x2eff, 0xc10a,		0x21, 0
	.dw 0x2f40, 0xc10a,	0x2f7f, 0xc10a,		0x21, 0
	.dw 0x2fc0, 0xc10a,	0x2fff, 0xc10a,		0x21, 0
	.dw 0x3040, 0xc10a,	0x307f, 0xc10a,		0x21, 0
	.dw 0x30c0, 0xc10a,	0x30ff, 0xc10a,		0x21, 0
	.dw 0x3140, 0xc10a,	0x317f, 0xc10a,		0x21, 0
	.dw 0x31c0, 0xc10a,	0x31ff, 0xc10a,		0x21, 0
	.dw 0x3240, 0xc10a,	0x327f, 0xc10a,		0x21, 0
	.dw 0x32c0, 0xc10a,	0x32ff, 0xc10a,		0x21, 0
	.dw 0x3340, 0xc10a,	0x337f, 0xc10a,		0x21, 0
	.dw 0x33c0, 0xc10a,	0x33ff, 0xc10a,		0x21, 0
	.dw 0x3440, 0xc10a,	0x347f, 0xc10a,		0x21, 0
	.dw 0x34c0, 0xc10a,	0x34ff, 0xc10a,		0x21, 0
	.dw 0x3540, 0xc10a,	0x357f, 0xc10a,		0x21, 0
	.dw 0x35c0, 0xc10a,	0x35ff, 0xc10a,		0x21, 0
	.dw 0x3640, 0xc10a,	0x367f, 0xc10a,		0x21, 0
	.dw 0x36c0, 0xc10a,	0x36ff, 0xc10a,		0x21, 0
	.dw 0x3740, 0xc10a,	0x377f, 0xc10a,		0x21, 0
	.dw 0x37c0, 0xc10a,	0x37ff, 0xc10a,		0x21, 0
	.dw 0x3840, 0xc10a,	0x387f, 0xc10a,		0x21, 0
	.dw 0x38c0, 0xc10a,	0x38ff, 0xc10a,		0x21, 0
	.dw 0x3940, 0xc10a,	0x397f, 0xc10a,		0x21, 0
	.dw 0x39c0, 0xc10a,	0x5fff, 0xc10a,		0x21, 0
	.dw 0x6040, 0xc10a,	0x607f, 0xc10a,		0x21, 0
	.dw 0x60c0, 0xc10a,	0x60ff, 0xc10a,		0x21, 0
	.dw 0x6140, 0xc10a,	0x617f, 0xc10a,		0x21, 0
	.dw 0x61c0, 0xc10a,	0x61ff, 0xc10a,		0x21, 0
	.dw 0x6240, 0xc10a,	0x627f, 0xc10a,		0x21, 0
	.dw 0x62c0, 0xc10a,	0x62ff, 0xc10a,		0x21, 0
	.dw 0x6340, 0xc10a,	0x637f, 0xc10a,		0x21, 0
	.dw 0x63c0, 0xc10a,	0x63ff, 0xc10a,		0x21, 0
	.dw 0x6440, 0xc10a,	0x647f, 0xc10a,		0x21, 0
	.dw 0x64c0, 0xc10a,	0x64ff, 0xc10a,		0x21, 0
	.dw 0x6540, 0xc10a,	0x657f, 0xc10a,		0x21, 0
	.dw 0x65c0, 0xc10a,	0x65ff, 0xc10a,		0x21, 0
	.dw 0x6640, 0xc10a,	0x667f, 0xc10a,		0x21, 0
	.dw 0x66c0, 0xc10a,	0x66ff, 0xc10a,		0x21, 0
	.dw 0x6740, 0xc10a,	0x677f, 0xc10a,		0x21, 0
	.dw 0x67c0, 0xc10a,	0x67ff, 0xc10a,		0x21, 0
	.dw 0x6840, 0xc10a,	0x687f, 0xc10a,		0x21, 0
	.dw 0x68c0, 0xc10a,	0x68ff, 0xc10a,		0x21, 0
	.dw 0x6940, 0xc10a,	0x697f, 0xc10a,		0x21, 0
	.dw 0x69c0, 0xc10a,	0x69ff, 0xc10a,		0x21, 0
	.dw 0x6a40, 0xc10a,	0x6a7f, 0xc10a,		0x21, 0
	.dw 0x6ac0, 0xc10a,	0x6aff, 0xc10a,		0x21, 0
	.dw 0x6b40, 0xc10a,	0x6b7f, 0xc10a,		0x21, 0
	.dw 0x6bc0, 0xc10a,	0x6bff, 0xc10a,		0x21, 0
	.dw 0x6c40, 0xc10a,	0x6c7f, 0xc10a,		0x21, 0
	.dw 0x6cc0, 0xc10a,	0x6cff, 0xc10a,		0x21, 0
	.dw 0x6d40, 0xc10a,	0x6d7f, 0xc10a,		0x21, 0
	.dw 0x6dc0, 0xc10a,	0x6dff, 0xc10a,		0x21, 0
	.dw 0x6e40, 0xc10a,	0x6e7f, 0xc10a,		0x21, 0
	.dw 0x6ec0, 0xc10a,	0x6eff, 0xc10a,		0x21, 0
	.dw 0x6f40, 0xc10a,	0x6f7f, 0xc10a,		0x21, 0
	.dw 0x6fc0, 0xc10a,	0x6fff, 0xc10a,		0x21, 0
	.dw 0x7040, 0xc10a,	0x707f, 0xc10a,		0x21, 0
	.dw 0x70c0, 0xc10a,	0x70ff, 0xc10a,		0x21, 0
	.dw 0x7140, 0xc10a,	0x717f, 0xc10a,		0x21, 0
	.dw 0x71c0, 0xc10a,	0x71ff, 0xc10a,		0x21, 0
	.dw 0x7240, 0xc10a,	0x727f, 0xc10a,		0x21, 0
	.dw 0x72c0, 0xc10a,	0x72ff, 0xc10a,		0x21, 0
	.dw 0x7340, 0xc10a,	0x737f, 0xc10a,		0x21, 0
	.dw 0x73c0, 0xc10a,	0x73ff, 0xc10a,		0x21, 0
	.dw 0x7440, 0xc10a,	0x747f, 0xc10a,		0x21, 0
	.dw 0x74c0, 0xc10a,	0x74ff, 0xc10a,		0x21, 0
	.dw 0x7540, 0xc10a,	0x757f, 0xc10a,		0x21, 0
	.dw 0x75c0, 0xc10a,	0x75ff, 0xc10a,		0x21, 0
	.dw 0x7640, 0xc10a,	0x767f, 0xc10a,		0x21, 0
	.dw 0x76c0, 0xc10a,	0x76ff, 0xc10a,		0x21, 0
	.dw 0x7740, 0xc10a,	0x777f, 0xc10a,		0x21, 0
	.dw 0x77c0, 0xc10a,	0x77ff, 0xc10a,		0x21, 0
	.dw 0x7840, 0xc10a,	0x787f, 0xc10a,		0x21, 0
	.dw 0x78c0, 0xc10a,	0x78ff, 0xc10a,		0x21, 0
	.dw 0x7940, 0xc10a,	0x797f, 0xc10a,		0x21, 0
	.dw 0x79c0, 0xc10a,	0x9fff, 0xc10a,		0x21, 0
	.dw 0xa040, 0xc10a,	0xa07f, 0xc10a,		0x21, 0
	.dw 0xa0c0, 0xc10a,	0xa0ff, 0xc10a,		0x21, 0
	.dw 0xa140, 0xc10a,	0xa17f, 0xc10a,		0x21, 0
	.dw 0xa1c0, 0xc10a,	0xa1ff, 0xc10a,		0x21, 0
	.dw 0xa240, 0xc10a,	0xa27f, 0xc10a,		0x21, 0
	.dw 0xa2c0, 0xc10a,	0xa2ff, 0xc10a,		0x21, 0
	.dw 0xa340, 0xc10a,	0xa37f, 0xc10a,		0x21, 0
	.dw 0xa3c0, 0xc10a,	0xa3ff, 0xc10a,		0x21, 0
	.dw 0xa440, 0xc10a,	0xa47f, 0xc10a,		0x21, 0
	.dw 0xa4c0, 0xc10a,	0xa4ff, 0xc10a,		0x21, 0
	.dw 0xa540, 0xc10a,	0xa57f, 0xc10a,		0x21, 0
	.dw 0xa5c0, 0xc10a,	0xa5ff, 0xc10a,		0x21, 0
	.dw 0xa640, 0xc10a,	0xa67f, 0xc10a,		0x21, 0
	.dw 0xa6c0, 0xc10a,	0xa6ff, 0xc10a,		0x21, 0
	.dw 0xa740, 0xc10a,	0xa77f, 0xc10a,		0x21, 0
	.dw 0xa7c0, 0xc10a,	0xa7ff, 0xc10a,		0x21, 0
	.dw 0xa840, 0xc10a,	0xa87f, 0xc10a,		0x21, 0
	.dw 0xa8c0, 0xc10a,	0xa8ff, 0xc10a,		0x21, 0
	.dw 0xa940, 0xc10a,	0xa97f, 0xc10a,		0x21, 0
	.dw 0xa9c0, 0xc10a,	0xa9ff, 0xc10a,		0x21, 0
	.dw 0xaa40, 0xc10a,	0xaa7f, 0xc10a,		0x21, 0
	.dw 0xaac0, 0xc10a,	0xaaff, 0xc10a,		0x21, 0
	.dw 0xab40, 0xc10a,	0xab7f, 0xc10a,		0x21, 0
	.dw 0xabc0, 0xc10a,	0xabff, 0xc10a,		0x21, 0
	.dw 0xac40, 0xc10a,	0xac7f, 0xc10a,		0x21, 0
	.dw 0xacc0, 0xc10a,	0xacff, 0xc10a,		0x21, 0
	.dw 0xad40, 0xc10a,	0xad7f, 0xc10a,		0x21, 0
	.dw 0xadc0, 0xc10a,	0xadff, 0xc10a,		0x21, 0
	.dw 0xae40, 0xc10a,	0xae7f, 0xc10a,		0x21, 0
	.dw 0xaec0, 0xc10a,	0xaeff, 0xc10a,		0x21, 0
	.dw 0xaf40, 0xc10a,	0xaf7f, 0xc10a,		0x21, 0
	.dw 0xafc0, 0xc10a,	0xafff, 0xc10a,		0x21, 0
	.dw 0xb040, 0xc10a,	0xb07f, 0xc10a,		0x21, 0
	.dw 0xb0c0, 0xc10a,	0xb0ff, 0xc10a,		0x21, 0
	.dw 0xb140, 0xc10a,	0xb17f, 0xc10a,		0x21, 0
	.dw 0xb1c0, 0xc10a,	0xb1ff, 0xc10a,		0x21, 0
	.dw 0xb240, 0xc10a,	0xb27f, 0xc10a,		0x21, 0
	.dw 0xb2c0, 0xc10a,	0xb2ff, 0xc10a,		0x21, 0
	.dw 0xb340, 0xc10a,	0xb37f, 0xc10a,		0x21, 0
	.dw 0xb3c0, 0xc10a,	0xb3ff, 0xc10a,		0x21, 0
	.dw 0xb440, 0xc10a,	0xb47f, 0xc10a,		0x21, 0
	.dw 0xb4c0, 0xc10a,	0xb4ff, 0xc10a,		0x21, 0
	.dw 0xb540, 0xc10a,	0xb57f, 0xc10a,		0x21, 0
	.dw 0xb5c0, 0xc10a,	0xb5ff, 0xc10a,		0x21, 0
	.dw 0xb640, 0xc10a,	0xb67f, 0xc10a,		0x21, 0
	.dw 0xb6c0, 0xc10a,	0xb6ff, 0xc10a,		0x21, 0
	.dw 0xb740, 0xc10a,	0xb77f, 0xc10a,		0x21, 0
	.dw 0xb7c0, 0xc10a,	0xb7ff, 0xc10a,		0x21, 0
	.dw 0xb840, 0xc10a,	0xb87f, 0xc10a,		0x21, 0
	.dw 0xb8c0, 0xc10a,	0xb8ff, 0xc10a,		0x21, 0
	.dw 0xb940, 0xc10a,	0xb97f, 0xc10a,		0x21, 0
	.dw 0xb9c0, 0xc10a,	0xdfff, 0xc10a,		0x21, 0
	.dw 0xe040, 0xc10a,	0xe07f, 0xc10a,		0x21, 0
	.dw 0xe0c0, 0xc10a,	0xe0ff, 0xc10a,		0x21, 0
	.dw 0xe140, 0xc10a,	0xe17f, 0xc10a,		0x21, 0
	.dw 0xe1c0, 0xc10a,	0xe1ff, 0xc10a,		0x21, 0
	.dw 0xe240, 0xc10a,	0xe27f, 0xc10a,		0x21, 0
	.dw 0xe2c0, 0xc10a,	0xe2ff, 0xc10a,		0x21, 0
	.dw 0xe340, 0xc10a,	0xe37f, 0xc10a,		0x21, 0
	.dw 0xe3c0, 0xc10a,	0xe3ff, 0xc10a,		0x21, 0
	.dw 0xe440, 0xc10a,	0xe47f, 0xc10a,		0x21, 0
	.dw 0xe4c0, 0xc10a,	0xe4ff, 0xc10a,		0x21, 0
	.dw 0xe540, 0xc10a,	0xe57f, 0xc10a,		0x21, 0
	.dw 0xe5c0, 0xc10a,	0xe5ff, 0xc10a,		0x21, 0
	.dw 0xe640, 0xc10a,	0xe67f, 0xc10a,		0x21, 0
	.dw 0xe6c0, 0xc10a,	0xe6ff, 0xc10a,		0x21, 0
	.dw 0xe740, 0xc10a,	0xe77f, 0xc10a,		0x21, 0
	.dw 0xe7c0, 0xc10a,	0xe7ff, 0xc10a,		0x21, 0
	.dw 0xe840, 0xc10a,	0xe87f, 0xc10a,		0x21, 0
	.dw 0xe8c0, 0xc10a,	0xe8ff, 0xc10a,		0x21, 0
	.dw 0xe940, 0xc10a,	0xe97f, 0xc10a,		0x21, 0
	.dw 0xe9c0, 0xc10a,	0xe9ff, 0xc10a,		0x21, 0
	.dw 0xea40, 0xc10a,	0xea7f, 0xc10a,		0x21, 0
	.dw 0xeac0, 0xc10a,	0xeaff, 0xc10a,		0x21, 0
	.dw 0xeb40, 0xc10a,	0xeb7f, 0xc10a,		0x21, 0
	.dw 0xebc0, 0xc10a,	0xebff, 0xc10a,		0x21, 0
	.dw 0xec40, 0xc10a,	0xec7f, 0xc10a,		0x21, 0
	.dw 0xecc0, 0xc10a,	0xecff, 0xc10a,		0x21, 0
	.dw 0xed40, 0xc10a,	0xed7f, 0xc10a,		0x21, 0
	.dw 0xedc0, 0xc10a,	0xedff, 0xc10a,		0x21, 0
	.dw 0xee40, 0xc10a,	0xee7f, 0xc10a,		0x21, 0
	.dw 0xeec0, 0xc10a,	0xeeff, 0xc10a,		0x21, 0
	.dw 0xef40, 0xc10a,	0xef7f, 0xc10a,		0x21, 0
	.dw 0xefc0, 0xc10a,	0xefff, 0xc10a,		0x21, 0
	.dw 0xf040, 0xc10a,	0xf07f, 0xc10a,		0x21, 0
	.dw 0xf0c0, 0xc10a,	0xf0ff, 0xc10a,		0x21, 0
	.dw 0xf140, 0xc10a,	0xf17f, 0xc10a,		0x21, 0
	.dw 0xf1c0, 0xc10a,	0xf1ff, 0xc10a,		0x21, 0
	.dw 0xf240, 0xc10a,	0xf27f, 0xc10a,		0x21, 0
	.dw 0xf2c0, 0xc10a,	0xf2ff, 0xc10a,		0x21, 0
	.dw 0xf340, 0xc10a,	0xf37f, 0xc10a,		0x21, 0
	.dw 0xf3c0, 0xc10a,	0xf3ff, 0xc10a,		0x21, 0
	.dw 0xf440, 0xc10a,	0xf47f, 0xc10a,		0x21, 0
	.dw 0xf4c0, 0xc10a,	0xf4ff, 0xc10a,		0x21, 0
	.dw 0xf540, 0xc10a,	0xf57f, 0xc10a,		0x21, 0
	.dw 0xf5c0, 0xc10a,	0xf5ff, 0xc10a,		0x21, 0
	.dw 0xf640, 0xc10a,	0xf67f, 0xc10a,		0x21, 0
	.dw 0xf6c0, 0xc10a,	0xf6ff, 0xc10a,		0x21, 0
	.dw 0xf740, 0xc10a,	0xf77f, 0xc10a,		0x21, 0
	.dw 0xf7c0, 0xc10a,	0xf7ff, 0xc10a,		0x21, 0
	.dw 0xf840, 0xc10a,	0xf87f, 0xc10a,		0x21, 0
	.dw 0xf8c0, 0xc10a,	0xf8ff, 0xc10a,		0x21, 0
	.dw 0xf940, 0xc10a,	0xf97f, 0xc10a,		0x21, 0
	.dw 0xf9c0, 0xc10a,	0x1fff, 0xc10b,		0x21, 0
	.dw 0x2040, 0xc10b,	0x207f, 0xc10b,		0x21, 0
	.dw 0x20c0, 0xc10b,	0x20ff, 0xc10b,		0x21, 0
	.dw 0x2140, 0xc10b,	0x217f, 0xc10b,		0x21, 0
	.dw 0x21c0, 0xc10b,	0x21ff, 0xc10b,		0x21, 0
	.dw 0x2240, 0xc10b,	0x227f, 0xc10b,		0x21, 0
	.dw 0x22c0, 0xc10b,	0x22ff, 0xc10b,		0x21, 0
	.dw 0x2340, 0xc10b,	0x237f, 0xc10b,		0x21, 0
	.dw 0x23c0, 0xc10b,	0x23ff, 0xc10b,		0x21, 0
	.dw 0x2440, 0xc10b,	0x247f, 0xc10b,		0x21, 0
	.dw 0x24c0, 0xc10b,	0x24ff, 0xc10b,		0x21, 0
	.dw 0x2540, 0xc10b,	0x257f, 0xc10b,		0x21, 0
	.dw 0x25c0, 0xc10b,	0x25ff, 0xc10b,		0x21, 0
	.dw 0x2640, 0xc10b,	0x267f, 0xc10b,		0x21, 0
	.dw 0x26c0, 0xc10b,	0x26ff, 0xc10b,		0x21, 0
	.dw 0x2740, 0xc10b,	0x277f, 0xc10b,		0x21, 0
	.dw 0x27c0, 0xc10b,	0x27ff, 0xc10b,		0x21, 0
	.dw 0x2840, 0xc10b,	0x287f, 0xc10b,		0x21, 0
	.dw 0x28c0, 0xc10b,	0x28ff, 0xc10b,		0x21, 0
	.dw 0x2940, 0xc10b,	0x297f, 0xc10b,		0x21, 0
	.dw 0x29c0, 0xc10b,	0x29ff, 0xc10b,		0x21, 0
	.dw 0x2a40, 0xc10b,	0x2a7f, 0xc10b,		0x21, 0
	.dw 0x2ac0, 0xc10b,	0x2aff, 0xc10b,		0x21, 0
	.dw 0x2b40, 0xc10b,	0x2b7f, 0xc10b,		0x21, 0
	.dw 0x2bc0, 0xc10b,	0x2bff, 0xc10b,		0x21, 0
	.dw 0x2c40, 0xc10b,	0x2c7f, 0xc10b,		0x21, 0
	.dw 0x2cc0, 0xc10b,	0x2cff, 0xc10b,		0x21, 0
	.dw 0x2d40, 0xc10b,	0x2d7f, 0xc10b,		0x21, 0
	.dw 0x2dc0, 0xc10b,	0x2dff, 0xc10b,		0x21, 0
	.dw 0x2e40, 0xc10b,	0x2e7f, 0xc10b,		0x21, 0
	.dw 0x2ec0, 0xc10b,	0x2eff, 0xc10b,		0x21, 0
	.dw 0x2f40, 0xc10b,	0x2f7f, 0xc10b,		0x21, 0
	.dw 0x2fc0, 0xc10b,	0x2fff, 0xc10b,		0x21, 0
	.dw 0x3040, 0xc10b,	0x307f, 0xc10b,		0x21, 0
	.dw 0x30c0, 0xc10b,	0x30ff, 0xc10b,		0x21, 0
	.dw 0x3140, 0xc10b,	0x317f, 0xc10b,		0x21, 0
	.dw 0x31c0, 0xc10b,	0x31ff, 0xc10b,		0x21, 0
	.dw 0x3240, 0xc10b,	0x327f, 0xc10b,		0x21, 0
	.dw 0x32c0, 0xc10b,	0x32ff, 0xc10b,		0x21, 0
	.dw 0x3340, 0xc10b,	0x337f, 0xc10b,		0x21, 0
	.dw 0x33c0, 0xc10b,	0x33ff, 0xc10b,		0x21, 0
	.dw 0x3440, 0xc10b,	0x347f, 0xc10b,		0x21, 0
	.dw 0x34c0, 0xc10b,	0x34ff, 0xc10b,		0x21, 0
	.dw 0x3540, 0xc10b,	0x357f, 0xc10b,		0x21, 0
	.dw 0x35c0, 0xc10b,	0x35ff, 0xc10b,		0x21, 0
	.dw 0x3640, 0xc10b,	0x367f, 0xc10b,		0x21, 0
	.dw 0x36c0, 0xc10b,	0x36ff, 0xc10b,		0x21, 0
	.dw 0x3740, 0xc10b,	0x377f, 0xc10b,		0x21, 0
	.dw 0x37c0, 0xc10b,	0x37ff, 0xc10b,		0x21, 0
	.dw 0x3840, 0xc10b,	0x387f, 0xc10b,		0x21, 0
	.dw 0x38c0, 0xc10b,	0x38ff, 0xc10b,		0x21, 0
	.dw 0x3940, 0xc10b,	0x397f, 0xc10b,		0x21, 0
	.dw 0x39c0, 0xc10b,	0xffff, 0xc10b,		0x21, 0
	.dw 0x0040, 0xc10c,	0x007f, 0xc10c,		0x21, 0
	.dw 0x00c0, 0xc10c,	0x00ff, 0xc10c,		0x21, 0
	.dw 0x0140, 0xc10c,	0x017f, 0xc10c,		0x21, 0
	.dw 0x01c0, 0xc10c,	0x01ff, 0xc10c,		0x21, 0
	.dw 0x0240, 0xc10c,	0x027f, 0xc10c,		0x21, 0
	.dw 0x02c0, 0xc10c,	0x02ff, 0xc10c,		0x21, 0
	.dw 0x0340, 0xc10c,	0x037f, 0xc10c,		0x21, 0
	.dw 0x03c0, 0xc10c,	0x03ff, 0xc10c,		0x21, 0
	.dw 0x0440, 0xc10c,	0x047f, 0xc10c,		0x21, 0
	.dw 0x04c0, 0xc10c,	0x04ff, 0xc10c,		0x21, 0
	.dw 0x0540, 0xc10c,	0x057f, 0xc10c,		0x21, 0
	.dw 0x05c0, 0xc10c,	0x05ff, 0xc10c,		0x21, 0
	.dw 0x0640, 0xc10c,	0x067f, 0xc10c,		0x21, 0
	.dw 0x06c0, 0xc10c,	0x06ff, 0xc10c,		0x21, 0
	.dw 0x0740, 0xc10c,	0x077f, 0xc10c,		0x21, 0
	.dw 0x07c0, 0xc10c,	0x07ff, 0xc10c,		0x21, 0
	.dw 0x0840, 0xc10c,	0x087f, 0xc10c,		0x21, 0
	.dw 0x08c0, 0xc10c,	0x08ff, 0xc10c,		0x21, 0
	.dw 0x0940, 0xc10c,	0x097f, 0xc10c,		0x21, 0
	.dw 0x09c0, 0xc10c,	0x09ff, 0xc10c,		0x21, 0
	.dw 0x0a40, 0xc10c,	0x0a7f, 0xc10c,		0x21, 0
	.dw 0x0ac0, 0xc10c,	0x0aff, 0xc10c,		0x21, 0
	.dw 0x0b40, 0xc10c,	0x0b7f, 0xc10c,		0x21, 0
	.dw 0x0bc0, 0xc10c,	0x0bff, 0xc10c,		0x21, 0
	.dw 0x0c40, 0xc10c,	0x0c7f, 0xc10c,		0x21, 0
	.dw 0x0cc0, 0xc10c,	0x0cff, 0xc10c,		0x21, 0
	.dw 0x0d40, 0xc10c,	0x0d7f, 0xc10c,		0x21, 0
	.dw 0x0dc0, 0xc10c,	0x0dff, 0xc10c,		0x21, 0
	.dw 0x0e40, 0xc10c,	0x0e7f, 0xc10c,		0x21, 0
	.dw 0x0ec0, 0xc10c,	0x0eff, 0xc10c,		0x21, 0
	.dw 0x0f40, 0xc10c,	0x0f7f, 0xc10c,		0x21, 0
	.dw 0x0fc0, 0xc10c,	0x0fff, 0xc10c,		0x21, 0
	.dw 0x1040, 0xc10c,	0x107f, 0xc10c,		0x21, 0
	.dw 0x10c0, 0xc10c,	0x10ff, 0xc10c,		0x21, 0
	.dw 0x1140, 0xc10c,	0x117f, 0xc10c,		0x21, 0
	.dw 0x11c0, 0xc10c,	0x11ff, 0xc10c,		0x21, 0
	.dw 0x1240, 0xc10c,	0x127f, 0xc10c,		0x21, 0
	.dw 0x12c0, 0xc10c,	0x12ff, 0xc10c,		0x21, 0
	.dw 0x1340, 0xc10c,	0x137f, 0xc10c,		0x21, 0
	.dw 0x13c0, 0xc10c,	0x13ff, 0xc10c,		0x21, 0
	.dw 0x1440, 0xc10c,	0x147f, 0xc10c,		0x21, 0
	.dw 0x14c0, 0xc10c,	0x14ff, 0xc10c,		0x21, 0
	.dw 0x1540, 0xc10c,	0x157f, 0xc10c,		0x21, 0
	.dw 0x15c0, 0xc10c,	0x15ff, 0xc10c,		0x21, 0
	.dw 0x1640, 0xc10c,	0x167f, 0xc10c,		0x21, 0
	.dw 0x16c0, 0xc10c,	0x16ff, 0xc10c,		0x21, 0
	.dw 0x1740, 0xc10c,	0x177f, 0xc10c,		0x21, 0
	.dw 0x17c0, 0xc10c,	0x17ff, 0xc10c,		0x21, 0
	.dw 0x1840, 0xc10c,	0x187f, 0xc10c,		0x21, 0
	.dw 0x18c0, 0xc10c,	0x18ff, 0xc10c,		0x21, 0
	.dw 0x1940, 0xc10c,	0x197f, 0xc10c,		0x21, 0
	.dw 0x19c0, 0xc10c,	0x1fff, 0xc10c,		0x21, 0
	.dw 0x2040, 0xc10c,	0x207f, 0xc10c,		0x21, 0
	.dw 0x20c0, 0xc10c,	0x20ff, 0xc10c,		0x21, 0
	.dw 0x2140, 0xc10c,	0x217f, 0xc10c,		0x21, 0
	.dw 0x21c0, 0xc10c,	0x21ff, 0xc10c,		0x21, 0
	.dw 0x2240, 0xc10c,	0x227f, 0xc10c,		0x21, 0
	.dw 0x22c0, 0xc10c,	0x22ff, 0xc10c,		0x21, 0
	.dw 0x2340, 0xc10c,	0x237f, 0xc10c,		0x21, 0
	.dw 0x23c0, 0xc10c,	0x23ff, 0xc10c,		0x21, 0
	.dw 0x2440, 0xc10c,	0x247f, 0xc10c,		0x21, 0
	.dw 0x24c0, 0xc10c,	0x24ff, 0xc10c,		0x21, 0
	.dw 0x2540, 0xc10c,	0x257f, 0xc10c,		0x21, 0
	.dw 0x25c0, 0xc10c,	0x25ff, 0xc10c,		0x21, 0
	.dw 0x2640, 0xc10c,	0x267f, 0xc10c,		0x21, 0
	.dw 0x26c0, 0xc10c,	0x26ff, 0xc10c,		0x21, 0
	.dw 0x2740, 0xc10c,	0x277f, 0xc10c,		0x21, 0
	.dw 0x27c0, 0xc10c,	0x27ff, 0xc10c,		0x21, 0
	.dw 0x2840, 0xc10c,	0x287f, 0xc10c,		0x21, 0
	.dw 0x28c0, 0xc10c,	0x28ff, 0xc10c,		0x21, 0
	.dw 0x2940, 0xc10c,	0x297f, 0xc10c,		0x21, 0
	.dw 0x29c0, 0xc10c,	0x29ff, 0xc10c,		0x21, 0
	.dw 0x2a40, 0xc10c,	0x2a7f, 0xc10c,		0x21, 0
	.dw 0x2ac0, 0xc10c,	0x2aff, 0xc10c,		0x21, 0
	.dw 0x2b40, 0xc10c,	0x2b7f, 0xc10c,		0x21, 0
	.dw 0x2bc0, 0xc10c,	0x2bff, 0xc10c,		0x21, 0
	.dw 0x2c40, 0xc10c,	0x2c7f, 0xc10c,		0x21, 0
	.dw 0x2cc0, 0xc10c,	0x2cff, 0xc10c,		0x21, 0
	.dw 0x2d40, 0xc10c,	0x2d7f, 0xc10c,		0x21, 0
	.dw 0x2dc0, 0xc10c,	0x2dff, 0xc10c,		0x21, 0
	.dw 0x2e40, 0xc10c,	0x2e7f, 0xc10c,		0x21, 0
	.dw 0x2ec0, 0xc10c,	0x2eff, 0xc10c,		0x21, 0
	.dw 0x2f40, 0xc10c,	0x2f7f, 0xc10c,		0x21, 0
	.dw 0x2fc0, 0xc10c,	0x2fff, 0xc10c,		0x21, 0
	.dw 0x3040, 0xc10c,	0x307f, 0xc10c,		0x21, 0
	.dw 0x30c0, 0xc10c,	0x30ff, 0xc10c,		0x21, 0
	.dw 0x3140, 0xc10c,	0x317f, 0xc10c,		0x21, 0
	.dw 0x31c0, 0xc10c,	0x31ff, 0xc10c,		0x21, 0
	.dw 0x3240, 0xc10c,	0x327f, 0xc10c,		0x21, 0
	.dw 0x32c0, 0xc10c,	0x32ff, 0xc10c,		0x21, 0
	.dw 0x3340, 0xc10c,	0x337f, 0xc10c,		0x21, 0
	.dw 0x33c0, 0xc10c,	0x33ff, 0xc10c,		0x21, 0
	.dw 0x3440, 0xc10c,	0x347f, 0xc10c,		0x21, 0
	.dw 0x34c0, 0xc10c,	0x34ff, 0xc10c,		0x21, 0
	.dw 0x3540, 0xc10c,	0x357f, 0xc10c,		0x21, 0
	.dw 0x35c0, 0xc10c,	0x35ff, 0xc10c,		0x21, 0
	.dw 0x3640, 0xc10c,	0x367f, 0xc10c,		0x21, 0
	.dw 0x36c0, 0xc10c,	0x36ff, 0xc10c,		0x21, 0
	.dw 0x3740, 0xc10c,	0x377f, 0xc10c,		0x21, 0
	.dw 0x37c0, 0xc10c,	0x37ff, 0xc10c,		0x21, 0
	.dw 0x3840, 0xc10c,	0x387f, 0xc10c,		0x21, 0
	.dw 0x38c0, 0xc10c,	0x38ff, 0xc10c,		0x21, 0
	.dw 0x3940, 0xc10c,	0x397f, 0xc10c,		0x21, 0
	.dw 0x39c0, 0xc10c,	0x3fff, 0xc10c,		0x21, 0
	.dw 0x4040, 0xc10c,	0x407f, 0xc10c,		0x21, 0
	.dw 0x40c0, 0xc10c,	0x40ff, 0xc10c,		0x21, 0
	.dw 0x4140, 0xc10c,	0x417f, 0xc10c,		0x21, 0
	.dw 0x41c0, 0xc10c,	0x41ff, 0xc10c,		0x21, 0
	.dw 0x4240, 0xc10c,	0x427f, 0xc10c,		0x21, 0
	.dw 0x42c0, 0xc10c,	0x42ff, 0xc10c,		0x21, 0
	.dw 0x4340, 0xc10c,	0x437f, 0xc10c,		0x21, 0
	.dw 0x43c0, 0xc10c,	0x43ff, 0xc10c,		0x21, 0
	.dw 0x4440, 0xc10c,	0x447f, 0xc10c,		0x21, 0
	.dw 0x44c0, 0xc10c,	0x44ff, 0xc10c,		0x21, 0
	.dw 0x4540, 0xc10c,	0x457f, 0xc10c,		0x21, 0
	.dw 0x45c0, 0xc10c,	0x45ff, 0xc10c,		0x21, 0
	.dw 0x4640, 0xc10c,	0x467f, 0xc10c,		0x21, 0
	.dw 0x46c0, 0xc10c,	0x46ff, 0xc10c,		0x21, 0
	.dw 0x4740, 0xc10c,	0x477f, 0xc10c,		0x21, 0
	.dw 0x47c0, 0xc10c,	0x47ff, 0xc10c,		0x21, 0
	.dw 0x4840, 0xc10c,	0x487f, 0xc10c,		0x21, 0
	.dw 0x48c0, 0xc10c,	0x48ff, 0xc10c,		0x21, 0
	.dw 0x4940, 0xc10c,	0x497f, 0xc10c,		0x21, 0
	.dw 0x49c0, 0xc10c,	0x49ff, 0xc10c,		0x21, 0
	.dw 0x4a40, 0xc10c,	0x4a7f, 0xc10c,		0x21, 0
	.dw 0x4ac0, 0xc10c,	0x4aff, 0xc10c,		0x21, 0
	.dw 0x4b40, 0xc10c,	0x4b7f, 0xc10c,		0x21, 0
	.dw 0x4bc0, 0xc10c,	0x4bff, 0xc10c,		0x21, 0
	.dw 0x4c40, 0xc10c,	0x4c7f, 0xc10c,		0x21, 0
	.dw 0x4cc0, 0xc10c,	0x4cff, 0xc10c,		0x21, 0
	.dw 0x4d40, 0xc10c,	0x4d7f, 0xc10c,		0x21, 0
	.dw 0x4dc0, 0xc10c,	0x4dff, 0xc10c,		0x21, 0
	.dw 0x4e40, 0xc10c,	0x4e7f, 0xc10c,		0x21, 0
	.dw 0x4ec0, 0xc10c,	0x4eff, 0xc10c,		0x21, 0
	.dw 0x4f40, 0xc10c,	0x4f7f, 0xc10c,		0x21, 0
	.dw 0x4fc0, 0xc10c,	0x4fff, 0xc10c,		0x21, 0
	.dw 0x5040, 0xc10c,	0x507f, 0xc10c,		0x21, 0
	.dw 0x50c0, 0xc10c,	0x50ff, 0xc10c,		0x21, 0
	.dw 0x5140, 0xc10c,	0x517f, 0xc10c,		0x21, 0
	.dw 0x51c0, 0xc10c,	0x51ff, 0xc10c,		0x21, 0
	.dw 0x5240, 0xc10c,	0x527f, 0xc10c,		0x21, 0
	.dw 0x52c0, 0xc10c,	0x52ff, 0xc10c,		0x21, 0
	.dw 0x5340, 0xc10c,	0x537f, 0xc10c,		0x21, 0
	.dw 0x53c0, 0xc10c,	0x53ff, 0xc10c,		0x21, 0
	.dw 0x5440, 0xc10c,	0x547f, 0xc10c,		0x21, 0
	.dw 0x54c0, 0xc10c,	0x54ff, 0xc10c,		0x21, 0
	.dw 0x5540, 0xc10c,	0x557f, 0xc10c,		0x21, 0
	.dw 0x55c0, 0xc10c,	0x55ff, 0xc10c,		0x21, 0
	.dw 0x5640, 0xc10c,	0x567f, 0xc10c,		0x21, 0
	.dw 0x56c0, 0xc10c,	0x56ff, 0xc10c,		0x21, 0
	.dw 0x5740, 0xc10c,	0x577f, 0xc10c,		0x21, 0
	.dw 0x57c0, 0xc10c,	0x57ff, 0xc10c,		0x21, 0
	.dw 0x5840, 0xc10c,	0x587f, 0xc10c,		0x21, 0
	.dw 0x58c0, 0xc10c,	0x58ff, 0xc10c,		0x21, 0
	.dw 0x5940, 0xc10c,	0x597f, 0xc10c,		0x21, 0
	.dw 0x59c0, 0xc10c,	0x5fff, 0xc10c,		0x21, 0
	.dw 0x6040, 0xc10c,	0x607f, 0xc10c,		0x21, 0
	.dw 0x60c0, 0xc10c,	0x60ff, 0xc10c,		0x21, 0
	.dw 0x6140, 0xc10c,	0x617f, 0xc10c,		0x21, 0
	.dw 0x61c0, 0xc10c,	0x61ff, 0xc10c,		0x21, 0
	.dw 0x6240, 0xc10c,	0x627f, 0xc10c,		0x21, 0
	.dw 0x62c0, 0xc10c,	0x62ff, 0xc10c,		0x21, 0
	.dw 0x6340, 0xc10c,	0x637f, 0xc10c,		0x21, 0
	.dw 0x63c0, 0xc10c,	0x63ff, 0xc10c,		0x21, 0
	.dw 0x6440, 0xc10c,	0x647f, 0xc10c,		0x21, 0
	.dw 0x64c0, 0xc10c,	0x64ff, 0xc10c,		0x21, 0
	.dw 0x6540, 0xc10c,	0x657f, 0xc10c,		0x21, 0
	.dw 0x65c0, 0xc10c,	0x65ff, 0xc10c,		0x21, 0
	.dw 0x6640, 0xc10c,	0x667f, 0xc10c,		0x21, 0
	.dw 0x66c0, 0xc10c,	0x66ff, 0xc10c,		0x21, 0
	.dw 0x6740, 0xc10c,	0x677f, 0xc10c,		0x21, 0
	.dw 0x67c0, 0xc10c,	0x67ff, 0xc10c,		0x21, 0
	.dw 0x6840, 0xc10c,	0x687f, 0xc10c,		0x21, 0
	.dw 0x68c0, 0xc10c,	0x68ff, 0xc10c,		0x21, 0
	.dw 0x6940, 0xc10c,	0x697f, 0xc10c,		0x21, 0
	.dw 0x69c0, 0xc10c,	0x69ff, 0xc10c,		0x21, 0
	.dw 0x6a40, 0xc10c,	0x6a7f, 0xc10c,		0x21, 0
	.dw 0x6ac0, 0xc10c,	0x6aff, 0xc10c,		0x21, 0
	.dw 0x6b40, 0xc10c,	0x6b7f, 0xc10c,		0x21, 0
	.dw 0x6bc0, 0xc10c,	0x6bff, 0xc10c,		0x21, 0
	.dw 0x6c40, 0xc10c,	0x6c7f, 0xc10c,		0x21, 0
	.dw 0x6cc0, 0xc10c,	0x6cff, 0xc10c,		0x21, 0
	.dw 0x6d40, 0xc10c,	0x6d7f, 0xc10c,		0x21, 0
	.dw 0x6dc0, 0xc10c,	0x6dff, 0xc10c,		0x21, 0
	.dw 0x6e40, 0xc10c,	0x6e7f, 0xc10c,		0x21, 0
	.dw 0x6ec0, 0xc10c,	0x6eff, 0xc10c,		0x21, 0
	.dw 0x6f40, 0xc10c,	0x6f7f, 0xc10c,		0x21, 0
	.dw 0x6fc0, 0xc10c,	0x6fff, 0xc10c,		0x21, 0
	.dw 0x7040, 0xc10c,	0x707f, 0xc10c,		0x21, 0
	.dw 0x70c0, 0xc10c,	0x70ff, 0xc10c,		0x21, 0
	.dw 0x7140, 0xc10c,	0x717f, 0xc10c,		0x21, 0
	.dw 0x71c0, 0xc10c,	0x71ff, 0xc10c,		0x21, 0
	.dw 0x7240, 0xc10c,	0x727f, 0xc10c,		0x21, 0
	.dw 0x72c0, 0xc10c,	0x72ff, 0xc10c,		0x21, 0
	.dw 0x7340, 0xc10c,	0x737f, 0xc10c,		0x21, 0
	.dw 0x73c0, 0xc10c,	0x73ff, 0xc10c,		0x21, 0
	.dw 0x7440, 0xc10c,	0x747f, 0xc10c,		0x21, 0
	.dw 0x74c0, 0xc10c,	0x74ff, 0xc10c,		0x21, 0
	.dw 0x7540, 0xc10c,	0x757f, 0xc10c,		0x21, 0
	.dw 0x75c0, 0xc10c,	0x75ff, 0xc10c,		0x21, 0
	.dw 0x7640, 0xc10c,	0x767f, 0xc10c,		0x21, 0
	.dw 0x76c0, 0xc10c,	0x76ff, 0xc10c,		0x21, 0
	.dw 0x7740, 0xc10c,	0x777f, 0xc10c,		0x21, 0
	.dw 0x77c0, 0xc10c,	0x77ff, 0xc10c,		0x21, 0
	.dw 0x7840, 0xc10c,	0x787f, 0xc10c,		0x21, 0
	.dw 0x78c0, 0xc10c,	0x78ff, 0xc10c,		0x21, 0
	.dw 0x7940, 0xc10c,	0x797f, 0xc10c,		0x21, 0
	.dw 0x79c0, 0xc10c,	0x7fff, 0xc10c,		0x21, 0
	.dw 0x8040, 0xc10c,	0x807f, 0xc10c,		0x21, 0
	.dw 0x80c0, 0xc10c,	0x80ff, 0xc10c,		0x21, 0
	.dw 0x8140, 0xc10c,	0x817f, 0xc10c,		0x21, 0
	.dw 0x81c0, 0xc10c,	0x81ff, 0xc10c,		0x21, 0
	.dw 0x8240, 0xc10c,	0x827f, 0xc10c,		0x21, 0
	.dw 0x82c0, 0xc10c,	0x82ff, 0xc10c,		0x21, 0
	.dw 0x8340, 0xc10c,	0x837f, 0xc10c,		0x21, 0
	.dw 0x83c0, 0xc10c,	0x83ff, 0xc10c,		0x21, 0
	.dw 0x8440, 0xc10c,	0x847f, 0xc10c,		0x21, 0
	.dw 0x84c0, 0xc10c,	0x84ff, 0xc10c,		0x21, 0
	.dw 0x8540, 0xc10c,	0x857f, 0xc10c,		0x21, 0
	.dw 0x85c0, 0xc10c,	0x85ff, 0xc10c,		0x21, 0
	.dw 0x8640, 0xc10c,	0x867f, 0xc10c,		0x21, 0
	.dw 0x86c0, 0xc10c,	0x86ff, 0xc10c,		0x21, 0
	.dw 0x8740, 0xc10c,	0x877f, 0xc10c,		0x21, 0
	.dw 0x87c0, 0xc10c,	0x87ff, 0xc10c,		0x21, 0
	.dw 0x8840, 0xc10c,	0x887f, 0xc10c,		0x21, 0
	.dw 0x88c0, 0xc10c,	0x88ff, 0xc10c,		0x21, 0
	.dw 0x8940, 0xc10c,	0x897f, 0xc10c,		0x21, 0
	.dw 0x89c0, 0xc10c,	0x89ff, 0xc10c,		0x21, 0
	.dw 0x8a40, 0xc10c,	0x8a7f, 0xc10c,		0x21, 0
	.dw 0x8ac0, 0xc10c,	0x8aff, 0xc10c,		0x21, 0
	.dw 0x8b40, 0xc10c,	0x8b7f, 0xc10c,		0x21, 0
	.dw 0x8bc0, 0xc10c,	0x8bff, 0xc10c,		0x21, 0
	.dw 0x8c40, 0xc10c,	0x8c7f, 0xc10c,		0x21, 0
	.dw 0x8cc0, 0xc10c,	0x8cff, 0xc10c,		0x21, 0
	.dw 0x8d40, 0xc10c,	0x8d7f, 0xc10c,		0x21, 0
	.dw 0x8dc0, 0xc10c,	0x8dff, 0xc10c,		0x21, 0
	.dw 0x8e40, 0xc10c,	0x8e7f, 0xc10c,		0x21, 0
	.dw 0x8ec0, 0xc10c,	0x8eff, 0xc10c,		0x21, 0
	.dw 0x8f40, 0xc10c,	0x8f7f, 0xc10c,		0x21, 0
	.dw 0x8fc0, 0xc10c,	0x8fff, 0xc10c,		0x21, 0
	.dw 0x9040, 0xc10c,	0x907f, 0xc10c,		0x21, 0
	.dw 0x90c0, 0xc10c,	0x90ff, 0xc10c,		0x21, 0
	.dw 0x9140, 0xc10c,	0x917f, 0xc10c,		0x21, 0
	.dw 0x91c0, 0xc10c,	0x91ff, 0xc10c,		0x21, 0
	.dw 0x9240, 0xc10c,	0x927f, 0xc10c,		0x21, 0
	.dw 0x92c0, 0xc10c,	0x92ff, 0xc10c,		0x21, 0
	.dw 0x9340, 0xc10c,	0x937f, 0xc10c,		0x21, 0
	.dw 0x93c0, 0xc10c,	0x93ff, 0xc10c,		0x21, 0
	.dw 0x9440, 0xc10c,	0x947f, 0xc10c,		0x21, 0
	.dw 0x94c0, 0xc10c,	0x94ff, 0xc10c,		0x21, 0
	.dw 0x9540, 0xc10c,	0x957f, 0xc10c,		0x21, 0
	.dw 0x95c0, 0xc10c,	0x95ff, 0xc10c,		0x21, 0
	.dw 0x9640, 0xc10c,	0x967f, 0xc10c,		0x21, 0
	.dw 0x96c0, 0xc10c,	0x96ff, 0xc10c,		0x21, 0
	.dw 0x9740, 0xc10c,	0x977f, 0xc10c,		0x21, 0
	.dw 0x97c0, 0xc10c,	0x97ff, 0xc10c,		0x21, 0
	.dw 0x9840, 0xc10c,	0x987f, 0xc10c,		0x21, 0
	.dw 0x98c0, 0xc10c,	0x98ff, 0xc10c,		0x21, 0
	.dw 0x9940, 0xc10c,	0x997f, 0xc10c,		0x21, 0
	.dw 0x99c0, 0xc10c,	0x9fff, 0xc10c,		0x21, 0
	.dw 0xa040, 0xc10c,	0xa07f, 0xc10c,		0x21, 0
	.dw 0xa0c0, 0xc10c,	0xa0ff, 0xc10c,		0x21, 0
	.dw 0xa140, 0xc10c,	0xa17f, 0xc10c,		0x21, 0
	.dw 0xa1c0, 0xc10c,	0xa1ff, 0xc10c,		0x21, 0
	.dw 0xa240, 0xc10c,	0xa27f, 0xc10c,		0x21, 0
	.dw 0xa2c0, 0xc10c,	0xa2ff, 0xc10c,		0x21, 0
	.dw 0xa340, 0xc10c,	0xa37f, 0xc10c,		0x21, 0
	.dw 0xa3c0, 0xc10c,	0xa3ff, 0xc10c,		0x21, 0
	.dw 0xa440, 0xc10c,	0xa47f, 0xc10c,		0x21, 0
	.dw 0xa4c0, 0xc10c,	0xa4ff, 0xc10c,		0x21, 0
	.dw 0xa540, 0xc10c,	0xa57f, 0xc10c,		0x21, 0
	.dw 0xa5c0, 0xc10c,	0xa5ff, 0xc10c,		0x21, 0
	.dw 0xa640, 0xc10c,	0xa67f, 0xc10c,		0x21, 0
	.dw 0xa6c0, 0xc10c,	0xa6ff, 0xc10c,		0x21, 0
	.dw 0xa740, 0xc10c,	0xa77f, 0xc10c,		0x21, 0
	.dw 0xa7c0, 0xc10c,	0xa7ff, 0xc10c,		0x21, 0
	.dw 0xa840, 0xc10c,	0xa87f, 0xc10c,		0x21, 0
	.dw 0xa8c0, 0xc10c,	0xa8ff, 0xc10c,		0x21, 0
	.dw 0xa940, 0xc10c,	0xa97f, 0xc10c,		0x21, 0
	.dw 0xa9c0, 0xc10c,	0xa9ff, 0xc10c,		0x21, 0
	.dw 0xaa40, 0xc10c,	0xaa7f, 0xc10c,		0x21, 0
	.dw 0xaac0, 0xc10c,	0xaaff, 0xc10c,		0x21, 0
	.dw 0xab40, 0xc10c,	0xab7f, 0xc10c,		0x21, 0
	.dw 0xabc0, 0xc10c,	0xabff, 0xc10c,		0x21, 0
	.dw 0xac40, 0xc10c,	0xac7f, 0xc10c,		0x21, 0
	.dw 0xacc0, 0xc10c,	0xacff, 0xc10c,		0x21, 0
	.dw 0xad40, 0xc10c,	0xad7f, 0xc10c,		0x21, 0
	.dw 0xadc0, 0xc10c,	0xadff, 0xc10c,		0x21, 0
	.dw 0xae40, 0xc10c,	0xae7f, 0xc10c,		0x21, 0
	.dw 0xaec0, 0xc10c,	0xaeff, 0xc10c,		0x21, 0
	.dw 0xaf40, 0xc10c,	0xaf7f, 0xc10c,		0x21, 0
	.dw 0xafc0, 0xc10c,	0xafff, 0xc10c,		0x21, 0
	.dw 0xb040, 0xc10c,	0xb07f, 0xc10c,		0x21, 0
	.dw 0xb0c0, 0xc10c,	0xb0ff, 0xc10c,		0x21, 0
	.dw 0xb140, 0xc10c,	0xb17f, 0xc10c,		0x21, 0
	.dw 0xb1c0, 0xc10c,	0xb1ff, 0xc10c,		0x21, 0
	.dw 0xb240, 0xc10c,	0xb27f, 0xc10c,		0x21, 0
	.dw 0xb2c0, 0xc10c,	0xb2ff, 0xc10c,		0x21, 0
	.dw 0xb340, 0xc10c,	0xb37f, 0xc10c,		0x21, 0
	.dw 0xb3c0, 0xc10c,	0xb3ff, 0xc10c,		0x21, 0
	.dw 0xb440, 0xc10c,	0xb47f, 0xc10c,		0x21, 0
	.dw 0xb4c0, 0xc10c,	0xb4ff, 0xc10c,		0x21, 0
	.dw 0xb540, 0xc10c,	0xb57f, 0xc10c,		0x21, 0
	.dw 0xb5c0, 0xc10c,	0xb5ff, 0xc10c,		0x21, 0
	.dw 0xb640, 0xc10c,	0xb67f, 0xc10c,		0x21, 0
	.dw 0xb6c0, 0xc10c,	0xb6ff, 0xc10c,		0x21, 0
	.dw 0xb740, 0xc10c,	0xb77f, 0xc10c,		0x21, 0
	.dw 0xb7c0, 0xc10c,	0xb7ff, 0xc10c,		0x21, 0
	.dw 0xb840, 0xc10c,	0xb87f, 0xc10c,		0x21, 0
	.dw 0xb8c0, 0xc10c,	0xb8ff, 0xc10c,		0x21, 0
	.dw 0xb940, 0xc10c,	0xb97f, 0xc10c,		0x21, 0
	.dw 0xb9c0, 0xc10c,	0xbfff, 0xc10c,		0x21, 0
	.dw 0xc040, 0xc10c,	0xc07f, 0xc10c,		0x21, 0
	.dw 0xc0c0, 0xc10c,	0xc0ff, 0xc10c,		0x21, 0
	.dw 0xc140, 0xc10c,	0xc17f, 0xc10c,		0x21, 0
	.dw 0xc1c0, 0xc10c,	0xc1ff, 0xc10c,		0x21, 0
	.dw 0xc240, 0xc10c,	0xc27f, 0xc10c,		0x21, 0
	.dw 0xc2c0, 0xc10c,	0xc2ff, 0xc10c,		0x21, 0
	.dw 0xc340, 0xc10c,	0xc37f, 0xc10c,		0x21, 0
	.dw 0xc3c0, 0xc10c,	0xc3ff, 0xc10c,		0x21, 0
	.dw 0xc440, 0xc10c,	0xc47f, 0xc10c,		0x21, 0
	.dw 0xc4c0, 0xc10c,	0xc4ff, 0xc10c,		0x21, 0
	.dw 0xc540, 0xc10c,	0xc57f, 0xc10c,		0x21, 0
	.dw 0xc5c0, 0xc10c,	0xc5ff, 0xc10c,		0x21, 0
	.dw 0xc640, 0xc10c,	0xc67f, 0xc10c,		0x21, 0
	.dw 0xc6c0, 0xc10c,	0xc6ff, 0xc10c,		0x21, 0
	.dw 0xc740, 0xc10c,	0xc77f, 0xc10c,		0x21, 0
	.dw 0xc7c0, 0xc10c,	0xc7ff, 0xc10c,		0x21, 0
	.dw 0xc840, 0xc10c,	0xc87f, 0xc10c,		0x21, 0
	.dw 0xc8c0, 0xc10c,	0xc8ff, 0xc10c,		0x21, 0
	.dw 0xc940, 0xc10c,	0xc97f, 0xc10c,		0x21, 0
	.dw 0xc9c0, 0xc10c,	0xc9ff, 0xc10c,		0x21, 0
	.dw 0xca40, 0xc10c,	0xca7f, 0xc10c,		0x21, 0
	.dw 0xcac0, 0xc10c,	0xcaff, 0xc10c,		0x21, 0
	.dw 0xcb40, 0xc10c,	0xcb7f, 0xc10c,		0x21, 0
	.dw 0xcbc0, 0xc10c,	0xcbff, 0xc10c,		0x21, 0
	.dw 0xcc40, 0xc10c,	0xcc7f, 0xc10c,		0x21, 0
	.dw 0xccc0, 0xc10c,	0xccff, 0xc10c,		0x21, 0
	.dw 0xcd40, 0xc10c,	0xcd7f, 0xc10c,		0x21, 0
	.dw 0xcdc0, 0xc10c,	0xcdff, 0xc10c,		0x21, 0
	.dw 0xce40, 0xc10c,	0xce7f, 0xc10c,		0x21, 0
	.dw 0xcec0, 0xc10c,	0xceff, 0xc10c,		0x21, 0
	.dw 0xcf40, 0xc10c,	0xcf7f, 0xc10c,		0x21, 0
	.dw 0xcfc0, 0xc10c,	0xcfff, 0xc10c,		0x21, 0
	.dw 0xd040, 0xc10c,	0xd07f, 0xc10c,		0x21, 0
	.dw 0xd0c0, 0xc10c,	0xd0ff, 0xc10c,		0x21, 0
	.dw 0xd140, 0xc10c,	0xd17f, 0xc10c,		0x21, 0
	.dw 0xd1c0, 0xc10c,	0xd1ff, 0xc10c,		0x21, 0
	.dw 0xd240, 0xc10c,	0xd27f, 0xc10c,		0x21, 0
	.dw 0xd2c0, 0xc10c,	0xd2ff, 0xc10c,		0x21, 0
	.dw 0xd340, 0xc10c,	0xd37f, 0xc10c,		0x21, 0
	.dw 0xd3c0, 0xc10c,	0xd3ff, 0xc10c,		0x21, 0
	.dw 0xd440, 0xc10c,	0xd47f, 0xc10c,		0x21, 0
	.dw 0xd4c0, 0xc10c,	0xd4ff, 0xc10c,		0x21, 0
	.dw 0xd540, 0xc10c,	0xd57f, 0xc10c,		0x21, 0
	.dw 0xd5c0, 0xc10c,	0xd5ff, 0xc10c,		0x21, 0
	.dw 0xd640, 0xc10c,	0xd67f, 0xc10c,		0x21, 0
	.dw 0xd6c0, 0xc10c,	0xd6ff, 0xc10c,		0x21, 0
	.dw 0xd740, 0xc10c,	0xd77f, 0xc10c,		0x21, 0
	.dw 0xd7c0, 0xc10c,	0xd7ff, 0xc10c,		0x21, 0
	.dw 0xd840, 0xc10c,	0xd87f, 0xc10c,		0x21, 0
	.dw 0xd8c0, 0xc10c,	0xd8ff, 0xc10c,		0x21, 0
	.dw 0xd940, 0xc10c,	0xd97f, 0xc10c,		0x21, 0
	.dw 0xd9c0, 0xc10c,	0xdfff, 0xc10c,		0x21, 0
	.dw 0xe040, 0xc10c,	0xe07f, 0xc10c,		0x21, 0
	.dw 0xe0c0, 0xc10c,	0xe0ff, 0xc10c,		0x21, 0
	.dw 0xe140, 0xc10c,	0xe17f, 0xc10c,		0x21, 0
	.dw 0xe1c0, 0xc10c,	0xe1ff, 0xc10c,		0x21, 0
	.dw 0xe240, 0xc10c,	0xe27f, 0xc10c,		0x21, 0
	.dw 0xe2c0, 0xc10c,	0xe2ff, 0xc10c,		0x21, 0
	.dw 0xe340, 0xc10c,	0xe37f, 0xc10c,		0x21, 0
	.dw 0xe3c0, 0xc10c,	0xe3ff, 0xc10c,		0x21, 0
	.dw 0xe440, 0xc10c,	0xe47f, 0xc10c,		0x21, 0
	.dw 0xe4c0, 0xc10c,	0xe4ff, 0xc10c,		0x21, 0
	.dw 0xe540, 0xc10c,	0xe57f, 0xc10c,		0x21, 0
	.dw 0xe5c0, 0xc10c,	0xe5ff, 0xc10c,		0x21, 0
	.dw 0xe640, 0xc10c,	0xe67f, 0xc10c,		0x21, 0
	.dw 0xe6c0, 0xc10c,	0xe6ff, 0xc10c,		0x21, 0
	.dw 0xe740, 0xc10c,	0xe77f, 0xc10c,		0x21, 0
	.dw 0xe7c0, 0xc10c,	0xe7ff, 0xc10c,		0x21, 0
	.dw 0xe840, 0xc10c,	0xe87f, 0xc10c,		0x21, 0
	.dw 0xe8c0, 0xc10c,	0xe8ff, 0xc10c,		0x21, 0
	.dw 0xe940, 0xc10c,	0xe97f, 0xc10c,		0x21, 0
	.dw 0xe9c0, 0xc10c,	0xe9ff, 0xc10c,		0x21, 0
	.dw 0xea40, 0xc10c,	0xea7f, 0xc10c,		0x21, 0
	.dw 0xeac0, 0xc10c,	0xeaff, 0xc10c,		0x21, 0
	.dw 0xeb40, 0xc10c,	0xeb7f, 0xc10c,		0x21, 0
	.dw 0xebc0, 0xc10c,	0xebff, 0xc10c,		0x21, 0
	.dw 0xec40, 0xc10c,	0xec7f, 0xc10c,		0x21, 0
	.dw 0xecc0, 0xc10c,	0xecff, 0xc10c,		0x21, 0
	.dw 0xed40, 0xc10c,	0xed7f, 0xc10c,		0x21, 0
	.dw 0xedc0, 0xc10c,	0xedff, 0xc10c,		0x21, 0
	.dw 0xee40, 0xc10c,	0xee7f, 0xc10c,		0x21, 0
	.dw 0xeec0, 0xc10c,	0xeeff, 0xc10c,		0x21, 0
	.dw 0xef40, 0xc10c,	0xef7f, 0xc10c,		0x21, 0
	.dw 0xefc0, 0xc10c,	0xefff, 0xc10c,		0x21, 0
	.dw 0xf040, 0xc10c,	0xf07f, 0xc10c,		0x21, 0
	.dw 0xf0c0, 0xc10c,	0xf0ff, 0xc10c,		0x21, 0
	.dw 0xf140, 0xc10c,	0xf17f, 0xc10c,		0x21, 0
	.dw 0xf1c0, 0xc10c,	0xf1ff, 0xc10c,		0x21, 0
	.dw 0xf240, 0xc10c,	0xf27f, 0xc10c,		0x21, 0
	.dw 0xf2c0, 0xc10c,	0xf2ff, 0xc10c,		0x21, 0
	.dw 0xf340, 0xc10c,	0xf37f, 0xc10c,		0x21, 0
	.dw 0xf3c0, 0xc10c,	0xf3ff, 0xc10c,		0x21, 0
	.dw 0xf440, 0xc10c,	0xf47f, 0xc10c,		0x21, 0
	.dw 0xf4c0, 0xc10c,	0xf4ff, 0xc10c,		0x21, 0
	.dw 0xf540, 0xc10c,	0xf57f, 0xc10c,		0x21, 0
	.dw 0xf5c0, 0xc10c,	0xf5ff, 0xc10c,		0x21, 0
	.dw 0xf640, 0xc10c,	0xf67f, 0xc10c,		0x21, 0
	.dw 0xf6c0, 0xc10c,	0xf6ff, 0xc10c,		0x21, 0
	.dw 0xf740, 0xc10c,	0xf77f, 0xc10c,		0x21, 0
	.dw 0xf7c0, 0xc10c,	0xf7ff, 0xc10c,		0x21, 0
	.dw 0xf840, 0xc10c,	0xf87f, 0xc10c,		0x21, 0
	.dw 0xf8c0, 0xc10c,	0xf8ff, 0xc10c,		0x21, 0
	.dw 0xf940, 0xc10c,	0xf97f, 0xc10c,		0x21, 0
	.dw 0xf9c0, 0xc10c,	0xffff, 0xc10c,		0x21, 0
	.dw 0x0040, 0xc10d,	0x007f, 0xc10d,		0x21, 0
	.dw 0x00c0, 0xc10d,	0x00ff, 0xc10d,		0x21, 0
	.dw 0x0140, 0xc10d,	0x017f, 0xc10d,		0x21, 0
	.dw 0x01c0, 0xc10d,	0x01ff, 0xc10d,		0x21, 0
	.dw 0x0240, 0xc10d,	0x027f, 0xc10d,		0x21, 0
	.dw 0x02c0, 0xc10d,	0x02ff, 0xc10d,		0x21, 0
	.dw 0x0340, 0xc10d,	0x037f, 0xc10d,		0x21, 0
	.dw 0x03c0, 0xc10d,	0x03ff, 0xc10d,		0x21, 0
	.dw 0x0440, 0xc10d,	0x047f, 0xc10d,		0x21, 0
	.dw 0x04c0, 0xc10d,	0x04ff, 0xc10d,		0x21, 0
	.dw 0x0540, 0xc10d,	0x057f, 0xc10d,		0x21, 0
	.dw 0x05c0, 0xc10d,	0x05ff, 0xc10d,		0x21, 0
	.dw 0x0640, 0xc10d,	0x067f, 0xc10d,		0x21, 0
	.dw 0x06c0, 0xc10d,	0x06ff, 0xc10d,		0x21, 0
	.dw 0x0740, 0xc10d,	0x077f, 0xc10d,		0x21, 0
	.dw 0x07c0, 0xc10d,	0x07ff, 0xc10d,		0x21, 0
	.dw 0x0840, 0xc10d,	0x087f, 0xc10d,		0x21, 0
	.dw 0x08c0, 0xc10d,	0x08ff, 0xc10d,		0x21, 0
	.dw 0x0940, 0xc10d,	0x097f, 0xc10d,		0x21, 0
	.dw 0x09c0, 0xc10d,	0x09ff, 0xc10d,		0x21, 0
	.dw 0x0a40, 0xc10d,	0x0a7f, 0xc10d,		0x21, 0
	.dw 0x0ac0, 0xc10d,	0x0aff, 0xc10d,		0x21, 0
	.dw 0x0b40, 0xc10d,	0x0b7f, 0xc10d,		0x21, 0
	.dw 0x0bc0, 0xc10d,	0x0bff, 0xc10d,		0x21, 0
	.dw 0x0c40, 0xc10d,	0x0c7f, 0xc10d,		0x21, 0
	.dw 0x0cc0, 0xc10d,	0x0cff, 0xc10d,		0x21, 0
	.dw 0x0d40, 0xc10d,	0x0d7f, 0xc10d,		0x21, 0
	.dw 0x0dc0, 0xc10d,	0x0dff, 0xc10d,		0x21, 0
	.dw 0x0e40, 0xc10d,	0x0e7f, 0xc10d,		0x21, 0
	.dw 0x0ec0, 0xc10d,	0x0eff, 0xc10d,		0x21, 0
	.dw 0x0f40, 0xc10d,	0x0f7f, 0xc10d,		0x21, 0
	.dw 0x0fc0, 0xc10d,	0x0fff, 0xc10d,		0x21, 0
	.dw 0x1040, 0xc10d,	0x107f, 0xc10d,		0x21, 0
	.dw 0x10c0, 0xc10d,	0x10ff, 0xc10d,		0x21, 0
	.dw 0x1140, 0xc10d,	0x117f, 0xc10d,		0x21, 0
	.dw 0x11c0, 0xc10d,	0x11ff, 0xc10d,		0x21, 0
	.dw 0x1240, 0xc10d,	0x127f, 0xc10d,		0x21, 0
	.dw 0x12c0, 0xc10d,	0x12ff, 0xc10d,		0x21, 0
	.dw 0x1340, 0xc10d,	0x137f, 0xc10d,		0x21, 0
	.dw 0x13c0, 0xc10d,	0x13ff, 0xc10d,		0x21, 0
	.dw 0x1440, 0xc10d,	0x147f, 0xc10d,		0x21, 0
	.dw 0x14c0, 0xc10d,	0x14ff, 0xc10d,		0x21, 0
	.dw 0x1540, 0xc10d,	0x157f, 0xc10d,		0x21, 0
	.dw 0x15c0, 0xc10d,	0x15ff, 0xc10d,		0x21, 0
	.dw 0x1640, 0xc10d,	0x167f, 0xc10d,		0x21, 0
	.dw 0x16c0, 0xc10d,	0x16ff, 0xc10d,		0x21, 0
	.dw 0x1740, 0xc10d,	0x177f, 0xc10d,		0x21, 0
	.dw 0x17c0, 0xc10d,	0x17ff, 0xc10d,		0x21, 0
	.dw 0x1840, 0xc10d,	0x187f, 0xc10d,		0x21, 0
	.dw 0x18c0, 0xc10d,	0x18ff, 0xc10d,		0x21, 0
	.dw 0x1940, 0xc10d,	0x197f, 0xc10d,		0x21, 0
	.dw 0x19c0, 0xc10d,	0x1fff, 0xc10d,		0x21, 0
	.dw 0x2040, 0xc10d,	0x207f, 0xc10d,		0x21, 0
	.dw 0x20c0, 0xc10d,	0x20ff, 0xc10d,		0x21, 0
	.dw 0x2140, 0xc10d,	0x217f, 0xc10d,		0x21, 0
	.dw 0x21c0, 0xc10d,	0x21ff, 0xc10d,		0x21, 0
	.dw 0x2240, 0xc10d,	0x227f, 0xc10d,		0x21, 0
	.dw 0x22c0, 0xc10d,	0x22ff, 0xc10d,		0x21, 0
	.dw 0x2340, 0xc10d,	0x237f, 0xc10d,		0x21, 0
	.dw 0x23c0, 0xc10d,	0x23ff, 0xc10d,		0x21, 0
	.dw 0x2440, 0xc10d,	0x247f, 0xc10d,		0x21, 0
	.dw 0x24c0, 0xc10d,	0x24ff, 0xc10d,		0x21, 0
	.dw 0x2540, 0xc10d,	0x257f, 0xc10d,		0x21, 0
	.dw 0x25c0, 0xc10d,	0x25ff, 0xc10d,		0x21, 0
	.dw 0x2640, 0xc10d,	0x267f, 0xc10d,		0x21, 0
	.dw 0x26c0, 0xc10d,	0x26ff, 0xc10d,		0x21, 0
	.dw 0x2740, 0xc10d,	0x277f, 0xc10d,		0x21, 0
	.dw 0x27c0, 0xc10d,	0x27ff, 0xc10d,		0x21, 0
	.dw 0x2840, 0xc10d,	0x287f, 0xc10d,		0x21, 0
	.dw 0x28c0, 0xc10d,	0x28ff, 0xc10d,		0x21, 0
	.dw 0x2940, 0xc10d,	0x297f, 0xc10d,		0x21, 0
	.dw 0x29c0, 0xc10d,	0x29ff, 0xc10d,		0x21, 0
	.dw 0x2a40, 0xc10d,	0x2a7f, 0xc10d,		0x21, 0
	.dw 0x2ac0, 0xc10d,	0x2aff, 0xc10d,		0x21, 0
	.dw 0x2b40, 0xc10d,	0x2b7f, 0xc10d,		0x21, 0
	.dw 0x2bc0, 0xc10d,	0x2bff, 0xc10d,		0x21, 0
	.dw 0x2c40, 0xc10d,	0x2c7f, 0xc10d,		0x21, 0
	.dw 0x2cc0, 0xc10d,	0x2cff, 0xc10d,		0x21, 0
	.dw 0x2d40, 0xc10d,	0x2d7f, 0xc10d,		0x21, 0
	.dw 0x2dc0, 0xc10d,	0x2dff, 0xc10d,		0x21, 0
	.dw 0x2e40, 0xc10d,	0x2e7f, 0xc10d,		0x21, 0
	.dw 0x2ec0, 0xc10d,	0x2eff, 0xc10d,		0x21, 0
	.dw 0x2f40, 0xc10d,	0x2f7f, 0xc10d,		0x21, 0
	.dw 0x2fc0, 0xc10d,	0x2fff, 0xc10d,		0x21, 0
	.dw 0x3040, 0xc10d,	0x307f, 0xc10d,		0x21, 0
	.dw 0x30c0, 0xc10d,	0x30ff, 0xc10d,		0x21, 0
	.dw 0x3140, 0xc10d,	0x317f, 0xc10d,		0x21, 0
	.dw 0x31c0, 0xc10d,	0x31ff, 0xc10d,		0x21, 0
	.dw 0x3240, 0xc10d,	0x327f, 0xc10d,		0x21, 0
	.dw 0x32c0, 0xc10d,	0x32ff, 0xc10d,		0x21, 0
	.dw 0x3340, 0xc10d,	0x337f, 0xc10d,		0x21, 0
	.dw 0x33c0, 0xc10d,	0x33ff, 0xc10d,		0x21, 0
	.dw 0x3440, 0xc10d,	0x347f, 0xc10d,		0x21, 0
	.dw 0x34c0, 0xc10d,	0x34ff, 0xc10d,		0x21, 0
	.dw 0x3540, 0xc10d,	0x357f, 0xc10d,		0x21, 0
	.dw 0x35c0, 0xc10d,	0x35ff, 0xc10d,		0x21, 0
	.dw 0x3640, 0xc10d,	0x367f, 0xc10d,		0x21, 0
	.dw 0x36c0, 0xc10d,	0x36ff, 0xc10d,		0x21, 0
	.dw 0x3740, 0xc10d,	0x377f, 0xc10d,		0x21, 0
	.dw 0x37c0, 0xc10d,	0x37ff, 0xc10d,		0x21, 0
	.dw 0x3840, 0xc10d,	0x387f, 0xc10d,		0x21, 0
	.dw 0x38c0, 0xc10d,	0x38ff, 0xc10d,		0x21, 0
	.dw 0x3940, 0xc10d,	0x397f, 0xc10d,		0x21, 0
	.dw 0x39c0, 0xc10d,	0x3fff, 0xc10d,		0x21, 0
	.dw 0x4040, 0xc10d,	0x407f, 0xc10d,		0x21, 0
	.dw 0x40c0, 0xc10d,	0x40ff, 0xc10d,		0x21, 0
	.dw 0x4140, 0xc10d,	0x417f, 0xc10d,		0x21, 0
	.dw 0x41c0, 0xc10d,	0x41ff, 0xc10d,		0x21, 0
	.dw 0x4240, 0xc10d,	0x427f, 0xc10d,		0x21, 0
	.dw 0x42c0, 0xc10d,	0x42ff, 0xc10d,		0x21, 0
	.dw 0x4340, 0xc10d,	0x437f, 0xc10d,		0x21, 0
	.dw 0x43c0, 0xc10d,	0x43ff, 0xc10d,		0x21, 0
	.dw 0x4440, 0xc10d,	0x447f, 0xc10d,		0x21, 0
	.dw 0x44c0, 0xc10d,	0x44ff, 0xc10d,		0x21, 0
	.dw 0x4540, 0xc10d,	0x457f, 0xc10d,		0x21, 0
	.dw 0x45c0, 0xc10d,	0x45ff, 0xc10d,		0x21, 0
	.dw 0x4640, 0xc10d,	0x467f, 0xc10d,		0x21, 0
	.dw 0x46c0, 0xc10d,	0x46ff, 0xc10d,		0x21, 0
	.dw 0x4740, 0xc10d,	0x477f, 0xc10d,		0x21, 0
	.dw 0x47c0, 0xc10d,	0x47ff, 0xc10d,		0x21, 0
	.dw 0x4840, 0xc10d,	0x487f, 0xc10d,		0x21, 0
	.dw 0x48c0, 0xc10d,	0x48ff, 0xc10d,		0x21, 0
	.dw 0x4940, 0xc10d,	0x497f, 0xc10d,		0x21, 0
	.dw 0x49c0, 0xc10d,	0x49ff, 0xc10d,		0x21, 0
	.dw 0x4a40, 0xc10d,	0x4a7f, 0xc10d,		0x21, 0
	.dw 0x4ac0, 0xc10d,	0x4aff, 0xc10d,		0x21, 0
	.dw 0x4b40, 0xc10d,	0x4b7f, 0xc10d,		0x21, 0
	.dw 0x4bc0, 0xc10d,	0x4bff, 0xc10d,		0x21, 0
	.dw 0x4c40, 0xc10d,	0x4c7f, 0xc10d,		0x21, 0
	.dw 0x4cc0, 0xc10d,	0x4cff, 0xc10d,		0x21, 0
	.dw 0x4d40, 0xc10d,	0x4d7f, 0xc10d,		0x21, 0
	.dw 0x4dc0, 0xc10d,	0x4dff, 0xc10d,		0x21, 0
	.dw 0x4e40, 0xc10d,	0x4e7f, 0xc10d,		0x21, 0
	.dw 0x4ec0, 0xc10d,	0x4eff, 0xc10d,		0x21, 0
	.dw 0x4f40, 0xc10d,	0x4f7f, 0xc10d,		0x21, 0
	.dw 0x4fc0, 0xc10d,	0x4fff, 0xc10d,		0x21, 0
	.dw 0x5040, 0xc10d,	0x507f, 0xc10d,		0x21, 0
	.dw 0x50c0, 0xc10d,	0x50ff, 0xc10d,		0x21, 0
	.dw 0x5140, 0xc10d,	0x517f, 0xc10d,		0x21, 0
	.dw 0x51c0, 0xc10d,	0x51ff, 0xc10d,		0x21, 0
	.dw 0x5240, 0xc10d,	0x527f, 0xc10d,		0x21, 0
	.dw 0x52c0, 0xc10d,	0x52ff, 0xc10d,		0x21, 0
	.dw 0x5340, 0xc10d,	0x537f, 0xc10d,		0x21, 0
	.dw 0x53c0, 0xc10d,	0x53ff, 0xc10d,		0x21, 0
	.dw 0x5440, 0xc10d,	0x547f, 0xc10d,		0x21, 0
	.dw 0x54c0, 0xc10d,	0x54ff, 0xc10d,		0x21, 0
	.dw 0x5540, 0xc10d,	0x557f, 0xc10d,		0x21, 0
	.dw 0x55c0, 0xc10d,	0x55ff, 0xc10d,		0x21, 0
	.dw 0x5640, 0xc10d,	0x567f, 0xc10d,		0x21, 0
	.dw 0x56c0, 0xc10d,	0x56ff, 0xc10d,		0x21, 0
	.dw 0x5740, 0xc10d,	0x577f, 0xc10d,		0x21, 0
	.dw 0x57c0, 0xc10d,	0x57ff, 0xc10d,		0x21, 0
	.dw 0x5840, 0xc10d,	0x587f, 0xc10d,		0x21, 0
	.dw 0x58c0, 0xc10d,	0x58ff, 0xc10d,		0x21, 0
	.dw 0x5940, 0xc10d,	0x597f, 0xc10d,		0x21, 0
	.dw 0x59c0, 0xc10d,	0x5fff, 0xc10d,		0x21, 0
	.dw 0x6040, 0xc10d,	0x607f, 0xc10d,		0x21, 0
	.dw 0x60c0, 0xc10d,	0x60ff, 0xc10d,		0x21, 0
	.dw 0x6140, 0xc10d,	0x617f, 0xc10d,		0x21, 0
	.dw 0x61c0, 0xc10d,	0x61ff, 0xc10d,		0x21, 0
	.dw 0x6240, 0xc10d,	0x627f, 0xc10d,		0x21, 0
	.dw 0x62c0, 0xc10d,	0x62ff, 0xc10d,		0x21, 0
	.dw 0x6340, 0xc10d,	0x637f, 0xc10d,		0x21, 0
	.dw 0x63c0, 0xc10d,	0x63ff, 0xc10d,		0x21, 0
	.dw 0x6440, 0xc10d,	0x647f, 0xc10d,		0x21, 0
	.dw 0x64c0, 0xc10d,	0x64ff, 0xc10d,		0x21, 0
	.dw 0x6540, 0xc10d,	0x657f, 0xc10d,		0x21, 0
	.dw 0x65c0, 0xc10d,	0x65ff, 0xc10d,		0x21, 0
	.dw 0x6640, 0xc10d,	0x667f, 0xc10d,		0x21, 0
	.dw 0x66c0, 0xc10d,	0x66ff, 0xc10d,		0x21, 0
	.dw 0x6740, 0xc10d,	0x677f, 0xc10d,		0x21, 0
	.dw 0x67c0, 0xc10d,	0x67ff, 0xc10d,		0x21, 0
	.dw 0x6840, 0xc10d,	0x687f, 0xc10d,		0x21, 0
	.dw 0x68c0, 0xc10d,	0x68ff, 0xc10d,		0x21, 0
	.dw 0x6940, 0xc10d,	0x697f, 0xc10d,		0x21, 0
	.dw 0x69c0, 0xc10d,	0x69ff, 0xc10d,		0x21, 0
	.dw 0x6a40, 0xc10d,	0x6a7f, 0xc10d,		0x21, 0
	.dw 0x6ac0, 0xc10d,	0x6aff, 0xc10d,		0x21, 0
	.dw 0x6b40, 0xc10d,	0x6b7f, 0xc10d,		0x21, 0
	.dw 0x6bc0, 0xc10d,	0x6bff, 0xc10d,		0x21, 0
	.dw 0x6c40, 0xc10d,	0x6c7f, 0xc10d,		0x21, 0
	.dw 0x6cc0, 0xc10d,	0x6cff, 0xc10d,		0x21, 0
	.dw 0x6d40, 0xc10d,	0x6d7f, 0xc10d,		0x21, 0
	.dw 0x6dc0, 0xc10d,	0x6dff, 0xc10d,		0x21, 0
	.dw 0x6e40, 0xc10d,	0x6e7f, 0xc10d,		0x21, 0
	.dw 0x6ec0, 0xc10d,	0x6eff, 0xc10d,		0x21, 0
	.dw 0x6f40, 0xc10d,	0x6f7f, 0xc10d,		0x21, 0
	.dw 0x6fc0, 0xc10d,	0x6fff, 0xc10d,		0x21, 0
	.dw 0x7040, 0xc10d,	0x707f, 0xc10d,		0x21, 0
	.dw 0x70c0, 0xc10d,	0x70ff, 0xc10d,		0x21, 0
	.dw 0x7140, 0xc10d,	0x717f, 0xc10d,		0x21, 0
	.dw 0x71c0, 0xc10d,	0x71ff, 0xc10d,		0x21, 0
	.dw 0x7240, 0xc10d,	0x727f, 0xc10d,		0x21, 0
	.dw 0x72c0, 0xc10d,	0x72ff, 0xc10d,		0x21, 0
	.dw 0x7340, 0xc10d,	0x737f, 0xc10d,		0x21, 0
	.dw 0x73c0, 0xc10d,	0x73ff, 0xc10d,		0x21, 0
	.dw 0x7440, 0xc10d,	0x747f, 0xc10d,		0x21, 0
	.dw 0x74c0, 0xc10d,	0x74ff, 0xc10d,		0x21, 0
	.dw 0x7540, 0xc10d,	0x757f, 0xc10d,		0x21, 0
	.dw 0x75c0, 0xc10d,	0x75ff, 0xc10d,		0x21, 0
	.dw 0x7640, 0xc10d,	0x767f, 0xc10d,		0x21, 0
	.dw 0x76c0, 0xc10d,	0x76ff, 0xc10d,		0x21, 0
	.dw 0x7740, 0xc10d,	0x777f, 0xc10d,		0x21, 0
	.dw 0x77c0, 0xc10d,	0x77ff, 0xc10d,		0x21, 0
	.dw 0x7840, 0xc10d,	0x787f, 0xc10d,		0x21, 0
	.dw 0x78c0, 0xc10d,	0x78ff, 0xc10d,		0x21, 0
	.dw 0x7940, 0xc10d,	0x797f, 0xc10d,		0x21, 0
	.dw 0x79c0, 0xc10d,	0x7fff, 0xc10d,		0x21, 0
	.dw 0x8040, 0xc10d,	0x807f, 0xc10d,		0x21, 0
	.dw 0x80c0, 0xc10d,	0x80ff, 0xc10d,		0x21, 0
	.dw 0x8140, 0xc10d,	0x817f, 0xc10d,		0x21, 0
	.dw 0x81c0, 0xc10d,	0x81ff, 0xc10d,		0x21, 0
	.dw 0x8240, 0xc10d,	0x827f, 0xc10d,		0x21, 0
	.dw 0x82c0, 0xc10d,	0x82ff, 0xc10d,		0x21, 0
	.dw 0x8340, 0xc10d,	0x837f, 0xc10d,		0x21, 0
	.dw 0x83c0, 0xc10d,	0x83ff, 0xc10d,		0x21, 0
	.dw 0x8440, 0xc10d,	0x847f, 0xc10d,		0x21, 0
	.dw 0x84c0, 0xc10d,	0x84ff, 0xc10d,		0x21, 0
	.dw 0x8540, 0xc10d,	0x857f, 0xc10d,		0x21, 0
	.dw 0x85c0, 0xc10d,	0x85ff, 0xc10d,		0x21, 0
	.dw 0x8640, 0xc10d,	0x867f, 0xc10d,		0x21, 0
	.dw 0x86c0, 0xc10d,	0x86ff, 0xc10d,		0x21, 0
	.dw 0x8740, 0xc10d,	0x877f, 0xc10d,		0x21, 0
	.dw 0x87c0, 0xc10d,	0x87ff, 0xc10d,		0x21, 0
	.dw 0x8840, 0xc10d,	0x887f, 0xc10d,		0x21, 0
	.dw 0x88c0, 0xc10d,	0x88ff, 0xc10d,		0x21, 0
	.dw 0x8940, 0xc10d,	0x897f, 0xc10d,		0x21, 0
	.dw 0x89c0, 0xc10d,	0x89ff, 0xc10d,		0x21, 0
	.dw 0x8a40, 0xc10d,	0x8a7f, 0xc10d,		0x21, 0
	.dw 0x8ac0, 0xc10d,	0x8aff, 0xc10d,		0x21, 0
	.dw 0x8b40, 0xc10d,	0x8b7f, 0xc10d,		0x21, 0
	.dw 0x8bc0, 0xc10d,	0x8bff, 0xc10d,		0x21, 0
	.dw 0x8c40, 0xc10d,	0x8c7f, 0xc10d,		0x21, 0
	.dw 0x8cc0, 0xc10d,	0x8cff, 0xc10d,		0x21, 0
	.dw 0x8d40, 0xc10d,	0x8d7f, 0xc10d,		0x21, 0
	.dw 0x8dc0, 0xc10d,	0x8dff, 0xc10d,		0x21, 0
	.dw 0x8e40, 0xc10d,	0x8e7f, 0xc10d,		0x21, 0
	.dw 0x8ec0, 0xc10d,	0x8eff, 0xc10d,		0x21, 0
	.dw 0x8f40, 0xc10d,	0x8f7f, 0xc10d,		0x21, 0
	.dw 0x8fc0, 0xc10d,	0x8fff, 0xc10d,		0x21, 0
	.dw 0x9040, 0xc10d,	0x907f, 0xc10d,		0x21, 0
	.dw 0x90c0, 0xc10d,	0x90ff, 0xc10d,		0x21, 0
	.dw 0x9140, 0xc10d,	0x917f, 0xc10d,		0x21, 0
	.dw 0x91c0, 0xc10d,	0x91ff, 0xc10d,		0x21, 0
	.dw 0x9240, 0xc10d,	0x927f, 0xc10d,		0x21, 0
	.dw 0x92c0, 0xc10d,	0x92ff, 0xc10d,		0x21, 0
	.dw 0x9340, 0xc10d,	0x937f, 0xc10d,		0x21, 0
	.dw 0x93c0, 0xc10d,	0x93ff, 0xc10d,		0x21, 0
	.dw 0x9440, 0xc10d,	0x947f, 0xc10d,		0x21, 0
	.dw 0x94c0, 0xc10d,	0x94ff, 0xc10d,		0x21, 0
	.dw 0x9540, 0xc10d,	0x957f, 0xc10d,		0x21, 0
	.dw 0x95c0, 0xc10d,	0x95ff, 0xc10d,		0x21, 0
	.dw 0x9640, 0xc10d,	0x967f, 0xc10d,		0x21, 0
	.dw 0x96c0, 0xc10d,	0x96ff, 0xc10d,		0x21, 0
	.dw 0x9740, 0xc10d,	0x977f, 0xc10d,		0x21, 0
	.dw 0x97c0, 0xc10d,	0x97ff, 0xc10d,		0x21, 0
	.dw 0x9840, 0xc10d,	0x987f, 0xc10d,		0x21, 0
	.dw 0x98c0, 0xc10d,	0x98ff, 0xc10d,		0x21, 0
	.dw 0x9940, 0xc10d,	0x997f, 0xc10d,		0x21, 0
	.dw 0x99c0, 0xc10d,	0x9fff, 0xc10d,		0x21, 0
	.dw 0xa040, 0xc10d,	0xa07f, 0xc10d,		0x21, 0
	.dw 0xa0c0, 0xc10d,	0xa0ff, 0xc10d,		0x21, 0
	.dw 0xa140, 0xc10d,	0xa17f, 0xc10d,		0x21, 0
	.dw 0xa1c0, 0xc10d,	0xa1ff, 0xc10d,		0x21, 0
	.dw 0xa240, 0xc10d,	0xa27f, 0xc10d,		0x21, 0
	.dw 0xa2c0, 0xc10d,	0xa2ff, 0xc10d,		0x21, 0
	.dw 0xa340, 0xc10d,	0xa37f, 0xc10d,		0x21, 0
	.dw 0xa3c0, 0xc10d,	0xa3ff, 0xc10d,		0x21, 0
	.dw 0xa440, 0xc10d,	0xa47f, 0xc10d,		0x21, 0
	.dw 0xa4c0, 0xc10d,	0xa4ff, 0xc10d,		0x21, 0
	.dw 0xa540, 0xc10d,	0xa57f, 0xc10d,		0x21, 0
	.dw 0xa5c0, 0xc10d,	0xa5ff, 0xc10d,		0x21, 0
	.dw 0xa640, 0xc10d,	0xa67f, 0xc10d,		0x21, 0
	.dw 0xa6c0, 0xc10d,	0xa6ff, 0xc10d,		0x21, 0
	.dw 0xa740, 0xc10d,	0xa77f, 0xc10d,		0x21, 0
	.dw 0xa7c0, 0xc10d,	0xa7ff, 0xc10d,		0x21, 0
	.dw 0xa840, 0xc10d,	0xa87f, 0xc10d,		0x21, 0
	.dw 0xa8c0, 0xc10d,	0xa8ff, 0xc10d,		0x21, 0
	.dw 0xa940, 0xc10d,	0xa97f, 0xc10d,		0x21, 0
	.dw 0xa9c0, 0xc10d,	0xa9ff, 0xc10d,		0x21, 0
	.dw 0xaa40, 0xc10d,	0xaa7f, 0xc10d,		0x21, 0
	.dw 0xaac0, 0xc10d,	0xaaff, 0xc10d,		0x21, 0
	.dw 0xab40, 0xc10d,	0xab7f, 0xc10d,		0x21, 0
	.dw 0xabc0, 0xc10d,	0xabff, 0xc10d,		0x21, 0
	.dw 0xac40, 0xc10d,	0xac7f, 0xc10d,		0x21, 0
	.dw 0xacc0, 0xc10d,	0xacff, 0xc10d,		0x21, 0
	.dw 0xad40, 0xc10d,	0xad7f, 0xc10d,		0x21, 0
	.dw 0xadc0, 0xc10d,	0xadff, 0xc10d,		0x21, 0
	.dw 0xae40, 0xc10d,	0xae7f, 0xc10d,		0x21, 0
	.dw 0xaec0, 0xc10d,	0xaeff, 0xc10d,		0x21, 0
	.dw 0xaf40, 0xc10d,	0xaf7f, 0xc10d,		0x21, 0
	.dw 0xafc0, 0xc10d,	0xafff, 0xc10d,		0x21, 0
	.dw 0xb040, 0xc10d,	0xb07f, 0xc10d,		0x21, 0
	.dw 0xb0c0, 0xc10d,	0xb0ff, 0xc10d,		0x21, 0
	.dw 0xb140, 0xc10d,	0xb17f, 0xc10d,		0x21, 0
	.dw 0xb1c0, 0xc10d,	0xb1ff, 0xc10d,		0x21, 0
	.dw 0xb240, 0xc10d,	0xb27f, 0xc10d,		0x21, 0
	.dw 0xb2c0, 0xc10d,	0xb2ff, 0xc10d,		0x21, 0
	.dw 0xb340, 0xc10d,	0xb37f, 0xc10d,		0x21, 0
	.dw 0xb3c0, 0xc10d,	0xb3ff, 0xc10d,		0x21, 0
	.dw 0xb440, 0xc10d,	0xb47f, 0xc10d,		0x21, 0
	.dw 0xb4c0, 0xc10d,	0xb4ff, 0xc10d,		0x21, 0
	.dw 0xb540, 0xc10d,	0xb57f, 0xc10d,		0x21, 0
	.dw 0xb5c0, 0xc10d,	0xb5ff, 0xc10d,		0x21, 0
	.dw 0xb640, 0xc10d,	0xb67f, 0xc10d,		0x21, 0
	.dw 0xb6c0, 0xc10d,	0xb6ff, 0xc10d,		0x21, 0
	.dw 0xb740, 0xc10d,	0xb77f, 0xc10d,		0x21, 0
	.dw 0xb7c0, 0xc10d,	0xb7ff, 0xc10d,		0x21, 0
	.dw 0xb840, 0xc10d,	0xb87f, 0xc10d,		0x21, 0
	.dw 0xb8c0, 0xc10d,	0xb8ff, 0xc10d,		0x21, 0
	.dw 0xb940, 0xc10d,	0xb97f, 0xc10d,		0x21, 0
	.dw 0xb9c0, 0xc10d,	0xbfff, 0xc10d,		0x21, 0
	.dw 0xc040, 0xc10d,	0xc07f, 0xc10d,		0x21, 0
	.dw 0xc0c0, 0xc10d,	0xc0ff, 0xc10d,		0x21, 0
	.dw 0xc140, 0xc10d,	0xc17f, 0xc10d,		0x21, 0
	.dw 0xc1c0, 0xc10d,	0xc1ff, 0xc10d,		0x21, 0
	.dw 0xc240, 0xc10d,	0xc27f, 0xc10d,		0x21, 0
	.dw 0xc2c0, 0xc10d,	0xc2ff, 0xc10d,		0x21, 0
	.dw 0xc340, 0xc10d,	0xc37f, 0xc10d,		0x21, 0
	.dw 0xc3c0, 0xc10d,	0xc3ff, 0xc10d,		0x21, 0
	.dw 0xc440, 0xc10d,	0xc47f, 0xc10d,		0x21, 0
	.dw 0xc4c0, 0xc10d,	0xc4ff, 0xc10d,		0x21, 0
	.dw 0xc540, 0xc10d,	0xc57f, 0xc10d,		0x21, 0
	.dw 0xc5c0, 0xc10d,	0xc5ff, 0xc10d,		0x21, 0
	.dw 0xc640, 0xc10d,	0xc67f, 0xc10d,		0x21, 0
	.dw 0xc6c0, 0xc10d,	0xc6ff, 0xc10d,		0x21, 0
	.dw 0xc740, 0xc10d,	0xc77f, 0xc10d,		0x21, 0
	.dw 0xc7c0, 0xc10d,	0xc7ff, 0xc10d,		0x21, 0
	.dw 0xc840, 0xc10d,	0xc87f, 0xc10d,		0x21, 0
	.dw 0xc8c0, 0xc10d,	0xc8ff, 0xc10d,		0x21, 0
	.dw 0xc940, 0xc10d,	0xc97f, 0xc10d,		0x21, 0
	.dw 0xc9c0, 0xc10d,	0xc9ff, 0xc10d,		0x21, 0
	.dw 0xca40, 0xc10d,	0xca7f, 0xc10d,		0x21, 0
	.dw 0xcac0, 0xc10d,	0xcaff, 0xc10d,		0x21, 0
	.dw 0xcb40, 0xc10d,	0xcb7f, 0xc10d,		0x21, 0
	.dw 0xcbc0, 0xc10d,	0xcbff, 0xc10d,		0x21, 0
	.dw 0xcc40, 0xc10d,	0xcc7f, 0xc10d,		0x21, 0
	.dw 0xccc0, 0xc10d,	0xccff, 0xc10d,		0x21, 0
	.dw 0xcd40, 0xc10d,	0xcd7f, 0xc10d,		0x21, 0
	.dw 0xcdc0, 0xc10d,	0xcdff, 0xc10d,		0x21, 0
	.dw 0xce40, 0xc10d,	0xce7f, 0xc10d,		0x21, 0
	.dw 0xcec0, 0xc10d,	0xceff, 0xc10d,		0x21, 0
	.dw 0xcf40, 0xc10d,	0xcf7f, 0xc10d,		0x21, 0
	.dw 0xcfc0, 0xc10d,	0xcfff, 0xc10d,		0x21, 0
	.dw 0xd040, 0xc10d,	0xd07f, 0xc10d,		0x21, 0
	.dw 0xd0c0, 0xc10d,	0xd0ff, 0xc10d,		0x21, 0
	.dw 0xd140, 0xc10d,	0xd17f, 0xc10d,		0x21, 0
	.dw 0xd1c0, 0xc10d,	0xd1ff, 0xc10d,		0x21, 0
	.dw 0xd240, 0xc10d,	0xd27f, 0xc10d,		0x21, 0
	.dw 0xd2c0, 0xc10d,	0xd2ff, 0xc10d,		0x21, 0
	.dw 0xd340, 0xc10d,	0xd37f, 0xc10d,		0x21, 0
	.dw 0xd3c0, 0xc10d,	0xd3ff, 0xc10d,		0x21, 0
	.dw 0xd440, 0xc10d,	0xd47f, 0xc10d,		0x21, 0
	.dw 0xd4c0, 0xc10d,	0xd4ff, 0xc10d,		0x21, 0
	.dw 0xd540, 0xc10d,	0xd57f, 0xc10d,		0x21, 0
	.dw 0xd5c0, 0xc10d,	0xd5ff, 0xc10d,		0x21, 0
	.dw 0xd640, 0xc10d,	0xd67f, 0xc10d,		0x21, 0
	.dw 0xd6c0, 0xc10d,	0xd6ff, 0xc10d,		0x21, 0
	.dw 0xd740, 0xc10d,	0xd77f, 0xc10d,		0x21, 0
	.dw 0xd7c0, 0xc10d,	0xd7ff, 0xc10d,		0x21, 0
	.dw 0xd840, 0xc10d,	0xd87f, 0xc10d,		0x21, 0
	.dw 0xd8c0, 0xc10d,	0xd8ff, 0xc10d,		0x21, 0
	.dw 0xd940, 0xc10d,	0xd97f, 0xc10d,		0x21, 0
	.dw 0xd9c0, 0xc10d,	0xdfff, 0xc10d,		0x21, 0
	.dw 0xe040, 0xc10d,	0xe07f, 0xc10d,		0x21, 0
	.dw 0xe0c0, 0xc10d,	0xe0ff, 0xc10d,		0x21, 0
	.dw 0xe140, 0xc10d,	0xe17f, 0xc10d,		0x21, 0
	.dw 0xe1c0, 0xc10d,	0xe1ff, 0xc10d,		0x21, 0
	.dw 0xe240, 0xc10d,	0xe27f, 0xc10d,		0x21, 0
	.dw 0xe2c0, 0xc10d,	0xe2ff, 0xc10d,		0x21, 0
	.dw 0xe340, 0xc10d,	0xe37f, 0xc10d,		0x21, 0
	.dw 0xe3c0, 0xc10d,	0xe3ff, 0xc10d,		0x21, 0
	.dw 0xe440, 0xc10d,	0xe47f, 0xc10d,		0x21, 0
	.dw 0xe4c0, 0xc10d,	0xe4ff, 0xc10d,		0x21, 0
	.dw 0xe540, 0xc10d,	0xe57f, 0xc10d,		0x21, 0
	.dw 0xe5c0, 0xc10d,	0xe5ff, 0xc10d,		0x21, 0
	.dw 0xe640, 0xc10d,	0xe67f, 0xc10d,		0x21, 0
	.dw 0xe6c0, 0xc10d,	0xe6ff, 0xc10d,		0x21, 0
	.dw 0xe740, 0xc10d,	0xe77f, 0xc10d,		0x21, 0
	.dw 0xe7c0, 0xc10d,	0xe7ff, 0xc10d,		0x21, 0
	.dw 0xe840, 0xc10d,	0xe87f, 0xc10d,		0x21, 0
	.dw 0xe8c0, 0xc10d,	0xe8ff, 0xc10d,		0x21, 0
	.dw 0xe940, 0xc10d,	0xe97f, 0xc10d,		0x21, 0
	.dw 0xe9c0, 0xc10d,	0xe9ff, 0xc10d,		0x21, 0
	.dw 0xea40, 0xc10d,	0xea7f, 0xc10d,		0x21, 0
	.dw 0xeac0, 0xc10d,	0xeaff, 0xc10d,		0x21, 0
	.dw 0xeb40, 0xc10d,	0xeb7f, 0xc10d,		0x21, 0
	.dw 0xebc0, 0xc10d,	0xebff, 0xc10d,		0x21, 0
	.dw 0xec40, 0xc10d,	0xec7f, 0xc10d,		0x21, 0
	.dw 0xecc0, 0xc10d,	0xecff, 0xc10d,		0x21, 0
	.dw 0xed40, 0xc10d,	0xed7f, 0xc10d,		0x21, 0
	.dw 0xedc0, 0xc10d,	0xedff, 0xc10d,		0x21, 0
	.dw 0xee40, 0xc10d,	0xee7f, 0xc10d,		0x21, 0
	.dw 0xeec0, 0xc10d,	0xeeff, 0xc10d,		0x21, 0
	.dw 0xef40, 0xc10d,	0xef7f, 0xc10d,		0x21, 0
	.dw 0xefc0, 0xc10d,	0xefff, 0xc10d,		0x21, 0
	.dw 0xf040, 0xc10d,	0xf07f, 0xc10d,		0x21, 0
	.dw 0xf0c0, 0xc10d,	0xf0ff, 0xc10d,		0x21, 0
	.dw 0xf140, 0xc10d,	0xf17f, 0xc10d,		0x21, 0
	.dw 0xf1c0, 0xc10d,	0xf1ff, 0xc10d,		0x21, 0
	.dw 0xf240, 0xc10d,	0xf27f, 0xc10d,		0x21, 0
	.dw 0xf2c0, 0xc10d,	0xf2ff, 0xc10d,		0x21, 0
	.dw 0xf340, 0xc10d,	0xf37f, 0xc10d,		0x21, 0
	.dw 0xf3c0, 0xc10d,	0xf3ff, 0xc10d,		0x21, 0
	.dw 0xf440, 0xc10d,	0xf47f, 0xc10d,		0x21, 0
	.dw 0xf4c0, 0xc10d,	0xf4ff, 0xc10d,		0x21, 0
	.dw 0xf540, 0xc10d,	0xf57f, 0xc10d,		0x21, 0
	.dw 0xf5c0, 0xc10d,	0xf5ff, 0xc10d,		0x21, 0
	.dw 0xf640, 0xc10d,	0xf67f, 0xc10d,		0x21, 0
	.dw 0xf6c0, 0xc10d,	0xf6ff, 0xc10d,		0x21, 0
	.dw 0xf740, 0xc10d,	0xf77f, 0xc10d,		0x21, 0
	.dw 0xf7c0, 0xc10d,	0xf7ff, 0xc10d,		0x21, 0
	.dw 0xf840, 0xc10d,	0xf87f, 0xc10d,		0x21, 0
	.dw 0xf8c0, 0xc10d,	0xf8ff, 0xc10d,		0x21, 0
	.dw 0xf940, 0xc10d,	0xf97f, 0xc10d,		0x21, 0
	.dw 0xf9c0, 0xc10d,	0xffff, 0xc10d,		0x21, 0
	.dw 0x0040, 0xc10e,	0x007f, 0xc10e,		0x21, 0
	.dw 0x00c0, 0xc10e,	0x00ff, 0xc10e,		0x21, 0
	.dw 0x0140, 0xc10e,	0x017f, 0xc10e,		0x21, 0
	.dw 0x01c0, 0xc10e,	0x01ff, 0xc10e,		0x21, 0
	.dw 0x0240, 0xc10e,	0x027f, 0xc10e,		0x21, 0
	.dw 0x02c0, 0xc10e,	0x02ff, 0xc10e,		0x21, 0
	.dw 0x0340, 0xc10e,	0x037f, 0xc10e,		0x21, 0
	.dw 0x03c0, 0xc10e,	0x03ff, 0xc10e,		0x21, 0
	.dw 0x0440, 0xc10e,	0x047f, 0xc10e,		0x21, 0
	.dw 0x04c0, 0xc10e,	0x04ff, 0xc10e,		0x21, 0
	.dw 0x0540, 0xc10e,	0x057f, 0xc10e,		0x21, 0
	.dw 0x05c0, 0xc10e,	0x05ff, 0xc10e,		0x21, 0
	.dw 0x0640, 0xc10e,	0x067f, 0xc10e,		0x21, 0
	.dw 0x06c0, 0xc10e,	0x06ff, 0xc10e,		0x21, 0
	.dw 0x0740, 0xc10e,	0x077f, 0xc10e,		0x21, 0
	.dw 0x07c0, 0xc10e,	0x07ff, 0xc10e,		0x21, 0
	.dw 0x0840, 0xc10e,	0x087f, 0xc10e,		0x21, 0
	.dw 0x08c0, 0xc10e,	0x08ff, 0xc10e,		0x21, 0
	.dw 0x0940, 0xc10e,	0x097f, 0xc10e,		0x21, 0
	.dw 0x09c0, 0xc10e,	0x09ff, 0xc10e,		0x21, 0
	.dw 0x0a40, 0xc10e,	0x0a7f, 0xc10e,		0x21, 0
	.dw 0x0ac0, 0xc10e,	0x0aff, 0xc10e,		0x21, 0
	.dw 0x0b40, 0xc10e,	0x0b7f, 0xc10e,		0x21, 0
	.dw 0x0bc0, 0xc10e,	0x0bff, 0xc10e,		0x21, 0
	.dw 0x0c40, 0xc10e,	0x0c7f, 0xc10e,		0x21, 0
	.dw 0x0cc0, 0xc10e,	0x0cff, 0xc10e,		0x21, 0
	.dw 0x0d40, 0xc10e,	0x0d7f, 0xc10e,		0x21, 0
	.dw 0x0dc0, 0xc10e,	0x0dff, 0xc10e,		0x21, 0
	.dw 0x0e40, 0xc10e,	0x0e7f, 0xc10e,		0x21, 0
	.dw 0x0ec0, 0xc10e,	0x0eff, 0xc10e,		0x21, 0
	.dw 0x0f40, 0xc10e,	0x0f7f, 0xc10e,		0x21, 0
	.dw 0x0fc0, 0xc10e,	0x0fff, 0xc10e,		0x21, 0
	.dw 0x1040, 0xc10e,	0x107f, 0xc10e,		0x21, 0
	.dw 0x10c0, 0xc10e,	0x10ff, 0xc10e,		0x21, 0
	.dw 0x1140, 0xc10e,	0x117f, 0xc10e,		0x21, 0
	.dw 0x11c0, 0xc10e,	0x11ff, 0xc10e,		0x21, 0
	.dw 0x1240, 0xc10e,	0x127f, 0xc10e,		0x21, 0
	.dw 0x12c0, 0xc10e,	0x12ff, 0xc10e,		0x21, 0
	.dw 0x1340, 0xc10e,	0x137f, 0xc10e,		0x21, 0
	.dw 0x13c0, 0xc10e,	0x13ff, 0xc10e,		0x21, 0
	.dw 0x1440, 0xc10e,	0x147f, 0xc10e,		0x21, 0
	.dw 0x14c0, 0xc10e,	0x14ff, 0xc10e,		0x21, 0
	.dw 0x1540, 0xc10e,	0x157f, 0xc10e,		0x21, 0
	.dw 0x15c0, 0xc10e,	0x15ff, 0xc10e,		0x21, 0
	.dw 0x1640, 0xc10e,	0x167f, 0xc10e,		0x21, 0
	.dw 0x16c0, 0xc10e,	0x16ff, 0xc10e,		0x21, 0
	.dw 0x1740, 0xc10e,	0x177f, 0xc10e,		0x21, 0
	.dw 0x17c0, 0xc10e,	0x17ff, 0xc10e,		0x21, 0
	.dw 0x1840, 0xc10e,	0x187f, 0xc10e,		0x21, 0
	.dw 0x18c0, 0xc10e,	0x18ff, 0xc10e,		0x21, 0
	.dw 0x1940, 0xc10e,	0x197f, 0xc10e,		0x21, 0
	.dw 0x19c0, 0xc10e,	0x1fff, 0xc10e,		0x21, 0
	.dw 0x2040, 0xc10e,	0x207f, 0xc10e,		0x21, 0
	.dw 0x20c0, 0xc10e,	0x20ff, 0xc10e,		0x21, 0
	.dw 0x2140, 0xc10e,	0x217f, 0xc10e,		0x21, 0
	.dw 0x21c0, 0xc10e,	0x21ff, 0xc10e,		0x21, 0
	.dw 0x2240, 0xc10e,	0x227f, 0xc10e,		0x21, 0
	.dw 0x22c0, 0xc10e,	0x22ff, 0xc10e,		0x21, 0
	.dw 0x2340, 0xc10e,	0x237f, 0xc10e,		0x21, 0
	.dw 0x23c0, 0xc10e,	0x23ff, 0xc10e,		0x21, 0
	.dw 0x2440, 0xc10e,	0x247f, 0xc10e,		0x21, 0
	.dw 0x24c0, 0xc10e,	0x24ff, 0xc10e,		0x21, 0
	.dw 0x2540, 0xc10e,	0x257f, 0xc10e,		0x21, 0
	.dw 0x25c0, 0xc10e,	0x25ff, 0xc10e,		0x21, 0
	.dw 0x2640, 0xc10e,	0x267f, 0xc10e,		0x21, 0
	.dw 0x26c0, 0xc10e,	0x26ff, 0xc10e,		0x21, 0
	.dw 0x2740, 0xc10e,	0x277f, 0xc10e,		0x21, 0
	.dw 0x27c0, 0xc10e,	0x27ff, 0xc10e,		0x21, 0
	.dw 0x2840, 0xc10e,	0x287f, 0xc10e,		0x21, 0
	.dw 0x28c0, 0xc10e,	0x28ff, 0xc10e,		0x21, 0
	.dw 0x2940, 0xc10e,	0x297f, 0xc10e,		0x21, 0
	.dw 0x29c0, 0xc10e,	0x29ff, 0xc10e,		0x21, 0
	.dw 0x2a40, 0xc10e,	0x2a7f, 0xc10e,		0x21, 0
	.dw 0x2ac0, 0xc10e,	0x2aff, 0xc10e,		0x21, 0
	.dw 0x2b40, 0xc10e,	0x2b7f, 0xc10e,		0x21, 0
	.dw 0x2bc0, 0xc10e,	0x2bff, 0xc10e,		0x21, 0
	.dw 0x2c40, 0xc10e,	0x2c7f, 0xc10e,		0x21, 0
	.dw 0x2cc0, 0xc10e,	0x2cff, 0xc10e,		0x21, 0
	.dw 0x2d40, 0xc10e,	0x2d7f, 0xc10e,		0x21, 0
	.dw 0x2dc0, 0xc10e,	0x2dff, 0xc10e,		0x21, 0
	.dw 0x2e40, 0xc10e,	0x2e7f, 0xc10e,		0x21, 0
	.dw 0x2ec0, 0xc10e,	0x2eff, 0xc10e,		0x21, 0
	.dw 0x2f40, 0xc10e,	0x2f7f, 0xc10e,		0x21, 0
	.dw 0x2fc0, 0xc10e,	0x2fff, 0xc10e,		0x21, 0
	.dw 0x3040, 0xc10e,	0x307f, 0xc10e,		0x21, 0
	.dw 0x30c0, 0xc10e,	0x30ff, 0xc10e,		0x21, 0
	.dw 0x3140, 0xc10e,	0x317f, 0xc10e,		0x21, 0
	.dw 0x31c0, 0xc10e,	0x31ff, 0xc10e,		0x21, 0
	.dw 0x3240, 0xc10e,	0x327f, 0xc10e,		0x21, 0
	.dw 0x32c0, 0xc10e,	0x32ff, 0xc10e,		0x21, 0
	.dw 0x3340, 0xc10e,	0x337f, 0xc10e,		0x21, 0
	.dw 0x33c0, 0xc10e,	0x33ff, 0xc10e,		0x21, 0
	.dw 0x3440, 0xc10e,	0x347f, 0xc10e,		0x21, 0
	.dw 0x34c0, 0xc10e,	0x34ff, 0xc10e,		0x21, 0
	.dw 0x3540, 0xc10e,	0x357f, 0xc10e,		0x21, 0
	.dw 0x35c0, 0xc10e,	0x35ff, 0xc10e,		0x21, 0
	.dw 0x3640, 0xc10e,	0x367f, 0xc10e,		0x21, 0
	.dw 0x36c0, 0xc10e,	0x36ff, 0xc10e,		0x21, 0
	.dw 0x3740, 0xc10e,	0x377f, 0xc10e,		0x21, 0
	.dw 0x37c0, 0xc10e,	0x37ff, 0xc10e,		0x21, 0
	.dw 0x3840, 0xc10e,	0x387f, 0xc10e,		0x21, 0
	.dw 0x38c0, 0xc10e,	0x38ff, 0xc10e,		0x21, 0
	.dw 0x3940, 0xc10e,	0x397f, 0xc10e,		0x21, 0
	.dw 0x39c0, 0xc10e,	0x3fff, 0xc10e,		0x21, 0
	.dw 0x4040, 0xc10e,	0x407f, 0xc10e,		0x21, 0
	.dw 0x40c0, 0xc10e,	0x40ff, 0xc10e,		0x21, 0
	.dw 0x4140, 0xc10e,	0x417f, 0xc10e,		0x21, 0
	.dw 0x41c0, 0xc10e,	0x41ff, 0xc10e,		0x21, 0
	.dw 0x4240, 0xc10e,	0x427f, 0xc10e,		0x21, 0
	.dw 0x42c0, 0xc10e,	0x42ff, 0xc10e,		0x21, 0
	.dw 0x4340, 0xc10e,	0x437f, 0xc10e,		0x21, 0
	.dw 0x43c0, 0xc10e,	0x43ff, 0xc10e,		0x21, 0
	.dw 0x4440, 0xc10e,	0x447f, 0xc10e,		0x21, 0
	.dw 0x44c0, 0xc10e,	0x44ff, 0xc10e,		0x21, 0
	.dw 0x4540, 0xc10e,	0x457f, 0xc10e,		0x21, 0
	.dw 0x45c0, 0xc10e,	0x45ff, 0xc10e,		0x21, 0
	.dw 0x4640, 0xc10e,	0x467f, 0xc10e,		0x21, 0
	.dw 0x46c0, 0xc10e,	0x46ff, 0xc10e,		0x21, 0
	.dw 0x4740, 0xc10e,	0x477f, 0xc10e,		0x21, 0
	.dw 0x47c0, 0xc10e,	0x47ff, 0xc10e,		0x21, 0
	.dw 0x4840, 0xc10e,	0x487f, 0xc10e,		0x21, 0
	.dw 0x48c0, 0xc10e,	0x48ff, 0xc10e,		0x21, 0
	.dw 0x4940, 0xc10e,	0x497f, 0xc10e,		0x21, 0
	.dw 0x49c0, 0xc10e,	0x49ff, 0xc10e,		0x21, 0
	.dw 0x4a40, 0xc10e,	0x4a7f, 0xc10e,		0x21, 0
	.dw 0x4ac0, 0xc10e,	0x4aff, 0xc10e,		0x21, 0
	.dw 0x4b40, 0xc10e,	0x4b7f, 0xc10e,		0x21, 0
	.dw 0x4bc0, 0xc10e,	0x4bff, 0xc10e,		0x21, 0
	.dw 0x4c40, 0xc10e,	0x4c7f, 0xc10e,		0x21, 0
	.dw 0x4cc0, 0xc10e,	0x4cff, 0xc10e,		0x21, 0
	.dw 0x4d40, 0xc10e,	0x4d7f, 0xc10e,		0x21, 0
	.dw 0x4dc0, 0xc10e,	0x4dff, 0xc10e,		0x21, 0
	.dw 0x4e40, 0xc10e,	0x4e7f, 0xc10e,		0x21, 0
	.dw 0x4ec0, 0xc10e,	0x4eff, 0xc10e,		0x21, 0
	.dw 0x4f40, 0xc10e,	0x4f7f, 0xc10e,		0x21, 0
	.dw 0x4fc0, 0xc10e,	0x4fff, 0xc10e,		0x21, 0
	.dw 0x5040, 0xc10e,	0x507f, 0xc10e,		0x21, 0
	.dw 0x50c0, 0xc10e,	0x50ff, 0xc10e,		0x21, 0
	.dw 0x5140, 0xc10e,	0x517f, 0xc10e,		0x21, 0
	.dw 0x51c0, 0xc10e,	0x51ff, 0xc10e,		0x21, 0
	.dw 0x5240, 0xc10e,	0x527f, 0xc10e,		0x21, 0
	.dw 0x52c0, 0xc10e,	0x52ff, 0xc10e,		0x21, 0
	.dw 0x5340, 0xc10e,	0x537f, 0xc10e,		0x21, 0
	.dw 0x53c0, 0xc10e,	0x53ff, 0xc10e,		0x21, 0
	.dw 0x5440, 0xc10e,	0x547f, 0xc10e,		0x21, 0
	.dw 0x54c0, 0xc10e,	0x54ff, 0xc10e,		0x21, 0
	.dw 0x5540, 0xc10e,	0x557f, 0xc10e,		0x21, 0
	.dw 0x55c0, 0xc10e,	0x55ff, 0xc10e,		0x21, 0
	.dw 0x5640, 0xc10e,	0x567f, 0xc10e,		0x21, 0
	.dw 0x56c0, 0xc10e,	0x56ff, 0xc10e,		0x21, 0
	.dw 0x5740, 0xc10e,	0x577f, 0xc10e,		0x21, 0
	.dw 0x57c0, 0xc10e,	0x57ff, 0xc10e,		0x21, 0
	.dw 0x5840, 0xc10e,	0x587f, 0xc10e,		0x21, 0
	.dw 0x58c0, 0xc10e,	0x58ff, 0xc10e,		0x21, 0
	.dw 0x5940, 0xc10e,	0x597f, 0xc10e,		0x21, 0
	.dw 0x59c0, 0xc10e,	0x5fff, 0xc10e,		0x21, 0
	.dw 0x6040, 0xc10e,	0x607f, 0xc10e,		0x21, 0
	.dw 0x60c0, 0xc10e,	0x60ff, 0xc10e,		0x21, 0
	.dw 0x6140, 0xc10e,	0x617f, 0xc10e,		0x21, 0
	.dw 0x61c0, 0xc10e,	0x61ff, 0xc10e,		0x21, 0
	.dw 0x6240, 0xc10e,	0x627f, 0xc10e,		0x21, 0
	.dw 0x62c0, 0xc10e,	0x62ff, 0xc10e,		0x21, 0
	.dw 0x6340, 0xc10e,	0x637f, 0xc10e,		0x21, 0
	.dw 0x63c0, 0xc10e,	0x63ff, 0xc10e,		0x21, 0
	.dw 0x6440, 0xc10e,	0x647f, 0xc10e,		0x21, 0
	.dw 0x64c0, 0xc10e,	0x64ff, 0xc10e,		0x21, 0
	.dw 0x6540, 0xc10e,	0x657f, 0xc10e,		0x21, 0
	.dw 0x65c0, 0xc10e,	0x65ff, 0xc10e,		0x21, 0
	.dw 0x6640, 0xc10e,	0x667f, 0xc10e,		0x21, 0
	.dw 0x66c0, 0xc10e,	0x66ff, 0xc10e,		0x21, 0
	.dw 0x6740, 0xc10e,	0x677f, 0xc10e,		0x21, 0
	.dw 0x67c0, 0xc10e,	0x67ff, 0xc10e,		0x21, 0
	.dw 0x6840, 0xc10e,	0x687f, 0xc10e,		0x21, 0
	.dw 0x68c0, 0xc10e,	0x68ff, 0xc10e,		0x21, 0
	.dw 0x6940, 0xc10e,	0x697f, 0xc10e,		0x21, 0
	.dw 0x69c0, 0xc10e,	0x69ff, 0xc10e,		0x21, 0
	.dw 0x6a40, 0xc10e,	0x6a7f, 0xc10e,		0x21, 0
	.dw 0x6ac0, 0xc10e,	0x6aff, 0xc10e,		0x21, 0
	.dw 0x6b40, 0xc10e,	0x6b7f, 0xc10e,		0x21, 0
	.dw 0x6bc0, 0xc10e,	0x6bff, 0xc10e,		0x21, 0
	.dw 0x6c40, 0xc10e,	0x6c7f, 0xc10e,		0x21, 0
	.dw 0x6cc0, 0xc10e,	0x6cff, 0xc10e,		0x21, 0
	.dw 0x6d40, 0xc10e,	0x6d7f, 0xc10e,		0x21, 0
	.dw 0x6dc0, 0xc10e,	0x6dff, 0xc10e,		0x21, 0
	.dw 0x6e40, 0xc10e,	0x6e7f, 0xc10e,		0x21, 0
	.dw 0x6ec0, 0xc10e,	0x6eff, 0xc10e,		0x21, 0
	.dw 0x6f40, 0xc10e,	0x6f7f, 0xc10e,		0x21, 0
	.dw 0x6fc0, 0xc10e,	0x6fff, 0xc10e,		0x21, 0
	.dw 0x7040, 0xc10e,	0x707f, 0xc10e,		0x21, 0
	.dw 0x70c0, 0xc10e,	0x70ff, 0xc10e,		0x21, 0
	.dw 0x7140, 0xc10e,	0x717f, 0xc10e,		0x21, 0
	.dw 0x71c0, 0xc10e,	0x71ff, 0xc10e,		0x21, 0
	.dw 0x7240, 0xc10e,	0x727f, 0xc10e,		0x21, 0
	.dw 0x72c0, 0xc10e,	0x72ff, 0xc10e,		0x21, 0
	.dw 0x7340, 0xc10e,	0x737f, 0xc10e,		0x21, 0
	.dw 0x73c0, 0xc10e,	0x73ff, 0xc10e,		0x21, 0
	.dw 0x7440, 0xc10e,	0x747f, 0xc10e,		0x21, 0
	.dw 0x74c0, 0xc10e,	0x74ff, 0xc10e,		0x21, 0
	.dw 0x7540, 0xc10e,	0x757f, 0xc10e,		0x21, 0
	.dw 0x75c0, 0xc10e,	0x75ff, 0xc10e,		0x21, 0
	.dw 0x7640, 0xc10e,	0x767f, 0xc10e,		0x21, 0
	.dw 0x76c0, 0xc10e,	0x76ff, 0xc10e,		0x21, 0
	.dw 0x7740, 0xc10e,	0x777f, 0xc10e,		0x21, 0
	.dw 0x77c0, 0xc10e,	0x77ff, 0xc10e,		0x21, 0
	.dw 0x7840, 0xc10e,	0x787f, 0xc10e,		0x21, 0
	.dw 0x78c0, 0xc10e,	0x78ff, 0xc10e,		0x21, 0
	.dw 0x7940, 0xc10e,	0x797f, 0xc10e,		0x21, 0
	.dw 0x79c0, 0xc10e,	0x7fff, 0xc10e,		0x21, 0
	.dw 0x8040, 0xc10e,	0x807f, 0xc10e,		0x21, 0
	.dw 0x80c0, 0xc10e,	0x80ff, 0xc10e,		0x21, 0
	.dw 0x8140, 0xc10e,	0x817f, 0xc10e,		0x21, 0
	.dw 0x81c0, 0xc10e,	0x81ff, 0xc10e,		0x21, 0
	.dw 0x8240, 0xc10e,	0x827f, 0xc10e,		0x21, 0
	.dw 0x82c0, 0xc10e,	0x82ff, 0xc10e,		0x21, 0
	.dw 0x8340, 0xc10e,	0x837f, 0xc10e,		0x21, 0
	.dw 0x83c0, 0xc10e,	0x83ff, 0xc10e,		0x21, 0
	.dw 0x8440, 0xc10e,	0x847f, 0xc10e,		0x21, 0
	.dw 0x84c0, 0xc10e,	0x84ff, 0xc10e,		0x21, 0
	.dw 0x8540, 0xc10e,	0x857f, 0xc10e,		0x21, 0
	.dw 0x85c0, 0xc10e,	0x85ff, 0xc10e,		0x21, 0
	.dw 0x8640, 0xc10e,	0x867f, 0xc10e,		0x21, 0
	.dw 0x86c0, 0xc10e,	0x86ff, 0xc10e,		0x21, 0
	.dw 0x8740, 0xc10e,	0x877f, 0xc10e,		0x21, 0
	.dw 0x87c0, 0xc10e,	0x87ff, 0xc10e,		0x21, 0
	.dw 0x8840, 0xc10e,	0x887f, 0xc10e,		0x21, 0
	.dw 0x88c0, 0xc10e,	0x88ff, 0xc10e,		0x21, 0
	.dw 0x8940, 0xc10e,	0x897f, 0xc10e,		0x21, 0
	.dw 0x89c0, 0xc10e,	0x89ff, 0xc10e,		0x21, 0
	.dw 0x8a40, 0xc10e,	0x8a7f, 0xc10e,		0x21, 0
	.dw 0x8ac0, 0xc10e,	0x8aff, 0xc10e,		0x21, 0
	.dw 0x8b40, 0xc10e,	0x8b7f, 0xc10e,		0x21, 0
	.dw 0x8bc0, 0xc10e,	0x8bff, 0xc10e,		0x21, 0
	.dw 0x8c40, 0xc10e,	0x8c7f, 0xc10e,		0x21, 0
	.dw 0x8cc0, 0xc10e,	0x8cff, 0xc10e,		0x21, 0
	.dw 0x8d40, 0xc10e,	0x8d7f, 0xc10e,		0x21, 0
	.dw 0x8dc0, 0xc10e,	0x8dff, 0xc10e,		0x21, 0
	.dw 0x8e40, 0xc10e,	0x8e7f, 0xc10e,		0x21, 0
	.dw 0x8ec0, 0xc10e,	0x8eff, 0xc10e,		0x21, 0
	.dw 0x8f40, 0xc10e,	0x8f7f, 0xc10e,		0x21, 0
	.dw 0x8fc0, 0xc10e,	0x8fff, 0xc10e,		0x21, 0
	.dw 0x9040, 0xc10e,	0x907f, 0xc10e,		0x21, 0
	.dw 0x90c0, 0xc10e,	0x90ff, 0xc10e,		0x21, 0
	.dw 0x9140, 0xc10e,	0x917f, 0xc10e,		0x21, 0
	.dw 0x91c0, 0xc10e,	0x91ff, 0xc10e,		0x21, 0
	.dw 0x9240, 0xc10e,	0x927f, 0xc10e,		0x21, 0
	.dw 0x92c0, 0xc10e,	0x92ff, 0xc10e,		0x21, 0
	.dw 0x9340, 0xc10e,	0x937f, 0xc10e,		0x21, 0
	.dw 0x93c0, 0xc10e,	0x93ff, 0xc10e,		0x21, 0
	.dw 0x9440, 0xc10e,	0x947f, 0xc10e,		0x21, 0
	.dw 0x94c0, 0xc10e,	0x94ff, 0xc10e,		0x21, 0
	.dw 0x9540, 0xc10e,	0x957f, 0xc10e,		0x21, 0
	.dw 0x95c0, 0xc10e,	0x95ff, 0xc10e,		0x21, 0
	.dw 0x9640, 0xc10e,	0x967f, 0xc10e,		0x21, 0
	.dw 0x96c0, 0xc10e,	0x96ff, 0xc10e,		0x21, 0
	.dw 0x9740, 0xc10e,	0x977f, 0xc10e,		0x21, 0
	.dw 0x97c0, 0xc10e,	0x97ff, 0xc10e,		0x21, 0
	.dw 0x9840, 0xc10e,	0x987f, 0xc10e,		0x21, 0
	.dw 0x98c0, 0xc10e,	0x98ff, 0xc10e,		0x21, 0
	.dw 0x9940, 0xc10e,	0x997f, 0xc10e,		0x21, 0
	.dw 0x99c0, 0xc10e,	0x9fff, 0xc10e,		0x21, 0
	.dw 0xa040, 0xc10e,	0xa07f, 0xc10e,		0x21, 0
	.dw 0xa0c0, 0xc10e,	0xa0ff, 0xc10e,		0x21, 0
	.dw 0xa140, 0xc10e,	0xa17f, 0xc10e,		0x21, 0
	.dw 0xa1c0, 0xc10e,	0xa1ff, 0xc10e,		0x21, 0
	.dw 0xa240, 0xc10e,	0xa27f, 0xc10e,		0x21, 0
	.dw 0xa2c0, 0xc10e,	0xa2ff, 0xc10e,		0x21, 0
	.dw 0xa340, 0xc10e,	0xa37f, 0xc10e,		0x21, 0
	.dw 0xa3c0, 0xc10e,	0xa3ff, 0xc10e,		0x21, 0
	.dw 0xa440, 0xc10e,	0xa47f, 0xc10e,		0x21, 0
	.dw 0xa4c0, 0xc10e,	0xa4ff, 0xc10e,		0x21, 0
	.dw 0xa540, 0xc10e,	0xa57f, 0xc10e,		0x21, 0
	.dw 0xa5c0, 0xc10e,	0xa5ff, 0xc10e,		0x21, 0
	.dw 0xa640, 0xc10e,	0xa67f, 0xc10e,		0x21, 0
	.dw 0xa6c0, 0xc10e,	0xa6ff, 0xc10e,		0x21, 0
	.dw 0xa740, 0xc10e,	0xa77f, 0xc10e,		0x21, 0
	.dw 0xa7c0, 0xc10e,	0xa7ff, 0xc10e,		0x21, 0
	.dw 0xa840, 0xc10e,	0xa87f, 0xc10e,		0x21, 0
	.dw 0xa8c0, 0xc10e,	0xa8ff, 0xc10e,		0x21, 0
	.dw 0xa940, 0xc10e,	0xa97f, 0xc10e,		0x21, 0
	.dw 0xa9c0, 0xc10e,	0xa9ff, 0xc10e,		0x21, 0
	.dw 0xaa40, 0xc10e,	0xaa7f, 0xc10e,		0x21, 0
	.dw 0xaac0, 0xc10e,	0xaaff, 0xc10e,		0x21, 0
	.dw 0xab40, 0xc10e,	0xab7f, 0xc10e,		0x21, 0
	.dw 0xabc0, 0xc10e,	0xabff, 0xc10e,		0x21, 0
	.dw 0xac40, 0xc10e,	0xac7f, 0xc10e,		0x21, 0
	.dw 0xacc0, 0xc10e,	0xacff, 0xc10e,		0x21, 0
	.dw 0xad40, 0xc10e,	0xad7f, 0xc10e,		0x21, 0
	.dw 0xadc0, 0xc10e,	0xadff, 0xc10e,		0x21, 0
	.dw 0xae40, 0xc10e,	0xae7f, 0xc10e,		0x21, 0
	.dw 0xaec0, 0xc10e,	0xaeff, 0xc10e,		0x21, 0
	.dw 0xaf40, 0xc10e,	0xaf7f, 0xc10e,		0x21, 0
	.dw 0xafc0, 0xc10e,	0xafff, 0xc10e,		0x21, 0
	.dw 0xb040, 0xc10e,	0xb07f, 0xc10e,		0x21, 0
	.dw 0xb0c0, 0xc10e,	0xb0ff, 0xc10e,		0x21, 0
	.dw 0xb140, 0xc10e,	0xb17f, 0xc10e,		0x21, 0
	.dw 0xb1c0, 0xc10e,	0xb1ff, 0xc10e,		0x21, 0
	.dw 0xb240, 0xc10e,	0xb27f, 0xc10e,		0x21, 0
	.dw 0xb2c0, 0xc10e,	0xb2ff, 0xc10e,		0x21, 0
	.dw 0xb340, 0xc10e,	0xb37f, 0xc10e,		0x21, 0
	.dw 0xb3c0, 0xc10e,	0xb3ff, 0xc10e,		0x21, 0
	.dw 0xb440, 0xc10e,	0xb47f, 0xc10e,		0x21, 0
	.dw 0xb4c0, 0xc10e,	0xb4ff, 0xc10e,		0x21, 0
	.dw 0xb540, 0xc10e,	0xb57f, 0xc10e,		0x21, 0
	.dw 0xb5c0, 0xc10e,	0xb5ff, 0xc10e,		0x21, 0
	.dw 0xb640, 0xc10e,	0xb67f, 0xc10e,		0x21, 0
	.dw 0xb6c0, 0xc10e,	0xb6ff, 0xc10e,		0x21, 0
	.dw 0xb740, 0xc10e,	0xb77f, 0xc10e,		0x21, 0
	.dw 0xb7c0, 0xc10e,	0xb7ff, 0xc10e,		0x21, 0
	.dw 0xb840, 0xc10e,	0xb87f, 0xc10e,		0x21, 0
	.dw 0xb8c0, 0xc10e,	0xb8ff, 0xc10e,		0x21, 0
	.dw 0xb940, 0xc10e,	0xb97f, 0xc10e,		0x21, 0
	.dw 0xb9c0, 0xc10e,	0xbfff, 0xc10e,		0x21, 0
	.dw 0xc040, 0xc10e,	0xc07f, 0xc10e,		0x21, 0
	.dw 0xc0c0, 0xc10e,	0xc0ff, 0xc10e,		0x21, 0
	.dw 0xc140, 0xc10e,	0xc17f, 0xc10e,		0x21, 0
	.dw 0xc1c0, 0xc10e,	0xc1ff, 0xc10e,		0x21, 0
	.dw 0xc240, 0xc10e,	0xc27f, 0xc10e,		0x21, 0
	.dw 0xc2c0, 0xc10e,	0xc2ff, 0xc10e,		0x21, 0
	.dw 0xc340, 0xc10e,	0xc37f, 0xc10e,		0x21, 0
	.dw 0xc3c0, 0xc10e,	0xc3ff, 0xc10e,		0x21, 0
	.dw 0xc440, 0xc10e,	0xc47f, 0xc10e,		0x21, 0
	.dw 0xc4c0, 0xc10e,	0xc4ff, 0xc10e,		0x21, 0
	.dw 0xc540, 0xc10e,	0xc57f, 0xc10e,		0x21, 0
	.dw 0xc5c0, 0xc10e,	0xc5ff, 0xc10e,		0x21, 0
	.dw 0xc640, 0xc10e,	0xc67f, 0xc10e,		0x21, 0
	.dw 0xc6c0, 0xc10e,	0xc6ff, 0xc10e,		0x21, 0
	.dw 0xc740, 0xc10e,	0xc77f, 0xc10e,		0x21, 0
	.dw 0xc7c0, 0xc10e,	0xc7ff, 0xc10e,		0x21, 0
	.dw 0xc840, 0xc10e,	0xc87f, 0xc10e,		0x21, 0
	.dw 0xc8c0, 0xc10e,	0xc8ff, 0xc10e,		0x21, 0
	.dw 0xc940, 0xc10e,	0xc97f, 0xc10e,		0x21, 0
	.dw 0xc9c0, 0xc10e,	0xc9ff, 0xc10e,		0x21, 0
	.dw 0xca40, 0xc10e,	0xca7f, 0xc10e,		0x21, 0
	.dw 0xcac0, 0xc10e,	0xcaff, 0xc10e,		0x21, 0
	.dw 0xcb40, 0xc10e,	0xcb7f, 0xc10e,		0x21, 0
	.dw 0xcbc0, 0xc10e,	0xcbff, 0xc10e,		0x21, 0
	.dw 0xcc40, 0xc10e,	0xcc7f, 0xc10e,		0x21, 0
	.dw 0xccc0, 0xc10e,	0xccff, 0xc10e,		0x21, 0
	.dw 0xcd40, 0xc10e,	0xcd7f, 0xc10e,		0x21, 0
	.dw 0xcdc0, 0xc10e,	0xcdff, 0xc10e,		0x21, 0
	.dw 0xce40, 0xc10e,	0xce7f, 0xc10e,		0x21, 0
	.dw 0xcec0, 0xc10e,	0xceff, 0xc10e,		0x21, 0
	.dw 0xcf40, 0xc10e,	0xcf7f, 0xc10e,		0x21, 0
	.dw 0xcfc0, 0xc10e,	0xcfff, 0xc10e,		0x21, 0
	.dw 0xd040, 0xc10e,	0xd07f, 0xc10e,		0x21, 0
	.dw 0xd0c0, 0xc10e,	0xd0ff, 0xc10e,		0x21, 0
	.dw 0xd140, 0xc10e,	0xd17f, 0xc10e,		0x21, 0
	.dw 0xd1c0, 0xc10e,	0xd1ff, 0xc10e,		0x21, 0
	.dw 0xd240, 0xc10e,	0xd27f, 0xc10e,		0x21, 0
	.dw 0xd2c0, 0xc10e,	0xd2ff, 0xc10e,		0x21, 0
	.dw 0xd340, 0xc10e,	0xd37f, 0xc10e,		0x21, 0
	.dw 0xd3c0, 0xc10e,	0xd3ff, 0xc10e,		0x21, 0
	.dw 0xd440, 0xc10e,	0xd47f, 0xc10e,		0x21, 0
	.dw 0xd4c0, 0xc10e,	0xd4ff, 0xc10e,		0x21, 0
	.dw 0xd540, 0xc10e,	0xd57f, 0xc10e,		0x21, 0
	.dw 0xd5c0, 0xc10e,	0xd5ff, 0xc10e,		0x21, 0
	.dw 0xd640, 0xc10e,	0xd67f, 0xc10e,		0x21, 0
	.dw 0xd6c0, 0xc10e,	0xd6ff, 0xc10e,		0x21, 0
	.dw 0xd740, 0xc10e,	0xd77f, 0xc10e,		0x21, 0
	.dw 0xd7c0, 0xc10e,	0xd7ff, 0xc10e,		0x21, 0
	.dw 0xd840, 0xc10e,	0xd87f, 0xc10e,		0x21, 0
	.dw 0xd8c0, 0xc10e,	0xd8ff, 0xc10e,		0x21, 0
	.dw 0xd940, 0xc10e,	0xd97f, 0xc10e,		0x21, 0
	.dw 0xd9c0, 0xc10e,	0xdfff, 0xc10e,		0x21, 0
	.dw 0xe040, 0xc10e,	0xe07f, 0xc10e,		0x21, 0
	.dw 0xe0c0, 0xc10e,	0xe0ff, 0xc10e,		0x21, 0
	.dw 0xe140, 0xc10e,	0xe17f, 0xc10e,		0x21, 0
	.dw 0xe1c0, 0xc10e,	0xe1ff, 0xc10e,		0x21, 0
	.dw 0xe240, 0xc10e,	0xe27f, 0xc10e,		0x21, 0
	.dw 0xe2c0, 0xc10e,	0xe2ff, 0xc10e,		0x21, 0
	.dw 0xe340, 0xc10e,	0xe37f, 0xc10e,		0x21, 0
	.dw 0xe3c0, 0xc10e,	0xe3ff, 0xc10e,		0x21, 0
	.dw 0xe440, 0xc10e,	0xe47f, 0xc10e,		0x21, 0
	.dw 0xe4c0, 0xc10e,	0xe4ff, 0xc10e,		0x21, 0
	.dw 0xe540, 0xc10e,	0xe57f, 0xc10e,		0x21, 0
	.dw 0xe5c0, 0xc10e,	0xe5ff, 0xc10e,		0x21, 0
	.dw 0xe640, 0xc10e,	0xe67f, 0xc10e,		0x21, 0
	.dw 0xe6c0, 0xc10e,	0xe6ff, 0xc10e,		0x21, 0
	.dw 0xe740, 0xc10e,	0xe77f, 0xc10e,		0x21, 0
	.dw 0xe7c0, 0xc10e,	0xe7ff, 0xc10e,		0x21, 0
	.dw 0xe840, 0xc10e,	0xe87f, 0xc10e,		0x21, 0
	.dw 0xe8c0, 0xc10e,	0xe8ff, 0xc10e,		0x21, 0
	.dw 0xe940, 0xc10e,	0xe97f, 0xc10e,		0x21, 0
	.dw 0xe9c0, 0xc10e,	0xe9ff, 0xc10e,		0x21, 0
	.dw 0xea40, 0xc10e,	0xea7f, 0xc10e,		0x21, 0
	.dw 0xeac0, 0xc10e,	0xeaff, 0xc10e,		0x21, 0
	.dw 0xeb40, 0xc10e,	0xeb7f, 0xc10e,		0x21, 0
	.dw 0xebc0, 0xc10e,	0xebff, 0xc10e,		0x21, 0
	.dw 0xec40, 0xc10e,	0xec7f, 0xc10e,		0x21, 0
	.dw 0xecc0, 0xc10e,	0xecff, 0xc10e,		0x21, 0
	.dw 0xed40, 0xc10e,	0xed7f, 0xc10e,		0x21, 0
	.dw 0xedc0, 0xc10e,	0xedff, 0xc10e,		0x21, 0
	.dw 0xee40, 0xc10e,	0xee7f, 0xc10e,		0x21, 0
	.dw 0xeec0, 0xc10e,	0xeeff, 0xc10e,		0x21, 0
	.dw 0xef40, 0xc10e,	0xef7f, 0xc10e,		0x21, 0
	.dw 0xefc0, 0xc10e,	0xefff, 0xc10e,		0x21, 0
	.dw 0xf040, 0xc10e,	0xf07f, 0xc10e,		0x21, 0
	.dw 0xf0c0, 0xc10e,	0xf0ff, 0xc10e,		0x21, 0
	.dw 0xf140, 0xc10e,	0xf17f, 0xc10e,		0x21, 0
	.dw 0xf1c0, 0xc10e,	0xf1ff, 0xc10e,		0x21, 0
	.dw 0xf240, 0xc10e,	0xf27f, 0xc10e,		0x21, 0
	.dw 0xf2c0, 0xc10e,	0xf2ff, 0xc10e,		0x21, 0
	.dw 0xf340, 0xc10e,	0xf37f, 0xc10e,		0x21, 0
	.dw 0xf3c0, 0xc10e,	0xf3ff, 0xc10e,		0x21, 0
	.dw 0xf440, 0xc10e,	0xf47f, 0xc10e,		0x21, 0
	.dw 0xf4c0, 0xc10e,	0xf4ff, 0xc10e,		0x21, 0
	.dw 0xf540, 0xc10e,	0xf57f, 0xc10e,		0x21, 0
	.dw 0xf5c0, 0xc10e,	0xf5ff, 0xc10e,		0x21, 0
	.dw 0xf640, 0xc10e,	0xf67f, 0xc10e,		0x21, 0
	.dw 0xf6c0, 0xc10e,	0xf6ff, 0xc10e,		0x21, 0
	.dw 0xf740, 0xc10e,	0xf77f, 0xc10e,		0x21, 0
	.dw 0xf7c0, 0xc10e,	0xf7ff, 0xc10e,		0x21, 0
	.dw 0xf840, 0xc10e,	0xf87f, 0xc10e,		0x21, 0
	.dw 0xf8c0, 0xc10e,	0xf8ff, 0xc10e,		0x21, 0
	.dw 0xf940, 0xc10e,	0xf97f, 0xc10e,		0x21, 0
	.dw 0xf9c0, 0xc10e,	0xffff, 0xc10e,		0x21, 0
	.dw 0x0040, 0xc10f,	0x007f, 0xc10f,		0x21, 0
	.dw 0x00c0, 0xc10f,	0x00ff, 0xc10f,		0x21, 0
	.dw 0x0140, 0xc10f,	0x017f, 0xc10f,		0x21, 0
	.dw 0x01c0, 0xc10f,	0x01ff, 0xc10f,		0x21, 0
	.dw 0x0240, 0xc10f,	0x027f, 0xc10f,		0x21, 0
	.dw 0x02c0, 0xc10f,	0x02ff, 0xc10f,		0x21, 0
	.dw 0x0340, 0xc10f,	0x037f, 0xc10f,		0x21, 0
	.dw 0x03c0, 0xc10f,	0x03ff, 0xc10f,		0x21, 0
	.dw 0x0440, 0xc10f,	0x047f, 0xc10f,		0x21, 0
	.dw 0x04c0, 0xc10f,	0x04ff, 0xc10f,		0x21, 0
	.dw 0x0540, 0xc10f,	0x057f, 0xc10f,		0x21, 0
	.dw 0x05c0, 0xc10f,	0x05ff, 0xc10f,		0x21, 0
	.dw 0x0640, 0xc10f,	0x067f, 0xc10f,		0x21, 0
	.dw 0x06c0, 0xc10f,	0x06ff, 0xc10f,		0x21, 0
	.dw 0x0740, 0xc10f,	0x077f, 0xc10f,		0x21, 0
	.dw 0x07c0, 0xc10f,	0x07ff, 0xc10f,		0x21, 0
	.dw 0x0840, 0xc10f,	0x087f, 0xc10f,		0x21, 0
	.dw 0x08c0, 0xc10f,	0x08ff, 0xc10f,		0x21, 0
	.dw 0x0940, 0xc10f,	0x097f, 0xc10f,		0x21, 0
	.dw 0x09c0, 0xc10f,	0x09ff, 0xc10f,		0x21, 0
	.dw 0x0a40, 0xc10f,	0x0a7f, 0xc10f,		0x21, 0
	.dw 0x0ac0, 0xc10f,	0x0aff, 0xc10f,		0x21, 0
	.dw 0x0b40, 0xc10f,	0x0b7f, 0xc10f,		0x21, 0
	.dw 0x0bc0, 0xc10f,	0x0bff, 0xc10f,		0x21, 0
	.dw 0x0c40, 0xc10f,	0x0c7f, 0xc10f,		0x21, 0
	.dw 0x0cc0, 0xc10f,	0x0cff, 0xc10f,		0x21, 0
	.dw 0x0d40, 0xc10f,	0x0d7f, 0xc10f,		0x21, 0
	.dw 0x0dc0, 0xc10f,	0x0dff, 0xc10f,		0x21, 0
	.dw 0x0e40, 0xc10f,	0x0e7f, 0xc10f,		0x21, 0
	.dw 0x0ec0, 0xc10f,	0x0eff, 0xc10f,		0x21, 0
	.dw 0x0f40, 0xc10f,	0x0f7f, 0xc10f,		0x21, 0
	.dw 0x0fc0, 0xc10f,	0x0fff, 0xc10f,		0x21, 0
	.dw 0x1040, 0xc10f,	0x107f, 0xc10f,		0x21, 0
	.dw 0x10c0, 0xc10f,	0x10ff, 0xc10f,		0x21, 0
	.dw 0x1140, 0xc10f,	0x117f, 0xc10f,		0x21, 0
	.dw 0x11c0, 0xc10f,	0x11ff, 0xc10f,		0x21, 0
	.dw 0x1240, 0xc10f,	0x127f, 0xc10f,		0x21, 0
	.dw 0x12c0, 0xc10f,	0x12ff, 0xc10f,		0x21, 0
	.dw 0x1340, 0xc10f,	0x137f, 0xc10f,		0x21, 0
	.dw 0x13c0, 0xc10f,	0x13ff, 0xc10f,		0x21, 0
	.dw 0x1440, 0xc10f,	0x147f, 0xc10f,		0x21, 0
	.dw 0x14c0, 0xc10f,	0x14ff, 0xc10f,		0x21, 0
	.dw 0x1540, 0xc10f,	0x157f, 0xc10f,		0x21, 0
	.dw 0x15c0, 0xc10f,	0x15ff, 0xc10f,		0x21, 0
	.dw 0x1640, 0xc10f,	0x167f, 0xc10f,		0x21, 0
	.dw 0x16c0, 0xc10f,	0x16ff, 0xc10f,		0x21, 0
	.dw 0x1740, 0xc10f,	0x177f, 0xc10f,		0x21, 0
	.dw 0x17c0, 0xc10f,	0x17ff, 0xc10f,		0x21, 0
	.dw 0x1840, 0xc10f,	0x187f, 0xc10f,		0x21, 0
	.dw 0x18c0, 0xc10f,	0x18ff, 0xc10f,		0x21, 0
	.dw 0x1940, 0xc10f,	0x197f, 0xc10f,		0x21, 0
	.dw 0x19c0, 0xc10f,	0x1fff, 0xc10f,		0x21, 0
	.dw 0x2040, 0xc10f,	0x207f, 0xc10f,		0x21, 0
	.dw 0x20c0, 0xc10f,	0x20ff, 0xc10f,		0x21, 0
	.dw 0x2140, 0xc10f,	0x217f, 0xc10f,		0x21, 0
	.dw 0x21c0, 0xc10f,	0x21ff, 0xc10f,		0x21, 0
	.dw 0x2240, 0xc10f,	0x227f, 0xc10f,		0x21, 0
	.dw 0x22c0, 0xc10f,	0x22ff, 0xc10f,		0x21, 0
	.dw 0x2340, 0xc10f,	0x237f, 0xc10f,		0x21, 0
	.dw 0x23c0, 0xc10f,	0x23ff, 0xc10f,		0x21, 0
	.dw 0x2440, 0xc10f,	0x247f, 0xc10f,		0x21, 0
	.dw 0x24c0, 0xc10f,	0x24ff, 0xc10f,		0x21, 0
	.dw 0x2540, 0xc10f,	0x257f, 0xc10f,		0x21, 0
	.dw 0x25c0, 0xc10f,	0x25ff, 0xc10f,		0x21, 0
	.dw 0x2640, 0xc10f,	0x267f, 0xc10f,		0x21, 0
	.dw 0x26c0, 0xc10f,	0x26ff, 0xc10f,		0x21, 0
	.dw 0x2740, 0xc10f,	0x277f, 0xc10f,		0x21, 0
	.dw 0x27c0, 0xc10f,	0x27ff, 0xc10f,		0x21, 0
	.dw 0x2840, 0xc10f,	0x287f, 0xc10f,		0x21, 0
	.dw 0x28c0, 0xc10f,	0x28ff, 0xc10f,		0x21, 0
	.dw 0x2940, 0xc10f,	0x297f, 0xc10f,		0x21, 0
	.dw 0x29c0, 0xc10f,	0x29ff, 0xc10f,		0x21, 0
	.dw 0x2a40, 0xc10f,	0x2a7f, 0xc10f,		0x21, 0
	.dw 0x2ac0, 0xc10f,	0x2aff, 0xc10f,		0x21, 0
	.dw 0x2b40, 0xc10f,	0x2b7f, 0xc10f,		0x21, 0
	.dw 0x2bc0, 0xc10f,	0x2bff, 0xc10f,		0x21, 0
	.dw 0x2c40, 0xc10f,	0x2c7f, 0xc10f,		0x21, 0
	.dw 0x2cc0, 0xc10f,	0x2cff, 0xc10f,		0x21, 0
	.dw 0x2d40, 0xc10f,	0x2d7f, 0xc10f,		0x21, 0
	.dw 0x2dc0, 0xc10f,	0x2dff, 0xc10f,		0x21, 0
	.dw 0x2e40, 0xc10f,	0x2e7f, 0xc10f,		0x21, 0
	.dw 0x2ec0, 0xc10f,	0x2eff, 0xc10f,		0x21, 0
	.dw 0x2f40, 0xc10f,	0x2f7f, 0xc10f,		0x21, 0
	.dw 0x2fc0, 0xc10f,	0x2fff, 0xc10f,		0x21, 0
	.dw 0x3040, 0xc10f,	0x307f, 0xc10f,		0x21, 0
	.dw 0x30c0, 0xc10f,	0x30ff, 0xc10f,		0x21, 0
	.dw 0x3140, 0xc10f,	0x317f, 0xc10f,		0x21, 0
	.dw 0x31c0, 0xc10f,	0x31ff, 0xc10f,		0x21, 0
	.dw 0x3240, 0xc10f,	0x327f, 0xc10f,		0x21, 0
	.dw 0x32c0, 0xc10f,	0x32ff, 0xc10f,		0x21, 0
	.dw 0x3340, 0xc10f,	0x337f, 0xc10f,		0x21, 0
	.dw 0x33c0, 0xc10f,	0x33ff, 0xc10f,		0x21, 0
	.dw 0x3440, 0xc10f,	0x347f, 0xc10f,		0x21, 0
	.dw 0x34c0, 0xc10f,	0x34ff, 0xc10f,		0x21, 0
	.dw 0x3540, 0xc10f,	0x357f, 0xc10f,		0x21, 0
	.dw 0x35c0, 0xc10f,	0x35ff, 0xc10f,		0x21, 0
	.dw 0x3640, 0xc10f,	0x367f, 0xc10f,		0x21, 0
	.dw 0x36c0, 0xc10f,	0x36ff, 0xc10f,		0x21, 0
	.dw 0x3740, 0xc10f,	0x377f, 0xc10f,		0x21, 0
	.dw 0x37c0, 0xc10f,	0x37ff, 0xc10f,		0x21, 0
	.dw 0x3840, 0xc10f,	0x387f, 0xc10f,		0x21, 0
	.dw 0x38c0, 0xc10f,	0x38ff, 0xc10f,		0x21, 0
	.dw 0x3940, 0xc10f,	0x397f, 0xc10f,		0x21, 0
	.dw 0x39c0, 0xc10f,	0xffff, 0xc10f,		0x21, 0
	.dw 0x1a00, 0xc110,	0x1fff, 0xc110,		0x21, 0
	.dw 0x3a00, 0xc110,	0x3fff, 0xc110,		0x21, 0
	.dw 0x5a00, 0xc110,	0x5fff, 0xc110,		0x21, 0
	.dw 0x7a00, 0xc110,	0x7fff, 0xc110,		0x21, 0
	.dw 0x9a00, 0xc110,	0x9fff, 0xc110,		0x21, 0
	.dw 0xba00, 0xc110,	0xbfff, 0xc110,		0x21, 0
	.dw 0xda00, 0xc110,	0xdfff, 0xc110,		0x21, 0
	.dw 0xfa00, 0xc110,	0xffff, 0xc110,		0x21, 0
	.dw 0x1a00, 0xc111,	0x1fff, 0xc111,		0x21, 0
	.dw 0x3a00, 0xc111,	0x3fff, 0xc111,		0x21, 0
	.dw 0x5a00, 0xc111,	0x5fff, 0xc111,		0x21, 0
	.dw 0x7a00, 0xc111,	0x7fff, 0xc111,		0x21, 0
	.dw 0x9a00, 0xc111,	0x9fff, 0xc111,		0x21, 0
	.dw 0xba00, 0xc111,	0xbfff, 0xc111,		0x21, 0
	.dw 0xda00, 0xc111,	0xdfff, 0xc111,		0x21, 0
	.dw 0xfa00, 0xc111,	0xffff, 0xc111,		0x21, 0
	.dw 0x1a00, 0xc112,	0x1fff, 0xc112,		0x21, 0
	.dw 0x3a00, 0xc112,	0x3fff, 0xc112,		0x21, 0
	.dw 0x5a00, 0xc112,	0x5fff, 0xc112,		0x21, 0
	.dw 0x7a00, 0xc112,	0x7fff, 0xc112,		0x21, 0
	.dw 0x9a00, 0xc112,	0x9fff, 0xc112,		0x21, 0
	.dw 0xba00, 0xc112,	0xbfff, 0xc112,		0x21, 0
	.dw 0xda00, 0xc112,	0xdfff, 0xc112,		0x21, 0
	.dw 0xfa00, 0xc112,	0xffff, 0xc113,		0x21, 0
	.dw 0x1a00, 0xc114,	0x1fff, 0xc114,		0x21, 0
	.dw 0x3a00, 0xc114,	0x3fff, 0xc114,		0x21, 0
	.dw 0x5a00, 0xc114,	0x5fff, 0xc114,		0x21, 0
	.dw 0x7a00, 0xc114,	0x7fff, 0xc114,		0x21, 0
	.dw 0x9a00, 0xc114,	0x9fff, 0xc114,		0x21, 0
	.dw 0xba00, 0xc114,	0xbfff, 0xc114,		0x21, 0
	.dw 0xda00, 0xc114,	0xdfff, 0xc114,		0x21, 0
	.dw 0xfa00, 0xc114,	0xffff, 0xc114,		0x21, 0
	.dw 0x1a00, 0xc115,	0x1fff, 0xc115,		0x21, 0
	.dw 0x3a00, 0xc115,	0x3fff, 0xc115,		0x21, 0
	.dw 0x5a00, 0xc115,	0x5fff, 0xc115,		0x21, 0
	.dw 0x7a00, 0xc115,	0x7fff, 0xc115,		0x21, 0
	.dw 0x9a00, 0xc115,	0x9fff, 0xc115,		0x21, 0
	.dw 0xba00, 0xc115,	0xbfff, 0xc115,		0x21, 0
	.dw 0xda00, 0xc115,	0xdfff, 0xc115,		0x21, 0
	.dw 0xfa00, 0xc115,	0xffff, 0xc115,		0x21, 0
	.dw 0x1a00, 0xc116,	0x1fff, 0xc116,		0x21, 0
	.dw 0x3a00, 0xc116,	0x3fff, 0xc116,		0x21, 0
	.dw 0x5a00, 0xc116,	0x5fff, 0xc116,		0x21, 0
	.dw 0x7a00, 0xc116,	0x7fff, 0xc116,		0x21, 0
	.dw 0x9a00, 0xc116,	0x9fff, 0xc116,		0x21, 0
	.dw 0xba00, 0xc116,	0xbfff, 0xc116,		0x21, 0
	.dw 0xda00, 0xc116,	0xdfff, 0xc116,		0x21, 0
	.dw 0xfa00, 0xc116,	0xffff, 0xc116,		0x21, 0
	.dw 0x1a00, 0xc117,	0x1fff, 0xc117,		0x21, 0
	.dw 0x3a00, 0xc117,	0x1fff, 0xc118,		0x21, 0
	.dw 0x2040, 0xc118,	0x207f, 0xc118,		0x21, 0
	.dw 0x20c0, 0xc118,	0x20ff, 0xc118,		0x21, 0
	.dw 0x2140, 0xc118,	0x217f, 0xc118,		0x21, 0
	.dw 0x21c0, 0xc118,	0x21ff, 0xc118,		0x21, 0
	.dw 0x2240, 0xc118,	0x227f, 0xc118,		0x21, 0
	.dw 0x22c0, 0xc118,	0x22ff, 0xc118,		0x21, 0
	.dw 0x2340, 0xc118,	0x237f, 0xc118,		0x21, 0
	.dw 0x23c0, 0xc118,	0x23ff, 0xc118,		0x21, 0
	.dw 0x2440, 0xc118,	0x247f, 0xc118,		0x21, 0
	.dw 0x24c0, 0xc118,	0x24ff, 0xc118,		0x21, 0
	.dw 0x2540, 0xc118,	0x257f, 0xc118,		0x21, 0
	.dw 0x25c0, 0xc118,	0x25ff, 0xc118,		0x21, 0
	.dw 0x2640, 0xc118,	0x267f, 0xc118,		0x21, 0
	.dw 0x26c0, 0xc118,	0x26ff, 0xc118,		0x21, 0
	.dw 0x2740, 0xc118,	0x277f, 0xc118,		0x21, 0
	.dw 0x27c0, 0xc118,	0x27ff, 0xc118,		0x21, 0
	.dw 0x2840, 0xc118,	0x287f, 0xc118,		0x21, 0
	.dw 0x28c0, 0xc118,	0x28ff, 0xc118,		0x21, 0
	.dw 0x2940, 0xc118,	0x297f, 0xc118,		0x21, 0
	.dw 0x29c0, 0xc118,	0x29ff, 0xc118,		0x21, 0
	.dw 0x2a40, 0xc118,	0x2a7f, 0xc118,		0x21, 0
	.dw 0x2ac0, 0xc118,	0x2aff, 0xc118,		0x21, 0
	.dw 0x2b40, 0xc118,	0x2b7f, 0xc118,		0x21, 0
	.dw 0x2bc0, 0xc118,	0x2bff, 0xc118,		0x21, 0
	.dw 0x2c40, 0xc118,	0x2c7f, 0xc118,		0x21, 0
	.dw 0x2cc0, 0xc118,	0x2cff, 0xc118,		0x21, 0
	.dw 0x2d40, 0xc118,	0x2d7f, 0xc118,		0x21, 0
	.dw 0x2dc0, 0xc118,	0x2dff, 0xc118,		0x21, 0
	.dw 0x2e40, 0xc118,	0x2e7f, 0xc118,		0x21, 0
	.dw 0x2ec0, 0xc118,	0x2eff, 0xc118,		0x21, 0
	.dw 0x2f40, 0xc118,	0x2f7f, 0xc118,		0x21, 0
	.dw 0x2fc0, 0xc118,	0x2fff, 0xc118,		0x21, 0
	.dw 0x3040, 0xc118,	0x307f, 0xc118,		0x21, 0
	.dw 0x30c0, 0xc118,	0x30ff, 0xc118,		0x21, 0
	.dw 0x3140, 0xc118,	0x317f, 0xc118,		0x21, 0
	.dw 0x31c0, 0xc118,	0x31ff, 0xc118,		0x21, 0
	.dw 0x3240, 0xc118,	0x327f, 0xc118,		0x21, 0
	.dw 0x32c0, 0xc118,	0x32ff, 0xc118,		0x21, 0
	.dw 0x3340, 0xc118,	0x337f, 0xc118,		0x21, 0
	.dw 0x33c0, 0xc118,	0x33ff, 0xc118,		0x21, 0
	.dw 0x3440, 0xc118,	0x347f, 0xc118,		0x21, 0
	.dw 0x34c0, 0xc118,	0x34ff, 0xc118,		0x21, 0
	.dw 0x3540, 0xc118,	0x357f, 0xc118,		0x21, 0
	.dw 0x35c0, 0xc118,	0x35ff, 0xc118,		0x21, 0
	.dw 0x3640, 0xc118,	0x367f, 0xc118,		0x21, 0
	.dw 0x36c0, 0xc118,	0x36ff, 0xc118,		0x21, 0
	.dw 0x3740, 0xc118,	0x377f, 0xc118,		0x21, 0
	.dw 0x37c0, 0xc118,	0x37ff, 0xc118,		0x21, 0
	.dw 0x3840, 0xc118,	0x387f, 0xc118,		0x21, 0
	.dw 0x38c0, 0xc118,	0x38ff, 0xc118,		0x21, 0
	.dw 0x3940, 0xc118,	0x397f, 0xc118,		0x21, 0
	.dw 0x39c0, 0xc118,	0x5fff, 0xc118,		0x21, 0
	.dw 0x6040, 0xc118,	0x607f, 0xc118,		0x21, 0
	.dw 0x60c0, 0xc118,	0x60ff, 0xc118,		0x21, 0
	.dw 0x6140, 0xc118,	0x617f, 0xc118,		0x21, 0
	.dw 0x61c0, 0xc118,	0x61ff, 0xc118,		0x21, 0
	.dw 0x6240, 0xc118,	0x627f, 0xc118,		0x21, 0
	.dw 0x62c0, 0xc118,	0x62ff, 0xc118,		0x21, 0
	.dw 0x6340, 0xc118,	0x637f, 0xc118,		0x21, 0
	.dw 0x63c0, 0xc118,	0x63ff, 0xc118,		0x21, 0
	.dw 0x6440, 0xc118,	0x647f, 0xc118,		0x21, 0
	.dw 0x64c0, 0xc118,	0x64ff, 0xc118,		0x21, 0
	.dw 0x6540, 0xc118,	0x657f, 0xc118,		0x21, 0
	.dw 0x65c0, 0xc118,	0x65ff, 0xc118,		0x21, 0
	.dw 0x6640, 0xc118,	0x667f, 0xc118,		0x21, 0
	.dw 0x66c0, 0xc118,	0x66ff, 0xc118,		0x21, 0
	.dw 0x6740, 0xc118,	0x677f, 0xc118,		0x21, 0
	.dw 0x67c0, 0xc118,	0x67ff, 0xc118,		0x21, 0
	.dw 0x6840, 0xc118,	0x687f, 0xc118,		0x21, 0
	.dw 0x68c0, 0xc118,	0x68ff, 0xc118,		0x21, 0
	.dw 0x6940, 0xc118,	0x697f, 0xc118,		0x21, 0
	.dw 0x69c0, 0xc118,	0x69ff, 0xc118,		0x21, 0
	.dw 0x6a40, 0xc118,	0x6a7f, 0xc118,		0x21, 0
	.dw 0x6ac0, 0xc118,	0x6aff, 0xc118,		0x21, 0
	.dw 0x6b40, 0xc118,	0x6b7f, 0xc118,		0x21, 0
	.dw 0x6bc0, 0xc118,	0x6bff, 0xc118,		0x21, 0
	.dw 0x6c40, 0xc118,	0x6c7f, 0xc118,		0x21, 0
	.dw 0x6cc0, 0xc118,	0x6cff, 0xc118,		0x21, 0
	.dw 0x6d40, 0xc118,	0x6d7f, 0xc118,		0x21, 0
	.dw 0x6dc0, 0xc118,	0x6dff, 0xc118,		0x21, 0
	.dw 0x6e40, 0xc118,	0x6e7f, 0xc118,		0x21, 0
	.dw 0x6ec0, 0xc118,	0x6eff, 0xc118,		0x21, 0
	.dw 0x6f40, 0xc118,	0x6f7f, 0xc118,		0x21, 0
	.dw 0x6fc0, 0xc118,	0x6fff, 0xc118,		0x21, 0
	.dw 0x7040, 0xc118,	0x707f, 0xc118,		0x21, 0
	.dw 0x70c0, 0xc118,	0x70ff, 0xc118,		0x21, 0
	.dw 0x7140, 0xc118,	0x717f, 0xc118,		0x21, 0
	.dw 0x71c0, 0xc118,	0x71ff, 0xc118,		0x21, 0
	.dw 0x7240, 0xc118,	0x727f, 0xc118,		0x21, 0
	.dw 0x72c0, 0xc118,	0x72ff, 0xc118,		0x21, 0
	.dw 0x7340, 0xc118,	0x737f, 0xc118,		0x21, 0
	.dw 0x73c0, 0xc118,	0x73ff, 0xc118,		0x21, 0
	.dw 0x7440, 0xc118,	0x747f, 0xc118,		0x21, 0
	.dw 0x74c0, 0xc118,	0x74ff, 0xc118,		0x21, 0
	.dw 0x7540, 0xc118,	0x757f, 0xc118,		0x21, 0
	.dw 0x75c0, 0xc118,	0x75ff, 0xc118,		0x21, 0
	.dw 0x7640, 0xc118,	0x767f, 0xc118,		0x21, 0
	.dw 0x76c0, 0xc118,	0x76ff, 0xc118,		0x21, 0
	.dw 0x7740, 0xc118,	0x777f, 0xc118,		0x21, 0
	.dw 0x77c0, 0xc118,	0x77ff, 0xc118,		0x21, 0
	.dw 0x7840, 0xc118,	0x787f, 0xc118,		0x21, 0
	.dw 0x78c0, 0xc118,	0x78ff, 0xc118,		0x21, 0
	.dw 0x7940, 0xc118,	0x797f, 0xc118,		0x21, 0
	.dw 0x79c0, 0xc118,	0x9fff, 0xc118,		0x21, 0
	.dw 0xa040, 0xc118,	0xa07f, 0xc118,		0x21, 0
	.dw 0xa0c0, 0xc118,	0xa0ff, 0xc118,		0x21, 0
	.dw 0xa140, 0xc118,	0xa17f, 0xc118,		0x21, 0
	.dw 0xa1c0, 0xc118,	0xa1ff, 0xc118,		0x21, 0
	.dw 0xa240, 0xc118,	0xa27f, 0xc118,		0x21, 0
	.dw 0xa2c0, 0xc118,	0xa2ff, 0xc118,		0x21, 0
	.dw 0xa340, 0xc118,	0xa37f, 0xc118,		0x21, 0
	.dw 0xa3c0, 0xc118,	0xa3ff, 0xc118,		0x21, 0
	.dw 0xa440, 0xc118,	0xa47f, 0xc118,		0x21, 0
	.dw 0xa4c0, 0xc118,	0xa4ff, 0xc118,		0x21, 0
	.dw 0xa540, 0xc118,	0xa57f, 0xc118,		0x21, 0
	.dw 0xa5c0, 0xc118,	0xa5ff, 0xc118,		0x21, 0
	.dw 0xa640, 0xc118,	0xa67f, 0xc118,		0x21, 0
	.dw 0xa6c0, 0xc118,	0xa6ff, 0xc118,		0x21, 0
	.dw 0xa740, 0xc118,	0xa77f, 0xc118,		0x21, 0
	.dw 0xa7c0, 0xc118,	0xa7ff, 0xc118,		0x21, 0
	.dw 0xa840, 0xc118,	0xa87f, 0xc118,		0x21, 0
	.dw 0xa8c0, 0xc118,	0xa8ff, 0xc118,		0x21, 0
	.dw 0xa940, 0xc118,	0xa97f, 0xc118,		0x21, 0
	.dw 0xa9c0, 0xc118,	0xa9ff, 0xc118,		0x21, 0
	.dw 0xaa40, 0xc118,	0xaa7f, 0xc118,		0x21, 0
	.dw 0xaac0, 0xc118,	0xaaff, 0xc118,		0x21, 0
	.dw 0xab40, 0xc118,	0xab7f, 0xc118,		0x21, 0
	.dw 0xabc0, 0xc118,	0xabff, 0xc118,		0x21, 0
	.dw 0xac40, 0xc118,	0xac7f, 0xc118,		0x21, 0
	.dw 0xacc0, 0xc118,	0xacff, 0xc118,		0x21, 0
	.dw 0xad40, 0xc118,	0xad7f, 0xc118,		0x21, 0
	.dw 0xadc0, 0xc118,	0xadff, 0xc118,		0x21, 0
	.dw 0xae40, 0xc118,	0xae7f, 0xc118,		0x21, 0
	.dw 0xaec0, 0xc118,	0xaeff, 0xc118,		0x21, 0
	.dw 0xaf40, 0xc118,	0xaf7f, 0xc118,		0x21, 0
	.dw 0xafc0, 0xc118,	0xafff, 0xc118,		0x21, 0
	.dw 0xb040, 0xc118,	0xb07f, 0xc118,		0x21, 0
	.dw 0xb0c0, 0xc118,	0xb0ff, 0xc118,		0x21, 0
	.dw 0xb140, 0xc118,	0xb17f, 0xc118,		0x21, 0
	.dw 0xb1c0, 0xc118,	0xb1ff, 0xc118,		0x21, 0
	.dw 0xb240, 0xc118,	0xb27f, 0xc118,		0x21, 0
	.dw 0xb2c0, 0xc118,	0xb2ff, 0xc118,		0x21, 0
	.dw 0xb340, 0xc118,	0xb37f, 0xc118,		0x21, 0
	.dw 0xb3c0, 0xc118,	0xb3ff, 0xc118,		0x21, 0
	.dw 0xb440, 0xc118,	0xb47f, 0xc118,		0x21, 0
	.dw 0xb4c0, 0xc118,	0xb4ff, 0xc118,		0x21, 0
	.dw 0xb540, 0xc118,	0xb57f, 0xc118,		0x21, 0
	.dw 0xb5c0, 0xc118,	0xb5ff, 0xc118,		0x21, 0
	.dw 0xb640, 0xc118,	0xb67f, 0xc118,		0x21, 0
	.dw 0xb6c0, 0xc118,	0xb6ff, 0xc118,		0x21, 0
	.dw 0xb740, 0xc118,	0xb77f, 0xc118,		0x21, 0
	.dw 0xb7c0, 0xc118,	0xb7ff, 0xc118,		0x21, 0
	.dw 0xb840, 0xc118,	0xb87f, 0xc118,		0x21, 0
	.dw 0xb8c0, 0xc118,	0xb8ff, 0xc118,		0x21, 0
	.dw 0xb940, 0xc118,	0xb97f, 0xc118,		0x21, 0
	.dw 0xb9c0, 0xc118,	0xdfff, 0xc118,		0x21, 0
	.dw 0xe040, 0xc118,	0xe07f, 0xc118,		0x21, 0
	.dw 0xe0c0, 0xc118,	0xe0ff, 0xc118,		0x21, 0
	.dw 0xe140, 0xc118,	0xe17f, 0xc118,		0x21, 0
	.dw 0xe1c0, 0xc118,	0xe1ff, 0xc118,		0x21, 0
	.dw 0xe240, 0xc118,	0xe27f, 0xc118,		0x21, 0
	.dw 0xe2c0, 0xc118,	0xe2ff, 0xc118,		0x21, 0
	.dw 0xe340, 0xc118,	0xe37f, 0xc118,		0x21, 0
	.dw 0xe3c0, 0xc118,	0xe3ff, 0xc118,		0x21, 0
	.dw 0xe440, 0xc118,	0xe47f, 0xc118,		0x21, 0
	.dw 0xe4c0, 0xc118,	0xe4ff, 0xc118,		0x21, 0
	.dw 0xe540, 0xc118,	0xe57f, 0xc118,		0x21, 0
	.dw 0xe5c0, 0xc118,	0xe5ff, 0xc118,		0x21, 0
	.dw 0xe640, 0xc118,	0xe67f, 0xc118,		0x21, 0
	.dw 0xe6c0, 0xc118,	0xe6ff, 0xc118,		0x21, 0
	.dw 0xe740, 0xc118,	0xe77f, 0xc118,		0x21, 0
	.dw 0xe7c0, 0xc118,	0xe7ff, 0xc118,		0x21, 0
	.dw 0xe840, 0xc118,	0xe87f, 0xc118,		0x21, 0
	.dw 0xe8c0, 0xc118,	0xe8ff, 0xc118,		0x21, 0
	.dw 0xe940, 0xc118,	0xe97f, 0xc118,		0x21, 0
	.dw 0xe9c0, 0xc118,	0xe9ff, 0xc118,		0x21, 0
	.dw 0xea40, 0xc118,	0xea7f, 0xc118,		0x21, 0
	.dw 0xeac0, 0xc118,	0xeaff, 0xc118,		0x21, 0
	.dw 0xeb40, 0xc118,	0xeb7f, 0xc118,		0x21, 0
	.dw 0xebc0, 0xc118,	0xebff, 0xc118,		0x21, 0
	.dw 0xec40, 0xc118,	0xec7f, 0xc118,		0x21, 0
	.dw 0xecc0, 0xc118,	0xecff, 0xc118,		0x21, 0
	.dw 0xed40, 0xc118,	0xed7f, 0xc118,		0x21, 0
	.dw 0xedc0, 0xc118,	0xedff, 0xc118,		0x21, 0
	.dw 0xee40, 0xc118,	0xee7f, 0xc118,		0x21, 0
	.dw 0xeec0, 0xc118,	0xeeff, 0xc118,		0x21, 0
	.dw 0xef40, 0xc118,	0xef7f, 0xc118,		0x21, 0
	.dw 0xefc0, 0xc118,	0xefff, 0xc118,		0x21, 0
	.dw 0xf040, 0xc118,	0xf07f, 0xc118,		0x21, 0
	.dw 0xf0c0, 0xc118,	0xf0ff, 0xc118,		0x21, 0
	.dw 0xf140, 0xc118,	0xf17f, 0xc118,		0x21, 0
	.dw 0xf1c0, 0xc118,	0xf1ff, 0xc118,		0x21, 0
	.dw 0xf240, 0xc118,	0xf27f, 0xc118,		0x21, 0
	.dw 0xf2c0, 0xc118,	0xf2ff, 0xc118,		0x21, 0
	.dw 0xf340, 0xc118,	0xf37f, 0xc118,		0x21, 0
	.dw 0xf3c0, 0xc118,	0xf3ff, 0xc118,		0x21, 0
	.dw 0xf440, 0xc118,	0xf47f, 0xc118,		0x21, 0
	.dw 0xf4c0, 0xc118,	0xf4ff, 0xc118,		0x21, 0
	.dw 0xf540, 0xc118,	0xf57f, 0xc118,		0x21, 0
	.dw 0xf5c0, 0xc118,	0xf5ff, 0xc118,		0x21, 0
	.dw 0xf640, 0xc118,	0xf67f, 0xc118,		0x21, 0
	.dw 0xf6c0, 0xc118,	0xf6ff, 0xc118,		0x21, 0
	.dw 0xf740, 0xc118,	0xf77f, 0xc118,		0x21, 0
	.dw 0xf7c0, 0xc118,	0xf7ff, 0xc118,		0x21, 0
	.dw 0xf840, 0xc118,	0xf87f, 0xc118,		0x21, 0
	.dw 0xf8c0, 0xc118,	0xf8ff, 0xc118,		0x21, 0
	.dw 0xf940, 0xc118,	0xf97f, 0xc118,		0x21, 0
	.dw 0xf9c0, 0xc118,	0x1fff, 0xc119,		0x21, 0
	.dw 0x2040, 0xc119,	0x207f, 0xc119,		0x21, 0
	.dw 0x20c0, 0xc119,	0x20ff, 0xc119,		0x21, 0
	.dw 0x2140, 0xc119,	0x217f, 0xc119,		0x21, 0
	.dw 0x21c0, 0xc119,	0x21ff, 0xc119,		0x21, 0
	.dw 0x2240, 0xc119,	0x227f, 0xc119,		0x21, 0
	.dw 0x22c0, 0xc119,	0x22ff, 0xc119,		0x21, 0
	.dw 0x2340, 0xc119,	0x237f, 0xc119,		0x21, 0
	.dw 0x23c0, 0xc119,	0x23ff, 0xc119,		0x21, 0
	.dw 0x2440, 0xc119,	0x247f, 0xc119,		0x21, 0
	.dw 0x24c0, 0xc119,	0x24ff, 0xc119,		0x21, 0
	.dw 0x2540, 0xc119,	0x257f, 0xc119,		0x21, 0
	.dw 0x25c0, 0xc119,	0x25ff, 0xc119,		0x21, 0
	.dw 0x2640, 0xc119,	0x267f, 0xc119,		0x21, 0
	.dw 0x26c0, 0xc119,	0x26ff, 0xc119,		0x21, 0
	.dw 0x2740, 0xc119,	0x277f, 0xc119,		0x21, 0
	.dw 0x27c0, 0xc119,	0x27ff, 0xc119,		0x21, 0
	.dw 0x2840, 0xc119,	0x287f, 0xc119,		0x21, 0
	.dw 0x28c0, 0xc119,	0x28ff, 0xc119,		0x21, 0
	.dw 0x2940, 0xc119,	0x297f, 0xc119,		0x21, 0
	.dw 0x29c0, 0xc119,	0x29ff, 0xc119,		0x21, 0
	.dw 0x2a40, 0xc119,	0x2a7f, 0xc119,		0x21, 0
	.dw 0x2ac0, 0xc119,	0x2aff, 0xc119,		0x21, 0
	.dw 0x2b40, 0xc119,	0x2b7f, 0xc119,		0x21, 0
	.dw 0x2bc0, 0xc119,	0x2bff, 0xc119,		0x21, 0
	.dw 0x2c40, 0xc119,	0x2c7f, 0xc119,		0x21, 0
	.dw 0x2cc0, 0xc119,	0x2cff, 0xc119,		0x21, 0
	.dw 0x2d40, 0xc119,	0x2d7f, 0xc119,		0x21, 0
	.dw 0x2dc0, 0xc119,	0x2dff, 0xc119,		0x21, 0
	.dw 0x2e40, 0xc119,	0x2e7f, 0xc119,		0x21, 0
	.dw 0x2ec0, 0xc119,	0x2eff, 0xc119,		0x21, 0
	.dw 0x2f40, 0xc119,	0x2f7f, 0xc119,		0x21, 0
	.dw 0x2fc0, 0xc119,	0x2fff, 0xc119,		0x21, 0
	.dw 0x3040, 0xc119,	0x307f, 0xc119,		0x21, 0
	.dw 0x30c0, 0xc119,	0x30ff, 0xc119,		0x21, 0
	.dw 0x3140, 0xc119,	0x317f, 0xc119,		0x21, 0
	.dw 0x31c0, 0xc119,	0x31ff, 0xc119,		0x21, 0
	.dw 0x3240, 0xc119,	0x327f, 0xc119,		0x21, 0
	.dw 0x32c0, 0xc119,	0x32ff, 0xc119,		0x21, 0
	.dw 0x3340, 0xc119,	0x337f, 0xc119,		0x21, 0
	.dw 0x33c0, 0xc119,	0x33ff, 0xc119,		0x21, 0
	.dw 0x3440, 0xc119,	0x347f, 0xc119,		0x21, 0
	.dw 0x34c0, 0xc119,	0x34ff, 0xc119,		0x21, 0
	.dw 0x3540, 0xc119,	0x357f, 0xc119,		0x21, 0
	.dw 0x35c0, 0xc119,	0x35ff, 0xc119,		0x21, 0
	.dw 0x3640, 0xc119,	0x367f, 0xc119,		0x21, 0
	.dw 0x36c0, 0xc119,	0x36ff, 0xc119,		0x21, 0
	.dw 0x3740, 0xc119,	0x377f, 0xc119,		0x21, 0
	.dw 0x37c0, 0xc119,	0x37ff, 0xc119,		0x21, 0
	.dw 0x3840, 0xc119,	0x387f, 0xc119,		0x21, 0
	.dw 0x38c0, 0xc119,	0x38ff, 0xc119,		0x21, 0
	.dw 0x3940, 0xc119,	0x397f, 0xc119,		0x21, 0
	.dw 0x39c0, 0xc119,	0x5fff, 0xc119,		0x21, 0
	.dw 0x6040, 0xc119,	0x607f, 0xc119,		0x21, 0
	.dw 0x60c0, 0xc119,	0x60ff, 0xc119,		0x21, 0
	.dw 0x6140, 0xc119,	0x617f, 0xc119,		0x21, 0
	.dw 0x61c0, 0xc119,	0x61ff, 0xc119,		0x21, 0
	.dw 0x6240, 0xc119,	0x627f, 0xc119,		0x21, 0
	.dw 0x62c0, 0xc119,	0x62ff, 0xc119,		0x21, 0
	.dw 0x6340, 0xc119,	0x637f, 0xc119,		0x21, 0
	.dw 0x63c0, 0xc119,	0x63ff, 0xc119,		0x21, 0
	.dw 0x6440, 0xc119,	0x647f, 0xc119,		0x21, 0
	.dw 0x64c0, 0xc119,	0x64ff, 0xc119,		0x21, 0
	.dw 0x6540, 0xc119,	0x657f, 0xc119,		0x21, 0
	.dw 0x65c0, 0xc119,	0x65ff, 0xc119,		0x21, 0
	.dw 0x6640, 0xc119,	0x667f, 0xc119,		0x21, 0
	.dw 0x66c0, 0xc119,	0x66ff, 0xc119,		0x21, 0
	.dw 0x6740, 0xc119,	0x677f, 0xc119,		0x21, 0
	.dw 0x67c0, 0xc119,	0x67ff, 0xc119,		0x21, 0
	.dw 0x6840, 0xc119,	0x687f, 0xc119,		0x21, 0
	.dw 0x68c0, 0xc119,	0x68ff, 0xc119,		0x21, 0
	.dw 0x6940, 0xc119,	0x697f, 0xc119,		0x21, 0
	.dw 0x69c0, 0xc119,	0x69ff, 0xc119,		0x21, 0
	.dw 0x6a40, 0xc119,	0x6a7f, 0xc119,		0x21, 0
	.dw 0x6ac0, 0xc119,	0x6aff, 0xc119,		0x21, 0
	.dw 0x6b40, 0xc119,	0x6b7f, 0xc119,		0x21, 0
	.dw 0x6bc0, 0xc119,	0x6bff, 0xc119,		0x21, 0
	.dw 0x6c40, 0xc119,	0x6c7f, 0xc119,		0x21, 0
	.dw 0x6cc0, 0xc119,	0x6cff, 0xc119,		0x21, 0
	.dw 0x6d40, 0xc119,	0x6d7f, 0xc119,		0x21, 0
	.dw 0x6dc0, 0xc119,	0x6dff, 0xc119,		0x21, 0
	.dw 0x6e40, 0xc119,	0x6e7f, 0xc119,		0x21, 0
	.dw 0x6ec0, 0xc119,	0x6eff, 0xc119,		0x21, 0
	.dw 0x6f40, 0xc119,	0x6f7f, 0xc119,		0x21, 0
	.dw 0x6fc0, 0xc119,	0x6fff, 0xc119,		0x21, 0
	.dw 0x7040, 0xc119,	0x707f, 0xc119,		0x21, 0
	.dw 0x70c0, 0xc119,	0x70ff, 0xc119,		0x21, 0
	.dw 0x7140, 0xc119,	0x717f, 0xc119,		0x21, 0
	.dw 0x71c0, 0xc119,	0x71ff, 0xc119,		0x21, 0
	.dw 0x7240, 0xc119,	0x727f, 0xc119,		0x21, 0
	.dw 0x72c0, 0xc119,	0x72ff, 0xc119,		0x21, 0
	.dw 0x7340, 0xc119,	0x737f, 0xc119,		0x21, 0
	.dw 0x73c0, 0xc119,	0x73ff, 0xc119,		0x21, 0
	.dw 0x7440, 0xc119,	0x747f, 0xc119,		0x21, 0
	.dw 0x74c0, 0xc119,	0x74ff, 0xc119,		0x21, 0
	.dw 0x7540, 0xc119,	0x757f, 0xc119,		0x21, 0
	.dw 0x75c0, 0xc119,	0x75ff, 0xc119,		0x21, 0
	.dw 0x7640, 0xc119,	0x767f, 0xc119,		0x21, 0
	.dw 0x76c0, 0xc119,	0x76ff, 0xc119,		0x21, 0
	.dw 0x7740, 0xc119,	0x777f, 0xc119,		0x21, 0
	.dw 0x77c0, 0xc119,	0x77ff, 0xc119,		0x21, 0
	.dw 0x7840, 0xc119,	0x787f, 0xc119,		0x21, 0
	.dw 0x78c0, 0xc119,	0x78ff, 0xc119,		0x21, 0
	.dw 0x7940, 0xc119,	0x797f, 0xc119,		0x21, 0
	.dw 0x79c0, 0xc119,	0x9fff, 0xc119,		0x21, 0
	.dw 0xa040, 0xc119,	0xa07f, 0xc119,		0x21, 0
	.dw 0xa0c0, 0xc119,	0xa0ff, 0xc119,		0x21, 0
	.dw 0xa140, 0xc119,	0xa17f, 0xc119,		0x21, 0
	.dw 0xa1c0, 0xc119,	0xa1ff, 0xc119,		0x21, 0
	.dw 0xa240, 0xc119,	0xa27f, 0xc119,		0x21, 0
	.dw 0xa2c0, 0xc119,	0xa2ff, 0xc119,		0x21, 0
	.dw 0xa340, 0xc119,	0xa37f, 0xc119,		0x21, 0
	.dw 0xa3c0, 0xc119,	0xa3ff, 0xc119,		0x21, 0
	.dw 0xa440, 0xc119,	0xa47f, 0xc119,		0x21, 0
	.dw 0xa4c0, 0xc119,	0xa4ff, 0xc119,		0x21, 0
	.dw 0xa540, 0xc119,	0xa57f, 0xc119,		0x21, 0
	.dw 0xa5c0, 0xc119,	0xa5ff, 0xc119,		0x21, 0
	.dw 0xa640, 0xc119,	0xa67f, 0xc119,		0x21, 0
	.dw 0xa6c0, 0xc119,	0xa6ff, 0xc119,		0x21, 0
	.dw 0xa740, 0xc119,	0xa77f, 0xc119,		0x21, 0
	.dw 0xa7c0, 0xc119,	0xa7ff, 0xc119,		0x21, 0
	.dw 0xa840, 0xc119,	0xa87f, 0xc119,		0x21, 0
	.dw 0xa8c0, 0xc119,	0xa8ff, 0xc119,		0x21, 0
	.dw 0xa940, 0xc119,	0xa97f, 0xc119,		0x21, 0
	.dw 0xa9c0, 0xc119,	0xa9ff, 0xc119,		0x21, 0
	.dw 0xaa40, 0xc119,	0xaa7f, 0xc119,		0x21, 0
	.dw 0xaac0, 0xc119,	0xaaff, 0xc119,		0x21, 0
	.dw 0xab40, 0xc119,	0xab7f, 0xc119,		0x21, 0
	.dw 0xabc0, 0xc119,	0xabff, 0xc119,		0x21, 0
	.dw 0xac40, 0xc119,	0xac7f, 0xc119,		0x21, 0
	.dw 0xacc0, 0xc119,	0xacff, 0xc119,		0x21, 0
	.dw 0xad40, 0xc119,	0xad7f, 0xc119,		0x21, 0
	.dw 0xadc0, 0xc119,	0xadff, 0xc119,		0x21, 0
	.dw 0xae40, 0xc119,	0xae7f, 0xc119,		0x21, 0
	.dw 0xaec0, 0xc119,	0xaeff, 0xc119,		0x21, 0
	.dw 0xaf40, 0xc119,	0xaf7f, 0xc119,		0x21, 0
	.dw 0xafc0, 0xc119,	0xafff, 0xc119,		0x21, 0
	.dw 0xb040, 0xc119,	0xb07f, 0xc119,		0x21, 0
	.dw 0xb0c0, 0xc119,	0xb0ff, 0xc119,		0x21, 0
	.dw 0xb140, 0xc119,	0xb17f, 0xc119,		0x21, 0
	.dw 0xb1c0, 0xc119,	0xb1ff, 0xc119,		0x21, 0
	.dw 0xb240, 0xc119,	0xb27f, 0xc119,		0x21, 0
	.dw 0xb2c0, 0xc119,	0xb2ff, 0xc119,		0x21, 0
	.dw 0xb340, 0xc119,	0xb37f, 0xc119,		0x21, 0
	.dw 0xb3c0, 0xc119,	0xb3ff, 0xc119,		0x21, 0
	.dw 0xb440, 0xc119,	0xb47f, 0xc119,		0x21, 0
	.dw 0xb4c0, 0xc119,	0xb4ff, 0xc119,		0x21, 0
	.dw 0xb540, 0xc119,	0xb57f, 0xc119,		0x21, 0
	.dw 0xb5c0, 0xc119,	0xb5ff, 0xc119,		0x21, 0
	.dw 0xb640, 0xc119,	0xb67f, 0xc119,		0x21, 0
	.dw 0xb6c0, 0xc119,	0xb6ff, 0xc119,		0x21, 0
	.dw 0xb740, 0xc119,	0xb77f, 0xc119,		0x21, 0
	.dw 0xb7c0, 0xc119,	0xb7ff, 0xc119,		0x21, 0
	.dw 0xb840, 0xc119,	0xb87f, 0xc119,		0x21, 0
	.dw 0xb8c0, 0xc119,	0xb8ff, 0xc119,		0x21, 0
	.dw 0xb940, 0xc119,	0xb97f, 0xc119,		0x21, 0
	.dw 0xb9c0, 0xc119,	0xdfff, 0xc119,		0x21, 0
	.dw 0xe040, 0xc119,	0xe07f, 0xc119,		0x21, 0
	.dw 0xe0c0, 0xc119,	0xe0ff, 0xc119,		0x21, 0
	.dw 0xe140, 0xc119,	0xe17f, 0xc119,		0x21, 0
	.dw 0xe1c0, 0xc119,	0xe1ff, 0xc119,		0x21, 0
	.dw 0xe240, 0xc119,	0xe27f, 0xc119,		0x21, 0
	.dw 0xe2c0, 0xc119,	0xe2ff, 0xc119,		0x21, 0
	.dw 0xe340, 0xc119,	0xe37f, 0xc119,		0x21, 0
	.dw 0xe3c0, 0xc119,	0xe3ff, 0xc119,		0x21, 0
	.dw 0xe440, 0xc119,	0xe47f, 0xc119,		0x21, 0
	.dw 0xe4c0, 0xc119,	0xe4ff, 0xc119,		0x21, 0
	.dw 0xe540, 0xc119,	0xe57f, 0xc119,		0x21, 0
	.dw 0xe5c0, 0xc119,	0xe5ff, 0xc119,		0x21, 0
	.dw 0xe640, 0xc119,	0xe67f, 0xc119,		0x21, 0
	.dw 0xe6c0, 0xc119,	0xe6ff, 0xc119,		0x21, 0
	.dw 0xe740, 0xc119,	0xe77f, 0xc119,		0x21, 0
	.dw 0xe7c0, 0xc119,	0xe7ff, 0xc119,		0x21, 0
	.dw 0xe840, 0xc119,	0xe87f, 0xc119,		0x21, 0
	.dw 0xe8c0, 0xc119,	0xe8ff, 0xc119,		0x21, 0
	.dw 0xe940, 0xc119,	0xe97f, 0xc119,		0x21, 0
	.dw 0xe9c0, 0xc119,	0xe9ff, 0xc119,		0x21, 0
	.dw 0xea40, 0xc119,	0xea7f, 0xc119,		0x21, 0
	.dw 0xeac0, 0xc119,	0xeaff, 0xc119,		0x21, 0
	.dw 0xeb40, 0xc119,	0xeb7f, 0xc119,		0x21, 0
	.dw 0xebc0, 0xc119,	0xebff, 0xc119,		0x21, 0
	.dw 0xec40, 0xc119,	0xec7f, 0xc119,		0x21, 0
	.dw 0xecc0, 0xc119,	0xecff, 0xc119,		0x21, 0
	.dw 0xed40, 0xc119,	0xed7f, 0xc119,		0x21, 0
	.dw 0xedc0, 0xc119,	0xedff, 0xc119,		0x21, 0
	.dw 0xee40, 0xc119,	0xee7f, 0xc119,		0x21, 0
	.dw 0xeec0, 0xc119,	0xeeff, 0xc119,		0x21, 0
	.dw 0xef40, 0xc119,	0xef7f, 0xc119,		0x21, 0
	.dw 0xefc0, 0xc119,	0xefff, 0xc119,		0x21, 0
	.dw 0xf040, 0xc119,	0xf07f, 0xc119,		0x21, 0
	.dw 0xf0c0, 0xc119,	0xf0ff, 0xc119,		0x21, 0
	.dw 0xf140, 0xc119,	0xf17f, 0xc119,		0x21, 0
	.dw 0xf1c0, 0xc119,	0xf1ff, 0xc119,		0x21, 0
	.dw 0xf240, 0xc119,	0xf27f, 0xc119,		0x21, 0
	.dw 0xf2c0, 0xc119,	0xf2ff, 0xc119,		0x21, 0
	.dw 0xf340, 0xc119,	0xf37f, 0xc119,		0x21, 0
	.dw 0xf3c0, 0xc119,	0xf3ff, 0xc119,		0x21, 0
	.dw 0xf440, 0xc119,	0xf47f, 0xc119,		0x21, 0
	.dw 0xf4c0, 0xc119,	0xf4ff, 0xc119,		0x21, 0
	.dw 0xf540, 0xc119,	0xf57f, 0xc119,		0x21, 0
	.dw 0xf5c0, 0xc119,	0xf5ff, 0xc119,		0x21, 0
	.dw 0xf640, 0xc119,	0xf67f, 0xc119,		0x21, 0
	.dw 0xf6c0, 0xc119,	0xf6ff, 0xc119,		0x21, 0
	.dw 0xf740, 0xc119,	0xf77f, 0xc119,		0x21, 0
	.dw 0xf7c0, 0xc119,	0xf7ff, 0xc119,		0x21, 0
	.dw 0xf840, 0xc119,	0xf87f, 0xc119,		0x21, 0
	.dw 0xf8c0, 0xc119,	0xf8ff, 0xc119,		0x21, 0
	.dw 0xf940, 0xc119,	0xf97f, 0xc119,		0x21, 0
	.dw 0xf9c0, 0xc119,	0x1fff, 0xc11a,		0x21, 0
	.dw 0x2040, 0xc11a,	0x207f, 0xc11a,		0x21, 0
	.dw 0x20c0, 0xc11a,	0x20ff, 0xc11a,		0x21, 0
	.dw 0x2140, 0xc11a,	0x217f, 0xc11a,		0x21, 0
	.dw 0x21c0, 0xc11a,	0x21ff, 0xc11a,		0x21, 0
	.dw 0x2240, 0xc11a,	0x227f, 0xc11a,		0x21, 0
	.dw 0x22c0, 0xc11a,	0x22ff, 0xc11a,		0x21, 0
	.dw 0x2340, 0xc11a,	0x237f, 0xc11a,		0x21, 0
	.dw 0x23c0, 0xc11a,	0x23ff, 0xc11a,		0x21, 0
	.dw 0x2440, 0xc11a,	0x247f, 0xc11a,		0x21, 0
	.dw 0x24c0, 0xc11a,	0x24ff, 0xc11a,		0x21, 0
	.dw 0x2540, 0xc11a,	0x257f, 0xc11a,		0x21, 0
	.dw 0x25c0, 0xc11a,	0x25ff, 0xc11a,		0x21, 0
	.dw 0x2640, 0xc11a,	0x267f, 0xc11a,		0x21, 0
	.dw 0x26c0, 0xc11a,	0x26ff, 0xc11a,		0x21, 0
	.dw 0x2740, 0xc11a,	0x277f, 0xc11a,		0x21, 0
	.dw 0x27c0, 0xc11a,	0x27ff, 0xc11a,		0x21, 0
	.dw 0x2840, 0xc11a,	0x287f, 0xc11a,		0x21, 0
	.dw 0x28c0, 0xc11a,	0x28ff, 0xc11a,		0x21, 0
	.dw 0x2940, 0xc11a,	0x297f, 0xc11a,		0x21, 0
	.dw 0x29c0, 0xc11a,	0x29ff, 0xc11a,		0x21, 0
	.dw 0x2a40, 0xc11a,	0x2a7f, 0xc11a,		0x21, 0
	.dw 0x2ac0, 0xc11a,	0x2aff, 0xc11a,		0x21, 0
	.dw 0x2b40, 0xc11a,	0x2b7f, 0xc11a,		0x21, 0
	.dw 0x2bc0, 0xc11a,	0x2bff, 0xc11a,		0x21, 0
	.dw 0x2c40, 0xc11a,	0x2c7f, 0xc11a,		0x21, 0
	.dw 0x2cc0, 0xc11a,	0x2cff, 0xc11a,		0x21, 0
	.dw 0x2d40, 0xc11a,	0x2d7f, 0xc11a,		0x21, 0
	.dw 0x2dc0, 0xc11a,	0x2dff, 0xc11a,		0x21, 0
	.dw 0x2e40, 0xc11a,	0x2e7f, 0xc11a,		0x21, 0
	.dw 0x2ec0, 0xc11a,	0x2eff, 0xc11a,		0x21, 0
	.dw 0x2f40, 0xc11a,	0x2f7f, 0xc11a,		0x21, 0
	.dw 0x2fc0, 0xc11a,	0x2fff, 0xc11a,		0x21, 0
	.dw 0x3040, 0xc11a,	0x307f, 0xc11a,		0x21, 0
	.dw 0x30c0, 0xc11a,	0x30ff, 0xc11a,		0x21, 0
	.dw 0x3140, 0xc11a,	0x317f, 0xc11a,		0x21, 0
	.dw 0x31c0, 0xc11a,	0x31ff, 0xc11a,		0x21, 0
	.dw 0x3240, 0xc11a,	0x327f, 0xc11a,		0x21, 0
	.dw 0x32c0, 0xc11a,	0x32ff, 0xc11a,		0x21, 0
	.dw 0x3340, 0xc11a,	0x337f, 0xc11a,		0x21, 0
	.dw 0x33c0, 0xc11a,	0x33ff, 0xc11a,		0x21, 0
	.dw 0x3440, 0xc11a,	0x347f, 0xc11a,		0x21, 0
	.dw 0x34c0, 0xc11a,	0x34ff, 0xc11a,		0x21, 0
	.dw 0x3540, 0xc11a,	0x357f, 0xc11a,		0x21, 0
	.dw 0x35c0, 0xc11a,	0x35ff, 0xc11a,		0x21, 0
	.dw 0x3640, 0xc11a,	0x367f, 0xc11a,		0x21, 0
	.dw 0x36c0, 0xc11a,	0x36ff, 0xc11a,		0x21, 0
	.dw 0x3740, 0xc11a,	0x377f, 0xc11a,		0x21, 0
	.dw 0x37c0, 0xc11a,	0x37ff, 0xc11a,		0x21, 0
	.dw 0x3840, 0xc11a,	0x387f, 0xc11a,		0x21, 0
	.dw 0x38c0, 0xc11a,	0x38ff, 0xc11a,		0x21, 0
	.dw 0x3940, 0xc11a,	0x397f, 0xc11a,		0x21, 0
	.dw 0x39c0, 0xc11a,	0x5fff, 0xc11a,		0x21, 0
	.dw 0x6040, 0xc11a,	0x607f, 0xc11a,		0x21, 0
	.dw 0x60c0, 0xc11a,	0x60ff, 0xc11a,		0x21, 0
	.dw 0x6140, 0xc11a,	0x617f, 0xc11a,		0x21, 0
	.dw 0x61c0, 0xc11a,	0x61ff, 0xc11a,		0x21, 0
	.dw 0x6240, 0xc11a,	0x627f, 0xc11a,		0x21, 0
	.dw 0x62c0, 0xc11a,	0x62ff, 0xc11a,		0x21, 0
	.dw 0x6340, 0xc11a,	0x637f, 0xc11a,		0x21, 0
	.dw 0x63c0, 0xc11a,	0x63ff, 0xc11a,		0x21, 0
	.dw 0x6440, 0xc11a,	0x647f, 0xc11a,		0x21, 0
	.dw 0x64c0, 0xc11a,	0x64ff, 0xc11a,		0x21, 0
	.dw 0x6540, 0xc11a,	0x657f, 0xc11a,		0x21, 0
	.dw 0x65c0, 0xc11a,	0x65ff, 0xc11a,		0x21, 0
	.dw 0x6640, 0xc11a,	0x667f, 0xc11a,		0x21, 0
	.dw 0x66c0, 0xc11a,	0x66ff, 0xc11a,		0x21, 0
	.dw 0x6740, 0xc11a,	0x677f, 0xc11a,		0x21, 0
	.dw 0x67c0, 0xc11a,	0x67ff, 0xc11a,		0x21, 0
	.dw 0x6840, 0xc11a,	0x687f, 0xc11a,		0x21, 0
	.dw 0x68c0, 0xc11a,	0x68ff, 0xc11a,		0x21, 0
	.dw 0x6940, 0xc11a,	0x697f, 0xc11a,		0x21, 0
	.dw 0x69c0, 0xc11a,	0x69ff, 0xc11a,		0x21, 0
	.dw 0x6a40, 0xc11a,	0x6a7f, 0xc11a,		0x21, 0
	.dw 0x6ac0, 0xc11a,	0x6aff, 0xc11a,		0x21, 0
	.dw 0x6b40, 0xc11a,	0x6b7f, 0xc11a,		0x21, 0
	.dw 0x6bc0, 0xc11a,	0x6bff, 0xc11a,		0x21, 0
	.dw 0x6c40, 0xc11a,	0x6c7f, 0xc11a,		0x21, 0
	.dw 0x6cc0, 0xc11a,	0x6cff, 0xc11a,		0x21, 0
	.dw 0x6d40, 0xc11a,	0x6d7f, 0xc11a,		0x21, 0
	.dw 0x6dc0, 0xc11a,	0x6dff, 0xc11a,		0x21, 0
	.dw 0x6e40, 0xc11a,	0x6e7f, 0xc11a,		0x21, 0
	.dw 0x6ec0, 0xc11a,	0x6eff, 0xc11a,		0x21, 0
	.dw 0x6f40, 0xc11a,	0x6f7f, 0xc11a,		0x21, 0
	.dw 0x6fc0, 0xc11a,	0x6fff, 0xc11a,		0x21, 0
	.dw 0x7040, 0xc11a,	0x707f, 0xc11a,		0x21, 0
	.dw 0x70c0, 0xc11a,	0x70ff, 0xc11a,		0x21, 0
	.dw 0x7140, 0xc11a,	0x717f, 0xc11a,		0x21, 0
	.dw 0x71c0, 0xc11a,	0x71ff, 0xc11a,		0x21, 0
	.dw 0x7240, 0xc11a,	0x727f, 0xc11a,		0x21, 0
	.dw 0x72c0, 0xc11a,	0x72ff, 0xc11a,		0x21, 0
	.dw 0x7340, 0xc11a,	0x737f, 0xc11a,		0x21, 0
	.dw 0x73c0, 0xc11a,	0x73ff, 0xc11a,		0x21, 0
	.dw 0x7440, 0xc11a,	0x747f, 0xc11a,		0x21, 0
	.dw 0x74c0, 0xc11a,	0x74ff, 0xc11a,		0x21, 0
	.dw 0x7540, 0xc11a,	0x757f, 0xc11a,		0x21, 0
	.dw 0x75c0, 0xc11a,	0x75ff, 0xc11a,		0x21, 0
	.dw 0x7640, 0xc11a,	0x767f, 0xc11a,		0x21, 0
	.dw 0x76c0, 0xc11a,	0x76ff, 0xc11a,		0x21, 0
	.dw 0x7740, 0xc11a,	0x777f, 0xc11a,		0x21, 0
	.dw 0x77c0, 0xc11a,	0x77ff, 0xc11a,		0x21, 0
	.dw 0x7840, 0xc11a,	0x787f, 0xc11a,		0x21, 0
	.dw 0x78c0, 0xc11a,	0x78ff, 0xc11a,		0x21, 0
	.dw 0x7940, 0xc11a,	0x797f, 0xc11a,		0x21, 0
	.dw 0x79c0, 0xc11a,	0x9fff, 0xc11a,		0x21, 0
	.dw 0xa040, 0xc11a,	0xa07f, 0xc11a,		0x21, 0
	.dw 0xa0c0, 0xc11a,	0xa0ff, 0xc11a,		0x21, 0
	.dw 0xa140, 0xc11a,	0xa17f, 0xc11a,		0x21, 0
	.dw 0xa1c0, 0xc11a,	0xa1ff, 0xc11a,		0x21, 0
	.dw 0xa240, 0xc11a,	0xa27f, 0xc11a,		0x21, 0
	.dw 0xa2c0, 0xc11a,	0xa2ff, 0xc11a,		0x21, 0
	.dw 0xa340, 0xc11a,	0xa37f, 0xc11a,		0x21, 0
	.dw 0xa3c0, 0xc11a,	0xa3ff, 0xc11a,		0x21, 0
	.dw 0xa440, 0xc11a,	0xa47f, 0xc11a,		0x21, 0
	.dw 0xa4c0, 0xc11a,	0xa4ff, 0xc11a,		0x21, 0
	.dw 0xa540, 0xc11a,	0xa57f, 0xc11a,		0x21, 0
	.dw 0xa5c0, 0xc11a,	0xa5ff, 0xc11a,		0x21, 0
	.dw 0xa640, 0xc11a,	0xa67f, 0xc11a,		0x21, 0
	.dw 0xa6c0, 0xc11a,	0xa6ff, 0xc11a,		0x21, 0
	.dw 0xa740, 0xc11a,	0xa77f, 0xc11a,		0x21, 0
	.dw 0xa7c0, 0xc11a,	0xa7ff, 0xc11a,		0x21, 0
	.dw 0xa840, 0xc11a,	0xa87f, 0xc11a,		0x21, 0
	.dw 0xa8c0, 0xc11a,	0xa8ff, 0xc11a,		0x21, 0
	.dw 0xa940, 0xc11a,	0xa97f, 0xc11a,		0x21, 0
	.dw 0xa9c0, 0xc11a,	0xa9ff, 0xc11a,		0x21, 0
	.dw 0xaa40, 0xc11a,	0xaa7f, 0xc11a,		0x21, 0
	.dw 0xaac0, 0xc11a,	0xaaff, 0xc11a,		0x21, 0
	.dw 0xab40, 0xc11a,	0xab7f, 0xc11a,		0x21, 0
	.dw 0xabc0, 0xc11a,	0xabff, 0xc11a,		0x21, 0
	.dw 0xac40, 0xc11a,	0xac7f, 0xc11a,		0x21, 0
	.dw 0xacc0, 0xc11a,	0xacff, 0xc11a,		0x21, 0
	.dw 0xad40, 0xc11a,	0xad7f, 0xc11a,		0x21, 0
	.dw 0xadc0, 0xc11a,	0xadff, 0xc11a,		0x21, 0
	.dw 0xae40, 0xc11a,	0xae7f, 0xc11a,		0x21, 0
	.dw 0xaec0, 0xc11a,	0xaeff, 0xc11a,		0x21, 0
	.dw 0xaf40, 0xc11a,	0xaf7f, 0xc11a,		0x21, 0
	.dw 0xafc0, 0xc11a,	0xafff, 0xc11a,		0x21, 0
	.dw 0xb040, 0xc11a,	0xb07f, 0xc11a,		0x21, 0
	.dw 0xb0c0, 0xc11a,	0xb0ff, 0xc11a,		0x21, 0
	.dw 0xb140, 0xc11a,	0xb17f, 0xc11a,		0x21, 0
	.dw 0xb1c0, 0xc11a,	0xb1ff, 0xc11a,		0x21, 0
	.dw 0xb240, 0xc11a,	0xb27f, 0xc11a,		0x21, 0
	.dw 0xb2c0, 0xc11a,	0xb2ff, 0xc11a,		0x21, 0
	.dw 0xb340, 0xc11a,	0xb37f, 0xc11a,		0x21, 0
	.dw 0xb3c0, 0xc11a,	0xb3ff, 0xc11a,		0x21, 0
	.dw 0xb440, 0xc11a,	0xb47f, 0xc11a,		0x21, 0
	.dw 0xb4c0, 0xc11a,	0xb4ff, 0xc11a,		0x21, 0
	.dw 0xb540, 0xc11a,	0xb57f, 0xc11a,		0x21, 0
	.dw 0xb5c0, 0xc11a,	0xb5ff, 0xc11a,		0x21, 0
	.dw 0xb640, 0xc11a,	0xb67f, 0xc11a,		0x21, 0
	.dw 0xb6c0, 0xc11a,	0xb6ff, 0xc11a,		0x21, 0
	.dw 0xb740, 0xc11a,	0xb77f, 0xc11a,		0x21, 0
	.dw 0xb7c0, 0xc11a,	0xb7ff, 0xc11a,		0x21, 0
	.dw 0xb840, 0xc11a,	0xb87f, 0xc11a,		0x21, 0
	.dw 0xb8c0, 0xc11a,	0xb8ff, 0xc11a,		0x21, 0
	.dw 0xb940, 0xc11a,	0xb97f, 0xc11a,		0x21, 0
	.dw 0xb9c0, 0xc11a,	0xdfff, 0xc11a,		0x21, 0
	.dw 0xe040, 0xc11a,	0xe07f, 0xc11a,		0x21, 0
	.dw 0xe0c0, 0xc11a,	0xe0ff, 0xc11a,		0x21, 0
	.dw 0xe140, 0xc11a,	0xe17f, 0xc11a,		0x21, 0
	.dw 0xe1c0, 0xc11a,	0xe1ff, 0xc11a,		0x21, 0
	.dw 0xe240, 0xc11a,	0xe27f, 0xc11a,		0x21, 0
	.dw 0xe2c0, 0xc11a,	0xe2ff, 0xc11a,		0x21, 0
	.dw 0xe340, 0xc11a,	0xe37f, 0xc11a,		0x21, 0
	.dw 0xe3c0, 0xc11a,	0xe3ff, 0xc11a,		0x21, 0
	.dw 0xe440, 0xc11a,	0xe47f, 0xc11a,		0x21, 0
	.dw 0xe4c0, 0xc11a,	0xe4ff, 0xc11a,		0x21, 0
	.dw 0xe540, 0xc11a,	0xe57f, 0xc11a,		0x21, 0
	.dw 0xe5c0, 0xc11a,	0xe5ff, 0xc11a,		0x21, 0
	.dw 0xe640, 0xc11a,	0xe67f, 0xc11a,		0x21, 0
	.dw 0xe6c0, 0xc11a,	0xe6ff, 0xc11a,		0x21, 0
	.dw 0xe740, 0xc11a,	0xe77f, 0xc11a,		0x21, 0
	.dw 0xe7c0, 0xc11a,	0xe7ff, 0xc11a,		0x21, 0
	.dw 0xe840, 0xc11a,	0xe87f, 0xc11a,		0x21, 0
	.dw 0xe8c0, 0xc11a,	0xe8ff, 0xc11a,		0x21, 0
	.dw 0xe940, 0xc11a,	0xe97f, 0xc11a,		0x21, 0
	.dw 0xe9c0, 0xc11a,	0xe9ff, 0xc11a,		0x21, 0
	.dw 0xea40, 0xc11a,	0xea7f, 0xc11a,		0x21, 0
	.dw 0xeac0, 0xc11a,	0xeaff, 0xc11a,		0x21, 0
	.dw 0xeb40, 0xc11a,	0xeb7f, 0xc11a,		0x21, 0
	.dw 0xebc0, 0xc11a,	0xebff, 0xc11a,		0x21, 0
	.dw 0xec40, 0xc11a,	0xec7f, 0xc11a,		0x21, 0
	.dw 0xecc0, 0xc11a,	0xecff, 0xc11a,		0x21, 0
	.dw 0xed40, 0xc11a,	0xed7f, 0xc11a,		0x21, 0
	.dw 0xedc0, 0xc11a,	0xedff, 0xc11a,		0x21, 0
	.dw 0xee40, 0xc11a,	0xee7f, 0xc11a,		0x21, 0
	.dw 0xeec0, 0xc11a,	0xeeff, 0xc11a,		0x21, 0
	.dw 0xef40, 0xc11a,	0xef7f, 0xc11a,		0x21, 0
	.dw 0xefc0, 0xc11a,	0xefff, 0xc11a,		0x21, 0
	.dw 0xf040, 0xc11a,	0xf07f, 0xc11a,		0x21, 0
	.dw 0xf0c0, 0xc11a,	0xf0ff, 0xc11a,		0x21, 0
	.dw 0xf140, 0xc11a,	0xf17f, 0xc11a,		0x21, 0
	.dw 0xf1c0, 0xc11a,	0xf1ff, 0xc11a,		0x21, 0
	.dw 0xf240, 0xc11a,	0xf27f, 0xc11a,		0x21, 0
	.dw 0xf2c0, 0xc11a,	0xf2ff, 0xc11a,		0x21, 0
	.dw 0xf340, 0xc11a,	0xf37f, 0xc11a,		0x21, 0
	.dw 0xf3c0, 0xc11a,	0xf3ff, 0xc11a,		0x21, 0
	.dw 0xf440, 0xc11a,	0xf47f, 0xc11a,		0x21, 0
	.dw 0xf4c0, 0xc11a,	0xf4ff, 0xc11a,		0x21, 0
	.dw 0xf540, 0xc11a,	0xf57f, 0xc11a,		0x21, 0
	.dw 0xf5c0, 0xc11a,	0xf5ff, 0xc11a,		0x21, 0
	.dw 0xf640, 0xc11a,	0xf67f, 0xc11a,		0x21, 0
	.dw 0xf6c0, 0xc11a,	0xf6ff, 0xc11a,		0x21, 0
	.dw 0xf740, 0xc11a,	0xf77f, 0xc11a,		0x21, 0
	.dw 0xf7c0, 0xc11a,	0xf7ff, 0xc11a,		0x21, 0
	.dw 0xf840, 0xc11a,	0xf87f, 0xc11a,		0x21, 0
	.dw 0xf8c0, 0xc11a,	0xf8ff, 0xc11a,		0x21, 0
	.dw 0xf940, 0xc11a,	0xf97f, 0xc11a,		0x21, 0
	.dw 0xf9c0, 0xc11a,	0xffff, 0xc11b,		0x21, 0
	.dw 0x0040, 0xc11c,	0x007f, 0xc11c,		0x21, 0
	.dw 0x00c0, 0xc11c,	0x00ff, 0xc11c,		0x21, 0
	.dw 0x0140, 0xc11c,	0x017f, 0xc11c,		0x21, 0
	.dw 0x01c0, 0xc11c,	0x01ff, 0xc11c,		0x21, 0
	.dw 0x0240, 0xc11c,	0x027f, 0xc11c,		0x21, 0
	.dw 0x02c0, 0xc11c,	0x02ff, 0xc11c,		0x21, 0
	.dw 0x0340, 0xc11c,	0x037f, 0xc11c,		0x21, 0
	.dw 0x03c0, 0xc11c,	0x03ff, 0xc11c,		0x21, 0
	.dw 0x0440, 0xc11c,	0x047f, 0xc11c,		0x21, 0
	.dw 0x04c0, 0xc11c,	0x04ff, 0xc11c,		0x21, 0
	.dw 0x0540, 0xc11c,	0x057f, 0xc11c,		0x21, 0
	.dw 0x05c0, 0xc11c,	0x05ff, 0xc11c,		0x21, 0
	.dw 0x0640, 0xc11c,	0x067f, 0xc11c,		0x21, 0
	.dw 0x06c0, 0xc11c,	0x06ff, 0xc11c,		0x21, 0
	.dw 0x0740, 0xc11c,	0x077f, 0xc11c,		0x21, 0
	.dw 0x07c0, 0xc11c,	0x07ff, 0xc11c,		0x21, 0
	.dw 0x0840, 0xc11c,	0x087f, 0xc11c,		0x21, 0
	.dw 0x08c0, 0xc11c,	0x08ff, 0xc11c,		0x21, 0
	.dw 0x0940, 0xc11c,	0x097f, 0xc11c,		0x21, 0
	.dw 0x09c0, 0xc11c,	0x09ff, 0xc11c,		0x21, 0
	.dw 0x0a40, 0xc11c,	0x0a7f, 0xc11c,		0x21, 0
	.dw 0x0ac0, 0xc11c,	0x0aff, 0xc11c,		0x21, 0
	.dw 0x0b40, 0xc11c,	0x0b7f, 0xc11c,		0x21, 0
	.dw 0x0bc0, 0xc11c,	0x0bff, 0xc11c,		0x21, 0
	.dw 0x0c40, 0xc11c,	0x0c7f, 0xc11c,		0x21, 0
	.dw 0x0cc0, 0xc11c,	0x0cff, 0xc11c,		0x21, 0
	.dw 0x0d40, 0xc11c,	0x0d7f, 0xc11c,		0x21, 0
	.dw 0x0dc0, 0xc11c,	0x0dff, 0xc11c,		0x21, 0
	.dw 0x0e40, 0xc11c,	0x0e7f, 0xc11c,		0x21, 0
	.dw 0x0ec0, 0xc11c,	0x0eff, 0xc11c,		0x21, 0
	.dw 0x0f40, 0xc11c,	0x0f7f, 0xc11c,		0x21, 0
	.dw 0x0fc0, 0xc11c,	0x0fff, 0xc11c,		0x21, 0
	.dw 0x1040, 0xc11c,	0x107f, 0xc11c,		0x21, 0
	.dw 0x10c0, 0xc11c,	0x10ff, 0xc11c,		0x21, 0
	.dw 0x1140, 0xc11c,	0x117f, 0xc11c,		0x21, 0
	.dw 0x11c0, 0xc11c,	0x11ff, 0xc11c,		0x21, 0
	.dw 0x1240, 0xc11c,	0x127f, 0xc11c,		0x21, 0
	.dw 0x12c0, 0xc11c,	0x12ff, 0xc11c,		0x21, 0
	.dw 0x1340, 0xc11c,	0x137f, 0xc11c,		0x21, 0
	.dw 0x13c0, 0xc11c,	0x13ff, 0xc11c,		0x21, 0
	.dw 0x1440, 0xc11c,	0x147f, 0xc11c,		0x21, 0
	.dw 0x14c0, 0xc11c,	0x14ff, 0xc11c,		0x21, 0
	.dw 0x1540, 0xc11c,	0x157f, 0xc11c,		0x21, 0
	.dw 0x15c0, 0xc11c,	0x15ff, 0xc11c,		0x21, 0
	.dw 0x1640, 0xc11c,	0x167f, 0xc11c,		0x21, 0
	.dw 0x16c0, 0xc11c,	0x16ff, 0xc11c,		0x21, 0
	.dw 0x1740, 0xc11c,	0x177f, 0xc11c,		0x21, 0
	.dw 0x17c0, 0xc11c,	0x17ff, 0xc11c,		0x21, 0
	.dw 0x1840, 0xc11c,	0x187f, 0xc11c,		0x21, 0
	.dw 0x18c0, 0xc11c,	0x18ff, 0xc11c,		0x21, 0
	.dw 0x1940, 0xc11c,	0x197f, 0xc11c,		0x21, 0
	.dw 0x19c0, 0xc11c,	0x1fff, 0xc11c,		0x21, 0
	.dw 0x2040, 0xc11c,	0x207f, 0xc11c,		0x21, 0
	.dw 0x20c0, 0xc11c,	0x20ff, 0xc11c,		0x21, 0
	.dw 0x2140, 0xc11c,	0x217f, 0xc11c,		0x21, 0
	.dw 0x21c0, 0xc11c,	0x21ff, 0xc11c,		0x21, 0
	.dw 0x2240, 0xc11c,	0x227f, 0xc11c,		0x21, 0
	.dw 0x22c0, 0xc11c,	0x22ff, 0xc11c,		0x21, 0
	.dw 0x2340, 0xc11c,	0x237f, 0xc11c,		0x21, 0
	.dw 0x23c0, 0xc11c,	0x23ff, 0xc11c,		0x21, 0
	.dw 0x2440, 0xc11c,	0x247f, 0xc11c,		0x21, 0
	.dw 0x24c0, 0xc11c,	0x24ff, 0xc11c,		0x21, 0
	.dw 0x2540, 0xc11c,	0x257f, 0xc11c,		0x21, 0
	.dw 0x25c0, 0xc11c,	0x25ff, 0xc11c,		0x21, 0
	.dw 0x2640, 0xc11c,	0x267f, 0xc11c,		0x21, 0
	.dw 0x26c0, 0xc11c,	0x26ff, 0xc11c,		0x21, 0
	.dw 0x2740, 0xc11c,	0x277f, 0xc11c,		0x21, 0
	.dw 0x27c0, 0xc11c,	0x27ff, 0xc11c,		0x21, 0
	.dw 0x2840, 0xc11c,	0x287f, 0xc11c,		0x21, 0
	.dw 0x28c0, 0xc11c,	0x28ff, 0xc11c,		0x21, 0
	.dw 0x2940, 0xc11c,	0x297f, 0xc11c,		0x21, 0
	.dw 0x29c0, 0xc11c,	0x29ff, 0xc11c,		0x21, 0
	.dw 0x2a40, 0xc11c,	0x2a7f, 0xc11c,		0x21, 0
	.dw 0x2ac0, 0xc11c,	0x2aff, 0xc11c,		0x21, 0
	.dw 0x2b40, 0xc11c,	0x2b7f, 0xc11c,		0x21, 0
	.dw 0x2bc0, 0xc11c,	0x2bff, 0xc11c,		0x21, 0
	.dw 0x2c40, 0xc11c,	0x2c7f, 0xc11c,		0x21, 0
	.dw 0x2cc0, 0xc11c,	0x2cff, 0xc11c,		0x21, 0
	.dw 0x2d40, 0xc11c,	0x2d7f, 0xc11c,		0x21, 0
	.dw 0x2dc0, 0xc11c,	0x2dff, 0xc11c,		0x21, 0
	.dw 0x2e40, 0xc11c,	0x2e7f, 0xc11c,		0x21, 0
	.dw 0x2ec0, 0xc11c,	0x2eff, 0xc11c,		0x21, 0
	.dw 0x2f40, 0xc11c,	0x2f7f, 0xc11c,		0x21, 0
	.dw 0x2fc0, 0xc11c,	0x2fff, 0xc11c,		0x21, 0
	.dw 0x3040, 0xc11c,	0x307f, 0xc11c,		0x21, 0
	.dw 0x30c0, 0xc11c,	0x30ff, 0xc11c,		0x21, 0
	.dw 0x3140, 0xc11c,	0x317f, 0xc11c,		0x21, 0
	.dw 0x31c0, 0xc11c,	0x31ff, 0xc11c,		0x21, 0
	.dw 0x3240, 0xc11c,	0x327f, 0xc11c,		0x21, 0
	.dw 0x32c0, 0xc11c,	0x32ff, 0xc11c,		0x21, 0
	.dw 0x3340, 0xc11c,	0x337f, 0xc11c,		0x21, 0
	.dw 0x33c0, 0xc11c,	0x33ff, 0xc11c,		0x21, 0
	.dw 0x3440, 0xc11c,	0x347f, 0xc11c,		0x21, 0
	.dw 0x34c0, 0xc11c,	0x34ff, 0xc11c,		0x21, 0
	.dw 0x3540, 0xc11c,	0x357f, 0xc11c,		0x21, 0
	.dw 0x35c0, 0xc11c,	0x35ff, 0xc11c,		0x21, 0
	.dw 0x3640, 0xc11c,	0x367f, 0xc11c,		0x21, 0
	.dw 0x36c0, 0xc11c,	0x36ff, 0xc11c,		0x21, 0
	.dw 0x3740, 0xc11c,	0x377f, 0xc11c,		0x21, 0
	.dw 0x37c0, 0xc11c,	0x37ff, 0xc11c,		0x21, 0
	.dw 0x3840, 0xc11c,	0x387f, 0xc11c,		0x21, 0
	.dw 0x38c0, 0xc11c,	0x38ff, 0xc11c,		0x21, 0
	.dw 0x3940, 0xc11c,	0x397f, 0xc11c,		0x21, 0
	.dw 0x39c0, 0xc11c,	0x3fff, 0xc11c,		0x21, 0
	.dw 0x4040, 0xc11c,	0x407f, 0xc11c,		0x21, 0
	.dw 0x40c0, 0xc11c,	0x40ff, 0xc11c,		0x21, 0
	.dw 0x4140, 0xc11c,	0x417f, 0xc11c,		0x21, 0
	.dw 0x41c0, 0xc11c,	0x41ff, 0xc11c,		0x21, 0
	.dw 0x4240, 0xc11c,	0x427f, 0xc11c,		0x21, 0
	.dw 0x42c0, 0xc11c,	0x42ff, 0xc11c,		0x21, 0
	.dw 0x4340, 0xc11c,	0x437f, 0xc11c,		0x21, 0
	.dw 0x43c0, 0xc11c,	0x43ff, 0xc11c,		0x21, 0
	.dw 0x4440, 0xc11c,	0x447f, 0xc11c,		0x21, 0
	.dw 0x44c0, 0xc11c,	0x44ff, 0xc11c,		0x21, 0
	.dw 0x4540, 0xc11c,	0x457f, 0xc11c,		0x21, 0
	.dw 0x45c0, 0xc11c,	0x45ff, 0xc11c,		0x21, 0
	.dw 0x4640, 0xc11c,	0x467f, 0xc11c,		0x21, 0
	.dw 0x46c0, 0xc11c,	0x46ff, 0xc11c,		0x21, 0
	.dw 0x4740, 0xc11c,	0x477f, 0xc11c,		0x21, 0
	.dw 0x47c0, 0xc11c,	0x47ff, 0xc11c,		0x21, 0
	.dw 0x4840, 0xc11c,	0x487f, 0xc11c,		0x21, 0
	.dw 0x48c0, 0xc11c,	0x48ff, 0xc11c,		0x21, 0
	.dw 0x4940, 0xc11c,	0x497f, 0xc11c,		0x21, 0
	.dw 0x49c0, 0xc11c,	0x49ff, 0xc11c,		0x21, 0
	.dw 0x4a40, 0xc11c,	0x4a7f, 0xc11c,		0x21, 0
	.dw 0x4ac0, 0xc11c,	0x4aff, 0xc11c,		0x21, 0
	.dw 0x4b40, 0xc11c,	0x4b7f, 0xc11c,		0x21, 0
	.dw 0x4bc0, 0xc11c,	0x4bff, 0xc11c,		0x21, 0
	.dw 0x4c40, 0xc11c,	0x4c7f, 0xc11c,		0x21, 0
	.dw 0x4cc0, 0xc11c,	0x4cff, 0xc11c,		0x21, 0
	.dw 0x4d40, 0xc11c,	0x4d7f, 0xc11c,		0x21, 0
	.dw 0x4dc0, 0xc11c,	0x4dff, 0xc11c,		0x21, 0
	.dw 0x4e40, 0xc11c,	0x4e7f, 0xc11c,		0x21, 0
	.dw 0x4ec0, 0xc11c,	0x4eff, 0xc11c,		0x21, 0
	.dw 0x4f40, 0xc11c,	0x4f7f, 0xc11c,		0x21, 0
	.dw 0x4fc0, 0xc11c,	0x4fff, 0xc11c,		0x21, 0
	.dw 0x5040, 0xc11c,	0x507f, 0xc11c,		0x21, 0
	.dw 0x50c0, 0xc11c,	0x50ff, 0xc11c,		0x21, 0
	.dw 0x5140, 0xc11c,	0x517f, 0xc11c,		0x21, 0
	.dw 0x51c0, 0xc11c,	0x51ff, 0xc11c,		0x21, 0
	.dw 0x5240, 0xc11c,	0x527f, 0xc11c,		0x21, 0
	.dw 0x52c0, 0xc11c,	0x52ff, 0xc11c,		0x21, 0
	.dw 0x5340, 0xc11c,	0x537f, 0xc11c,		0x21, 0
	.dw 0x53c0, 0xc11c,	0x53ff, 0xc11c,		0x21, 0
	.dw 0x5440, 0xc11c,	0x547f, 0xc11c,		0x21, 0
	.dw 0x54c0, 0xc11c,	0x54ff, 0xc11c,		0x21, 0
	.dw 0x5540, 0xc11c,	0x557f, 0xc11c,		0x21, 0
	.dw 0x55c0, 0xc11c,	0x55ff, 0xc11c,		0x21, 0
	.dw 0x5640, 0xc11c,	0x567f, 0xc11c,		0x21, 0
	.dw 0x56c0, 0xc11c,	0x56ff, 0xc11c,		0x21, 0
	.dw 0x5740, 0xc11c,	0x577f, 0xc11c,		0x21, 0
	.dw 0x57c0, 0xc11c,	0x57ff, 0xc11c,		0x21, 0
	.dw 0x5840, 0xc11c,	0x587f, 0xc11c,		0x21, 0
	.dw 0x58c0, 0xc11c,	0x58ff, 0xc11c,		0x21, 0
	.dw 0x5940, 0xc11c,	0x597f, 0xc11c,		0x21, 0
	.dw 0x59c0, 0xc11c,	0x5fff, 0xc11c,		0x21, 0
	.dw 0x6040, 0xc11c,	0x607f, 0xc11c,		0x21, 0
	.dw 0x60c0, 0xc11c,	0x60ff, 0xc11c,		0x21, 0
	.dw 0x6140, 0xc11c,	0x617f, 0xc11c,		0x21, 0
	.dw 0x61c0, 0xc11c,	0x61ff, 0xc11c,		0x21, 0
	.dw 0x6240, 0xc11c,	0x627f, 0xc11c,		0x21, 0
	.dw 0x62c0, 0xc11c,	0x62ff, 0xc11c,		0x21, 0
	.dw 0x6340, 0xc11c,	0x637f, 0xc11c,		0x21, 0
	.dw 0x63c0, 0xc11c,	0x63ff, 0xc11c,		0x21, 0
	.dw 0x6440, 0xc11c,	0x647f, 0xc11c,		0x21, 0
	.dw 0x64c0, 0xc11c,	0x64ff, 0xc11c,		0x21, 0
	.dw 0x6540, 0xc11c,	0x657f, 0xc11c,		0x21, 0
	.dw 0x65c0, 0xc11c,	0x65ff, 0xc11c,		0x21, 0
	.dw 0x6640, 0xc11c,	0x667f, 0xc11c,		0x21, 0
	.dw 0x66c0, 0xc11c,	0x66ff, 0xc11c,		0x21, 0
	.dw 0x6740, 0xc11c,	0x677f, 0xc11c,		0x21, 0
	.dw 0x67c0, 0xc11c,	0x67ff, 0xc11c,		0x21, 0
	.dw 0x6840, 0xc11c,	0x687f, 0xc11c,		0x21, 0
	.dw 0x68c0, 0xc11c,	0x68ff, 0xc11c,		0x21, 0
	.dw 0x6940, 0xc11c,	0x697f, 0xc11c,		0x21, 0
	.dw 0x69c0, 0xc11c,	0x69ff, 0xc11c,		0x21, 0
	.dw 0x6a40, 0xc11c,	0x6a7f, 0xc11c,		0x21, 0
	.dw 0x6ac0, 0xc11c,	0x6aff, 0xc11c,		0x21, 0
	.dw 0x6b40, 0xc11c,	0x6b7f, 0xc11c,		0x21, 0
	.dw 0x6bc0, 0xc11c,	0x6bff, 0xc11c,		0x21, 0
	.dw 0x6c40, 0xc11c,	0x6c7f, 0xc11c,		0x21, 0
	.dw 0x6cc0, 0xc11c,	0x6cff, 0xc11c,		0x21, 0
	.dw 0x6d40, 0xc11c,	0x6d7f, 0xc11c,		0x21, 0
	.dw 0x6dc0, 0xc11c,	0x6dff, 0xc11c,		0x21, 0
	.dw 0x6e40, 0xc11c,	0x6e7f, 0xc11c,		0x21, 0
	.dw 0x6ec0, 0xc11c,	0x6eff, 0xc11c,		0x21, 0
	.dw 0x6f40, 0xc11c,	0x6f7f, 0xc11c,		0x21, 0
	.dw 0x6fc0, 0xc11c,	0x6fff, 0xc11c,		0x21, 0
	.dw 0x7040, 0xc11c,	0x707f, 0xc11c,		0x21, 0
	.dw 0x70c0, 0xc11c,	0x70ff, 0xc11c,		0x21, 0
	.dw 0x7140, 0xc11c,	0x717f, 0xc11c,		0x21, 0
	.dw 0x71c0, 0xc11c,	0x71ff, 0xc11c,		0x21, 0
	.dw 0x7240, 0xc11c,	0x727f, 0xc11c,		0x21, 0
	.dw 0x72c0, 0xc11c,	0x72ff, 0xc11c,		0x21, 0
	.dw 0x7340, 0xc11c,	0x737f, 0xc11c,		0x21, 0
	.dw 0x73c0, 0xc11c,	0x73ff, 0xc11c,		0x21, 0
	.dw 0x7440, 0xc11c,	0x747f, 0xc11c,		0x21, 0
	.dw 0x74c0, 0xc11c,	0x74ff, 0xc11c,		0x21, 0
	.dw 0x7540, 0xc11c,	0x757f, 0xc11c,		0x21, 0
	.dw 0x75c0, 0xc11c,	0x75ff, 0xc11c,		0x21, 0
	.dw 0x7640, 0xc11c,	0x767f, 0xc11c,		0x21, 0
	.dw 0x76c0, 0xc11c,	0x76ff, 0xc11c,		0x21, 0
	.dw 0x7740, 0xc11c,	0x777f, 0xc11c,		0x21, 0
	.dw 0x77c0, 0xc11c,	0x77ff, 0xc11c,		0x21, 0
	.dw 0x7840, 0xc11c,	0x787f, 0xc11c,		0x21, 0
	.dw 0x78c0, 0xc11c,	0x78ff, 0xc11c,		0x21, 0
	.dw 0x7940, 0xc11c,	0x797f, 0xc11c,		0x21, 0
	.dw 0x79c0, 0xc11c,	0x7fff, 0xc11c,		0x21, 0
	.dw 0x8040, 0xc11c,	0x807f, 0xc11c,		0x21, 0
	.dw 0x80c0, 0xc11c,	0x80ff, 0xc11c,		0x21, 0
	.dw 0x8140, 0xc11c,	0x817f, 0xc11c,		0x21, 0
	.dw 0x81c0, 0xc11c,	0x81ff, 0xc11c,		0x21, 0
	.dw 0x8240, 0xc11c,	0x827f, 0xc11c,		0x21, 0
	.dw 0x82c0, 0xc11c,	0x82ff, 0xc11c,		0x21, 0
	.dw 0x8340, 0xc11c,	0x837f, 0xc11c,		0x21, 0
	.dw 0x83c0, 0xc11c,	0x83ff, 0xc11c,		0x21, 0
	.dw 0x8440, 0xc11c,	0x847f, 0xc11c,		0x21, 0
	.dw 0x84c0, 0xc11c,	0x84ff, 0xc11c,		0x21, 0
	.dw 0x8540, 0xc11c,	0x857f, 0xc11c,		0x21, 0
	.dw 0x85c0, 0xc11c,	0x85ff, 0xc11c,		0x21, 0
	.dw 0x8640, 0xc11c,	0x867f, 0xc11c,		0x21, 0
	.dw 0x86c0, 0xc11c,	0x86ff, 0xc11c,		0x21, 0
	.dw 0x8740, 0xc11c,	0x877f, 0xc11c,		0x21, 0
	.dw 0x87c0, 0xc11c,	0x87ff, 0xc11c,		0x21, 0
	.dw 0x8840, 0xc11c,	0x887f, 0xc11c,		0x21, 0
	.dw 0x88c0, 0xc11c,	0x88ff, 0xc11c,		0x21, 0
	.dw 0x8940, 0xc11c,	0x897f, 0xc11c,		0x21, 0
	.dw 0x89c0, 0xc11c,	0x89ff, 0xc11c,		0x21, 0
	.dw 0x8a40, 0xc11c,	0x8a7f, 0xc11c,		0x21, 0
	.dw 0x8ac0, 0xc11c,	0x8aff, 0xc11c,		0x21, 0
	.dw 0x8b40, 0xc11c,	0x8b7f, 0xc11c,		0x21, 0
	.dw 0x8bc0, 0xc11c,	0x8bff, 0xc11c,		0x21, 0
	.dw 0x8c40, 0xc11c,	0x8c7f, 0xc11c,		0x21, 0
	.dw 0x8cc0, 0xc11c,	0x8cff, 0xc11c,		0x21, 0
	.dw 0x8d40, 0xc11c,	0x8d7f, 0xc11c,		0x21, 0
	.dw 0x8dc0, 0xc11c,	0x8dff, 0xc11c,		0x21, 0
	.dw 0x8e40, 0xc11c,	0x8e7f, 0xc11c,		0x21, 0
	.dw 0x8ec0, 0xc11c,	0x8eff, 0xc11c,		0x21, 0
	.dw 0x8f40, 0xc11c,	0x8f7f, 0xc11c,		0x21, 0
	.dw 0x8fc0, 0xc11c,	0x8fff, 0xc11c,		0x21, 0
	.dw 0x9040, 0xc11c,	0x907f, 0xc11c,		0x21, 0
	.dw 0x90c0, 0xc11c,	0x90ff, 0xc11c,		0x21, 0
	.dw 0x9140, 0xc11c,	0x917f, 0xc11c,		0x21, 0
	.dw 0x91c0, 0xc11c,	0x91ff, 0xc11c,		0x21, 0
	.dw 0x9240, 0xc11c,	0x927f, 0xc11c,		0x21, 0
	.dw 0x92c0, 0xc11c,	0x92ff, 0xc11c,		0x21, 0
	.dw 0x9340, 0xc11c,	0x937f, 0xc11c,		0x21, 0
	.dw 0x93c0, 0xc11c,	0x93ff, 0xc11c,		0x21, 0
	.dw 0x9440, 0xc11c,	0x947f, 0xc11c,		0x21, 0
	.dw 0x94c0, 0xc11c,	0x94ff, 0xc11c,		0x21, 0
	.dw 0x9540, 0xc11c,	0x957f, 0xc11c,		0x21, 0
	.dw 0x95c0, 0xc11c,	0x95ff, 0xc11c,		0x21, 0
	.dw 0x9640, 0xc11c,	0x967f, 0xc11c,		0x21, 0
	.dw 0x96c0, 0xc11c,	0x96ff, 0xc11c,		0x21, 0
	.dw 0x9740, 0xc11c,	0x977f, 0xc11c,		0x21, 0
	.dw 0x97c0, 0xc11c,	0x97ff, 0xc11c,		0x21, 0
	.dw 0x9840, 0xc11c,	0x987f, 0xc11c,		0x21, 0
	.dw 0x98c0, 0xc11c,	0x98ff, 0xc11c,		0x21, 0
	.dw 0x9940, 0xc11c,	0x997f, 0xc11c,		0x21, 0
	.dw 0x99c0, 0xc11c,	0x9fff, 0xc11c,		0x21, 0
	.dw 0xa040, 0xc11c,	0xa07f, 0xc11c,		0x21, 0
	.dw 0xa0c0, 0xc11c,	0xa0ff, 0xc11c,		0x21, 0
	.dw 0xa140, 0xc11c,	0xa17f, 0xc11c,		0x21, 0
	.dw 0xa1c0, 0xc11c,	0xa1ff, 0xc11c,		0x21, 0
	.dw 0xa240, 0xc11c,	0xa27f, 0xc11c,		0x21, 0
	.dw 0xa2c0, 0xc11c,	0xa2ff, 0xc11c,		0x21, 0
	.dw 0xa340, 0xc11c,	0xa37f, 0xc11c,		0x21, 0
	.dw 0xa3c0, 0xc11c,	0xa3ff, 0xc11c,		0x21, 0
	.dw 0xa440, 0xc11c,	0xa47f, 0xc11c,		0x21, 0
	.dw 0xa4c0, 0xc11c,	0xa4ff, 0xc11c,		0x21, 0
	.dw 0xa540, 0xc11c,	0xa57f, 0xc11c,		0x21, 0
	.dw 0xa5c0, 0xc11c,	0xa5ff, 0xc11c,		0x21, 0
	.dw 0xa640, 0xc11c,	0xa67f, 0xc11c,		0x21, 0
	.dw 0xa6c0, 0xc11c,	0xa6ff, 0xc11c,		0x21, 0
	.dw 0xa740, 0xc11c,	0xa77f, 0xc11c,		0x21, 0
	.dw 0xa7c0, 0xc11c,	0xa7ff, 0xc11c,		0x21, 0
	.dw 0xa840, 0xc11c,	0xa87f, 0xc11c,		0x21, 0
	.dw 0xa8c0, 0xc11c,	0xa8ff, 0xc11c,		0x21, 0
	.dw 0xa940, 0xc11c,	0xa97f, 0xc11c,		0x21, 0
	.dw 0xa9c0, 0xc11c,	0xa9ff, 0xc11c,		0x21, 0
	.dw 0xaa40, 0xc11c,	0xaa7f, 0xc11c,		0x21, 0
	.dw 0xaac0, 0xc11c,	0xaaff, 0xc11c,		0x21, 0
	.dw 0xab40, 0xc11c,	0xab7f, 0xc11c,		0x21, 0
	.dw 0xabc0, 0xc11c,	0xabff, 0xc11c,		0x21, 0
	.dw 0xac40, 0xc11c,	0xac7f, 0xc11c,		0x21, 0
	.dw 0xacc0, 0xc11c,	0xacff, 0xc11c,		0x21, 0
	.dw 0xad40, 0xc11c,	0xad7f, 0xc11c,		0x21, 0
	.dw 0xadc0, 0xc11c,	0xadff, 0xc11c,		0x21, 0
	.dw 0xae40, 0xc11c,	0xae7f, 0xc11c,		0x21, 0
	.dw 0xaec0, 0xc11c,	0xaeff, 0xc11c,		0x21, 0
	.dw 0xaf40, 0xc11c,	0xaf7f, 0xc11c,		0x21, 0
	.dw 0xafc0, 0xc11c,	0xafff, 0xc11c,		0x21, 0
	.dw 0xb040, 0xc11c,	0xb07f, 0xc11c,		0x21, 0
	.dw 0xb0c0, 0xc11c,	0xb0ff, 0xc11c,		0x21, 0
	.dw 0xb140, 0xc11c,	0xb17f, 0xc11c,		0x21, 0
	.dw 0xb1c0, 0xc11c,	0xb1ff, 0xc11c,		0x21, 0
	.dw 0xb240, 0xc11c,	0xb27f, 0xc11c,		0x21, 0
	.dw 0xb2c0, 0xc11c,	0xb2ff, 0xc11c,		0x21, 0
	.dw 0xb340, 0xc11c,	0xb37f, 0xc11c,		0x21, 0
	.dw 0xb3c0, 0xc11c,	0xb3ff, 0xc11c,		0x21, 0
	.dw 0xb440, 0xc11c,	0xb47f, 0xc11c,		0x21, 0
	.dw 0xb4c0, 0xc11c,	0xb4ff, 0xc11c,		0x21, 0
	.dw 0xb540, 0xc11c,	0xb57f, 0xc11c,		0x21, 0
	.dw 0xb5c0, 0xc11c,	0xb5ff, 0xc11c,		0x21, 0
	.dw 0xb640, 0xc11c,	0xb67f, 0xc11c,		0x21, 0
	.dw 0xb6c0, 0xc11c,	0xb6ff, 0xc11c,		0x21, 0
	.dw 0xb740, 0xc11c,	0xb77f, 0xc11c,		0x21, 0
	.dw 0xb7c0, 0xc11c,	0xb7ff, 0xc11c,		0x21, 0
	.dw 0xb840, 0xc11c,	0xb87f, 0xc11c,		0x21, 0
	.dw 0xb8c0, 0xc11c,	0xb8ff, 0xc11c,		0x21, 0
	.dw 0xb940, 0xc11c,	0xb97f, 0xc11c,		0x21, 0
	.dw 0xb9c0, 0xc11c,	0xbfff, 0xc11c,		0x21, 0
	.dw 0xc040, 0xc11c,	0xc07f, 0xc11c,		0x21, 0
	.dw 0xc0c0, 0xc11c,	0xc0ff, 0xc11c,		0x21, 0
	.dw 0xc140, 0xc11c,	0xc17f, 0xc11c,		0x21, 0
	.dw 0xc1c0, 0xc11c,	0xc1ff, 0xc11c,		0x21, 0
	.dw 0xc240, 0xc11c,	0xc27f, 0xc11c,		0x21, 0
	.dw 0xc2c0, 0xc11c,	0xc2ff, 0xc11c,		0x21, 0
	.dw 0xc340, 0xc11c,	0xc37f, 0xc11c,		0x21, 0
	.dw 0xc3c0, 0xc11c,	0xc3ff, 0xc11c,		0x21, 0
	.dw 0xc440, 0xc11c,	0xc47f, 0xc11c,		0x21, 0
	.dw 0xc4c0, 0xc11c,	0xc4ff, 0xc11c,		0x21, 0
	.dw 0xc540, 0xc11c,	0xc57f, 0xc11c,		0x21, 0
	.dw 0xc5c0, 0xc11c,	0xc5ff, 0xc11c,		0x21, 0
	.dw 0xc640, 0xc11c,	0xc67f, 0xc11c,		0x21, 0
	.dw 0xc6c0, 0xc11c,	0xc6ff, 0xc11c,		0x21, 0
	.dw 0xc740, 0xc11c,	0xc77f, 0xc11c,		0x21, 0
	.dw 0xc7c0, 0xc11c,	0xc7ff, 0xc11c,		0x21, 0
	.dw 0xc840, 0xc11c,	0xc87f, 0xc11c,		0x21, 0
	.dw 0xc8c0, 0xc11c,	0xc8ff, 0xc11c,		0x21, 0
	.dw 0xc940, 0xc11c,	0xc97f, 0xc11c,		0x21, 0
	.dw 0xc9c0, 0xc11c,	0xc9ff, 0xc11c,		0x21, 0
	.dw 0xca40, 0xc11c,	0xca7f, 0xc11c,		0x21, 0
	.dw 0xcac0, 0xc11c,	0xcaff, 0xc11c,		0x21, 0
	.dw 0xcb40, 0xc11c,	0xcb7f, 0xc11c,		0x21, 0
	.dw 0xcbc0, 0xc11c,	0xcbff, 0xc11c,		0x21, 0
	.dw 0xcc40, 0xc11c,	0xcc7f, 0xc11c,		0x21, 0
	.dw 0xccc0, 0xc11c,	0xccff, 0xc11c,		0x21, 0
	.dw 0xcd40, 0xc11c,	0xcd7f, 0xc11c,		0x21, 0
	.dw 0xcdc0, 0xc11c,	0xcdff, 0xc11c,		0x21, 0
	.dw 0xce40, 0xc11c,	0xce7f, 0xc11c,		0x21, 0
	.dw 0xcec0, 0xc11c,	0xceff, 0xc11c,		0x21, 0
	.dw 0xcf40, 0xc11c,	0xcf7f, 0xc11c,		0x21, 0
	.dw 0xcfc0, 0xc11c,	0xcfff, 0xc11c,		0x21, 0
	.dw 0xd040, 0xc11c,	0xd07f, 0xc11c,		0x21, 0
	.dw 0xd0c0, 0xc11c,	0xd0ff, 0xc11c,		0x21, 0
	.dw 0xd140, 0xc11c,	0xd17f, 0xc11c,		0x21, 0
	.dw 0xd1c0, 0xc11c,	0xd1ff, 0xc11c,		0x21, 0
	.dw 0xd240, 0xc11c,	0xd27f, 0xc11c,		0x21, 0
	.dw 0xd2c0, 0xc11c,	0xd2ff, 0xc11c,		0x21, 0
	.dw 0xd340, 0xc11c,	0xd37f, 0xc11c,		0x21, 0
	.dw 0xd3c0, 0xc11c,	0xd3ff, 0xc11c,		0x21, 0
	.dw 0xd440, 0xc11c,	0xd47f, 0xc11c,		0x21, 0
	.dw 0xd4c0, 0xc11c,	0xd4ff, 0xc11c,		0x21, 0
	.dw 0xd540, 0xc11c,	0xd57f, 0xc11c,		0x21, 0
	.dw 0xd5c0, 0xc11c,	0xd5ff, 0xc11c,		0x21, 0
	.dw 0xd640, 0xc11c,	0xd67f, 0xc11c,		0x21, 0
	.dw 0xd6c0, 0xc11c,	0xd6ff, 0xc11c,		0x21, 0
	.dw 0xd740, 0xc11c,	0xd77f, 0xc11c,		0x21, 0
	.dw 0xd7c0, 0xc11c,	0xd7ff, 0xc11c,		0x21, 0
	.dw 0xd840, 0xc11c,	0xd87f, 0xc11c,		0x21, 0
	.dw 0xd8c0, 0xc11c,	0xd8ff, 0xc11c,		0x21, 0
	.dw 0xd940, 0xc11c,	0xd97f, 0xc11c,		0x21, 0
	.dw 0xd9c0, 0xc11c,	0xdfff, 0xc11c,		0x21, 0
	.dw 0xe040, 0xc11c,	0xe07f, 0xc11c,		0x21, 0
	.dw 0xe0c0, 0xc11c,	0xe0ff, 0xc11c,		0x21, 0
	.dw 0xe140, 0xc11c,	0xe17f, 0xc11c,		0x21, 0
	.dw 0xe1c0, 0xc11c,	0xe1ff, 0xc11c,		0x21, 0
	.dw 0xe240, 0xc11c,	0xe27f, 0xc11c,		0x21, 0
	.dw 0xe2c0, 0xc11c,	0xe2ff, 0xc11c,		0x21, 0
	.dw 0xe340, 0xc11c,	0xe37f, 0xc11c,		0x21, 0
	.dw 0xe3c0, 0xc11c,	0xe3ff, 0xc11c,		0x21, 0
	.dw 0xe440, 0xc11c,	0xe47f, 0xc11c,		0x21, 0
	.dw 0xe4c0, 0xc11c,	0xe4ff, 0xc11c,		0x21, 0
	.dw 0xe540, 0xc11c,	0xe57f, 0xc11c,		0x21, 0
	.dw 0xe5c0, 0xc11c,	0xe5ff, 0xc11c,		0x21, 0
	.dw 0xe640, 0xc11c,	0xe67f, 0xc11c,		0x21, 0
	.dw 0xe6c0, 0xc11c,	0xe6ff, 0xc11c,		0x21, 0
	.dw 0xe740, 0xc11c,	0xe77f, 0xc11c,		0x21, 0
	.dw 0xe7c0, 0xc11c,	0xe7ff, 0xc11c,		0x21, 0
	.dw 0xe840, 0xc11c,	0xe87f, 0xc11c,		0x21, 0
	.dw 0xe8c0, 0xc11c,	0xe8ff, 0xc11c,		0x21, 0
	.dw 0xe940, 0xc11c,	0xe97f, 0xc11c,		0x21, 0
	.dw 0xe9c0, 0xc11c,	0xe9ff, 0xc11c,		0x21, 0
	.dw 0xea40, 0xc11c,	0xea7f, 0xc11c,		0x21, 0
	.dw 0xeac0, 0xc11c,	0xeaff, 0xc11c,		0x21, 0
	.dw 0xeb40, 0xc11c,	0xeb7f, 0xc11c,		0x21, 0
	.dw 0xebc0, 0xc11c,	0xebff, 0xc11c,		0x21, 0
	.dw 0xec40, 0xc11c,	0xec7f, 0xc11c,		0x21, 0
	.dw 0xecc0, 0xc11c,	0xecff, 0xc11c,		0x21, 0
	.dw 0xed40, 0xc11c,	0xed7f, 0xc11c,		0x21, 0
	.dw 0xedc0, 0xc11c,	0xedff, 0xc11c,		0x21, 0
	.dw 0xee40, 0xc11c,	0xee7f, 0xc11c,		0x21, 0
	.dw 0xeec0, 0xc11c,	0xeeff, 0xc11c,		0x21, 0
	.dw 0xef40, 0xc11c,	0xef7f, 0xc11c,		0x21, 0
	.dw 0xefc0, 0xc11c,	0xefff, 0xc11c,		0x21, 0
	.dw 0xf040, 0xc11c,	0xf07f, 0xc11c,		0x21, 0
	.dw 0xf0c0, 0xc11c,	0xf0ff, 0xc11c,		0x21, 0
	.dw 0xf140, 0xc11c,	0xf17f, 0xc11c,		0x21, 0
	.dw 0xf1c0, 0xc11c,	0xf1ff, 0xc11c,		0x21, 0
	.dw 0xf240, 0xc11c,	0xf27f, 0xc11c,		0x21, 0
	.dw 0xf2c0, 0xc11c,	0xf2ff, 0xc11c,		0x21, 0
	.dw 0xf340, 0xc11c,	0xf37f, 0xc11c,		0x21, 0
	.dw 0xf3c0, 0xc11c,	0xf3ff, 0xc11c,		0x21, 0
	.dw 0xf440, 0xc11c,	0xf47f, 0xc11c,		0x21, 0
	.dw 0xf4c0, 0xc11c,	0xf4ff, 0xc11c,		0x21, 0
	.dw 0xf540, 0xc11c,	0xf57f, 0xc11c,		0x21, 0
	.dw 0xf5c0, 0xc11c,	0xf5ff, 0xc11c,		0x21, 0
	.dw 0xf640, 0xc11c,	0xf67f, 0xc11c,		0x21, 0
	.dw 0xf6c0, 0xc11c,	0xf6ff, 0xc11c,		0x21, 0
	.dw 0xf740, 0xc11c,	0xf77f, 0xc11c,		0x21, 0
	.dw 0xf7c0, 0xc11c,	0xf7ff, 0xc11c,		0x21, 0
	.dw 0xf840, 0xc11c,	0xf87f, 0xc11c,		0x21, 0
	.dw 0xf8c0, 0xc11c,	0xf8ff, 0xc11c,		0x21, 0
	.dw 0xf940, 0xc11c,	0xf97f, 0xc11c,		0x21, 0
	.dw 0xf9c0, 0xc11c,	0xffff, 0xc11c,		0x21, 0
	.dw 0x0040, 0xc11d,	0x007f, 0xc11d,		0x21, 0
	.dw 0x00c0, 0xc11d,	0x00ff, 0xc11d,		0x21, 0
	.dw 0x0140, 0xc11d,	0x017f, 0xc11d,		0x21, 0
	.dw 0x01c0, 0xc11d,	0x01ff, 0xc11d,		0x21, 0
	.dw 0x0240, 0xc11d,	0x027f, 0xc11d,		0x21, 0
	.dw 0x02c0, 0xc11d,	0x02ff, 0xc11d,		0x21, 0
	.dw 0x0340, 0xc11d,	0x037f, 0xc11d,		0x21, 0
	.dw 0x03c0, 0xc11d,	0x03ff, 0xc11d,		0x21, 0
	.dw 0x0440, 0xc11d,	0x047f, 0xc11d,		0x21, 0
	.dw 0x04c0, 0xc11d,	0x04ff, 0xc11d,		0x21, 0
	.dw 0x0540, 0xc11d,	0x057f, 0xc11d,		0x21, 0
	.dw 0x05c0, 0xc11d,	0x05ff, 0xc11d,		0x21, 0
	.dw 0x0640, 0xc11d,	0x067f, 0xc11d,		0x21, 0
	.dw 0x06c0, 0xc11d,	0x06ff, 0xc11d,		0x21, 0
	.dw 0x0740, 0xc11d,	0x077f, 0xc11d,		0x21, 0
	.dw 0x07c0, 0xc11d,	0x07ff, 0xc11d,		0x21, 0
	.dw 0x0840, 0xc11d,	0x087f, 0xc11d,		0x21, 0
	.dw 0x08c0, 0xc11d,	0x08ff, 0xc11d,		0x21, 0
	.dw 0x0940, 0xc11d,	0x097f, 0xc11d,		0x21, 0
	.dw 0x09c0, 0xc11d,	0x09ff, 0xc11d,		0x21, 0
	.dw 0x0a40, 0xc11d,	0x0a7f, 0xc11d,		0x21, 0
	.dw 0x0ac0, 0xc11d,	0x0aff, 0xc11d,		0x21, 0
	.dw 0x0b40, 0xc11d,	0x0b7f, 0xc11d,		0x21, 0
	.dw 0x0bc0, 0xc11d,	0x0bff, 0xc11d,		0x21, 0
	.dw 0x0c40, 0xc11d,	0x0c7f, 0xc11d,		0x21, 0
	.dw 0x0cc0, 0xc11d,	0x0cff, 0xc11d,		0x21, 0
	.dw 0x0d40, 0xc11d,	0x0d7f, 0xc11d,		0x21, 0
	.dw 0x0dc0, 0xc11d,	0x0dff, 0xc11d,		0x21, 0
	.dw 0x0e40, 0xc11d,	0x0e7f, 0xc11d,		0x21, 0
	.dw 0x0ec0, 0xc11d,	0x0eff, 0xc11d,		0x21, 0
	.dw 0x0f40, 0xc11d,	0x0f7f, 0xc11d,		0x21, 0
	.dw 0x0fc0, 0xc11d,	0x0fff, 0xc11d,		0x21, 0
	.dw 0x1040, 0xc11d,	0x107f, 0xc11d,		0x21, 0
	.dw 0x10c0, 0xc11d,	0x10ff, 0xc11d,		0x21, 0
	.dw 0x1140, 0xc11d,	0x117f, 0xc11d,		0x21, 0
	.dw 0x11c0, 0xc11d,	0x11ff, 0xc11d,		0x21, 0
	.dw 0x1240, 0xc11d,	0x127f, 0xc11d,		0x21, 0
	.dw 0x12c0, 0xc11d,	0x12ff, 0xc11d,		0x21, 0
	.dw 0x1340, 0xc11d,	0x137f, 0xc11d,		0x21, 0
	.dw 0x13c0, 0xc11d,	0x13ff, 0xc11d,		0x21, 0
	.dw 0x1440, 0xc11d,	0x147f, 0xc11d,		0x21, 0
	.dw 0x14c0, 0xc11d,	0x14ff, 0xc11d,		0x21, 0
	.dw 0x1540, 0xc11d,	0x157f, 0xc11d,		0x21, 0
	.dw 0x15c0, 0xc11d,	0x15ff, 0xc11d,		0x21, 0
	.dw 0x1640, 0xc11d,	0x167f, 0xc11d,		0x21, 0
	.dw 0x16c0, 0xc11d,	0x16ff, 0xc11d,		0x21, 0
	.dw 0x1740, 0xc11d,	0x177f, 0xc11d,		0x21, 0
	.dw 0x17c0, 0xc11d,	0x17ff, 0xc11d,		0x21, 0
	.dw 0x1840, 0xc11d,	0x187f, 0xc11d,		0x21, 0
	.dw 0x18c0, 0xc11d,	0x18ff, 0xc11d,		0x21, 0
	.dw 0x1940, 0xc11d,	0x197f, 0xc11d,		0x21, 0
	.dw 0x19c0, 0xc11d,	0x1fff, 0xc11d,		0x21, 0
	.dw 0x2040, 0xc11d,	0x207f, 0xc11d,		0x21, 0
	.dw 0x20c0, 0xc11d,	0x20ff, 0xc11d,		0x21, 0
	.dw 0x2140, 0xc11d,	0x217f, 0xc11d,		0x21, 0
	.dw 0x21c0, 0xc11d,	0x21ff, 0xc11d,		0x21, 0
	.dw 0x2240, 0xc11d,	0x227f, 0xc11d,		0x21, 0
	.dw 0x22c0, 0xc11d,	0x22ff, 0xc11d,		0x21, 0
	.dw 0x2340, 0xc11d,	0x237f, 0xc11d,		0x21, 0
	.dw 0x23c0, 0xc11d,	0x23ff, 0xc11d,		0x21, 0
	.dw 0x2440, 0xc11d,	0x247f, 0xc11d,		0x21, 0
	.dw 0x24c0, 0xc11d,	0x24ff, 0xc11d,		0x21, 0
	.dw 0x2540, 0xc11d,	0x257f, 0xc11d,		0x21, 0
	.dw 0x25c0, 0xc11d,	0x25ff, 0xc11d,		0x21, 0
	.dw 0x2640, 0xc11d,	0x267f, 0xc11d,		0x21, 0
	.dw 0x26c0, 0xc11d,	0x26ff, 0xc11d,		0x21, 0
	.dw 0x2740, 0xc11d,	0x277f, 0xc11d,		0x21, 0
	.dw 0x27c0, 0xc11d,	0x27ff, 0xc11d,		0x21, 0
	.dw 0x2840, 0xc11d,	0x287f, 0xc11d,		0x21, 0
	.dw 0x28c0, 0xc11d,	0x28ff, 0xc11d,		0x21, 0
	.dw 0x2940, 0xc11d,	0x297f, 0xc11d,		0x21, 0
	.dw 0x29c0, 0xc11d,	0x29ff, 0xc11d,		0x21, 0
	.dw 0x2a40, 0xc11d,	0x2a7f, 0xc11d,		0x21, 0
	.dw 0x2ac0, 0xc11d,	0x2aff, 0xc11d,		0x21, 0
	.dw 0x2b40, 0xc11d,	0x2b7f, 0xc11d,		0x21, 0
	.dw 0x2bc0, 0xc11d,	0x2bff, 0xc11d,		0x21, 0
	.dw 0x2c40, 0xc11d,	0x2c7f, 0xc11d,		0x21, 0
	.dw 0x2cc0, 0xc11d,	0x2cff, 0xc11d,		0x21, 0
	.dw 0x2d40, 0xc11d,	0x2d7f, 0xc11d,		0x21, 0
	.dw 0x2dc0, 0xc11d,	0x2dff, 0xc11d,		0x21, 0
	.dw 0x2e40, 0xc11d,	0x2e7f, 0xc11d,		0x21, 0
	.dw 0x2ec0, 0xc11d,	0x2eff, 0xc11d,		0x21, 0
	.dw 0x2f40, 0xc11d,	0x2f7f, 0xc11d,		0x21, 0
	.dw 0x2fc0, 0xc11d,	0x2fff, 0xc11d,		0x21, 0
	.dw 0x3040, 0xc11d,	0x307f, 0xc11d,		0x21, 0
	.dw 0x30c0, 0xc11d,	0x30ff, 0xc11d,		0x21, 0
	.dw 0x3140, 0xc11d,	0x317f, 0xc11d,		0x21, 0
	.dw 0x31c0, 0xc11d,	0x31ff, 0xc11d,		0x21, 0
	.dw 0x3240, 0xc11d,	0x327f, 0xc11d,		0x21, 0
	.dw 0x32c0, 0xc11d,	0x32ff, 0xc11d,		0x21, 0
	.dw 0x3340, 0xc11d,	0x337f, 0xc11d,		0x21, 0
	.dw 0x33c0, 0xc11d,	0x33ff, 0xc11d,		0x21, 0
	.dw 0x3440, 0xc11d,	0x347f, 0xc11d,		0x21, 0
	.dw 0x34c0, 0xc11d,	0x34ff, 0xc11d,		0x21, 0
	.dw 0x3540, 0xc11d,	0x357f, 0xc11d,		0x21, 0
	.dw 0x35c0, 0xc11d,	0x35ff, 0xc11d,		0x21, 0
	.dw 0x3640, 0xc11d,	0x367f, 0xc11d,		0x21, 0
	.dw 0x36c0, 0xc11d,	0x36ff, 0xc11d,		0x21, 0
	.dw 0x3740, 0xc11d,	0x377f, 0xc11d,		0x21, 0
	.dw 0x37c0, 0xc11d,	0x37ff, 0xc11d,		0x21, 0
	.dw 0x3840, 0xc11d,	0x387f, 0xc11d,		0x21, 0
	.dw 0x38c0, 0xc11d,	0x38ff, 0xc11d,		0x21, 0
	.dw 0x3940, 0xc11d,	0x397f, 0xc11d,		0x21, 0
	.dw 0x39c0, 0xc11d,	0x3fff, 0xc11d,		0x21, 0
	.dw 0x4040, 0xc11d,	0x407f, 0xc11d,		0x21, 0
	.dw 0x40c0, 0xc11d,	0x40ff, 0xc11d,		0x21, 0
	.dw 0x4140, 0xc11d,	0x417f, 0xc11d,		0x21, 0
	.dw 0x41c0, 0xc11d,	0x41ff, 0xc11d,		0x21, 0
	.dw 0x4240, 0xc11d,	0x427f, 0xc11d,		0x21, 0
	.dw 0x42c0, 0xc11d,	0x42ff, 0xc11d,		0x21, 0
	.dw 0x4340, 0xc11d,	0x437f, 0xc11d,		0x21, 0
	.dw 0x43c0, 0xc11d,	0x43ff, 0xc11d,		0x21, 0
	.dw 0x4440, 0xc11d,	0x447f, 0xc11d,		0x21, 0
	.dw 0x44c0, 0xc11d,	0x44ff, 0xc11d,		0x21, 0
	.dw 0x4540, 0xc11d,	0x457f, 0xc11d,		0x21, 0
	.dw 0x45c0, 0xc11d,	0x45ff, 0xc11d,		0x21, 0
	.dw 0x4640, 0xc11d,	0x467f, 0xc11d,		0x21, 0
	.dw 0x46c0, 0xc11d,	0x46ff, 0xc11d,		0x21, 0
	.dw 0x4740, 0xc11d,	0x477f, 0xc11d,		0x21, 0
	.dw 0x47c0, 0xc11d,	0x47ff, 0xc11d,		0x21, 0
	.dw 0x4840, 0xc11d,	0x487f, 0xc11d,		0x21, 0
	.dw 0x48c0, 0xc11d,	0x48ff, 0xc11d,		0x21, 0
	.dw 0x4940, 0xc11d,	0x497f, 0xc11d,		0x21, 0
	.dw 0x49c0, 0xc11d,	0x49ff, 0xc11d,		0x21, 0
	.dw 0x4a40, 0xc11d,	0x4a7f, 0xc11d,		0x21, 0
	.dw 0x4ac0, 0xc11d,	0x4aff, 0xc11d,		0x21, 0
	.dw 0x4b40, 0xc11d,	0x4b7f, 0xc11d,		0x21, 0
	.dw 0x4bc0, 0xc11d,	0x4bff, 0xc11d,		0x21, 0
	.dw 0x4c40, 0xc11d,	0x4c7f, 0xc11d,		0x21, 0
	.dw 0x4cc0, 0xc11d,	0x4cff, 0xc11d,		0x21, 0
	.dw 0x4d40, 0xc11d,	0x4d7f, 0xc11d,		0x21, 0
	.dw 0x4dc0, 0xc11d,	0x4dff, 0xc11d,		0x21, 0
	.dw 0x4e40, 0xc11d,	0x4e7f, 0xc11d,		0x21, 0
	.dw 0x4ec0, 0xc11d,	0x4eff, 0xc11d,		0x21, 0
	.dw 0x4f40, 0xc11d,	0x4f7f, 0xc11d,		0x21, 0
	.dw 0x4fc0, 0xc11d,	0x4fff, 0xc11d,		0x21, 0
	.dw 0x5040, 0xc11d,	0x507f, 0xc11d,		0x21, 0
	.dw 0x50c0, 0xc11d,	0x50ff, 0xc11d,		0x21, 0
	.dw 0x5140, 0xc11d,	0x517f, 0xc11d,		0x21, 0
	.dw 0x51c0, 0xc11d,	0x51ff, 0xc11d,		0x21, 0
	.dw 0x5240, 0xc11d,	0x527f, 0xc11d,		0x21, 0
	.dw 0x52c0, 0xc11d,	0x52ff, 0xc11d,		0x21, 0
	.dw 0x5340, 0xc11d,	0x537f, 0xc11d,		0x21, 0
	.dw 0x53c0, 0xc11d,	0x53ff, 0xc11d,		0x21, 0
	.dw 0x5440, 0xc11d,	0x547f, 0xc11d,		0x21, 0
	.dw 0x54c0, 0xc11d,	0x54ff, 0xc11d,		0x21, 0
	.dw 0x5540, 0xc11d,	0x557f, 0xc11d,		0x21, 0
	.dw 0x55c0, 0xc11d,	0x55ff, 0xc11d,		0x21, 0
	.dw 0x5640, 0xc11d,	0x567f, 0xc11d,		0x21, 0
	.dw 0x56c0, 0xc11d,	0x56ff, 0xc11d,		0x21, 0
	.dw 0x5740, 0xc11d,	0x577f, 0xc11d,		0x21, 0
	.dw 0x57c0, 0xc11d,	0x57ff, 0xc11d,		0x21, 0
	.dw 0x5840, 0xc11d,	0x587f, 0xc11d,		0x21, 0
	.dw 0x58c0, 0xc11d,	0x58ff, 0xc11d,		0x21, 0
	.dw 0x5940, 0xc11d,	0x597f, 0xc11d,		0x21, 0
	.dw 0x59c0, 0xc11d,	0x5fff, 0xc11d,		0x21, 0
	.dw 0x6040, 0xc11d,	0x607f, 0xc11d,		0x21, 0
	.dw 0x60c0, 0xc11d,	0x60ff, 0xc11d,		0x21, 0
	.dw 0x6140, 0xc11d,	0x617f, 0xc11d,		0x21, 0
	.dw 0x61c0, 0xc11d,	0x61ff, 0xc11d,		0x21, 0
	.dw 0x6240, 0xc11d,	0x627f, 0xc11d,		0x21, 0
	.dw 0x62c0, 0xc11d,	0x62ff, 0xc11d,		0x21, 0
	.dw 0x6340, 0xc11d,	0x637f, 0xc11d,		0x21, 0
	.dw 0x63c0, 0xc11d,	0x63ff, 0xc11d,		0x21, 0
	.dw 0x6440, 0xc11d,	0x647f, 0xc11d,		0x21, 0
	.dw 0x64c0, 0xc11d,	0x64ff, 0xc11d,		0x21, 0
	.dw 0x6540, 0xc11d,	0x657f, 0xc11d,		0x21, 0
	.dw 0x65c0, 0xc11d,	0x65ff, 0xc11d,		0x21, 0
	.dw 0x6640, 0xc11d,	0x667f, 0xc11d,		0x21, 0
	.dw 0x66c0, 0xc11d,	0x66ff, 0xc11d,		0x21, 0
	.dw 0x6740, 0xc11d,	0x677f, 0xc11d,		0x21, 0
	.dw 0x67c0, 0xc11d,	0x67ff, 0xc11d,		0x21, 0
	.dw 0x6840, 0xc11d,	0x687f, 0xc11d,		0x21, 0
	.dw 0x68c0, 0xc11d,	0x68ff, 0xc11d,		0x21, 0
	.dw 0x6940, 0xc11d,	0x697f, 0xc11d,		0x21, 0
	.dw 0x69c0, 0xc11d,	0x69ff, 0xc11d,		0x21, 0
	.dw 0x6a40, 0xc11d,	0x6a7f, 0xc11d,		0x21, 0
	.dw 0x6ac0, 0xc11d,	0x6aff, 0xc11d,		0x21, 0
	.dw 0x6b40, 0xc11d,	0x6b7f, 0xc11d,		0x21, 0
	.dw 0x6bc0, 0xc11d,	0x6bff, 0xc11d,		0x21, 0
	.dw 0x6c40, 0xc11d,	0x6c7f, 0xc11d,		0x21, 0
	.dw 0x6cc0, 0xc11d,	0x6cff, 0xc11d,		0x21, 0
	.dw 0x6d40, 0xc11d,	0x6d7f, 0xc11d,		0x21, 0
	.dw 0x6dc0, 0xc11d,	0x6dff, 0xc11d,		0x21, 0
	.dw 0x6e40, 0xc11d,	0x6e7f, 0xc11d,		0x21, 0
	.dw 0x6ec0, 0xc11d,	0x6eff, 0xc11d,		0x21, 0
	.dw 0x6f40, 0xc11d,	0x6f7f, 0xc11d,		0x21, 0
	.dw 0x6fc0, 0xc11d,	0x6fff, 0xc11d,		0x21, 0
	.dw 0x7040, 0xc11d,	0x707f, 0xc11d,		0x21, 0
	.dw 0x70c0, 0xc11d,	0x70ff, 0xc11d,		0x21, 0
	.dw 0x7140, 0xc11d,	0x717f, 0xc11d,		0x21, 0
	.dw 0x71c0, 0xc11d,	0x71ff, 0xc11d,		0x21, 0
	.dw 0x7240, 0xc11d,	0x727f, 0xc11d,		0x21, 0
	.dw 0x72c0, 0xc11d,	0x72ff, 0xc11d,		0x21, 0
	.dw 0x7340, 0xc11d,	0x737f, 0xc11d,		0x21, 0
	.dw 0x73c0, 0xc11d,	0x73ff, 0xc11d,		0x21, 0
	.dw 0x7440, 0xc11d,	0x747f, 0xc11d,		0x21, 0
	.dw 0x74c0, 0xc11d,	0x74ff, 0xc11d,		0x21, 0
	.dw 0x7540, 0xc11d,	0x757f, 0xc11d,		0x21, 0
	.dw 0x75c0, 0xc11d,	0x75ff, 0xc11d,		0x21, 0
	.dw 0x7640, 0xc11d,	0x767f, 0xc11d,		0x21, 0
	.dw 0x76c0, 0xc11d,	0x76ff, 0xc11d,		0x21, 0
	.dw 0x7740, 0xc11d,	0x777f, 0xc11d,		0x21, 0
	.dw 0x77c0, 0xc11d,	0x77ff, 0xc11d,		0x21, 0
	.dw 0x7840, 0xc11d,	0x787f, 0xc11d,		0x21, 0
	.dw 0x78c0, 0xc11d,	0x78ff, 0xc11d,		0x21, 0
	.dw 0x7940, 0xc11d,	0x797f, 0xc11d,		0x21, 0
	.dw 0x79c0, 0xc11d,	0x7fff, 0xc11d,		0x21, 0
	.dw 0x8040, 0xc11d,	0x807f, 0xc11d,		0x21, 0
	.dw 0x80c0, 0xc11d,	0x80ff, 0xc11d,		0x21, 0
	.dw 0x8140, 0xc11d,	0x817f, 0xc11d,		0x21, 0
	.dw 0x81c0, 0xc11d,	0x81ff, 0xc11d,		0x21, 0
	.dw 0x8240, 0xc11d,	0x827f, 0xc11d,		0x21, 0
	.dw 0x82c0, 0xc11d,	0x82ff, 0xc11d,		0x21, 0
	.dw 0x8340, 0xc11d,	0x837f, 0xc11d,		0x21, 0
	.dw 0x83c0, 0xc11d,	0x83ff, 0xc11d,		0x21, 0
	.dw 0x8440, 0xc11d,	0x847f, 0xc11d,		0x21, 0
	.dw 0x84c0, 0xc11d,	0x84ff, 0xc11d,		0x21, 0
	.dw 0x8540, 0xc11d,	0x857f, 0xc11d,		0x21, 0
	.dw 0x85c0, 0xc11d,	0x85ff, 0xc11d,		0x21, 0
	.dw 0x8640, 0xc11d,	0x867f, 0xc11d,		0x21, 0
	.dw 0x86c0, 0xc11d,	0x86ff, 0xc11d,		0x21, 0
	.dw 0x8740, 0xc11d,	0x877f, 0xc11d,		0x21, 0
	.dw 0x87c0, 0xc11d,	0x87ff, 0xc11d,		0x21, 0
	.dw 0x8840, 0xc11d,	0x887f, 0xc11d,		0x21, 0
	.dw 0x88c0, 0xc11d,	0x88ff, 0xc11d,		0x21, 0
	.dw 0x8940, 0xc11d,	0x897f, 0xc11d,		0x21, 0
	.dw 0x89c0, 0xc11d,	0x89ff, 0xc11d,		0x21, 0
	.dw 0x8a40, 0xc11d,	0x8a7f, 0xc11d,		0x21, 0
	.dw 0x8ac0, 0xc11d,	0x8aff, 0xc11d,		0x21, 0
	.dw 0x8b40, 0xc11d,	0x8b7f, 0xc11d,		0x21, 0
	.dw 0x8bc0, 0xc11d,	0x8bff, 0xc11d,		0x21, 0
	.dw 0x8c40, 0xc11d,	0x8c7f, 0xc11d,		0x21, 0
	.dw 0x8cc0, 0xc11d,	0x8cff, 0xc11d,		0x21, 0
	.dw 0x8d40, 0xc11d,	0x8d7f, 0xc11d,		0x21, 0
	.dw 0x8dc0, 0xc11d,	0x8dff, 0xc11d,		0x21, 0
	.dw 0x8e40, 0xc11d,	0x8e7f, 0xc11d,		0x21, 0
	.dw 0x8ec0, 0xc11d,	0x8eff, 0xc11d,		0x21, 0
	.dw 0x8f40, 0xc11d,	0x8f7f, 0xc11d,		0x21, 0
	.dw 0x8fc0, 0xc11d,	0x8fff, 0xc11d,		0x21, 0
	.dw 0x9040, 0xc11d,	0x907f, 0xc11d,		0x21, 0
	.dw 0x90c0, 0xc11d,	0x90ff, 0xc11d,		0x21, 0
	.dw 0x9140, 0xc11d,	0x917f, 0xc11d,		0x21, 0
	.dw 0x91c0, 0xc11d,	0x91ff, 0xc11d,		0x21, 0
	.dw 0x9240, 0xc11d,	0x927f, 0xc11d,		0x21, 0
	.dw 0x92c0, 0xc11d,	0x92ff, 0xc11d,		0x21, 0
	.dw 0x9340, 0xc11d,	0x937f, 0xc11d,		0x21, 0
	.dw 0x93c0, 0xc11d,	0x93ff, 0xc11d,		0x21, 0
	.dw 0x9440, 0xc11d,	0x947f, 0xc11d,		0x21, 0
	.dw 0x94c0, 0xc11d,	0x94ff, 0xc11d,		0x21, 0
	.dw 0x9540, 0xc11d,	0x957f, 0xc11d,		0x21, 0
	.dw 0x95c0, 0xc11d,	0x95ff, 0xc11d,		0x21, 0
	.dw 0x9640, 0xc11d,	0x967f, 0xc11d,		0x21, 0
	.dw 0x96c0, 0xc11d,	0x96ff, 0xc11d,		0x21, 0
	.dw 0x9740, 0xc11d,	0x977f, 0xc11d,		0x21, 0
	.dw 0x97c0, 0xc11d,	0x97ff, 0xc11d,		0x21, 0
	.dw 0x9840, 0xc11d,	0x987f, 0xc11d,		0x21, 0
	.dw 0x98c0, 0xc11d,	0x98ff, 0xc11d,		0x21, 0
	.dw 0x9940, 0xc11d,	0x997f, 0xc11d,		0x21, 0
	.dw 0x99c0, 0xc11d,	0x9fff, 0xc11d,		0x21, 0
	.dw 0xa040, 0xc11d,	0xa07f, 0xc11d,		0x21, 0
	.dw 0xa0c0, 0xc11d,	0xa0ff, 0xc11d,		0x21, 0
	.dw 0xa140, 0xc11d,	0xa17f, 0xc11d,		0x21, 0
	.dw 0xa1c0, 0xc11d,	0xa1ff, 0xc11d,		0x21, 0
	.dw 0xa240, 0xc11d,	0xa27f, 0xc11d,		0x21, 0
	.dw 0xa2c0, 0xc11d,	0xa2ff, 0xc11d,		0x21, 0
	.dw 0xa340, 0xc11d,	0xa37f, 0xc11d,		0x21, 0
	.dw 0xa3c0, 0xc11d,	0xa3ff, 0xc11d,		0x21, 0
	.dw 0xa440, 0xc11d,	0xa47f, 0xc11d,		0x21, 0
	.dw 0xa4c0, 0xc11d,	0xa4ff, 0xc11d,		0x21, 0
	.dw 0xa540, 0xc11d,	0xa57f, 0xc11d,		0x21, 0
	.dw 0xa5c0, 0xc11d,	0xa5ff, 0xc11d,		0x21, 0
	.dw 0xa640, 0xc11d,	0xa67f, 0xc11d,		0x21, 0
	.dw 0xa6c0, 0xc11d,	0xa6ff, 0xc11d,		0x21, 0
	.dw 0xa740, 0xc11d,	0xa77f, 0xc11d,		0x21, 0
	.dw 0xa7c0, 0xc11d,	0xa7ff, 0xc11d,		0x21, 0
	.dw 0xa840, 0xc11d,	0xa87f, 0xc11d,		0x21, 0
	.dw 0xa8c0, 0xc11d,	0xa8ff, 0xc11d,		0x21, 0
	.dw 0xa940, 0xc11d,	0xa97f, 0xc11d,		0x21, 0
	.dw 0xa9c0, 0xc11d,	0xa9ff, 0xc11d,		0x21, 0
	.dw 0xaa40, 0xc11d,	0xaa7f, 0xc11d,		0x21, 0
	.dw 0xaac0, 0xc11d,	0xaaff, 0xc11d,		0x21, 0
	.dw 0xab40, 0xc11d,	0xab7f, 0xc11d,		0x21, 0
	.dw 0xabc0, 0xc11d,	0xabff, 0xc11d,		0x21, 0
	.dw 0xac40, 0xc11d,	0xac7f, 0xc11d,		0x21, 0
	.dw 0xacc0, 0xc11d,	0xacff, 0xc11d,		0x21, 0
	.dw 0xad40, 0xc11d,	0xad7f, 0xc11d,		0x21, 0
	.dw 0xadc0, 0xc11d,	0xadff, 0xc11d,		0x21, 0
	.dw 0xae40, 0xc11d,	0xae7f, 0xc11d,		0x21, 0
	.dw 0xaec0, 0xc11d,	0xaeff, 0xc11d,		0x21, 0
	.dw 0xaf40, 0xc11d,	0xaf7f, 0xc11d,		0x21, 0
	.dw 0xafc0, 0xc11d,	0xafff, 0xc11d,		0x21, 0
	.dw 0xb040, 0xc11d,	0xb07f, 0xc11d,		0x21, 0
	.dw 0xb0c0, 0xc11d,	0xb0ff, 0xc11d,		0x21, 0
	.dw 0xb140, 0xc11d,	0xb17f, 0xc11d,		0x21, 0
	.dw 0xb1c0, 0xc11d,	0xb1ff, 0xc11d,		0x21, 0
	.dw 0xb240, 0xc11d,	0xb27f, 0xc11d,		0x21, 0
	.dw 0xb2c0, 0xc11d,	0xb2ff, 0xc11d,		0x21, 0
	.dw 0xb340, 0xc11d,	0xb37f, 0xc11d,		0x21, 0
	.dw 0xb3c0, 0xc11d,	0xb3ff, 0xc11d,		0x21, 0
	.dw 0xb440, 0xc11d,	0xb47f, 0xc11d,		0x21, 0
	.dw 0xb4c0, 0xc11d,	0xb4ff, 0xc11d,		0x21, 0
	.dw 0xb540, 0xc11d,	0xb57f, 0xc11d,		0x21, 0
	.dw 0xb5c0, 0xc11d,	0xb5ff, 0xc11d,		0x21, 0
	.dw 0xb640, 0xc11d,	0xb67f, 0xc11d,		0x21, 0
	.dw 0xb6c0, 0xc11d,	0xb6ff, 0xc11d,		0x21, 0
	.dw 0xb740, 0xc11d,	0xb77f, 0xc11d,		0x21, 0
	.dw 0xb7c0, 0xc11d,	0xb7ff, 0xc11d,		0x21, 0
	.dw 0xb840, 0xc11d,	0xb87f, 0xc11d,		0x21, 0
	.dw 0xb8c0, 0xc11d,	0xb8ff, 0xc11d,		0x21, 0
	.dw 0xb940, 0xc11d,	0xb97f, 0xc11d,		0x21, 0
	.dw 0xb9c0, 0xc11d,	0xbfff, 0xc11d,		0x21, 0
	.dw 0xc040, 0xc11d,	0xc07f, 0xc11d,		0x21, 0
	.dw 0xc0c0, 0xc11d,	0xc0ff, 0xc11d,		0x21, 0
	.dw 0xc140, 0xc11d,	0xc17f, 0xc11d,		0x21, 0
	.dw 0xc1c0, 0xc11d,	0xc1ff, 0xc11d,		0x21, 0
	.dw 0xc240, 0xc11d,	0xc27f, 0xc11d,		0x21, 0
	.dw 0xc2c0, 0xc11d,	0xc2ff, 0xc11d,		0x21, 0
	.dw 0xc340, 0xc11d,	0xc37f, 0xc11d,		0x21, 0
	.dw 0xc3c0, 0xc11d,	0xc3ff, 0xc11d,		0x21, 0
	.dw 0xc440, 0xc11d,	0xc47f, 0xc11d,		0x21, 0
	.dw 0xc4c0, 0xc11d,	0xc4ff, 0xc11d,		0x21, 0
	.dw 0xc540, 0xc11d,	0xc57f, 0xc11d,		0x21, 0
	.dw 0xc5c0, 0xc11d,	0xc5ff, 0xc11d,		0x21, 0
	.dw 0xc640, 0xc11d,	0xc67f, 0xc11d,		0x21, 0
	.dw 0xc6c0, 0xc11d,	0xc6ff, 0xc11d,		0x21, 0
	.dw 0xc740, 0xc11d,	0xc77f, 0xc11d,		0x21, 0
	.dw 0xc7c0, 0xc11d,	0xc7ff, 0xc11d,		0x21, 0
	.dw 0xc840, 0xc11d,	0xc87f, 0xc11d,		0x21, 0
	.dw 0xc8c0, 0xc11d,	0xc8ff, 0xc11d,		0x21, 0
	.dw 0xc940, 0xc11d,	0xc97f, 0xc11d,		0x21, 0
	.dw 0xc9c0, 0xc11d,	0xc9ff, 0xc11d,		0x21, 0
	.dw 0xca40, 0xc11d,	0xca7f, 0xc11d,		0x21, 0
	.dw 0xcac0, 0xc11d,	0xcaff, 0xc11d,		0x21, 0
	.dw 0xcb40, 0xc11d,	0xcb7f, 0xc11d,		0x21, 0
	.dw 0xcbc0, 0xc11d,	0xcbff, 0xc11d,		0x21, 0
	.dw 0xcc40, 0xc11d,	0xcc7f, 0xc11d,		0x21, 0
	.dw 0xccc0, 0xc11d,	0xccff, 0xc11d,		0x21, 0
	.dw 0xcd40, 0xc11d,	0xcd7f, 0xc11d,		0x21, 0
	.dw 0xcdc0, 0xc11d,	0xcdff, 0xc11d,		0x21, 0
	.dw 0xce40, 0xc11d,	0xce7f, 0xc11d,		0x21, 0
	.dw 0xcec0, 0xc11d,	0xceff, 0xc11d,		0x21, 0
	.dw 0xcf40, 0xc11d,	0xcf7f, 0xc11d,		0x21, 0
	.dw 0xcfc0, 0xc11d,	0xcfff, 0xc11d,		0x21, 0
	.dw 0xd040, 0xc11d,	0xd07f, 0xc11d,		0x21, 0
	.dw 0xd0c0, 0xc11d,	0xd0ff, 0xc11d,		0x21, 0
	.dw 0xd140, 0xc11d,	0xd17f, 0xc11d,		0x21, 0
	.dw 0xd1c0, 0xc11d,	0xd1ff, 0xc11d,		0x21, 0
	.dw 0xd240, 0xc11d,	0xd27f, 0xc11d,		0x21, 0
	.dw 0xd2c0, 0xc11d,	0xd2ff, 0xc11d,		0x21, 0
	.dw 0xd340, 0xc11d,	0xd37f, 0xc11d,		0x21, 0
	.dw 0xd3c0, 0xc11d,	0xd3ff, 0xc11d,		0x21, 0
	.dw 0xd440, 0xc11d,	0xd47f, 0xc11d,		0x21, 0
	.dw 0xd4c0, 0xc11d,	0xd4ff, 0xc11d,		0x21, 0
	.dw 0xd540, 0xc11d,	0xd57f, 0xc11d,		0x21, 0
	.dw 0xd5c0, 0xc11d,	0xd5ff, 0xc11d,		0x21, 0
	.dw 0xd640, 0xc11d,	0xd67f, 0xc11d,		0x21, 0
	.dw 0xd6c0, 0xc11d,	0xd6ff, 0xc11d,		0x21, 0
	.dw 0xd740, 0xc11d,	0xd77f, 0xc11d,		0x21, 0
	.dw 0xd7c0, 0xc11d,	0xd7ff, 0xc11d,		0x21, 0
	.dw 0xd840, 0xc11d,	0xd87f, 0xc11d,		0x21, 0
	.dw 0xd8c0, 0xc11d,	0xd8ff, 0xc11d,		0x21, 0
	.dw 0xd940, 0xc11d,	0xd97f, 0xc11d,		0x21, 0
	.dw 0xd9c0, 0xc11d,	0xdfff, 0xc11d,		0x21, 0
	.dw 0xe040, 0xc11d,	0xe07f, 0xc11d,		0x21, 0
	.dw 0xe0c0, 0xc11d,	0xe0ff, 0xc11d,		0x21, 0
	.dw 0xe140, 0xc11d,	0xe17f, 0xc11d,		0x21, 0
	.dw 0xe1c0, 0xc11d,	0xe1ff, 0xc11d,		0x21, 0
	.dw 0xe240, 0xc11d,	0xe27f, 0xc11d,		0x21, 0
	.dw 0xe2c0, 0xc11d,	0xe2ff, 0xc11d,		0x21, 0
	.dw 0xe340, 0xc11d,	0xe37f, 0xc11d,		0x21, 0
	.dw 0xe3c0, 0xc11d,	0xe3ff, 0xc11d,		0x21, 0
	.dw 0xe440, 0xc11d,	0xe47f, 0xc11d,		0x21, 0
	.dw 0xe4c0, 0xc11d,	0xe4ff, 0xc11d,		0x21, 0
	.dw 0xe540, 0xc11d,	0xe57f, 0xc11d,		0x21, 0
	.dw 0xe5c0, 0xc11d,	0xe5ff, 0xc11d,		0x21, 0
	.dw 0xe640, 0xc11d,	0xe67f, 0xc11d,		0x21, 0
	.dw 0xe6c0, 0xc11d,	0xe6ff, 0xc11d,		0x21, 0
	.dw 0xe740, 0xc11d,	0xe77f, 0xc11d,		0x21, 0
	.dw 0xe7c0, 0xc11d,	0xe7ff, 0xc11d,		0x21, 0
	.dw 0xe840, 0xc11d,	0xe87f, 0xc11d,		0x21, 0
	.dw 0xe8c0, 0xc11d,	0xe8ff, 0xc11d,		0x21, 0
	.dw 0xe940, 0xc11d,	0xe97f, 0xc11d,		0x21, 0
	.dw 0xe9c0, 0xc11d,	0xe9ff, 0xc11d,		0x21, 0
	.dw 0xea40, 0xc11d,	0xea7f, 0xc11d,		0x21, 0
	.dw 0xeac0, 0xc11d,	0xeaff, 0xc11d,		0x21, 0
	.dw 0xeb40, 0xc11d,	0xeb7f, 0xc11d,		0x21, 0
	.dw 0xebc0, 0xc11d,	0xebff, 0xc11d,		0x21, 0
	.dw 0xec40, 0xc11d,	0xec7f, 0xc11d,		0x21, 0
	.dw 0xecc0, 0xc11d,	0xecff, 0xc11d,		0x21, 0
	.dw 0xed40, 0xc11d,	0xed7f, 0xc11d,		0x21, 0
	.dw 0xedc0, 0xc11d,	0xedff, 0xc11d,		0x21, 0
	.dw 0xee40, 0xc11d,	0xee7f, 0xc11d,		0x21, 0
	.dw 0xeec0, 0xc11d,	0xeeff, 0xc11d,		0x21, 0
	.dw 0xef40, 0xc11d,	0xef7f, 0xc11d,		0x21, 0
	.dw 0xefc0, 0xc11d,	0xefff, 0xc11d,		0x21, 0
	.dw 0xf040, 0xc11d,	0xf07f, 0xc11d,		0x21, 0
	.dw 0xf0c0, 0xc11d,	0xf0ff, 0xc11d,		0x21, 0
	.dw 0xf140, 0xc11d,	0xf17f, 0xc11d,		0x21, 0
	.dw 0xf1c0, 0xc11d,	0xf1ff, 0xc11d,		0x21, 0
	.dw 0xf240, 0xc11d,	0xf27f, 0xc11d,		0x21, 0
	.dw 0xf2c0, 0xc11d,	0xf2ff, 0xc11d,		0x21, 0
	.dw 0xf340, 0xc11d,	0xf37f, 0xc11d,		0x21, 0
	.dw 0xf3c0, 0xc11d,	0xf3ff, 0xc11d,		0x21, 0
	.dw 0xf440, 0xc11d,	0xf47f, 0xc11d,		0x21, 0
	.dw 0xf4c0, 0xc11d,	0xf4ff, 0xc11d,		0x21, 0
	.dw 0xf540, 0xc11d,	0xf57f, 0xc11d,		0x21, 0
	.dw 0xf5c0, 0xc11d,	0xf5ff, 0xc11d,		0x21, 0
	.dw 0xf640, 0xc11d,	0xf67f, 0xc11d,		0x21, 0
	.dw 0xf6c0, 0xc11d,	0xf6ff, 0xc11d,		0x21, 0
	.dw 0xf740, 0xc11d,	0xf77f, 0xc11d,		0x21, 0
	.dw 0xf7c0, 0xc11d,	0xf7ff, 0xc11d,		0x21, 0
	.dw 0xf840, 0xc11d,	0xf87f, 0xc11d,		0x21, 0
	.dw 0xf8c0, 0xc11d,	0xf8ff, 0xc11d,		0x21, 0
	.dw 0xf940, 0xc11d,	0xf97f, 0xc11d,		0x21, 0
	.dw 0xf9c0, 0xc11d,	0xffff, 0xc11d,		0x21, 0
	.dw 0x0040, 0xc11e,	0x007f, 0xc11e,		0x21, 0
	.dw 0x00c0, 0xc11e,	0x00ff, 0xc11e,		0x21, 0
	.dw 0x0140, 0xc11e,	0x017f, 0xc11e,		0x21, 0
	.dw 0x01c0, 0xc11e,	0x01ff, 0xc11e,		0x21, 0
	.dw 0x0240, 0xc11e,	0x027f, 0xc11e,		0x21, 0
	.dw 0x02c0, 0xc11e,	0x02ff, 0xc11e,		0x21, 0
	.dw 0x0340, 0xc11e,	0x037f, 0xc11e,		0x21, 0
	.dw 0x03c0, 0xc11e,	0x03ff, 0xc11e,		0x21, 0
	.dw 0x0440, 0xc11e,	0x047f, 0xc11e,		0x21, 0
	.dw 0x04c0, 0xc11e,	0x04ff, 0xc11e,		0x21, 0
	.dw 0x0540, 0xc11e,	0x057f, 0xc11e,		0x21, 0
	.dw 0x05c0, 0xc11e,	0x05ff, 0xc11e,		0x21, 0
	.dw 0x0640, 0xc11e,	0x067f, 0xc11e,		0x21, 0
	.dw 0x06c0, 0xc11e,	0x06ff, 0xc11e,		0x21, 0
	.dw 0x0740, 0xc11e,	0x077f, 0xc11e,		0x21, 0
	.dw 0x07c0, 0xc11e,	0x07ff, 0xc11e,		0x21, 0
	.dw 0x0840, 0xc11e,	0x087f, 0xc11e,		0x21, 0
	.dw 0x08c0, 0xc11e,	0x08ff, 0xc11e,		0x21, 0
	.dw 0x0940, 0xc11e,	0x097f, 0xc11e,		0x21, 0
	.dw 0x09c0, 0xc11e,	0x09ff, 0xc11e,		0x21, 0
	.dw 0x0a40, 0xc11e,	0x0a7f, 0xc11e,		0x21, 0
	.dw 0x0ac0, 0xc11e,	0x0aff, 0xc11e,		0x21, 0
	.dw 0x0b40, 0xc11e,	0x0b7f, 0xc11e,		0x21, 0
	.dw 0x0bc0, 0xc11e,	0x0bff, 0xc11e,		0x21, 0
	.dw 0x0c40, 0xc11e,	0x0c7f, 0xc11e,		0x21, 0
	.dw 0x0cc0, 0xc11e,	0x0cff, 0xc11e,		0x21, 0
	.dw 0x0d40, 0xc11e,	0x0d7f, 0xc11e,		0x21, 0
	.dw 0x0dc0, 0xc11e,	0x0dff, 0xc11e,		0x21, 0
	.dw 0x0e40, 0xc11e,	0x0e7f, 0xc11e,		0x21, 0
	.dw 0x0ec0, 0xc11e,	0x0eff, 0xc11e,		0x21, 0
	.dw 0x0f40, 0xc11e,	0x0f7f, 0xc11e,		0x21, 0
	.dw 0x0fc0, 0xc11e,	0x0fff, 0xc11e,		0x21, 0
	.dw 0x1040, 0xc11e,	0x107f, 0xc11e,		0x21, 0
	.dw 0x10c0, 0xc11e,	0x10ff, 0xc11e,		0x21, 0
	.dw 0x1140, 0xc11e,	0x117f, 0xc11e,		0x21, 0
	.dw 0x11c0, 0xc11e,	0x11ff, 0xc11e,		0x21, 0
	.dw 0x1240, 0xc11e,	0x127f, 0xc11e,		0x21, 0
	.dw 0x12c0, 0xc11e,	0x12ff, 0xc11e,		0x21, 0
	.dw 0x1340, 0xc11e,	0x137f, 0xc11e,		0x21, 0
	.dw 0x13c0, 0xc11e,	0x13ff, 0xc11e,		0x21, 0
	.dw 0x1440, 0xc11e,	0x147f, 0xc11e,		0x21, 0
	.dw 0x14c0, 0xc11e,	0x14ff, 0xc11e,		0x21, 0
	.dw 0x1540, 0xc11e,	0x157f, 0xc11e,		0x21, 0
	.dw 0x15c0, 0xc11e,	0x15ff, 0xc11e,		0x21, 0
	.dw 0x1640, 0xc11e,	0x167f, 0xc11e,		0x21, 0
	.dw 0x16c0, 0xc11e,	0x16ff, 0xc11e,		0x21, 0
	.dw 0x1740, 0xc11e,	0x177f, 0xc11e,		0x21, 0
	.dw 0x17c0, 0xc11e,	0x17ff, 0xc11e,		0x21, 0
	.dw 0x1840, 0xc11e,	0x187f, 0xc11e,		0x21, 0
	.dw 0x18c0, 0xc11e,	0x18ff, 0xc11e,		0x21, 0
	.dw 0x1940, 0xc11e,	0x197f, 0xc11e,		0x21, 0
	.dw 0x19c0, 0xc11e,	0x1fff, 0xc11e,		0x21, 0
	.dw 0x2040, 0xc11e,	0x207f, 0xc11e,		0x21, 0
	.dw 0x20c0, 0xc11e,	0x20ff, 0xc11e,		0x21, 0
	.dw 0x2140, 0xc11e,	0x217f, 0xc11e,		0x21, 0
	.dw 0x21c0, 0xc11e,	0x21ff, 0xc11e,		0x21, 0
	.dw 0x2240, 0xc11e,	0x227f, 0xc11e,		0x21, 0
	.dw 0x22c0, 0xc11e,	0x22ff, 0xc11e,		0x21, 0
	.dw 0x2340, 0xc11e,	0x237f, 0xc11e,		0x21, 0
	.dw 0x23c0, 0xc11e,	0x23ff, 0xc11e,		0x21, 0
	.dw 0x2440, 0xc11e,	0x247f, 0xc11e,		0x21, 0
	.dw 0x24c0, 0xc11e,	0x24ff, 0xc11e,		0x21, 0
	.dw 0x2540, 0xc11e,	0x257f, 0xc11e,		0x21, 0
	.dw 0x25c0, 0xc11e,	0x25ff, 0xc11e,		0x21, 0
	.dw 0x2640, 0xc11e,	0x267f, 0xc11e,		0x21, 0
	.dw 0x26c0, 0xc11e,	0x26ff, 0xc11e,		0x21, 0
	.dw 0x2740, 0xc11e,	0x277f, 0xc11e,		0x21, 0
	.dw 0x27c0, 0xc11e,	0x27ff, 0xc11e,		0x21, 0
	.dw 0x2840, 0xc11e,	0x287f, 0xc11e,		0x21, 0
	.dw 0x28c0, 0xc11e,	0x28ff, 0xc11e,		0x21, 0
	.dw 0x2940, 0xc11e,	0x297f, 0xc11e,		0x21, 0
	.dw 0x29c0, 0xc11e,	0x29ff, 0xc11e,		0x21, 0
	.dw 0x2a40, 0xc11e,	0x2a7f, 0xc11e,		0x21, 0
	.dw 0x2ac0, 0xc11e,	0x2aff, 0xc11e,		0x21, 0
	.dw 0x2b40, 0xc11e,	0x2b7f, 0xc11e,		0x21, 0
	.dw 0x2bc0, 0xc11e,	0x2bff, 0xc11e,		0x21, 0
	.dw 0x2c40, 0xc11e,	0x2c7f, 0xc11e,		0x21, 0
	.dw 0x2cc0, 0xc11e,	0x2cff, 0xc11e,		0x21, 0
	.dw 0x2d40, 0xc11e,	0x2d7f, 0xc11e,		0x21, 0
	.dw 0x2dc0, 0xc11e,	0x2dff, 0xc11e,		0x21, 0
	.dw 0x2e40, 0xc11e,	0x2e7f, 0xc11e,		0x21, 0
	.dw 0x2ec0, 0xc11e,	0x2eff, 0xc11e,		0x21, 0
	.dw 0x2f40, 0xc11e,	0x2f7f, 0xc11e,		0x21, 0
	.dw 0x2fc0, 0xc11e,	0x2fff, 0xc11e,		0x21, 0
	.dw 0x3040, 0xc11e,	0x307f, 0xc11e,		0x21, 0
	.dw 0x30c0, 0xc11e,	0x30ff, 0xc11e,		0x21, 0
	.dw 0x3140, 0xc11e,	0x317f, 0xc11e,		0x21, 0
	.dw 0x31c0, 0xc11e,	0x31ff, 0xc11e,		0x21, 0
	.dw 0x3240, 0xc11e,	0x327f, 0xc11e,		0x21, 0
	.dw 0x32c0, 0xc11e,	0x32ff, 0xc11e,		0x21, 0
	.dw 0x3340, 0xc11e,	0x337f, 0xc11e,		0x21, 0
	.dw 0x33c0, 0xc11e,	0x33ff, 0xc11e,		0x21, 0
	.dw 0x3440, 0xc11e,	0x347f, 0xc11e,		0x21, 0
	.dw 0x34c0, 0xc11e,	0x34ff, 0xc11e,		0x21, 0
	.dw 0x3540, 0xc11e,	0x357f, 0xc11e,		0x21, 0
	.dw 0x35c0, 0xc11e,	0x35ff, 0xc11e,		0x21, 0
	.dw 0x3640, 0xc11e,	0x367f, 0xc11e,		0x21, 0
	.dw 0x36c0, 0xc11e,	0x36ff, 0xc11e,		0x21, 0
	.dw 0x3740, 0xc11e,	0x377f, 0xc11e,		0x21, 0
	.dw 0x37c0, 0xc11e,	0x37ff, 0xc11e,		0x21, 0
	.dw 0x3840, 0xc11e,	0x387f, 0xc11e,		0x21, 0
	.dw 0x38c0, 0xc11e,	0x38ff, 0xc11e,		0x21, 0
	.dw 0x3940, 0xc11e,	0x397f, 0xc11e,		0x21, 0
	.dw 0x39c0, 0xc11e,	0x3fff, 0xc11e,		0x21, 0
	.dw 0x4040, 0xc11e,	0x407f, 0xc11e,		0x21, 0
	.dw 0x40c0, 0xc11e,	0x40ff, 0xc11e,		0x21, 0
	.dw 0x4140, 0xc11e,	0x417f, 0xc11e,		0x21, 0
	.dw 0x41c0, 0xc11e,	0x41ff, 0xc11e,		0x21, 0
	.dw 0x4240, 0xc11e,	0x427f, 0xc11e,		0x21, 0
	.dw 0x42c0, 0xc11e,	0x42ff, 0xc11e,		0x21, 0
	.dw 0x4340, 0xc11e,	0x437f, 0xc11e,		0x21, 0
	.dw 0x43c0, 0xc11e,	0x43ff, 0xc11e,		0x21, 0
	.dw 0x4440, 0xc11e,	0x447f, 0xc11e,		0x21, 0
	.dw 0x44c0, 0xc11e,	0x44ff, 0xc11e,		0x21, 0
	.dw 0x4540, 0xc11e,	0x457f, 0xc11e,		0x21, 0
	.dw 0x45c0, 0xc11e,	0x45ff, 0xc11e,		0x21, 0
	.dw 0x4640, 0xc11e,	0x467f, 0xc11e,		0x21, 0
	.dw 0x46c0, 0xc11e,	0x46ff, 0xc11e,		0x21, 0
	.dw 0x4740, 0xc11e,	0x477f, 0xc11e,		0x21, 0
	.dw 0x47c0, 0xc11e,	0x47ff, 0xc11e,		0x21, 0
	.dw 0x4840, 0xc11e,	0x487f, 0xc11e,		0x21, 0
	.dw 0x48c0, 0xc11e,	0x48ff, 0xc11e,		0x21, 0
	.dw 0x4940, 0xc11e,	0x497f, 0xc11e,		0x21, 0
	.dw 0x49c0, 0xc11e,	0x49ff, 0xc11e,		0x21, 0
	.dw 0x4a40, 0xc11e,	0x4a7f, 0xc11e,		0x21, 0
	.dw 0x4ac0, 0xc11e,	0x4aff, 0xc11e,		0x21, 0
	.dw 0x4b40, 0xc11e,	0x4b7f, 0xc11e,		0x21, 0
	.dw 0x4bc0, 0xc11e,	0x4bff, 0xc11e,		0x21, 0
	.dw 0x4c40, 0xc11e,	0x4c7f, 0xc11e,		0x21, 0
	.dw 0x4cc0, 0xc11e,	0x4cff, 0xc11e,		0x21, 0
	.dw 0x4d40, 0xc11e,	0x4d7f, 0xc11e,		0x21, 0
	.dw 0x4dc0, 0xc11e,	0x4dff, 0xc11e,		0x21, 0
	.dw 0x4e40, 0xc11e,	0x4e7f, 0xc11e,		0x21, 0
	.dw 0x4ec0, 0xc11e,	0x4eff, 0xc11e,		0x21, 0
	.dw 0x4f40, 0xc11e,	0x4f7f, 0xc11e,		0x21, 0
	.dw 0x4fc0, 0xc11e,	0x4fff, 0xc11e,		0x21, 0
	.dw 0x5040, 0xc11e,	0x507f, 0xc11e,		0x21, 0
	.dw 0x50c0, 0xc11e,	0x50ff, 0xc11e,		0x21, 0
	.dw 0x5140, 0xc11e,	0x517f, 0xc11e,		0x21, 0
	.dw 0x51c0, 0xc11e,	0x51ff, 0xc11e,		0x21, 0
	.dw 0x5240, 0xc11e,	0x527f, 0xc11e,		0x21, 0
	.dw 0x52c0, 0xc11e,	0x52ff, 0xc11e,		0x21, 0
	.dw 0x5340, 0xc11e,	0x537f, 0xc11e,		0x21, 0
	.dw 0x53c0, 0xc11e,	0x53ff, 0xc11e,		0x21, 0
	.dw 0x5440, 0xc11e,	0x547f, 0xc11e,		0x21, 0
	.dw 0x54c0, 0xc11e,	0x54ff, 0xc11e,		0x21, 0
	.dw 0x5540, 0xc11e,	0x557f, 0xc11e,		0x21, 0
	.dw 0x55c0, 0xc11e,	0x55ff, 0xc11e,		0x21, 0
	.dw 0x5640, 0xc11e,	0x567f, 0xc11e,		0x21, 0
	.dw 0x56c0, 0xc11e,	0x56ff, 0xc11e,		0x21, 0
	.dw 0x5740, 0xc11e,	0x577f, 0xc11e,		0x21, 0
	.dw 0x57c0, 0xc11e,	0x57ff, 0xc11e,		0x21, 0
	.dw 0x5840, 0xc11e,	0x587f, 0xc11e,		0x21, 0
	.dw 0x58c0, 0xc11e,	0x58ff, 0xc11e,		0x21, 0
	.dw 0x5940, 0xc11e,	0x597f, 0xc11e,		0x21, 0
	.dw 0x59c0, 0xc11e,	0x5fff, 0xc11e,		0x21, 0
	.dw 0x6040, 0xc11e,	0x607f, 0xc11e,		0x21, 0
	.dw 0x60c0, 0xc11e,	0x60ff, 0xc11e,		0x21, 0
	.dw 0x6140, 0xc11e,	0x617f, 0xc11e,		0x21, 0
	.dw 0x61c0, 0xc11e,	0x61ff, 0xc11e,		0x21, 0
	.dw 0x6240, 0xc11e,	0x627f, 0xc11e,		0x21, 0
	.dw 0x62c0, 0xc11e,	0x62ff, 0xc11e,		0x21, 0
	.dw 0x6340, 0xc11e,	0x637f, 0xc11e,		0x21, 0
	.dw 0x63c0, 0xc11e,	0x63ff, 0xc11e,		0x21, 0
	.dw 0x6440, 0xc11e,	0x647f, 0xc11e,		0x21, 0
	.dw 0x64c0, 0xc11e,	0x64ff, 0xc11e,		0x21, 0
	.dw 0x6540, 0xc11e,	0x657f, 0xc11e,		0x21, 0
	.dw 0x65c0, 0xc11e,	0x65ff, 0xc11e,		0x21, 0
	.dw 0x6640, 0xc11e,	0x667f, 0xc11e,		0x21, 0
	.dw 0x66c0, 0xc11e,	0x66ff, 0xc11e,		0x21, 0
	.dw 0x6740, 0xc11e,	0x677f, 0xc11e,		0x21, 0
	.dw 0x67c0, 0xc11e,	0x67ff, 0xc11e,		0x21, 0
	.dw 0x6840, 0xc11e,	0x687f, 0xc11e,		0x21, 0
	.dw 0x68c0, 0xc11e,	0x68ff, 0xc11e,		0x21, 0
	.dw 0x6940, 0xc11e,	0x697f, 0xc11e,		0x21, 0
	.dw 0x69c0, 0xc11e,	0x69ff, 0xc11e,		0x21, 0
	.dw 0x6a40, 0xc11e,	0x6a7f, 0xc11e,		0x21, 0
	.dw 0x6ac0, 0xc11e,	0x6aff, 0xc11e,		0x21, 0
	.dw 0x6b40, 0xc11e,	0x6b7f, 0xc11e,		0x21, 0
	.dw 0x6bc0, 0xc11e,	0x6bff, 0xc11e,		0x21, 0
	.dw 0x6c40, 0xc11e,	0x6c7f, 0xc11e,		0x21, 0
	.dw 0x6cc0, 0xc11e,	0x6cff, 0xc11e,		0x21, 0
	.dw 0x6d40, 0xc11e,	0x6d7f, 0xc11e,		0x21, 0
	.dw 0x6dc0, 0xc11e,	0x6dff, 0xc11e,		0x21, 0
	.dw 0x6e40, 0xc11e,	0x6e7f, 0xc11e,		0x21, 0
	.dw 0x6ec0, 0xc11e,	0x6eff, 0xc11e,		0x21, 0
	.dw 0x6f40, 0xc11e,	0x6f7f, 0xc11e,		0x21, 0
	.dw 0x6fc0, 0xc11e,	0x6fff, 0xc11e,		0x21, 0
	.dw 0x7040, 0xc11e,	0x707f, 0xc11e,		0x21, 0
	.dw 0x70c0, 0xc11e,	0x70ff, 0xc11e,		0x21, 0
	.dw 0x7140, 0xc11e,	0x717f, 0xc11e,		0x21, 0
	.dw 0x71c0, 0xc11e,	0x71ff, 0xc11e,		0x21, 0
	.dw 0x7240, 0xc11e,	0x727f, 0xc11e,		0x21, 0
	.dw 0x72c0, 0xc11e,	0x72ff, 0xc11e,		0x21, 0
	.dw 0x7340, 0xc11e,	0x737f, 0xc11e,		0x21, 0
	.dw 0x73c0, 0xc11e,	0x73ff, 0xc11e,		0x21, 0
	.dw 0x7440, 0xc11e,	0x747f, 0xc11e,		0x21, 0
	.dw 0x74c0, 0xc11e,	0x74ff, 0xc11e,		0x21, 0
	.dw 0x7540, 0xc11e,	0x757f, 0xc11e,		0x21, 0
	.dw 0x75c0, 0xc11e,	0x75ff, 0xc11e,		0x21, 0
	.dw 0x7640, 0xc11e,	0x767f, 0xc11e,		0x21, 0
	.dw 0x76c0, 0xc11e,	0x76ff, 0xc11e,		0x21, 0
	.dw 0x7740, 0xc11e,	0x777f, 0xc11e,		0x21, 0
	.dw 0x77c0, 0xc11e,	0x77ff, 0xc11e,		0x21, 0
	.dw 0x7840, 0xc11e,	0x787f, 0xc11e,		0x21, 0
	.dw 0x78c0, 0xc11e,	0x78ff, 0xc11e,		0x21, 0
	.dw 0x7940, 0xc11e,	0x797f, 0xc11e,		0x21, 0
	.dw 0x79c0, 0xc11e,	0x7fff, 0xc11e,		0x21, 0
	.dw 0x8040, 0xc11e,	0x807f, 0xc11e,		0x21, 0
	.dw 0x80c0, 0xc11e,	0x80ff, 0xc11e,		0x21, 0
	.dw 0x8140, 0xc11e,	0x817f, 0xc11e,		0x21, 0
	.dw 0x81c0, 0xc11e,	0x81ff, 0xc11e,		0x21, 0
	.dw 0x8240, 0xc11e,	0x827f, 0xc11e,		0x21, 0
	.dw 0x82c0, 0xc11e,	0x82ff, 0xc11e,		0x21, 0
	.dw 0x8340, 0xc11e,	0x837f, 0xc11e,		0x21, 0
	.dw 0x83c0, 0xc11e,	0x83ff, 0xc11e,		0x21, 0
	.dw 0x8440, 0xc11e,	0x847f, 0xc11e,		0x21, 0
	.dw 0x84c0, 0xc11e,	0x84ff, 0xc11e,		0x21, 0
	.dw 0x8540, 0xc11e,	0x857f, 0xc11e,		0x21, 0
	.dw 0x85c0, 0xc11e,	0x85ff, 0xc11e,		0x21, 0
	.dw 0x8640, 0xc11e,	0x867f, 0xc11e,		0x21, 0
	.dw 0x86c0, 0xc11e,	0x86ff, 0xc11e,		0x21, 0
	.dw 0x8740, 0xc11e,	0x877f, 0xc11e,		0x21, 0
	.dw 0x87c0, 0xc11e,	0x87ff, 0xc11e,		0x21, 0
	.dw 0x8840, 0xc11e,	0x887f, 0xc11e,		0x21, 0
	.dw 0x88c0, 0xc11e,	0x88ff, 0xc11e,		0x21, 0
	.dw 0x8940, 0xc11e,	0x897f, 0xc11e,		0x21, 0
	.dw 0x89c0, 0xc11e,	0x89ff, 0xc11e,		0x21, 0
	.dw 0x8a40, 0xc11e,	0x8a7f, 0xc11e,		0x21, 0
	.dw 0x8ac0, 0xc11e,	0x8aff, 0xc11e,		0x21, 0
	.dw 0x8b40, 0xc11e,	0x8b7f, 0xc11e,		0x21, 0
	.dw 0x8bc0, 0xc11e,	0x8bff, 0xc11e,		0x21, 0
	.dw 0x8c40, 0xc11e,	0x8c7f, 0xc11e,		0x21, 0
	.dw 0x8cc0, 0xc11e,	0x8cff, 0xc11e,		0x21, 0
	.dw 0x8d40, 0xc11e,	0x8d7f, 0xc11e,		0x21, 0
	.dw 0x8dc0, 0xc11e,	0x8dff, 0xc11e,		0x21, 0
	.dw 0x8e40, 0xc11e,	0x8e7f, 0xc11e,		0x21, 0
	.dw 0x8ec0, 0xc11e,	0x8eff, 0xc11e,		0x21, 0
	.dw 0x8f40, 0xc11e,	0x8f7f, 0xc11e,		0x21, 0
	.dw 0x8fc0, 0xc11e,	0x8fff, 0xc11e,		0x21, 0
	.dw 0x9040, 0xc11e,	0x907f, 0xc11e,		0x21, 0
	.dw 0x90c0, 0xc11e,	0x90ff, 0xc11e,		0x21, 0
	.dw 0x9140, 0xc11e,	0x917f, 0xc11e,		0x21, 0
	.dw 0x91c0, 0xc11e,	0x91ff, 0xc11e,		0x21, 0
	.dw 0x9240, 0xc11e,	0x927f, 0xc11e,		0x21, 0
	.dw 0x92c0, 0xc11e,	0x92ff, 0xc11e,		0x21, 0
	.dw 0x9340, 0xc11e,	0x937f, 0xc11e,		0x21, 0
	.dw 0x93c0, 0xc11e,	0x93ff, 0xc11e,		0x21, 0
	.dw 0x9440, 0xc11e,	0x947f, 0xc11e,		0x21, 0
	.dw 0x94c0, 0xc11e,	0x94ff, 0xc11e,		0x21, 0
	.dw 0x9540, 0xc11e,	0x957f, 0xc11e,		0x21, 0
	.dw 0x95c0, 0xc11e,	0x95ff, 0xc11e,		0x21, 0
	.dw 0x9640, 0xc11e,	0x967f, 0xc11e,		0x21, 0
	.dw 0x96c0, 0xc11e,	0x96ff, 0xc11e,		0x21, 0
	.dw 0x9740, 0xc11e,	0x977f, 0xc11e,		0x21, 0
	.dw 0x97c0, 0xc11e,	0x97ff, 0xc11e,		0x21, 0
	.dw 0x9840, 0xc11e,	0x987f, 0xc11e,		0x21, 0
	.dw 0x98c0, 0xc11e,	0x98ff, 0xc11e,		0x21, 0
	.dw 0x9940, 0xc11e,	0x997f, 0xc11e,		0x21, 0
	.dw 0x99c0, 0xc11e,	0x9fff, 0xc11e,		0x21, 0
	.dw 0xa040, 0xc11e,	0xa07f, 0xc11e,		0x21, 0
	.dw 0xa0c0, 0xc11e,	0xa0ff, 0xc11e,		0x21, 0
	.dw 0xa140, 0xc11e,	0xa17f, 0xc11e,		0x21, 0
	.dw 0xa1c0, 0xc11e,	0xa1ff, 0xc11e,		0x21, 0
	.dw 0xa240, 0xc11e,	0xa27f, 0xc11e,		0x21, 0
	.dw 0xa2c0, 0xc11e,	0xa2ff, 0xc11e,		0x21, 0
	.dw 0xa340, 0xc11e,	0xa37f, 0xc11e,		0x21, 0
	.dw 0xa3c0, 0xc11e,	0xa3ff, 0xc11e,		0x21, 0
	.dw 0xa440, 0xc11e,	0xa47f, 0xc11e,		0x21, 0
	.dw 0xa4c0, 0xc11e,	0xa4ff, 0xc11e,		0x21, 0
	.dw 0xa540, 0xc11e,	0xa57f, 0xc11e,		0x21, 0
	.dw 0xa5c0, 0xc11e,	0xa5ff, 0xc11e,		0x21, 0
	.dw 0xa640, 0xc11e,	0xa67f, 0xc11e,		0x21, 0
	.dw 0xa6c0, 0xc11e,	0xa6ff, 0xc11e,		0x21, 0
	.dw 0xa740, 0xc11e,	0xa77f, 0xc11e,		0x21, 0
	.dw 0xa7c0, 0xc11e,	0xa7ff, 0xc11e,		0x21, 0
	.dw 0xa840, 0xc11e,	0xa87f, 0xc11e,		0x21, 0
	.dw 0xa8c0, 0xc11e,	0xa8ff, 0xc11e,		0x21, 0
	.dw 0xa940, 0xc11e,	0xa97f, 0xc11e,		0x21, 0
	.dw 0xa9c0, 0xc11e,	0xa9ff, 0xc11e,		0x21, 0
	.dw 0xaa40, 0xc11e,	0xaa7f, 0xc11e,		0x21, 0
	.dw 0xaac0, 0xc11e,	0xaaff, 0xc11e,		0x21, 0
	.dw 0xab40, 0xc11e,	0xab7f, 0xc11e,		0x21, 0
	.dw 0xabc0, 0xc11e,	0xabff, 0xc11e,		0x21, 0
	.dw 0xac40, 0xc11e,	0xac7f, 0xc11e,		0x21, 0
	.dw 0xacc0, 0xc11e,	0xacff, 0xc11e,		0x21, 0
	.dw 0xad40, 0xc11e,	0xad7f, 0xc11e,		0x21, 0
	.dw 0xadc0, 0xc11e,	0xadff, 0xc11e,		0x21, 0
	.dw 0xae40, 0xc11e,	0xae7f, 0xc11e,		0x21, 0
	.dw 0xaec0, 0xc11e,	0xaeff, 0xc11e,		0x21, 0
	.dw 0xaf40, 0xc11e,	0xaf7f, 0xc11e,		0x21, 0
	.dw 0xafc0, 0xc11e,	0xafff, 0xc11e,		0x21, 0
	.dw 0xb040, 0xc11e,	0xb07f, 0xc11e,		0x21, 0
	.dw 0xb0c0, 0xc11e,	0xb0ff, 0xc11e,		0x21, 0
	.dw 0xb140, 0xc11e,	0xb17f, 0xc11e,		0x21, 0
	.dw 0xb1c0, 0xc11e,	0xb1ff, 0xc11e,		0x21, 0
	.dw 0xb240, 0xc11e,	0xb27f, 0xc11e,		0x21, 0
	.dw 0xb2c0, 0xc11e,	0xb2ff, 0xc11e,		0x21, 0
	.dw 0xb340, 0xc11e,	0xb37f, 0xc11e,		0x21, 0
	.dw 0xb3c0, 0xc11e,	0xb3ff, 0xc11e,		0x21, 0
	.dw 0xb440, 0xc11e,	0xb47f, 0xc11e,		0x21, 0
	.dw 0xb4c0, 0xc11e,	0xb4ff, 0xc11e,		0x21, 0
	.dw 0xb540, 0xc11e,	0xb57f, 0xc11e,		0x21, 0
	.dw 0xb5c0, 0xc11e,	0xb5ff, 0xc11e,		0x21, 0
	.dw 0xb640, 0xc11e,	0xb67f, 0xc11e,		0x21, 0
	.dw 0xb6c0, 0xc11e,	0xb6ff, 0xc11e,		0x21, 0
	.dw 0xb740, 0xc11e,	0xb77f, 0xc11e,		0x21, 0
	.dw 0xb7c0, 0xc11e,	0xb7ff, 0xc11e,		0x21, 0
	.dw 0xb840, 0xc11e,	0xb87f, 0xc11e,		0x21, 0
	.dw 0xb8c0, 0xc11e,	0xb8ff, 0xc11e,		0x21, 0
	.dw 0xb940, 0xc11e,	0xb97f, 0xc11e,		0x21, 0
	.dw 0xb9c0, 0xc11e,	0xbfff, 0xc11e,		0x21, 0
	.dw 0xc040, 0xc11e,	0xc07f, 0xc11e,		0x21, 0
	.dw 0xc0c0, 0xc11e,	0xc0ff, 0xc11e,		0x21, 0
	.dw 0xc140, 0xc11e,	0xc17f, 0xc11e,		0x21, 0
	.dw 0xc1c0, 0xc11e,	0xc1ff, 0xc11e,		0x21, 0
	.dw 0xc240, 0xc11e,	0xc27f, 0xc11e,		0x21, 0
	.dw 0xc2c0, 0xc11e,	0xc2ff, 0xc11e,		0x21, 0
	.dw 0xc340, 0xc11e,	0xc37f, 0xc11e,		0x21, 0
	.dw 0xc3c0, 0xc11e,	0xc3ff, 0xc11e,		0x21, 0
	.dw 0xc440, 0xc11e,	0xc47f, 0xc11e,		0x21, 0
	.dw 0xc4c0, 0xc11e,	0xc4ff, 0xc11e,		0x21, 0
	.dw 0xc540, 0xc11e,	0xc57f, 0xc11e,		0x21, 0
	.dw 0xc5c0, 0xc11e,	0xc5ff, 0xc11e,		0x21, 0
	.dw 0xc640, 0xc11e,	0xc67f, 0xc11e,		0x21, 0
	.dw 0xc6c0, 0xc11e,	0xc6ff, 0xc11e,		0x21, 0
	.dw 0xc740, 0xc11e,	0xc77f, 0xc11e,		0x21, 0
	.dw 0xc7c0, 0xc11e,	0xc7ff, 0xc11e,		0x21, 0
	.dw 0xc840, 0xc11e,	0xc87f, 0xc11e,		0x21, 0
	.dw 0xc8c0, 0xc11e,	0xc8ff, 0xc11e,		0x21, 0
	.dw 0xc940, 0xc11e,	0xc97f, 0xc11e,		0x21, 0
	.dw 0xc9c0, 0xc11e,	0xc9ff, 0xc11e,		0x21, 0
	.dw 0xca40, 0xc11e,	0xca7f, 0xc11e,		0x21, 0
	.dw 0xcac0, 0xc11e,	0xcaff, 0xc11e,		0x21, 0
	.dw 0xcb40, 0xc11e,	0xcb7f, 0xc11e,		0x21, 0
	.dw 0xcbc0, 0xc11e,	0xcbff, 0xc11e,		0x21, 0
	.dw 0xcc40, 0xc11e,	0xcc7f, 0xc11e,		0x21, 0
	.dw 0xccc0, 0xc11e,	0xccff, 0xc11e,		0x21, 0
	.dw 0xcd40, 0xc11e,	0xcd7f, 0xc11e,		0x21, 0
	.dw 0xcdc0, 0xc11e,	0xcdff, 0xc11e,		0x21, 0
	.dw 0xce40, 0xc11e,	0xce7f, 0xc11e,		0x21, 0
	.dw 0xcec0, 0xc11e,	0xceff, 0xc11e,		0x21, 0
	.dw 0xcf40, 0xc11e,	0xcf7f, 0xc11e,		0x21, 0
	.dw 0xcfc0, 0xc11e,	0xcfff, 0xc11e,		0x21, 0
	.dw 0xd040, 0xc11e,	0xd07f, 0xc11e,		0x21, 0
	.dw 0xd0c0, 0xc11e,	0xd0ff, 0xc11e,		0x21, 0
	.dw 0xd140, 0xc11e,	0xd17f, 0xc11e,		0x21, 0
	.dw 0xd1c0, 0xc11e,	0xd1ff, 0xc11e,		0x21, 0
	.dw 0xd240, 0xc11e,	0xd27f, 0xc11e,		0x21, 0
	.dw 0xd2c0, 0xc11e,	0xd2ff, 0xc11e,		0x21, 0
	.dw 0xd340, 0xc11e,	0xd37f, 0xc11e,		0x21, 0
	.dw 0xd3c0, 0xc11e,	0xd3ff, 0xc11e,		0x21, 0
	.dw 0xd440, 0xc11e,	0xd47f, 0xc11e,		0x21, 0
	.dw 0xd4c0, 0xc11e,	0xd4ff, 0xc11e,		0x21, 0
	.dw 0xd540, 0xc11e,	0xd57f, 0xc11e,		0x21, 0
	.dw 0xd5c0, 0xc11e,	0xd5ff, 0xc11e,		0x21, 0
	.dw 0xd640, 0xc11e,	0xd67f, 0xc11e,		0x21, 0
	.dw 0xd6c0, 0xc11e,	0xd6ff, 0xc11e,		0x21, 0
	.dw 0xd740, 0xc11e,	0xd77f, 0xc11e,		0x21, 0
	.dw 0xd7c0, 0xc11e,	0xd7ff, 0xc11e,		0x21, 0
	.dw 0xd840, 0xc11e,	0xd87f, 0xc11e,		0x21, 0
	.dw 0xd8c0, 0xc11e,	0xd8ff, 0xc11e,		0x21, 0
	.dw 0xd940, 0xc11e,	0xd97f, 0xc11e,		0x21, 0
	.dw 0xd9c0, 0xc11e,	0xdfff, 0xc11e,		0x21, 0
	.dw 0xe040, 0xc11e,	0xe07f, 0xc11e,		0x21, 0
	.dw 0xe0c0, 0xc11e,	0xe0ff, 0xc11e,		0x21, 0
	.dw 0xe140, 0xc11e,	0xe17f, 0xc11e,		0x21, 0
	.dw 0xe1c0, 0xc11e,	0xe1ff, 0xc11e,		0x21, 0
	.dw 0xe240, 0xc11e,	0xe27f, 0xc11e,		0x21, 0
	.dw 0xe2c0, 0xc11e,	0xe2ff, 0xc11e,		0x21, 0
	.dw 0xe340, 0xc11e,	0xe37f, 0xc11e,		0x21, 0
	.dw 0xe3c0, 0xc11e,	0xe3ff, 0xc11e,		0x21, 0
	.dw 0xe440, 0xc11e,	0xe47f, 0xc11e,		0x21, 0
	.dw 0xe4c0, 0xc11e,	0xe4ff, 0xc11e,		0x21, 0
	.dw 0xe540, 0xc11e,	0xe57f, 0xc11e,		0x21, 0
	.dw 0xe5c0, 0xc11e,	0xe5ff, 0xc11e,		0x21, 0
	.dw 0xe640, 0xc11e,	0xe67f, 0xc11e,		0x21, 0
	.dw 0xe6c0, 0xc11e,	0xe6ff, 0xc11e,		0x21, 0
	.dw 0xe740, 0xc11e,	0xe77f, 0xc11e,		0x21, 0
	.dw 0xe7c0, 0xc11e,	0xe7ff, 0xc11e,		0x21, 0
	.dw 0xe840, 0xc11e,	0xe87f, 0xc11e,		0x21, 0
	.dw 0xe8c0, 0xc11e,	0xe8ff, 0xc11e,		0x21, 0
	.dw 0xe940, 0xc11e,	0xe97f, 0xc11e,		0x21, 0
	.dw 0xe9c0, 0xc11e,	0xe9ff, 0xc11e,		0x21, 0
	.dw 0xea40, 0xc11e,	0xea7f, 0xc11e,		0x21, 0
	.dw 0xeac0, 0xc11e,	0xeaff, 0xc11e,		0x21, 0
	.dw 0xeb40, 0xc11e,	0xeb7f, 0xc11e,		0x21, 0
	.dw 0xebc0, 0xc11e,	0xebff, 0xc11e,		0x21, 0
	.dw 0xec40, 0xc11e,	0xec7f, 0xc11e,		0x21, 0
	.dw 0xecc0, 0xc11e,	0xecff, 0xc11e,		0x21, 0
	.dw 0xed40, 0xc11e,	0xed7f, 0xc11e,		0x21, 0
	.dw 0xedc0, 0xc11e,	0xedff, 0xc11e,		0x21, 0
	.dw 0xee40, 0xc11e,	0xee7f, 0xc11e,		0x21, 0
	.dw 0xeec0, 0xc11e,	0xeeff, 0xc11e,		0x21, 0
	.dw 0xef40, 0xc11e,	0xef7f, 0xc11e,		0x21, 0
	.dw 0xefc0, 0xc11e,	0xefff, 0xc11e,		0x21, 0
	.dw 0xf040, 0xc11e,	0xf07f, 0xc11e,		0x21, 0
	.dw 0xf0c0, 0xc11e,	0xf0ff, 0xc11e,		0x21, 0
	.dw 0xf140, 0xc11e,	0xf17f, 0xc11e,		0x21, 0
	.dw 0xf1c0, 0xc11e,	0xf1ff, 0xc11e,		0x21, 0
	.dw 0xf240, 0xc11e,	0xf27f, 0xc11e,		0x21, 0
	.dw 0xf2c0, 0xc11e,	0xf2ff, 0xc11e,		0x21, 0
	.dw 0xf340, 0xc11e,	0xf37f, 0xc11e,		0x21, 0
	.dw 0xf3c0, 0xc11e,	0xf3ff, 0xc11e,		0x21, 0
	.dw 0xf440, 0xc11e,	0xf47f, 0xc11e,		0x21, 0
	.dw 0xf4c0, 0xc11e,	0xf4ff, 0xc11e,		0x21, 0
	.dw 0xf540, 0xc11e,	0xf57f, 0xc11e,		0x21, 0
	.dw 0xf5c0, 0xc11e,	0xf5ff, 0xc11e,		0x21, 0
	.dw 0xf640, 0xc11e,	0xf67f, 0xc11e,		0x21, 0
	.dw 0xf6c0, 0xc11e,	0xf6ff, 0xc11e,		0x21, 0
	.dw 0xf740, 0xc11e,	0xf77f, 0xc11e,		0x21, 0
	.dw 0xf7c0, 0xc11e,	0xf7ff, 0xc11e,		0x21, 0
	.dw 0xf840, 0xc11e,	0xf87f, 0xc11e,		0x21, 0
	.dw 0xf8c0, 0xc11e,	0xf8ff, 0xc11e,		0x21, 0
	.dw 0xf940, 0xc11e,	0xf97f, 0xc11e,		0x21, 0
	.dw 0xf9c0, 0xc11e,	0xffff, 0xc11e,		0x21, 0
	.dw 0x0040, 0xc11f,	0x007f, 0xc11f,		0x21, 0
	.dw 0x00c0, 0xc11f,	0x00ff, 0xc11f,		0x21, 0
	.dw 0x0140, 0xc11f,	0x017f, 0xc11f,		0x21, 0
	.dw 0x01c0, 0xc11f,	0x01ff, 0xc11f,		0x21, 0
	.dw 0x0240, 0xc11f,	0x027f, 0xc11f,		0x21, 0
	.dw 0x02c0, 0xc11f,	0x02ff, 0xc11f,		0x21, 0
	.dw 0x0340, 0xc11f,	0x037f, 0xc11f,		0x21, 0
	.dw 0x03c0, 0xc11f,	0x03ff, 0xc11f,		0x21, 0
	.dw 0x0440, 0xc11f,	0x047f, 0xc11f,		0x21, 0
	.dw 0x04c0, 0xc11f,	0x04ff, 0xc11f,		0x21, 0
	.dw 0x0540, 0xc11f,	0x057f, 0xc11f,		0x21, 0
	.dw 0x05c0, 0xc11f,	0x05ff, 0xc11f,		0x21, 0
	.dw 0x0640, 0xc11f,	0x067f, 0xc11f,		0x21, 0
	.dw 0x06c0, 0xc11f,	0x06ff, 0xc11f,		0x21, 0
	.dw 0x0740, 0xc11f,	0x077f, 0xc11f,		0x21, 0
	.dw 0x07c0, 0xc11f,	0x07ff, 0xc11f,		0x21, 0
	.dw 0x0840, 0xc11f,	0x087f, 0xc11f,		0x21, 0
	.dw 0x08c0, 0xc11f,	0x08ff, 0xc11f,		0x21, 0
	.dw 0x0940, 0xc11f,	0x097f, 0xc11f,		0x21, 0
	.dw 0x09c0, 0xc11f,	0x09ff, 0xc11f,		0x21, 0
	.dw 0x0a40, 0xc11f,	0x0a7f, 0xc11f,		0x21, 0
	.dw 0x0ac0, 0xc11f,	0x0aff, 0xc11f,		0x21, 0
	.dw 0x0b40, 0xc11f,	0x0b7f, 0xc11f,		0x21, 0
	.dw 0x0bc0, 0xc11f,	0x0bff, 0xc11f,		0x21, 0
	.dw 0x0c40, 0xc11f,	0x0c7f, 0xc11f,		0x21, 0
	.dw 0x0cc0, 0xc11f,	0x0cff, 0xc11f,		0x21, 0
	.dw 0x0d40, 0xc11f,	0x0d7f, 0xc11f,		0x21, 0
	.dw 0x0dc0, 0xc11f,	0x0dff, 0xc11f,		0x21, 0
	.dw 0x0e40, 0xc11f,	0x0e7f, 0xc11f,		0x21, 0
	.dw 0x0ec0, 0xc11f,	0x0eff, 0xc11f,		0x21, 0
	.dw 0x0f40, 0xc11f,	0x0f7f, 0xc11f,		0x21, 0
	.dw 0x0fc0, 0xc11f,	0x0fff, 0xc11f,		0x21, 0
	.dw 0x1040, 0xc11f,	0x107f, 0xc11f,		0x21, 0
	.dw 0x10c0, 0xc11f,	0x10ff, 0xc11f,		0x21, 0
	.dw 0x1140, 0xc11f,	0x117f, 0xc11f,		0x21, 0
	.dw 0x11c0, 0xc11f,	0x11ff, 0xc11f,		0x21, 0
	.dw 0x1240, 0xc11f,	0x127f, 0xc11f,		0x21, 0
	.dw 0x12c0, 0xc11f,	0x12ff, 0xc11f,		0x21, 0
	.dw 0x1340, 0xc11f,	0x137f, 0xc11f,		0x21, 0
	.dw 0x13c0, 0xc11f,	0x13ff, 0xc11f,		0x21, 0
	.dw 0x1440, 0xc11f,	0x147f, 0xc11f,		0x21, 0
	.dw 0x14c0, 0xc11f,	0x14ff, 0xc11f,		0x21, 0
	.dw 0x1540, 0xc11f,	0x157f, 0xc11f,		0x21, 0
	.dw 0x15c0, 0xc11f,	0x15ff, 0xc11f,		0x21, 0
	.dw 0x1640, 0xc11f,	0x167f, 0xc11f,		0x21, 0
	.dw 0x16c0, 0xc11f,	0x16ff, 0xc11f,		0x21, 0
	.dw 0x1740, 0xc11f,	0x177f, 0xc11f,		0x21, 0
	.dw 0x17c0, 0xc11f,	0x17ff, 0xc11f,		0x21, 0
	.dw 0x1840, 0xc11f,	0x187f, 0xc11f,		0x21, 0
	.dw 0x18c0, 0xc11f,	0x18ff, 0xc11f,		0x21, 0
	.dw 0x1940, 0xc11f,	0x197f, 0xc11f,		0x21, 0
	.dw 0x19c0, 0xc11f,	0x1fff, 0xc11f,		0x21, 0
	.dw 0x2040, 0xc11f,	0x207f, 0xc11f,		0x21, 0
	.dw 0x20c0, 0xc11f,	0x20ff, 0xc11f,		0x21, 0
	.dw 0x2140, 0xc11f,	0x217f, 0xc11f,		0x21, 0
	.dw 0x21c0, 0xc11f,	0x21ff, 0xc11f,		0x21, 0
	.dw 0x2240, 0xc11f,	0x227f, 0xc11f,		0x21, 0
	.dw 0x22c0, 0xc11f,	0x22ff, 0xc11f,		0x21, 0
	.dw 0x2340, 0xc11f,	0x237f, 0xc11f,		0x21, 0
	.dw 0x23c0, 0xc11f,	0x23ff, 0xc11f,		0x21, 0
	.dw 0x2440, 0xc11f,	0x247f, 0xc11f,		0x21, 0
	.dw 0x24c0, 0xc11f,	0x24ff, 0xc11f,		0x21, 0
	.dw 0x2540, 0xc11f,	0x257f, 0xc11f,		0x21, 0
	.dw 0x25c0, 0xc11f,	0x25ff, 0xc11f,		0x21, 0
	.dw 0x2640, 0xc11f,	0x267f, 0xc11f,		0x21, 0
	.dw 0x26c0, 0xc11f,	0x26ff, 0xc11f,		0x21, 0
	.dw 0x2740, 0xc11f,	0x277f, 0xc11f,		0x21, 0
	.dw 0x27c0, 0xc11f,	0x27ff, 0xc11f,		0x21, 0
	.dw 0x2840, 0xc11f,	0x287f, 0xc11f,		0x21, 0
	.dw 0x28c0, 0xc11f,	0x28ff, 0xc11f,		0x21, 0
	.dw 0x2940, 0xc11f,	0x297f, 0xc11f,		0x21, 0
	.dw 0x29c0, 0xc11f,	0x29ff, 0xc11f,		0x21, 0
	.dw 0x2a40, 0xc11f,	0x2a7f, 0xc11f,		0x21, 0
	.dw 0x2ac0, 0xc11f,	0x2aff, 0xc11f,		0x21, 0
	.dw 0x2b40, 0xc11f,	0x2b7f, 0xc11f,		0x21, 0
	.dw 0x2bc0, 0xc11f,	0x2bff, 0xc11f,		0x21, 0
	.dw 0x2c40, 0xc11f,	0x2c7f, 0xc11f,		0x21, 0
	.dw 0x2cc0, 0xc11f,	0x2cff, 0xc11f,		0x21, 0
	.dw 0x2d40, 0xc11f,	0x2d7f, 0xc11f,		0x21, 0
	.dw 0x2dc0, 0xc11f,	0x2dff, 0xc11f,		0x21, 0
	.dw 0x2e40, 0xc11f,	0x2e7f, 0xc11f,		0x21, 0
	.dw 0x2ec0, 0xc11f,	0x2eff, 0xc11f,		0x21, 0
	.dw 0x2f40, 0xc11f,	0x2f7f, 0xc11f,		0x21, 0
	.dw 0x2fc0, 0xc11f,	0x2fff, 0xc11f,		0x21, 0
	.dw 0x3040, 0xc11f,	0x307f, 0xc11f,		0x21, 0
	.dw 0x30c0, 0xc11f,	0x30ff, 0xc11f,		0x21, 0
	.dw 0x3140, 0xc11f,	0x317f, 0xc11f,		0x21, 0
	.dw 0x31c0, 0xc11f,	0x31ff, 0xc11f,		0x21, 0
	.dw 0x3240, 0xc11f,	0x327f, 0xc11f,		0x21, 0
	.dw 0x32c0, 0xc11f,	0x32ff, 0xc11f,		0x21, 0
	.dw 0x3340, 0xc11f,	0x337f, 0xc11f,		0x21, 0
	.dw 0x33c0, 0xc11f,	0x33ff, 0xc11f,		0x21, 0
	.dw 0x3440, 0xc11f,	0x347f, 0xc11f,		0x21, 0
	.dw 0x34c0, 0xc11f,	0x34ff, 0xc11f,		0x21, 0
	.dw 0x3540, 0xc11f,	0x357f, 0xc11f,		0x21, 0
	.dw 0x35c0, 0xc11f,	0x35ff, 0xc11f,		0x21, 0
	.dw 0x3640, 0xc11f,	0x367f, 0xc11f,		0x21, 0
	.dw 0x36c0, 0xc11f,	0x36ff, 0xc11f,		0x21, 0
	.dw 0x3740, 0xc11f,	0x377f, 0xc11f,		0x21, 0
	.dw 0x37c0, 0xc11f,	0x37ff, 0xc11f,		0x21, 0
	.dw 0x3840, 0xc11f,	0x387f, 0xc11f,		0x21, 0
	.dw 0x38c0, 0xc11f,	0x38ff, 0xc11f,		0x21, 0
	.dw 0x3940, 0xc11f,	0x397f, 0xc11f,		0x21, 0
	.dw 0x39c0, 0xc11f,	0x1fff, 0xc120,		0x21, 0
	.dw 0x3a00, 0xc120,	0x5fff, 0xc120,		0x21, 0
	.dw 0x7a00, 0xc120,	0x9fff, 0xc120,		0x21, 0
	.dw 0xba00, 0xc120,	0xdfff, 0xc120,		0x21, 0
	.dw 0xfa00, 0xc120,	0x1fff, 0xc121,		0x21, 0
	.dw 0x3a00, 0xc121,	0x5fff, 0xc121,		0x21, 0
	.dw 0x7a00, 0xc121,	0x9fff, 0xc121,		0x21, 0
	.dw 0xba00, 0xc121,	0xdfff, 0xc121,		0x21, 0
	.dw 0xfa00, 0xc121,	0x1fff, 0xc122,		0x21, 0
	.dw 0x3a00, 0xc122,	0x5fff, 0xc122,		0x21, 0
	.dw 0x7a00, 0xc122,	0x9fff, 0xc122,		0x21, 0
	.dw 0xba00, 0xc122,	0xdfff, 0xc122,		0x21, 0
	.dw 0xfa00, 0xc122,	0x1fff, 0xc123,		0x21, 0
	.dw 0x3a00, 0xc123,	0xffff, 0xc123,		0x21, 0
	.dw 0x1a00, 0xc124,	0x1fff, 0xc124,		0x21, 0
	.dw 0x3a00, 0xc124,	0x3fff, 0xc124,		0x21, 0
	.dw 0x5a00, 0xc124,	0x5fff, 0xc124,		0x21, 0
	.dw 0x7a00, 0xc124,	0x7fff, 0xc124,		0x21, 0
	.dw 0x9a00, 0xc124,	0x9fff, 0xc124,		0x21, 0
	.dw 0xba00, 0xc124,	0xbfff, 0xc124,		0x21, 0
	.dw 0xda00, 0xc124,	0xdfff, 0xc124,		0x21, 0
	.dw 0xfa00, 0xc124,	0xffff, 0xc124,		0x21, 0
	.dw 0x1a00, 0xc125,	0x1fff, 0xc125,		0x21, 0
	.dw 0x3a00, 0xc125,	0x3fff, 0xc125,		0x21, 0
	.dw 0x5a00, 0xc125,	0x5fff, 0xc125,		0x21, 0
	.dw 0x7a00, 0xc125,	0x7fff, 0xc125,		0x21, 0
	.dw 0x9a00, 0xc125,	0x9fff, 0xc125,		0x21, 0
	.dw 0xba00, 0xc125,	0xbfff, 0xc125,		0x21, 0
	.dw 0xda00, 0xc125,	0xdfff, 0xc125,		0x21, 0
	.dw 0xfa00, 0xc125,	0xffff, 0xc125,		0x21, 0
	.dw 0x1a00, 0xc126,	0x1fff, 0xc126,		0x21, 0
	.dw 0x3a00, 0xc126,	0x3fff, 0xc126,		0x21, 0
	.dw 0x5a00, 0xc126,	0x5fff, 0xc126,		0x21, 0
	.dw 0x7a00, 0xc126,	0x7fff, 0xc126,		0x21, 0
	.dw 0x9a00, 0xc126,	0x9fff, 0xc126,		0x21, 0
	.dw 0xba00, 0xc126,	0xbfff, 0xc126,		0x21, 0
	.dw 0xda00, 0xc126,	0xdfff, 0xc126,		0x21, 0
	.dw 0xfa00, 0xc126,	0xffff, 0xc126,		0x21, 0
	.dw 0x1a00, 0xc127,	0x1fff, 0xc127,		0x21, 0
	.dw 0x3a00, 0xc127,	0x1fff, 0xc128,		0x21, 0
	.dw 0x2040, 0xc128,	0x207f, 0xc128,		0x21, 0
	.dw 0x20c0, 0xc128,	0x20ff, 0xc128,		0x21, 0
	.dw 0x2140, 0xc128,	0x217f, 0xc128,		0x21, 0
	.dw 0x21c0, 0xc128,	0x21ff, 0xc128,		0x21, 0
	.dw 0x2240, 0xc128,	0x227f, 0xc128,		0x21, 0
	.dw 0x22c0, 0xc128,	0x22ff, 0xc128,		0x21, 0
	.dw 0x2340, 0xc128,	0x237f, 0xc128,		0x21, 0
	.dw 0x23c0, 0xc128,	0x23ff, 0xc128,		0x21, 0
	.dw 0x2440, 0xc128,	0x247f, 0xc128,		0x21, 0
	.dw 0x24c0, 0xc128,	0x24ff, 0xc128,		0x21, 0
	.dw 0x2540, 0xc128,	0x257f, 0xc128,		0x21, 0
	.dw 0x25c0, 0xc128,	0x25ff, 0xc128,		0x21, 0
	.dw 0x2640, 0xc128,	0x267f, 0xc128,		0x21, 0
	.dw 0x26c0, 0xc128,	0x26ff, 0xc128,		0x21, 0
	.dw 0x2740, 0xc128,	0x277f, 0xc128,		0x21, 0
	.dw 0x27c0, 0xc128,	0x27ff, 0xc128,		0x21, 0
	.dw 0x2840, 0xc128,	0x287f, 0xc128,		0x21, 0
	.dw 0x28c0, 0xc128,	0x28ff, 0xc128,		0x21, 0
	.dw 0x2940, 0xc128,	0x297f, 0xc128,		0x21, 0
	.dw 0x29c0, 0xc128,	0x29ff, 0xc128,		0x21, 0
	.dw 0x2a40, 0xc128,	0x2a7f, 0xc128,		0x21, 0
	.dw 0x2ac0, 0xc128,	0x2aff, 0xc128,		0x21, 0
	.dw 0x2b40, 0xc128,	0x2b7f, 0xc128,		0x21, 0
	.dw 0x2bc0, 0xc128,	0x2bff, 0xc128,		0x21, 0
	.dw 0x2c40, 0xc128,	0x2c7f, 0xc128,		0x21, 0
	.dw 0x2cc0, 0xc128,	0x2cff, 0xc128,		0x21, 0
	.dw 0x2d40, 0xc128,	0x2d7f, 0xc128,		0x21, 0
	.dw 0x2dc0, 0xc128,	0x2dff, 0xc128,		0x21, 0
	.dw 0x2e40, 0xc128,	0x2e7f, 0xc128,		0x21, 0
	.dw 0x2ec0, 0xc128,	0x2eff, 0xc128,		0x21, 0
	.dw 0x2f40, 0xc128,	0x2f7f, 0xc128,		0x21, 0
	.dw 0x2fc0, 0xc128,	0x2fff, 0xc128,		0x21, 0
	.dw 0x3040, 0xc128,	0x307f, 0xc128,		0x21, 0
	.dw 0x30c0, 0xc128,	0x30ff, 0xc128,		0x21, 0
	.dw 0x3140, 0xc128,	0x317f, 0xc128,		0x21, 0
	.dw 0x31c0, 0xc128,	0x31ff, 0xc128,		0x21, 0
	.dw 0x3240, 0xc128,	0x327f, 0xc128,		0x21, 0
	.dw 0x32c0, 0xc128,	0x32ff, 0xc128,		0x21, 0
	.dw 0x3340, 0xc128,	0x337f, 0xc128,		0x21, 0
	.dw 0x33c0, 0xc128,	0x33ff, 0xc128,		0x21, 0
	.dw 0x3440, 0xc128,	0x347f, 0xc128,		0x21, 0
	.dw 0x34c0, 0xc128,	0x34ff, 0xc128,		0x21, 0
	.dw 0x3540, 0xc128,	0x357f, 0xc128,		0x21, 0
	.dw 0x35c0, 0xc128,	0x35ff, 0xc128,		0x21, 0
	.dw 0x3640, 0xc128,	0x367f, 0xc128,		0x21, 0
	.dw 0x36c0, 0xc128,	0x36ff, 0xc128,		0x21, 0
	.dw 0x3740, 0xc128,	0x377f, 0xc128,		0x21, 0
	.dw 0x37c0, 0xc128,	0x37ff, 0xc128,		0x21, 0
	.dw 0x3840, 0xc128,	0x387f, 0xc128,		0x21, 0
	.dw 0x38c0, 0xc128,	0x38ff, 0xc128,		0x21, 0
	.dw 0x3940, 0xc128,	0x397f, 0xc128,		0x21, 0
	.dw 0x39c0, 0xc128,	0x5fff, 0xc128,		0x21, 0
	.dw 0x6040, 0xc128,	0x607f, 0xc128,		0x21, 0
	.dw 0x60c0, 0xc128,	0x60ff, 0xc128,		0x21, 0
	.dw 0x6140, 0xc128,	0x617f, 0xc128,		0x21, 0
	.dw 0x61c0, 0xc128,	0x61ff, 0xc128,		0x21, 0
	.dw 0x6240, 0xc128,	0x627f, 0xc128,		0x21, 0
	.dw 0x62c0, 0xc128,	0x62ff, 0xc128,		0x21, 0
	.dw 0x6340, 0xc128,	0x637f, 0xc128,		0x21, 0
	.dw 0x63c0, 0xc128,	0x63ff, 0xc128,		0x21, 0
	.dw 0x6440, 0xc128,	0x647f, 0xc128,		0x21, 0
	.dw 0x64c0, 0xc128,	0x64ff, 0xc128,		0x21, 0
	.dw 0x6540, 0xc128,	0x657f, 0xc128,		0x21, 0
	.dw 0x65c0, 0xc128,	0x65ff, 0xc128,		0x21, 0
	.dw 0x6640, 0xc128,	0x667f, 0xc128,		0x21, 0
	.dw 0x66c0, 0xc128,	0x66ff, 0xc128,		0x21, 0
	.dw 0x6740, 0xc128,	0x677f, 0xc128,		0x21, 0
	.dw 0x67c0, 0xc128,	0x67ff, 0xc128,		0x21, 0
	.dw 0x6840, 0xc128,	0x687f, 0xc128,		0x21, 0
	.dw 0x68c0, 0xc128,	0x68ff, 0xc128,		0x21, 0
	.dw 0x6940, 0xc128,	0x697f, 0xc128,		0x21, 0
	.dw 0x69c0, 0xc128,	0x69ff, 0xc128,		0x21, 0
	.dw 0x6a40, 0xc128,	0x6a7f, 0xc128,		0x21, 0
	.dw 0x6ac0, 0xc128,	0x6aff, 0xc128,		0x21, 0
	.dw 0x6b40, 0xc128,	0x6b7f, 0xc128,		0x21, 0
	.dw 0x6bc0, 0xc128,	0x6bff, 0xc128,		0x21, 0
	.dw 0x6c40, 0xc128,	0x6c7f, 0xc128,		0x21, 0
	.dw 0x6cc0, 0xc128,	0x6cff, 0xc128,		0x21, 0
	.dw 0x6d40, 0xc128,	0x6d7f, 0xc128,		0x21, 0
	.dw 0x6dc0, 0xc128,	0x6dff, 0xc128,		0x21, 0
	.dw 0x6e40, 0xc128,	0x6e7f, 0xc128,		0x21, 0
	.dw 0x6ec0, 0xc128,	0x6eff, 0xc128,		0x21, 0
	.dw 0x6f40, 0xc128,	0x6f7f, 0xc128,		0x21, 0
	.dw 0x6fc0, 0xc128,	0x6fff, 0xc128,		0x21, 0
	.dw 0x7040, 0xc128,	0x707f, 0xc128,		0x21, 0
	.dw 0x70c0, 0xc128,	0x70ff, 0xc128,		0x21, 0
	.dw 0x7140, 0xc128,	0x717f, 0xc128,		0x21, 0
	.dw 0x71c0, 0xc128,	0x71ff, 0xc128,		0x21, 0
	.dw 0x7240, 0xc128,	0x727f, 0xc128,		0x21, 0
	.dw 0x72c0, 0xc128,	0x72ff, 0xc128,		0x21, 0
	.dw 0x7340, 0xc128,	0x737f, 0xc128,		0x21, 0
	.dw 0x73c0, 0xc128,	0x73ff, 0xc128,		0x21, 0
	.dw 0x7440, 0xc128,	0x747f, 0xc128,		0x21, 0
	.dw 0x74c0, 0xc128,	0x74ff, 0xc128,		0x21, 0
	.dw 0x7540, 0xc128,	0x757f, 0xc128,		0x21, 0
	.dw 0x75c0, 0xc128,	0x75ff, 0xc128,		0x21, 0
	.dw 0x7640, 0xc128,	0x767f, 0xc128,		0x21, 0
	.dw 0x76c0, 0xc128,	0x76ff, 0xc128,		0x21, 0
	.dw 0x7740, 0xc128,	0x777f, 0xc128,		0x21, 0
	.dw 0x77c0, 0xc128,	0x77ff, 0xc128,		0x21, 0
	.dw 0x7840, 0xc128,	0x787f, 0xc128,		0x21, 0
	.dw 0x78c0, 0xc128,	0x78ff, 0xc128,		0x21, 0
	.dw 0x7940, 0xc128,	0x797f, 0xc128,		0x21, 0
	.dw 0x79c0, 0xc128,	0x9fff, 0xc128,		0x21, 0
	.dw 0xa040, 0xc128,	0xa07f, 0xc128,		0x21, 0
	.dw 0xa0c0, 0xc128,	0xa0ff, 0xc128,		0x21, 0
	.dw 0xa140, 0xc128,	0xa17f, 0xc128,		0x21, 0
	.dw 0xa1c0, 0xc128,	0xa1ff, 0xc128,		0x21, 0
	.dw 0xa240, 0xc128,	0xa27f, 0xc128,		0x21, 0
	.dw 0xa2c0, 0xc128,	0xa2ff, 0xc128,		0x21, 0
	.dw 0xa340, 0xc128,	0xa37f, 0xc128,		0x21, 0
	.dw 0xa3c0, 0xc128,	0xa3ff, 0xc128,		0x21, 0
	.dw 0xa440, 0xc128,	0xa47f, 0xc128,		0x21, 0
	.dw 0xa4c0, 0xc128,	0xa4ff, 0xc128,		0x21, 0
	.dw 0xa540, 0xc128,	0xa57f, 0xc128,		0x21, 0
	.dw 0xa5c0, 0xc128,	0xa5ff, 0xc128,		0x21, 0
	.dw 0xa640, 0xc128,	0xa67f, 0xc128,		0x21, 0
	.dw 0xa6c0, 0xc128,	0xa6ff, 0xc128,		0x21, 0
	.dw 0xa740, 0xc128,	0xa77f, 0xc128,		0x21, 0
	.dw 0xa7c0, 0xc128,	0xa7ff, 0xc128,		0x21, 0
	.dw 0xa840, 0xc128,	0xa87f, 0xc128,		0x21, 0
	.dw 0xa8c0, 0xc128,	0xa8ff, 0xc128,		0x21, 0
	.dw 0xa940, 0xc128,	0xa97f, 0xc128,		0x21, 0
	.dw 0xa9c0, 0xc128,	0xa9ff, 0xc128,		0x21, 0
	.dw 0xaa40, 0xc128,	0xaa7f, 0xc128,		0x21, 0
	.dw 0xaac0, 0xc128,	0xaaff, 0xc128,		0x21, 0
	.dw 0xab40, 0xc128,	0xab7f, 0xc128,		0x21, 0
	.dw 0xabc0, 0xc128,	0xabff, 0xc128,		0x21, 0
	.dw 0xac40, 0xc128,	0xac7f, 0xc128,		0x21, 0
	.dw 0xacc0, 0xc128,	0xacff, 0xc128,		0x21, 0
	.dw 0xad40, 0xc128,	0xad7f, 0xc128,		0x21, 0
	.dw 0xadc0, 0xc128,	0xadff, 0xc128,		0x21, 0
	.dw 0xae40, 0xc128,	0xae7f, 0xc128,		0x21, 0
	.dw 0xaec0, 0xc128,	0xaeff, 0xc128,		0x21, 0
	.dw 0xaf40, 0xc128,	0xaf7f, 0xc128,		0x21, 0
	.dw 0xafc0, 0xc128,	0xafff, 0xc128,		0x21, 0
	.dw 0xb040, 0xc128,	0xb07f, 0xc128,		0x21, 0
	.dw 0xb0c0, 0xc128,	0xb0ff, 0xc128,		0x21, 0
	.dw 0xb140, 0xc128,	0xb17f, 0xc128,		0x21, 0
	.dw 0xb1c0, 0xc128,	0xb1ff, 0xc128,		0x21, 0
	.dw 0xb240, 0xc128,	0xb27f, 0xc128,		0x21, 0
	.dw 0xb2c0, 0xc128,	0xb2ff, 0xc128,		0x21, 0
	.dw 0xb340, 0xc128,	0xb37f, 0xc128,		0x21, 0
	.dw 0xb3c0, 0xc128,	0xb3ff, 0xc128,		0x21, 0
	.dw 0xb440, 0xc128,	0xb47f, 0xc128,		0x21, 0
	.dw 0xb4c0, 0xc128,	0xb4ff, 0xc128,		0x21, 0
	.dw 0xb540, 0xc128,	0xb57f, 0xc128,		0x21, 0
	.dw 0xb5c0, 0xc128,	0xb5ff, 0xc128,		0x21, 0
	.dw 0xb640, 0xc128,	0xb67f, 0xc128,		0x21, 0
	.dw 0xb6c0, 0xc128,	0xb6ff, 0xc128,		0x21, 0
	.dw 0xb740, 0xc128,	0xb77f, 0xc128,		0x21, 0
	.dw 0xb7c0, 0xc128,	0xb7ff, 0xc128,		0x21, 0
	.dw 0xb840, 0xc128,	0xb87f, 0xc128,		0x21, 0
	.dw 0xb8c0, 0xc128,	0xb8ff, 0xc128,		0x21, 0
	.dw 0xb940, 0xc128,	0xb97f, 0xc128,		0x21, 0
	.dw 0xb9c0, 0xc128,	0xdfff, 0xc128,		0x21, 0
	.dw 0xe040, 0xc128,	0xe07f, 0xc128,		0x21, 0
	.dw 0xe0c0, 0xc128,	0xe0ff, 0xc128,		0x21, 0
	.dw 0xe140, 0xc128,	0xe17f, 0xc128,		0x21, 0
	.dw 0xe1c0, 0xc128,	0xe1ff, 0xc128,		0x21, 0
	.dw 0xe240, 0xc128,	0xe27f, 0xc128,		0x21, 0
	.dw 0xe2c0, 0xc128,	0xe2ff, 0xc128,		0x21, 0
	.dw 0xe340, 0xc128,	0xe37f, 0xc128,		0x21, 0
	.dw 0xe3c0, 0xc128,	0xe3ff, 0xc128,		0x21, 0
	.dw 0xe440, 0xc128,	0xe47f, 0xc128,		0x21, 0
	.dw 0xe4c0, 0xc128,	0xe4ff, 0xc128,		0x21, 0
	.dw 0xe540, 0xc128,	0xe57f, 0xc128,		0x21, 0
	.dw 0xe5c0, 0xc128,	0xe5ff, 0xc128,		0x21, 0
	.dw 0xe640, 0xc128,	0xe67f, 0xc128,		0x21, 0
	.dw 0xe6c0, 0xc128,	0xe6ff, 0xc128,		0x21, 0
	.dw 0xe740, 0xc128,	0xe77f, 0xc128,		0x21, 0
	.dw 0xe7c0, 0xc128,	0xe7ff, 0xc128,		0x21, 0
	.dw 0xe840, 0xc128,	0xe87f, 0xc128,		0x21, 0
	.dw 0xe8c0, 0xc128,	0xe8ff, 0xc128,		0x21, 0
	.dw 0xe940, 0xc128,	0xe97f, 0xc128,		0x21, 0
	.dw 0xe9c0, 0xc128,	0xe9ff, 0xc128,		0x21, 0
	.dw 0xea40, 0xc128,	0xea7f, 0xc128,		0x21, 0
	.dw 0xeac0, 0xc128,	0xeaff, 0xc128,		0x21, 0
	.dw 0xeb40, 0xc128,	0xeb7f, 0xc128,		0x21, 0
	.dw 0xebc0, 0xc128,	0xebff, 0xc128,		0x21, 0
	.dw 0xec40, 0xc128,	0xec7f, 0xc128,		0x21, 0
	.dw 0xecc0, 0xc128,	0xecff, 0xc128,		0x21, 0
	.dw 0xed40, 0xc128,	0xed7f, 0xc128,		0x21, 0
	.dw 0xedc0, 0xc128,	0xedff, 0xc128,		0x21, 0
	.dw 0xee40, 0xc128,	0xee7f, 0xc128,		0x21, 0
	.dw 0xeec0, 0xc128,	0xeeff, 0xc128,		0x21, 0
	.dw 0xef40, 0xc128,	0xef7f, 0xc128,		0x21, 0
	.dw 0xefc0, 0xc128,	0xefff, 0xc128,		0x21, 0
	.dw 0xf040, 0xc128,	0xf07f, 0xc128,		0x21, 0
	.dw 0xf0c0, 0xc128,	0xf0ff, 0xc128,		0x21, 0
	.dw 0xf140, 0xc128,	0xf17f, 0xc128,		0x21, 0
	.dw 0xf1c0, 0xc128,	0xf1ff, 0xc128,		0x21, 0
	.dw 0xf240, 0xc128,	0xf27f, 0xc128,		0x21, 0
	.dw 0xf2c0, 0xc128,	0xf2ff, 0xc128,		0x21, 0
	.dw 0xf340, 0xc128,	0xf37f, 0xc128,		0x21, 0
	.dw 0xf3c0, 0xc128,	0xf3ff, 0xc128,		0x21, 0
	.dw 0xf440, 0xc128,	0xf47f, 0xc128,		0x21, 0
	.dw 0xf4c0, 0xc128,	0xf4ff, 0xc128,		0x21, 0
	.dw 0xf540, 0xc128,	0xf57f, 0xc128,		0x21, 0
	.dw 0xf5c0, 0xc128,	0xf5ff, 0xc128,		0x21, 0
	.dw 0xf640, 0xc128,	0xf67f, 0xc128,		0x21, 0
	.dw 0xf6c0, 0xc128,	0xf6ff, 0xc128,		0x21, 0
	.dw 0xf740, 0xc128,	0xf77f, 0xc128,		0x21, 0
	.dw 0xf7c0, 0xc128,	0xf7ff, 0xc128,		0x21, 0
	.dw 0xf840, 0xc128,	0xf87f, 0xc128,		0x21, 0
	.dw 0xf8c0, 0xc128,	0xf8ff, 0xc128,		0x21, 0
	.dw 0xf940, 0xc128,	0xf97f, 0xc128,		0x21, 0
	.dw 0xf9c0, 0xc128,	0x1fff, 0xc129,		0x21, 0
	.dw 0x2040, 0xc129,	0x207f, 0xc129,		0x21, 0
	.dw 0x20c0, 0xc129,	0x20ff, 0xc129,		0x21, 0
	.dw 0x2140, 0xc129,	0x217f, 0xc129,		0x21, 0
	.dw 0x21c0, 0xc129,	0x21ff, 0xc129,		0x21, 0
	.dw 0x2240, 0xc129,	0x227f, 0xc129,		0x21, 0
	.dw 0x22c0, 0xc129,	0x22ff, 0xc129,		0x21, 0
	.dw 0x2340, 0xc129,	0x237f, 0xc129,		0x21, 0
	.dw 0x23c0, 0xc129,	0x23ff, 0xc129,		0x21, 0
	.dw 0x2440, 0xc129,	0x247f, 0xc129,		0x21, 0
	.dw 0x24c0, 0xc129,	0x24ff, 0xc129,		0x21, 0
	.dw 0x2540, 0xc129,	0x257f, 0xc129,		0x21, 0
	.dw 0x25c0, 0xc129,	0x25ff, 0xc129,		0x21, 0
	.dw 0x2640, 0xc129,	0x267f, 0xc129,		0x21, 0
	.dw 0x26c0, 0xc129,	0x26ff, 0xc129,		0x21, 0
	.dw 0x2740, 0xc129,	0x277f, 0xc129,		0x21, 0
	.dw 0x27c0, 0xc129,	0x27ff, 0xc129,		0x21, 0
	.dw 0x2840, 0xc129,	0x287f, 0xc129,		0x21, 0
	.dw 0x28c0, 0xc129,	0x28ff, 0xc129,		0x21, 0
	.dw 0x2940, 0xc129,	0x297f, 0xc129,		0x21, 0
	.dw 0x29c0, 0xc129,	0x29ff, 0xc129,		0x21, 0
	.dw 0x2a40, 0xc129,	0x2a7f, 0xc129,		0x21, 0
	.dw 0x2ac0, 0xc129,	0x2aff, 0xc129,		0x21, 0
	.dw 0x2b40, 0xc129,	0x2b7f, 0xc129,		0x21, 0
	.dw 0x2bc0, 0xc129,	0x2bff, 0xc129,		0x21, 0
	.dw 0x2c40, 0xc129,	0x2c7f, 0xc129,		0x21, 0
	.dw 0x2cc0, 0xc129,	0x2cff, 0xc129,		0x21, 0
	.dw 0x2d40, 0xc129,	0x2d7f, 0xc129,		0x21, 0
	.dw 0x2dc0, 0xc129,	0x2dff, 0xc129,		0x21, 0
	.dw 0x2e40, 0xc129,	0x2e7f, 0xc129,		0x21, 0
	.dw 0x2ec0, 0xc129,	0x2eff, 0xc129,		0x21, 0
	.dw 0x2f40, 0xc129,	0x2f7f, 0xc129,		0x21, 0
	.dw 0x2fc0, 0xc129,	0x2fff, 0xc129,		0x21, 0
	.dw 0x3040, 0xc129,	0x307f, 0xc129,		0x21, 0
	.dw 0x30c0, 0xc129,	0x30ff, 0xc129,		0x21, 0
	.dw 0x3140, 0xc129,	0x317f, 0xc129,		0x21, 0
	.dw 0x31c0, 0xc129,	0x31ff, 0xc129,		0x21, 0
	.dw 0x3240, 0xc129,	0x327f, 0xc129,		0x21, 0
	.dw 0x32c0, 0xc129,	0x32ff, 0xc129,		0x21, 0
	.dw 0x3340, 0xc129,	0x337f, 0xc129,		0x21, 0
	.dw 0x33c0, 0xc129,	0x33ff, 0xc129,		0x21, 0
	.dw 0x3440, 0xc129,	0x347f, 0xc129,		0x21, 0
	.dw 0x34c0, 0xc129,	0x34ff, 0xc129,		0x21, 0
	.dw 0x3540, 0xc129,	0x357f, 0xc129,		0x21, 0
	.dw 0x35c0, 0xc129,	0x35ff, 0xc129,		0x21, 0
	.dw 0x3640, 0xc129,	0x367f, 0xc129,		0x21, 0
	.dw 0x36c0, 0xc129,	0x36ff, 0xc129,		0x21, 0
	.dw 0x3740, 0xc129,	0x377f, 0xc129,		0x21, 0
	.dw 0x37c0, 0xc129,	0x37ff, 0xc129,		0x21, 0
	.dw 0x3840, 0xc129,	0x387f, 0xc129,		0x21, 0
	.dw 0x38c0, 0xc129,	0x38ff, 0xc129,		0x21, 0
	.dw 0x3940, 0xc129,	0x397f, 0xc129,		0x21, 0
	.dw 0x39c0, 0xc129,	0x5fff, 0xc129,		0x21, 0
	.dw 0x6040, 0xc129,	0x607f, 0xc129,		0x21, 0
	.dw 0x60c0, 0xc129,	0x60ff, 0xc129,		0x21, 0
	.dw 0x6140, 0xc129,	0x617f, 0xc129,		0x21, 0
	.dw 0x61c0, 0xc129,	0x61ff, 0xc129,		0x21, 0
	.dw 0x6240, 0xc129,	0x627f, 0xc129,		0x21, 0
	.dw 0x62c0, 0xc129,	0x62ff, 0xc129,		0x21, 0
	.dw 0x6340, 0xc129,	0x637f, 0xc129,		0x21, 0
	.dw 0x63c0, 0xc129,	0x63ff, 0xc129,		0x21, 0
	.dw 0x6440, 0xc129,	0x647f, 0xc129,		0x21, 0
	.dw 0x64c0, 0xc129,	0x64ff, 0xc129,		0x21, 0
	.dw 0x6540, 0xc129,	0x657f, 0xc129,		0x21, 0
	.dw 0x65c0, 0xc129,	0x65ff, 0xc129,		0x21, 0
	.dw 0x6640, 0xc129,	0x667f, 0xc129,		0x21, 0
	.dw 0x66c0, 0xc129,	0x66ff, 0xc129,		0x21, 0
	.dw 0x6740, 0xc129,	0x677f, 0xc129,		0x21, 0
	.dw 0x67c0, 0xc129,	0x67ff, 0xc129,		0x21, 0
	.dw 0x6840, 0xc129,	0x687f, 0xc129,		0x21, 0
	.dw 0x68c0, 0xc129,	0x68ff, 0xc129,		0x21, 0
	.dw 0x6940, 0xc129,	0x697f, 0xc129,		0x21, 0
	.dw 0x69c0, 0xc129,	0x69ff, 0xc129,		0x21, 0
	.dw 0x6a40, 0xc129,	0x6a7f, 0xc129,		0x21, 0
	.dw 0x6ac0, 0xc129,	0x6aff, 0xc129,		0x21, 0
	.dw 0x6b40, 0xc129,	0x6b7f, 0xc129,		0x21, 0
	.dw 0x6bc0, 0xc129,	0x6bff, 0xc129,		0x21, 0
	.dw 0x6c40, 0xc129,	0x6c7f, 0xc129,		0x21, 0
	.dw 0x6cc0, 0xc129,	0x6cff, 0xc129,		0x21, 0
	.dw 0x6d40, 0xc129,	0x6d7f, 0xc129,		0x21, 0
	.dw 0x6dc0, 0xc129,	0x6dff, 0xc129,		0x21, 0
	.dw 0x6e40, 0xc129,	0x6e7f, 0xc129,		0x21, 0
	.dw 0x6ec0, 0xc129,	0x6eff, 0xc129,		0x21, 0
	.dw 0x6f40, 0xc129,	0x6f7f, 0xc129,		0x21, 0
	.dw 0x6fc0, 0xc129,	0x6fff, 0xc129,		0x21, 0
	.dw 0x7040, 0xc129,	0x707f, 0xc129,		0x21, 0
	.dw 0x70c0, 0xc129,	0x70ff, 0xc129,		0x21, 0
	.dw 0x7140, 0xc129,	0x717f, 0xc129,		0x21, 0
	.dw 0x71c0, 0xc129,	0x71ff, 0xc129,		0x21, 0
	.dw 0x7240, 0xc129,	0x727f, 0xc129,		0x21, 0
	.dw 0x72c0, 0xc129,	0x72ff, 0xc129,		0x21, 0
	.dw 0x7340, 0xc129,	0x737f, 0xc129,		0x21, 0
	.dw 0x73c0, 0xc129,	0x73ff, 0xc129,		0x21, 0
	.dw 0x7440, 0xc129,	0x747f, 0xc129,		0x21, 0
	.dw 0x74c0, 0xc129,	0x74ff, 0xc129,		0x21, 0
	.dw 0x7540, 0xc129,	0x757f, 0xc129,		0x21, 0
	.dw 0x75c0, 0xc129,	0x75ff, 0xc129,		0x21, 0
	.dw 0x7640, 0xc129,	0x767f, 0xc129,		0x21, 0
	.dw 0x76c0, 0xc129,	0x76ff, 0xc129,		0x21, 0
	.dw 0x7740, 0xc129,	0x777f, 0xc129,		0x21, 0
	.dw 0x77c0, 0xc129,	0x77ff, 0xc129,		0x21, 0
	.dw 0x7840, 0xc129,	0x787f, 0xc129,		0x21, 0
	.dw 0x78c0, 0xc129,	0x78ff, 0xc129,		0x21, 0
	.dw 0x7940, 0xc129,	0x797f, 0xc129,		0x21, 0
	.dw 0x79c0, 0xc129,	0x9fff, 0xc129,		0x21, 0
	.dw 0xa040, 0xc129,	0xa07f, 0xc129,		0x21, 0
	.dw 0xa0c0, 0xc129,	0xa0ff, 0xc129,		0x21, 0
	.dw 0xa140, 0xc129,	0xa17f, 0xc129,		0x21, 0
	.dw 0xa1c0, 0xc129,	0xa1ff, 0xc129,		0x21, 0
	.dw 0xa240, 0xc129,	0xa27f, 0xc129,		0x21, 0
	.dw 0xa2c0, 0xc129,	0xa2ff, 0xc129,		0x21, 0
	.dw 0xa340, 0xc129,	0xa37f, 0xc129,		0x21, 0
	.dw 0xa3c0, 0xc129,	0xa3ff, 0xc129,		0x21, 0
	.dw 0xa440, 0xc129,	0xa47f, 0xc129,		0x21, 0
	.dw 0xa4c0, 0xc129,	0xa4ff, 0xc129,		0x21, 0
	.dw 0xa540, 0xc129,	0xa57f, 0xc129,		0x21, 0
	.dw 0xa5c0, 0xc129,	0xa5ff, 0xc129,		0x21, 0
	.dw 0xa640, 0xc129,	0xa67f, 0xc129,		0x21, 0
	.dw 0xa6c0, 0xc129,	0xa6ff, 0xc129,		0x21, 0
	.dw 0xa740, 0xc129,	0xa77f, 0xc129,		0x21, 0
	.dw 0xa7c0, 0xc129,	0xa7ff, 0xc129,		0x21, 0
	.dw 0xa840, 0xc129,	0xa87f, 0xc129,		0x21, 0
	.dw 0xa8c0, 0xc129,	0xa8ff, 0xc129,		0x21, 0
	.dw 0xa940, 0xc129,	0xa97f, 0xc129,		0x21, 0
	.dw 0xa9c0, 0xc129,	0xa9ff, 0xc129,		0x21, 0
	.dw 0xaa40, 0xc129,	0xaa7f, 0xc129,		0x21, 0
	.dw 0xaac0, 0xc129,	0xaaff, 0xc129,		0x21, 0
	.dw 0xab40, 0xc129,	0xab7f, 0xc129,		0x21, 0
	.dw 0xabc0, 0xc129,	0xabff, 0xc129,		0x21, 0
	.dw 0xac40, 0xc129,	0xac7f, 0xc129,		0x21, 0
	.dw 0xacc0, 0xc129,	0xacff, 0xc129,		0x21, 0
	.dw 0xad40, 0xc129,	0xad7f, 0xc129,		0x21, 0
	.dw 0xadc0, 0xc129,	0xadff, 0xc129,		0x21, 0
	.dw 0xae40, 0xc129,	0xae7f, 0xc129,		0x21, 0
	.dw 0xaec0, 0xc129,	0xaeff, 0xc129,		0x21, 0
	.dw 0xaf40, 0xc129,	0xaf7f, 0xc129,		0x21, 0
	.dw 0xafc0, 0xc129,	0xafff, 0xc129,		0x21, 0
	.dw 0xb040, 0xc129,	0xb07f, 0xc129,		0x21, 0
	.dw 0xb0c0, 0xc129,	0xb0ff, 0xc129,		0x21, 0
	.dw 0xb140, 0xc129,	0xb17f, 0xc129,		0x21, 0
	.dw 0xb1c0, 0xc129,	0xb1ff, 0xc129,		0x21, 0
	.dw 0xb240, 0xc129,	0xb27f, 0xc129,		0x21, 0
	.dw 0xb2c0, 0xc129,	0xb2ff, 0xc129,		0x21, 0
	.dw 0xb340, 0xc129,	0xb37f, 0xc129,		0x21, 0
	.dw 0xb3c0, 0xc129,	0xb3ff, 0xc129,		0x21, 0
	.dw 0xb440, 0xc129,	0xb47f, 0xc129,		0x21, 0
	.dw 0xb4c0, 0xc129,	0xb4ff, 0xc129,		0x21, 0
	.dw 0xb540, 0xc129,	0xb57f, 0xc129,		0x21, 0
	.dw 0xb5c0, 0xc129,	0xb5ff, 0xc129,		0x21, 0
	.dw 0xb640, 0xc129,	0xb67f, 0xc129,		0x21, 0
	.dw 0xb6c0, 0xc129,	0xb6ff, 0xc129,		0x21, 0
	.dw 0xb740, 0xc129,	0xb77f, 0xc129,		0x21, 0
	.dw 0xb7c0, 0xc129,	0xb7ff, 0xc129,		0x21, 0
	.dw 0xb840, 0xc129,	0xb87f, 0xc129,		0x21, 0
	.dw 0xb8c0, 0xc129,	0xb8ff, 0xc129,		0x21, 0
	.dw 0xb940, 0xc129,	0xb97f, 0xc129,		0x21, 0
	.dw 0xb9c0, 0xc129,	0xdfff, 0xc129,		0x21, 0
	.dw 0xe040, 0xc129,	0xe07f, 0xc129,		0x21, 0
	.dw 0xe0c0, 0xc129,	0xe0ff, 0xc129,		0x21, 0
	.dw 0xe140, 0xc129,	0xe17f, 0xc129,		0x21, 0
	.dw 0xe1c0, 0xc129,	0xe1ff, 0xc129,		0x21, 0
	.dw 0xe240, 0xc129,	0xe27f, 0xc129,		0x21, 0
	.dw 0xe2c0, 0xc129,	0xe2ff, 0xc129,		0x21, 0
	.dw 0xe340, 0xc129,	0xe37f, 0xc129,		0x21, 0
	.dw 0xe3c0, 0xc129,	0xe3ff, 0xc129,		0x21, 0
	.dw 0xe440, 0xc129,	0xe47f, 0xc129,		0x21, 0
	.dw 0xe4c0, 0xc129,	0xe4ff, 0xc129,		0x21, 0
	.dw 0xe540, 0xc129,	0xe57f, 0xc129,		0x21, 0
	.dw 0xe5c0, 0xc129,	0xe5ff, 0xc129,		0x21, 0
	.dw 0xe640, 0xc129,	0xe67f, 0xc129,		0x21, 0
	.dw 0xe6c0, 0xc129,	0xe6ff, 0xc129,		0x21, 0
	.dw 0xe740, 0xc129,	0xe77f, 0xc129,		0x21, 0
	.dw 0xe7c0, 0xc129,	0xe7ff, 0xc129,		0x21, 0
	.dw 0xe840, 0xc129,	0xe87f, 0xc129,		0x21, 0
	.dw 0xe8c0, 0xc129,	0xe8ff, 0xc129,		0x21, 0
	.dw 0xe940, 0xc129,	0xe97f, 0xc129,		0x21, 0
	.dw 0xe9c0, 0xc129,	0xe9ff, 0xc129,		0x21, 0
	.dw 0xea40, 0xc129,	0xea7f, 0xc129,		0x21, 0
	.dw 0xeac0, 0xc129,	0xeaff, 0xc129,		0x21, 0
	.dw 0xeb40, 0xc129,	0xeb7f, 0xc129,		0x21, 0
	.dw 0xebc0, 0xc129,	0xebff, 0xc129,		0x21, 0
	.dw 0xec40, 0xc129,	0xec7f, 0xc129,		0x21, 0
	.dw 0xecc0, 0xc129,	0xecff, 0xc129,		0x21, 0
	.dw 0xed40, 0xc129,	0xed7f, 0xc129,		0x21, 0
	.dw 0xedc0, 0xc129,	0xedff, 0xc129,		0x21, 0
	.dw 0xee40, 0xc129,	0xee7f, 0xc129,		0x21, 0
	.dw 0xeec0, 0xc129,	0xeeff, 0xc129,		0x21, 0
	.dw 0xef40, 0xc129,	0xef7f, 0xc129,		0x21, 0
	.dw 0xefc0, 0xc129,	0xefff, 0xc129,		0x21, 0
	.dw 0xf040, 0xc129,	0xf07f, 0xc129,		0x21, 0
	.dw 0xf0c0, 0xc129,	0xf0ff, 0xc129,		0x21, 0
	.dw 0xf140, 0xc129,	0xf17f, 0xc129,		0x21, 0
	.dw 0xf1c0, 0xc129,	0xf1ff, 0xc129,		0x21, 0
	.dw 0xf240, 0xc129,	0xf27f, 0xc129,		0x21, 0
	.dw 0xf2c0, 0xc129,	0xf2ff, 0xc129,		0x21, 0
	.dw 0xf340, 0xc129,	0xf37f, 0xc129,		0x21, 0
	.dw 0xf3c0, 0xc129,	0xf3ff, 0xc129,		0x21, 0
	.dw 0xf440, 0xc129,	0xf47f, 0xc129,		0x21, 0
	.dw 0xf4c0, 0xc129,	0xf4ff, 0xc129,		0x21, 0
	.dw 0xf540, 0xc129,	0xf57f, 0xc129,		0x21, 0
	.dw 0xf5c0, 0xc129,	0xf5ff, 0xc129,		0x21, 0
	.dw 0xf640, 0xc129,	0xf67f, 0xc129,		0x21, 0
	.dw 0xf6c0, 0xc129,	0xf6ff, 0xc129,		0x21, 0
	.dw 0xf740, 0xc129,	0xf77f, 0xc129,		0x21, 0
	.dw 0xf7c0, 0xc129,	0xf7ff, 0xc129,		0x21, 0
	.dw 0xf840, 0xc129,	0xf87f, 0xc129,		0x21, 0
	.dw 0xf8c0, 0xc129,	0xf8ff, 0xc129,		0x21, 0
	.dw 0xf940, 0xc129,	0xf97f, 0xc129,		0x21, 0
	.dw 0xf9c0, 0xc129,	0x1fff, 0xc12a,		0x21, 0
	.dw 0x2040, 0xc12a,	0x207f, 0xc12a,		0x21, 0
	.dw 0x20c0, 0xc12a,	0x20ff, 0xc12a,		0x21, 0
	.dw 0x2140, 0xc12a,	0x217f, 0xc12a,		0x21, 0
	.dw 0x21c0, 0xc12a,	0x21ff, 0xc12a,		0x21, 0
	.dw 0x2240, 0xc12a,	0x227f, 0xc12a,		0x21, 0
	.dw 0x22c0, 0xc12a,	0x22ff, 0xc12a,		0x21, 0
	.dw 0x2340, 0xc12a,	0x237f, 0xc12a,		0x21, 0
	.dw 0x23c0, 0xc12a,	0x23ff, 0xc12a,		0x21, 0
	.dw 0x2440, 0xc12a,	0x247f, 0xc12a,		0x21, 0
	.dw 0x24c0, 0xc12a,	0x24ff, 0xc12a,		0x21, 0
	.dw 0x2540, 0xc12a,	0x257f, 0xc12a,		0x21, 0
	.dw 0x25c0, 0xc12a,	0x25ff, 0xc12a,		0x21, 0
	.dw 0x2640, 0xc12a,	0x267f, 0xc12a,		0x21, 0
	.dw 0x26c0, 0xc12a,	0x26ff, 0xc12a,		0x21, 0
	.dw 0x2740, 0xc12a,	0x277f, 0xc12a,		0x21, 0
	.dw 0x27c0, 0xc12a,	0x27ff, 0xc12a,		0x21, 0
	.dw 0x2840, 0xc12a,	0x287f, 0xc12a,		0x21, 0
	.dw 0x28c0, 0xc12a,	0x28ff, 0xc12a,		0x21, 0
	.dw 0x2940, 0xc12a,	0x297f, 0xc12a,		0x21, 0
	.dw 0x29c0, 0xc12a,	0x29ff, 0xc12a,		0x21, 0
	.dw 0x2a40, 0xc12a,	0x2a7f, 0xc12a,		0x21, 0
	.dw 0x2ac0, 0xc12a,	0x2aff, 0xc12a,		0x21, 0
	.dw 0x2b40, 0xc12a,	0x2b7f, 0xc12a,		0x21, 0
	.dw 0x2bc0, 0xc12a,	0x2bff, 0xc12a,		0x21, 0
	.dw 0x2c40, 0xc12a,	0x2c7f, 0xc12a,		0x21, 0
	.dw 0x2cc0, 0xc12a,	0x2cff, 0xc12a,		0x21, 0
	.dw 0x2d40, 0xc12a,	0x2d7f, 0xc12a,		0x21, 0
	.dw 0x2dc0, 0xc12a,	0x2dff, 0xc12a,		0x21, 0
	.dw 0x2e40, 0xc12a,	0x2e7f, 0xc12a,		0x21, 0
	.dw 0x2ec0, 0xc12a,	0x2eff, 0xc12a,		0x21, 0
	.dw 0x2f40, 0xc12a,	0x2f7f, 0xc12a,		0x21, 0
	.dw 0x2fc0, 0xc12a,	0x2fff, 0xc12a,		0x21, 0
	.dw 0x3040, 0xc12a,	0x307f, 0xc12a,		0x21, 0
	.dw 0x30c0, 0xc12a,	0x30ff, 0xc12a,		0x21, 0
	.dw 0x3140, 0xc12a,	0x317f, 0xc12a,		0x21, 0
	.dw 0x31c0, 0xc12a,	0x31ff, 0xc12a,		0x21, 0
	.dw 0x3240, 0xc12a,	0x327f, 0xc12a,		0x21, 0
	.dw 0x32c0, 0xc12a,	0x32ff, 0xc12a,		0x21, 0
	.dw 0x3340, 0xc12a,	0x337f, 0xc12a,		0x21, 0
	.dw 0x33c0, 0xc12a,	0x33ff, 0xc12a,		0x21, 0
	.dw 0x3440, 0xc12a,	0x347f, 0xc12a,		0x21, 0
	.dw 0x34c0, 0xc12a,	0x34ff, 0xc12a,		0x21, 0
	.dw 0x3540, 0xc12a,	0x357f, 0xc12a,		0x21, 0
	.dw 0x35c0, 0xc12a,	0x35ff, 0xc12a,		0x21, 0
	.dw 0x3640, 0xc12a,	0x367f, 0xc12a,		0x21, 0
	.dw 0x36c0, 0xc12a,	0x36ff, 0xc12a,		0x21, 0
	.dw 0x3740, 0xc12a,	0x377f, 0xc12a,		0x21, 0
	.dw 0x37c0, 0xc12a,	0x37ff, 0xc12a,		0x21, 0
	.dw 0x3840, 0xc12a,	0x387f, 0xc12a,		0x21, 0
	.dw 0x38c0, 0xc12a,	0x38ff, 0xc12a,		0x21, 0
	.dw 0x3940, 0xc12a,	0x397f, 0xc12a,		0x21, 0
	.dw 0x39c0, 0xc12a,	0x5fff, 0xc12a,		0x21, 0
	.dw 0x6040, 0xc12a,	0x607f, 0xc12a,		0x21, 0
	.dw 0x60c0, 0xc12a,	0x60ff, 0xc12a,		0x21, 0
	.dw 0x6140, 0xc12a,	0x617f, 0xc12a,		0x21, 0
	.dw 0x61c0, 0xc12a,	0x61ff, 0xc12a,		0x21, 0
	.dw 0x6240, 0xc12a,	0x627f, 0xc12a,		0x21, 0
	.dw 0x62c0, 0xc12a,	0x62ff, 0xc12a,		0x21, 0
	.dw 0x6340, 0xc12a,	0x637f, 0xc12a,		0x21, 0
	.dw 0x63c0, 0xc12a,	0x63ff, 0xc12a,		0x21, 0
	.dw 0x6440, 0xc12a,	0x647f, 0xc12a,		0x21, 0
	.dw 0x64c0, 0xc12a,	0x64ff, 0xc12a,		0x21, 0
	.dw 0x6540, 0xc12a,	0x657f, 0xc12a,		0x21, 0
	.dw 0x65c0, 0xc12a,	0x65ff, 0xc12a,		0x21, 0
	.dw 0x6640, 0xc12a,	0x667f, 0xc12a,		0x21, 0
	.dw 0x66c0, 0xc12a,	0x66ff, 0xc12a,		0x21, 0
	.dw 0x6740, 0xc12a,	0x677f, 0xc12a,		0x21, 0
	.dw 0x67c0, 0xc12a,	0x67ff, 0xc12a,		0x21, 0
	.dw 0x6840, 0xc12a,	0x687f, 0xc12a,		0x21, 0
	.dw 0x68c0, 0xc12a,	0x68ff, 0xc12a,		0x21, 0
	.dw 0x6940, 0xc12a,	0x697f, 0xc12a,		0x21, 0
	.dw 0x69c0, 0xc12a,	0x69ff, 0xc12a,		0x21, 0
	.dw 0x6a40, 0xc12a,	0x6a7f, 0xc12a,		0x21, 0
	.dw 0x6ac0, 0xc12a,	0x6aff, 0xc12a,		0x21, 0
	.dw 0x6b40, 0xc12a,	0x6b7f, 0xc12a,		0x21, 0
	.dw 0x6bc0, 0xc12a,	0x6bff, 0xc12a,		0x21, 0
	.dw 0x6c40, 0xc12a,	0x6c7f, 0xc12a,		0x21, 0
	.dw 0x6cc0, 0xc12a,	0x6cff, 0xc12a,		0x21, 0
	.dw 0x6d40, 0xc12a,	0x6d7f, 0xc12a,		0x21, 0
	.dw 0x6dc0, 0xc12a,	0x6dff, 0xc12a,		0x21, 0
	.dw 0x6e40, 0xc12a,	0x6e7f, 0xc12a,		0x21, 0
	.dw 0x6ec0, 0xc12a,	0x6eff, 0xc12a,		0x21, 0
	.dw 0x6f40, 0xc12a,	0x6f7f, 0xc12a,		0x21, 0
	.dw 0x6fc0, 0xc12a,	0x6fff, 0xc12a,		0x21, 0
	.dw 0x7040, 0xc12a,	0x707f, 0xc12a,		0x21, 0
	.dw 0x70c0, 0xc12a,	0x70ff, 0xc12a,		0x21, 0
	.dw 0x7140, 0xc12a,	0x717f, 0xc12a,		0x21, 0
	.dw 0x71c0, 0xc12a,	0x71ff, 0xc12a,		0x21, 0
	.dw 0x7240, 0xc12a,	0x727f, 0xc12a,		0x21, 0
	.dw 0x72c0, 0xc12a,	0x72ff, 0xc12a,		0x21, 0
	.dw 0x7340, 0xc12a,	0x737f, 0xc12a,		0x21, 0
	.dw 0x73c0, 0xc12a,	0x73ff, 0xc12a,		0x21, 0
	.dw 0x7440, 0xc12a,	0x747f, 0xc12a,		0x21, 0
	.dw 0x74c0, 0xc12a,	0x74ff, 0xc12a,		0x21, 0
	.dw 0x7540, 0xc12a,	0x757f, 0xc12a,		0x21, 0
	.dw 0x75c0, 0xc12a,	0x75ff, 0xc12a,		0x21, 0
	.dw 0x7640, 0xc12a,	0x767f, 0xc12a,		0x21, 0
	.dw 0x76c0, 0xc12a,	0x76ff, 0xc12a,		0x21, 0
	.dw 0x7740, 0xc12a,	0x777f, 0xc12a,		0x21, 0
	.dw 0x77c0, 0xc12a,	0x77ff, 0xc12a,		0x21, 0
	.dw 0x7840, 0xc12a,	0x787f, 0xc12a,		0x21, 0
	.dw 0x78c0, 0xc12a,	0x78ff, 0xc12a,		0x21, 0
	.dw 0x7940, 0xc12a,	0x797f, 0xc12a,		0x21, 0
	.dw 0x79c0, 0xc12a,	0x9fff, 0xc12a,		0x21, 0
	.dw 0xa040, 0xc12a,	0xa07f, 0xc12a,		0x21, 0
	.dw 0xa0c0, 0xc12a,	0xa0ff, 0xc12a,		0x21, 0
	.dw 0xa140, 0xc12a,	0xa17f, 0xc12a,		0x21, 0
	.dw 0xa1c0, 0xc12a,	0xa1ff, 0xc12a,		0x21, 0
	.dw 0xa240, 0xc12a,	0xa27f, 0xc12a,		0x21, 0
	.dw 0xa2c0, 0xc12a,	0xa2ff, 0xc12a,		0x21, 0
	.dw 0xa340, 0xc12a,	0xa37f, 0xc12a,		0x21, 0
	.dw 0xa3c0, 0xc12a,	0xa3ff, 0xc12a,		0x21, 0
	.dw 0xa440, 0xc12a,	0xa47f, 0xc12a,		0x21, 0
	.dw 0xa4c0, 0xc12a,	0xa4ff, 0xc12a,		0x21, 0
	.dw 0xa540, 0xc12a,	0xa57f, 0xc12a,		0x21, 0
	.dw 0xa5c0, 0xc12a,	0xa5ff, 0xc12a,		0x21, 0
	.dw 0xa640, 0xc12a,	0xa67f, 0xc12a,		0x21, 0
	.dw 0xa6c0, 0xc12a,	0xa6ff, 0xc12a,		0x21, 0
	.dw 0xa740, 0xc12a,	0xa77f, 0xc12a,		0x21, 0
	.dw 0xa7c0, 0xc12a,	0xa7ff, 0xc12a,		0x21, 0
	.dw 0xa840, 0xc12a,	0xa87f, 0xc12a,		0x21, 0
	.dw 0xa8c0, 0xc12a,	0xa8ff, 0xc12a,		0x21, 0
	.dw 0xa940, 0xc12a,	0xa97f, 0xc12a,		0x21, 0
	.dw 0xa9c0, 0xc12a,	0xa9ff, 0xc12a,		0x21, 0
	.dw 0xaa40, 0xc12a,	0xaa7f, 0xc12a,		0x21, 0
	.dw 0xaac0, 0xc12a,	0xaaff, 0xc12a,		0x21, 0
	.dw 0xab40, 0xc12a,	0xab7f, 0xc12a,		0x21, 0
	.dw 0xabc0, 0xc12a,	0xabff, 0xc12a,		0x21, 0
	.dw 0xac40, 0xc12a,	0xac7f, 0xc12a,		0x21, 0
	.dw 0xacc0, 0xc12a,	0xacff, 0xc12a,		0x21, 0
	.dw 0xad40, 0xc12a,	0xad7f, 0xc12a,		0x21, 0
	.dw 0xadc0, 0xc12a,	0xadff, 0xc12a,		0x21, 0
	.dw 0xae40, 0xc12a,	0xae7f, 0xc12a,		0x21, 0
	.dw 0xaec0, 0xc12a,	0xaeff, 0xc12a,		0x21, 0
	.dw 0xaf40, 0xc12a,	0xaf7f, 0xc12a,		0x21, 0
	.dw 0xafc0, 0xc12a,	0xafff, 0xc12a,		0x21, 0
	.dw 0xb040, 0xc12a,	0xb07f, 0xc12a,		0x21, 0
	.dw 0xb0c0, 0xc12a,	0xb0ff, 0xc12a,		0x21, 0
	.dw 0xb140, 0xc12a,	0xb17f, 0xc12a,		0x21, 0
	.dw 0xb1c0, 0xc12a,	0xb1ff, 0xc12a,		0x21, 0
	.dw 0xb240, 0xc12a,	0xb27f, 0xc12a,		0x21, 0
	.dw 0xb2c0, 0xc12a,	0xb2ff, 0xc12a,		0x21, 0
	.dw 0xb340, 0xc12a,	0xb37f, 0xc12a,		0x21, 0
	.dw 0xb3c0, 0xc12a,	0xb3ff, 0xc12a,		0x21, 0
	.dw 0xb440, 0xc12a,	0xb47f, 0xc12a,		0x21, 0
	.dw 0xb4c0, 0xc12a,	0xb4ff, 0xc12a,		0x21, 0
	.dw 0xb540, 0xc12a,	0xb57f, 0xc12a,		0x21, 0
	.dw 0xb5c0, 0xc12a,	0xb5ff, 0xc12a,		0x21, 0
	.dw 0xb640, 0xc12a,	0xb67f, 0xc12a,		0x21, 0
	.dw 0xb6c0, 0xc12a,	0xb6ff, 0xc12a,		0x21, 0
	.dw 0xb740, 0xc12a,	0xb77f, 0xc12a,		0x21, 0
	.dw 0xb7c0, 0xc12a,	0xb7ff, 0xc12a,		0x21, 0
	.dw 0xb840, 0xc12a,	0xb87f, 0xc12a,		0x21, 0
	.dw 0xb8c0, 0xc12a,	0xb8ff, 0xc12a,		0x21, 0
	.dw 0xb940, 0xc12a,	0xb97f, 0xc12a,		0x21, 0
	.dw 0xb9c0, 0xc12a,	0xdfff, 0xc12a,		0x21, 0
	.dw 0xe040, 0xc12a,	0xe07f, 0xc12a,		0x21, 0
	.dw 0xe0c0, 0xc12a,	0xe0ff, 0xc12a,		0x21, 0
	.dw 0xe140, 0xc12a,	0xe17f, 0xc12a,		0x21, 0
	.dw 0xe1c0, 0xc12a,	0xe1ff, 0xc12a,		0x21, 0
	.dw 0xe240, 0xc12a,	0xe27f, 0xc12a,		0x21, 0
	.dw 0xe2c0, 0xc12a,	0xe2ff, 0xc12a,		0x21, 0
	.dw 0xe340, 0xc12a,	0xe37f, 0xc12a,		0x21, 0
	.dw 0xe3c0, 0xc12a,	0xe3ff, 0xc12a,		0x21, 0
	.dw 0xe440, 0xc12a,	0xe47f, 0xc12a,		0x21, 0
	.dw 0xe4c0, 0xc12a,	0xe4ff, 0xc12a,		0x21, 0
	.dw 0xe540, 0xc12a,	0xe57f, 0xc12a,		0x21, 0
	.dw 0xe5c0, 0xc12a,	0xe5ff, 0xc12a,		0x21, 0
	.dw 0xe640, 0xc12a,	0xe67f, 0xc12a,		0x21, 0
	.dw 0xe6c0, 0xc12a,	0xe6ff, 0xc12a,		0x21, 0
	.dw 0xe740, 0xc12a,	0xe77f, 0xc12a,		0x21, 0
	.dw 0xe7c0, 0xc12a,	0xe7ff, 0xc12a,		0x21, 0
	.dw 0xe840, 0xc12a,	0xe87f, 0xc12a,		0x21, 0
	.dw 0xe8c0, 0xc12a,	0xe8ff, 0xc12a,		0x21, 0
	.dw 0xe940, 0xc12a,	0xe97f, 0xc12a,		0x21, 0
	.dw 0xe9c0, 0xc12a,	0xe9ff, 0xc12a,		0x21, 0
	.dw 0xea40, 0xc12a,	0xea7f, 0xc12a,		0x21, 0
	.dw 0xeac0, 0xc12a,	0xeaff, 0xc12a,		0x21, 0
	.dw 0xeb40, 0xc12a,	0xeb7f, 0xc12a,		0x21, 0
	.dw 0xebc0, 0xc12a,	0xebff, 0xc12a,		0x21, 0
	.dw 0xec40, 0xc12a,	0xec7f, 0xc12a,		0x21, 0
	.dw 0xecc0, 0xc12a,	0xecff, 0xc12a,		0x21, 0
	.dw 0xed40, 0xc12a,	0xed7f, 0xc12a,		0x21, 0
	.dw 0xedc0, 0xc12a,	0xedff, 0xc12a,		0x21, 0
	.dw 0xee40, 0xc12a,	0xee7f, 0xc12a,		0x21, 0
	.dw 0xeec0, 0xc12a,	0xeeff, 0xc12a,		0x21, 0
	.dw 0xef40, 0xc12a,	0xef7f, 0xc12a,		0x21, 0
	.dw 0xefc0, 0xc12a,	0xefff, 0xc12a,		0x21, 0
	.dw 0xf040, 0xc12a,	0xf07f, 0xc12a,		0x21, 0
	.dw 0xf0c0, 0xc12a,	0xf0ff, 0xc12a,		0x21, 0
	.dw 0xf140, 0xc12a,	0xf17f, 0xc12a,		0x21, 0
	.dw 0xf1c0, 0xc12a,	0xf1ff, 0xc12a,		0x21, 0
	.dw 0xf240, 0xc12a,	0xf27f, 0xc12a,		0x21, 0
	.dw 0xf2c0, 0xc12a,	0xf2ff, 0xc12a,		0x21, 0
	.dw 0xf340, 0xc12a,	0xf37f, 0xc12a,		0x21, 0
	.dw 0xf3c0, 0xc12a,	0xf3ff, 0xc12a,		0x21, 0
	.dw 0xf440, 0xc12a,	0xf47f, 0xc12a,		0x21, 0
	.dw 0xf4c0, 0xc12a,	0xf4ff, 0xc12a,		0x21, 0
	.dw 0xf540, 0xc12a,	0xf57f, 0xc12a,		0x21, 0
	.dw 0xf5c0, 0xc12a,	0xf5ff, 0xc12a,		0x21, 0
	.dw 0xf640, 0xc12a,	0xf67f, 0xc12a,		0x21, 0
	.dw 0xf6c0, 0xc12a,	0xf6ff, 0xc12a,		0x21, 0
	.dw 0xf740, 0xc12a,	0xf77f, 0xc12a,		0x21, 0
	.dw 0xf7c0, 0xc12a,	0xf7ff, 0xc12a,		0x21, 0
	.dw 0xf840, 0xc12a,	0xf87f, 0xc12a,		0x21, 0
	.dw 0xf8c0, 0xc12a,	0xf8ff, 0xc12a,		0x21, 0
	.dw 0xf940, 0xc12a,	0xf97f, 0xc12a,		0x21, 0
	.dw 0xf9c0, 0xc12a,	0x1fff, 0xc12b,		0x21, 0
	.dw 0x2040, 0xc12b,	0x207f, 0xc12b,		0x21, 0
	.dw 0x20c0, 0xc12b,	0x20ff, 0xc12b,		0x21, 0
	.dw 0x2140, 0xc12b,	0x217f, 0xc12b,		0x21, 0
	.dw 0x21c0, 0xc12b,	0x21ff, 0xc12b,		0x21, 0
	.dw 0x2240, 0xc12b,	0x227f, 0xc12b,		0x21, 0
	.dw 0x22c0, 0xc12b,	0x22ff, 0xc12b,		0x21, 0
	.dw 0x2340, 0xc12b,	0x237f, 0xc12b,		0x21, 0
	.dw 0x23c0, 0xc12b,	0x23ff, 0xc12b,		0x21, 0
	.dw 0x2440, 0xc12b,	0x247f, 0xc12b,		0x21, 0
	.dw 0x24c0, 0xc12b,	0x24ff, 0xc12b,		0x21, 0
	.dw 0x2540, 0xc12b,	0x257f, 0xc12b,		0x21, 0
	.dw 0x25c0, 0xc12b,	0x25ff, 0xc12b,		0x21, 0
	.dw 0x2640, 0xc12b,	0x267f, 0xc12b,		0x21, 0
	.dw 0x26c0, 0xc12b,	0x26ff, 0xc12b,		0x21, 0
	.dw 0x2740, 0xc12b,	0x277f, 0xc12b,		0x21, 0
	.dw 0x27c0, 0xc12b,	0x27ff, 0xc12b,		0x21, 0
	.dw 0x2840, 0xc12b,	0x287f, 0xc12b,		0x21, 0
	.dw 0x28c0, 0xc12b,	0x28ff, 0xc12b,		0x21, 0
	.dw 0x2940, 0xc12b,	0x297f, 0xc12b,		0x21, 0
	.dw 0x29c0, 0xc12b,	0x29ff, 0xc12b,		0x21, 0
	.dw 0x2a40, 0xc12b,	0x2a7f, 0xc12b,		0x21, 0
	.dw 0x2ac0, 0xc12b,	0x2aff, 0xc12b,		0x21, 0
	.dw 0x2b40, 0xc12b,	0x2b7f, 0xc12b,		0x21, 0
	.dw 0x2bc0, 0xc12b,	0x2bff, 0xc12b,		0x21, 0
	.dw 0x2c40, 0xc12b,	0x2c7f, 0xc12b,		0x21, 0
	.dw 0x2cc0, 0xc12b,	0x2cff, 0xc12b,		0x21, 0
	.dw 0x2d40, 0xc12b,	0x2d7f, 0xc12b,		0x21, 0
	.dw 0x2dc0, 0xc12b,	0x2dff, 0xc12b,		0x21, 0
	.dw 0x2e40, 0xc12b,	0x2e7f, 0xc12b,		0x21, 0
	.dw 0x2ec0, 0xc12b,	0x2eff, 0xc12b,		0x21, 0
	.dw 0x2f40, 0xc12b,	0x2f7f, 0xc12b,		0x21, 0
	.dw 0x2fc0, 0xc12b,	0x2fff, 0xc12b,		0x21, 0
	.dw 0x3040, 0xc12b,	0x307f, 0xc12b,		0x21, 0
	.dw 0x30c0, 0xc12b,	0x30ff, 0xc12b,		0x21, 0
	.dw 0x3140, 0xc12b,	0x317f, 0xc12b,		0x21, 0
	.dw 0x31c0, 0xc12b,	0x31ff, 0xc12b,		0x21, 0
	.dw 0x3240, 0xc12b,	0x327f, 0xc12b,		0x21, 0
	.dw 0x32c0, 0xc12b,	0x32ff, 0xc12b,		0x21, 0
	.dw 0x3340, 0xc12b,	0x337f, 0xc12b,		0x21, 0
	.dw 0x33c0, 0xc12b,	0x33ff, 0xc12b,		0x21, 0
	.dw 0x3440, 0xc12b,	0x347f, 0xc12b,		0x21, 0
	.dw 0x34c0, 0xc12b,	0x34ff, 0xc12b,		0x21, 0
	.dw 0x3540, 0xc12b,	0x357f, 0xc12b,		0x21, 0
	.dw 0x35c0, 0xc12b,	0x35ff, 0xc12b,		0x21, 0
	.dw 0x3640, 0xc12b,	0x367f, 0xc12b,		0x21, 0
	.dw 0x36c0, 0xc12b,	0x36ff, 0xc12b,		0x21, 0
	.dw 0x3740, 0xc12b,	0x377f, 0xc12b,		0x21, 0
	.dw 0x37c0, 0xc12b,	0x37ff, 0xc12b,		0x21, 0
	.dw 0x3840, 0xc12b,	0x387f, 0xc12b,		0x21, 0
	.dw 0x38c0, 0xc12b,	0x38ff, 0xc12b,		0x21, 0
	.dw 0x3940, 0xc12b,	0x397f, 0xc12b,		0x21, 0
	.dw 0x39c0, 0xc12b,	0xffff, 0xc12b,		0x21, 0
	.dw 0x0040, 0xc12c,	0x007f, 0xc12c,		0x21, 0
	.dw 0x00c0, 0xc12c,	0x00ff, 0xc12c,		0x21, 0
	.dw 0x0140, 0xc12c,	0x017f, 0xc12c,		0x21, 0
	.dw 0x01c0, 0xc12c,	0x01ff, 0xc12c,		0x21, 0
	.dw 0x0240, 0xc12c,	0x027f, 0xc12c,		0x21, 0
	.dw 0x02c0, 0xc12c,	0x02ff, 0xc12c,		0x21, 0
	.dw 0x0340, 0xc12c,	0x037f, 0xc12c,		0x21, 0
	.dw 0x03c0, 0xc12c,	0x03ff, 0xc12c,		0x21, 0
	.dw 0x0440, 0xc12c,	0x047f, 0xc12c,		0x21, 0
	.dw 0x04c0, 0xc12c,	0x04ff, 0xc12c,		0x21, 0
	.dw 0x0540, 0xc12c,	0x057f, 0xc12c,		0x21, 0
	.dw 0x05c0, 0xc12c,	0x05ff, 0xc12c,		0x21, 0
	.dw 0x0640, 0xc12c,	0x067f, 0xc12c,		0x21, 0
	.dw 0x06c0, 0xc12c,	0x06ff, 0xc12c,		0x21, 0
	.dw 0x0740, 0xc12c,	0x077f, 0xc12c,		0x21, 0
	.dw 0x07c0, 0xc12c,	0x07ff, 0xc12c,		0x21, 0
	.dw 0x0840, 0xc12c,	0x087f, 0xc12c,		0x21, 0
	.dw 0x08c0, 0xc12c,	0x08ff, 0xc12c,		0x21, 0
	.dw 0x0940, 0xc12c,	0x097f, 0xc12c,		0x21, 0
	.dw 0x09c0, 0xc12c,	0x09ff, 0xc12c,		0x21, 0
	.dw 0x0a40, 0xc12c,	0x0a7f, 0xc12c,		0x21, 0
	.dw 0x0ac0, 0xc12c,	0x0aff, 0xc12c,		0x21, 0
	.dw 0x0b40, 0xc12c,	0x0b7f, 0xc12c,		0x21, 0
	.dw 0x0bc0, 0xc12c,	0x0bff, 0xc12c,		0x21, 0
	.dw 0x0c40, 0xc12c,	0x0c7f, 0xc12c,		0x21, 0
	.dw 0x0cc0, 0xc12c,	0x0cff, 0xc12c,		0x21, 0
	.dw 0x0d40, 0xc12c,	0x0d7f, 0xc12c,		0x21, 0
	.dw 0x0dc0, 0xc12c,	0x0dff, 0xc12c,		0x21, 0
	.dw 0x0e40, 0xc12c,	0x0e7f, 0xc12c,		0x21, 0
	.dw 0x0ec0, 0xc12c,	0x0eff, 0xc12c,		0x21, 0
	.dw 0x0f40, 0xc12c,	0x0f7f, 0xc12c,		0x21, 0
	.dw 0x0fc0, 0xc12c,	0x0fff, 0xc12c,		0x21, 0
	.dw 0x1040, 0xc12c,	0x107f, 0xc12c,		0x21, 0
	.dw 0x10c0, 0xc12c,	0x10ff, 0xc12c,		0x21, 0
	.dw 0x1140, 0xc12c,	0x117f, 0xc12c,		0x21, 0
	.dw 0x11c0, 0xc12c,	0x11ff, 0xc12c,		0x21, 0
	.dw 0x1240, 0xc12c,	0x127f, 0xc12c,		0x21, 0
	.dw 0x12c0, 0xc12c,	0x12ff, 0xc12c,		0x21, 0
	.dw 0x1340, 0xc12c,	0x137f, 0xc12c,		0x21, 0
	.dw 0x13c0, 0xc12c,	0x13ff, 0xc12c,		0x21, 0
	.dw 0x1440, 0xc12c,	0x147f, 0xc12c,		0x21, 0
	.dw 0x14c0, 0xc12c,	0x14ff, 0xc12c,		0x21, 0
	.dw 0x1540, 0xc12c,	0x157f, 0xc12c,		0x21, 0
	.dw 0x15c0, 0xc12c,	0x15ff, 0xc12c,		0x21, 0
	.dw 0x1640, 0xc12c,	0x167f, 0xc12c,		0x21, 0
	.dw 0x16c0, 0xc12c,	0x16ff, 0xc12c,		0x21, 0
	.dw 0x1740, 0xc12c,	0x177f, 0xc12c,		0x21, 0
	.dw 0x17c0, 0xc12c,	0x17ff, 0xc12c,		0x21, 0
	.dw 0x1840, 0xc12c,	0x187f, 0xc12c,		0x21, 0
	.dw 0x18c0, 0xc12c,	0x18ff, 0xc12c,		0x21, 0
	.dw 0x1940, 0xc12c,	0x197f, 0xc12c,		0x21, 0
	.dw 0x19c0, 0xc12c,	0x1fff, 0xc12c,		0x21, 0
	.dw 0x2040, 0xc12c,	0x207f, 0xc12c,		0x21, 0
	.dw 0x20c0, 0xc12c,	0x20ff, 0xc12c,		0x21, 0
	.dw 0x2140, 0xc12c,	0x217f, 0xc12c,		0x21, 0
	.dw 0x21c0, 0xc12c,	0x21ff, 0xc12c,		0x21, 0
	.dw 0x2240, 0xc12c,	0x227f, 0xc12c,		0x21, 0
	.dw 0x22c0, 0xc12c,	0x22ff, 0xc12c,		0x21, 0
	.dw 0x2340, 0xc12c,	0x237f, 0xc12c,		0x21, 0
	.dw 0x23c0, 0xc12c,	0x23ff, 0xc12c,		0x21, 0
	.dw 0x2440, 0xc12c,	0x247f, 0xc12c,		0x21, 0
	.dw 0x24c0, 0xc12c,	0x24ff, 0xc12c,		0x21, 0
	.dw 0x2540, 0xc12c,	0x257f, 0xc12c,		0x21, 0
	.dw 0x25c0, 0xc12c,	0x25ff, 0xc12c,		0x21, 0
	.dw 0x2640, 0xc12c,	0x267f, 0xc12c,		0x21, 0
	.dw 0x26c0, 0xc12c,	0x26ff, 0xc12c,		0x21, 0
	.dw 0x2740, 0xc12c,	0x277f, 0xc12c,		0x21, 0
	.dw 0x27c0, 0xc12c,	0x27ff, 0xc12c,		0x21, 0
	.dw 0x2840, 0xc12c,	0x287f, 0xc12c,		0x21, 0
	.dw 0x28c0, 0xc12c,	0x28ff, 0xc12c,		0x21, 0
	.dw 0x2940, 0xc12c,	0x297f, 0xc12c,		0x21, 0
	.dw 0x29c0, 0xc12c,	0x29ff, 0xc12c,		0x21, 0
	.dw 0x2a40, 0xc12c,	0x2a7f, 0xc12c,		0x21, 0
	.dw 0x2ac0, 0xc12c,	0x2aff, 0xc12c,		0x21, 0
	.dw 0x2b40, 0xc12c,	0x2b7f, 0xc12c,		0x21, 0
	.dw 0x2bc0, 0xc12c,	0x2bff, 0xc12c,		0x21, 0
	.dw 0x2c40, 0xc12c,	0x2c7f, 0xc12c,		0x21, 0
	.dw 0x2cc0, 0xc12c,	0x2cff, 0xc12c,		0x21, 0
	.dw 0x2d40, 0xc12c,	0x2d7f, 0xc12c,		0x21, 0
	.dw 0x2dc0, 0xc12c,	0x2dff, 0xc12c,		0x21, 0
	.dw 0x2e40, 0xc12c,	0x2e7f, 0xc12c,		0x21, 0
	.dw 0x2ec0, 0xc12c,	0x2eff, 0xc12c,		0x21, 0
	.dw 0x2f40, 0xc12c,	0x2f7f, 0xc12c,		0x21, 0
	.dw 0x2fc0, 0xc12c,	0x2fff, 0xc12c,		0x21, 0
	.dw 0x3040, 0xc12c,	0x307f, 0xc12c,		0x21, 0
	.dw 0x30c0, 0xc12c,	0x30ff, 0xc12c,		0x21, 0
	.dw 0x3140, 0xc12c,	0x317f, 0xc12c,		0x21, 0
	.dw 0x31c0, 0xc12c,	0x31ff, 0xc12c,		0x21, 0
	.dw 0x3240, 0xc12c,	0x327f, 0xc12c,		0x21, 0
	.dw 0x32c0, 0xc12c,	0x32ff, 0xc12c,		0x21, 0
	.dw 0x3340, 0xc12c,	0x337f, 0xc12c,		0x21, 0
	.dw 0x33c0, 0xc12c,	0x33ff, 0xc12c,		0x21, 0
	.dw 0x3440, 0xc12c,	0x347f, 0xc12c,		0x21, 0
	.dw 0x34c0, 0xc12c,	0x34ff, 0xc12c,		0x21, 0
	.dw 0x3540, 0xc12c,	0x357f, 0xc12c,		0x21, 0
	.dw 0x35c0, 0xc12c,	0x35ff, 0xc12c,		0x21, 0
	.dw 0x3640, 0xc12c,	0x367f, 0xc12c,		0x21, 0
	.dw 0x36c0, 0xc12c,	0x36ff, 0xc12c,		0x21, 0
	.dw 0x3740, 0xc12c,	0x377f, 0xc12c,		0x21, 0
	.dw 0x37c0, 0xc12c,	0x37ff, 0xc12c,		0x21, 0
	.dw 0x3840, 0xc12c,	0x387f, 0xc12c,		0x21, 0
	.dw 0x38c0, 0xc12c,	0x38ff, 0xc12c,		0x21, 0
	.dw 0x3940, 0xc12c,	0x397f, 0xc12c,		0x21, 0
	.dw 0x39c0, 0xc12c,	0x3fff, 0xc12c,		0x21, 0
	.dw 0x4040, 0xc12c,	0x407f, 0xc12c,		0x21, 0
	.dw 0x40c0, 0xc12c,	0x40ff, 0xc12c,		0x21, 0
	.dw 0x4140, 0xc12c,	0x417f, 0xc12c,		0x21, 0
	.dw 0x41c0, 0xc12c,	0x41ff, 0xc12c,		0x21, 0
	.dw 0x4240, 0xc12c,	0x427f, 0xc12c,		0x21, 0
	.dw 0x42c0, 0xc12c,	0x42ff, 0xc12c,		0x21, 0
	.dw 0x4340, 0xc12c,	0x437f, 0xc12c,		0x21, 0
	.dw 0x43c0, 0xc12c,	0x43ff, 0xc12c,		0x21, 0
	.dw 0x4440, 0xc12c,	0x447f, 0xc12c,		0x21, 0
	.dw 0x44c0, 0xc12c,	0x44ff, 0xc12c,		0x21, 0
	.dw 0x4540, 0xc12c,	0x457f, 0xc12c,		0x21, 0
	.dw 0x45c0, 0xc12c,	0x45ff, 0xc12c,		0x21, 0
	.dw 0x4640, 0xc12c,	0x467f, 0xc12c,		0x21, 0
	.dw 0x46c0, 0xc12c,	0x46ff, 0xc12c,		0x21, 0
	.dw 0x4740, 0xc12c,	0x477f, 0xc12c,		0x21, 0
	.dw 0x47c0, 0xc12c,	0x47ff, 0xc12c,		0x21, 0
	.dw 0x4840, 0xc12c,	0x487f, 0xc12c,		0x21, 0
	.dw 0x48c0, 0xc12c,	0x48ff, 0xc12c,		0x21, 0
	.dw 0x4940, 0xc12c,	0x497f, 0xc12c,		0x21, 0
	.dw 0x49c0, 0xc12c,	0x49ff, 0xc12c,		0x21, 0
	.dw 0x4a40, 0xc12c,	0x4a7f, 0xc12c,		0x21, 0
	.dw 0x4ac0, 0xc12c,	0x4aff, 0xc12c,		0x21, 0
	.dw 0x4b40, 0xc12c,	0x4b7f, 0xc12c,		0x21, 0
	.dw 0x4bc0, 0xc12c,	0x4bff, 0xc12c,		0x21, 0
	.dw 0x4c40, 0xc12c,	0x4c7f, 0xc12c,		0x21, 0
	.dw 0x4cc0, 0xc12c,	0x4cff, 0xc12c,		0x21, 0
	.dw 0x4d40, 0xc12c,	0x4d7f, 0xc12c,		0x21, 0
	.dw 0x4dc0, 0xc12c,	0x4dff, 0xc12c,		0x21, 0
	.dw 0x4e40, 0xc12c,	0x4e7f, 0xc12c,		0x21, 0
	.dw 0x4ec0, 0xc12c,	0x4eff, 0xc12c,		0x21, 0
	.dw 0x4f40, 0xc12c,	0x4f7f, 0xc12c,		0x21, 0
	.dw 0x4fc0, 0xc12c,	0x4fff, 0xc12c,		0x21, 0
	.dw 0x5040, 0xc12c,	0x507f, 0xc12c,		0x21, 0
	.dw 0x50c0, 0xc12c,	0x50ff, 0xc12c,		0x21, 0
	.dw 0x5140, 0xc12c,	0x517f, 0xc12c,		0x21, 0
	.dw 0x51c0, 0xc12c,	0x51ff, 0xc12c,		0x21, 0
	.dw 0x5240, 0xc12c,	0x527f, 0xc12c,		0x21, 0
	.dw 0x52c0, 0xc12c,	0x52ff, 0xc12c,		0x21, 0
	.dw 0x5340, 0xc12c,	0x537f, 0xc12c,		0x21, 0
	.dw 0x53c0, 0xc12c,	0x53ff, 0xc12c,		0x21, 0
	.dw 0x5440, 0xc12c,	0x547f, 0xc12c,		0x21, 0
	.dw 0x54c0, 0xc12c,	0x54ff, 0xc12c,		0x21, 0
	.dw 0x5540, 0xc12c,	0x557f, 0xc12c,		0x21, 0
	.dw 0x55c0, 0xc12c,	0x55ff, 0xc12c,		0x21, 0
	.dw 0x5640, 0xc12c,	0x567f, 0xc12c,		0x21, 0
	.dw 0x56c0, 0xc12c,	0x56ff, 0xc12c,		0x21, 0
	.dw 0x5740, 0xc12c,	0x577f, 0xc12c,		0x21, 0
	.dw 0x57c0, 0xc12c,	0x57ff, 0xc12c,		0x21, 0
	.dw 0x5840, 0xc12c,	0x587f, 0xc12c,		0x21, 0
	.dw 0x58c0, 0xc12c,	0x58ff, 0xc12c,		0x21, 0
	.dw 0x5940, 0xc12c,	0x597f, 0xc12c,		0x21, 0
	.dw 0x59c0, 0xc12c,	0x5fff, 0xc12c,		0x21, 0
	.dw 0x6040, 0xc12c,	0x607f, 0xc12c,		0x21, 0
	.dw 0x60c0, 0xc12c,	0x60ff, 0xc12c,		0x21, 0
	.dw 0x6140, 0xc12c,	0x617f, 0xc12c,		0x21, 0
	.dw 0x61c0, 0xc12c,	0x61ff, 0xc12c,		0x21, 0
	.dw 0x6240, 0xc12c,	0x627f, 0xc12c,		0x21, 0
	.dw 0x62c0, 0xc12c,	0x62ff, 0xc12c,		0x21, 0
	.dw 0x6340, 0xc12c,	0x637f, 0xc12c,		0x21, 0
	.dw 0x63c0, 0xc12c,	0x63ff, 0xc12c,		0x21, 0
	.dw 0x6440, 0xc12c,	0x647f, 0xc12c,		0x21, 0
	.dw 0x64c0, 0xc12c,	0x64ff, 0xc12c,		0x21, 0
	.dw 0x6540, 0xc12c,	0x657f, 0xc12c,		0x21, 0
	.dw 0x65c0, 0xc12c,	0x65ff, 0xc12c,		0x21, 0
	.dw 0x6640, 0xc12c,	0x667f, 0xc12c,		0x21, 0
	.dw 0x66c0, 0xc12c,	0x66ff, 0xc12c,		0x21, 0
	.dw 0x6740, 0xc12c,	0x677f, 0xc12c,		0x21, 0
	.dw 0x67c0, 0xc12c,	0x67ff, 0xc12c,		0x21, 0
	.dw 0x6840, 0xc12c,	0x687f, 0xc12c,		0x21, 0
	.dw 0x68c0, 0xc12c,	0x68ff, 0xc12c,		0x21, 0
	.dw 0x6940, 0xc12c,	0x697f, 0xc12c,		0x21, 0
	.dw 0x69c0, 0xc12c,	0x69ff, 0xc12c,		0x21, 0
	.dw 0x6a40, 0xc12c,	0x6a7f, 0xc12c,		0x21, 0
	.dw 0x6ac0, 0xc12c,	0x6aff, 0xc12c,		0x21, 0
	.dw 0x6b40, 0xc12c,	0x6b7f, 0xc12c,		0x21, 0
	.dw 0x6bc0, 0xc12c,	0x6bff, 0xc12c,		0x21, 0
	.dw 0x6c40, 0xc12c,	0x6c7f, 0xc12c,		0x21, 0
	.dw 0x6cc0, 0xc12c,	0x6cff, 0xc12c,		0x21, 0
	.dw 0x6d40, 0xc12c,	0x6d7f, 0xc12c,		0x21, 0
	.dw 0x6dc0, 0xc12c,	0x6dff, 0xc12c,		0x21, 0
	.dw 0x6e40, 0xc12c,	0x6e7f, 0xc12c,		0x21, 0
	.dw 0x6ec0, 0xc12c,	0x6eff, 0xc12c,		0x21, 0
	.dw 0x6f40, 0xc12c,	0x6f7f, 0xc12c,		0x21, 0
	.dw 0x6fc0, 0xc12c,	0x6fff, 0xc12c,		0x21, 0
	.dw 0x7040, 0xc12c,	0x707f, 0xc12c,		0x21, 0
	.dw 0x70c0, 0xc12c,	0x70ff, 0xc12c,		0x21, 0
	.dw 0x7140, 0xc12c,	0x717f, 0xc12c,		0x21, 0
	.dw 0x71c0, 0xc12c,	0x71ff, 0xc12c,		0x21, 0
	.dw 0x7240, 0xc12c,	0x727f, 0xc12c,		0x21, 0
	.dw 0x72c0, 0xc12c,	0x72ff, 0xc12c,		0x21, 0
	.dw 0x7340, 0xc12c,	0x737f, 0xc12c,		0x21, 0
	.dw 0x73c0, 0xc12c,	0x73ff, 0xc12c,		0x21, 0
	.dw 0x7440, 0xc12c,	0x747f, 0xc12c,		0x21, 0
	.dw 0x74c0, 0xc12c,	0x74ff, 0xc12c,		0x21, 0
	.dw 0x7540, 0xc12c,	0x757f, 0xc12c,		0x21, 0
	.dw 0x75c0, 0xc12c,	0x75ff, 0xc12c,		0x21, 0
	.dw 0x7640, 0xc12c,	0x767f, 0xc12c,		0x21, 0
	.dw 0x76c0, 0xc12c,	0x76ff, 0xc12c,		0x21, 0
	.dw 0x7740, 0xc12c,	0x777f, 0xc12c,		0x21, 0
	.dw 0x77c0, 0xc12c,	0x77ff, 0xc12c,		0x21, 0
	.dw 0x7840, 0xc12c,	0x787f, 0xc12c,		0x21, 0
	.dw 0x78c0, 0xc12c,	0x78ff, 0xc12c,		0x21, 0
	.dw 0x7940, 0xc12c,	0x797f, 0xc12c,		0x21, 0
	.dw 0x79c0, 0xc12c,	0x7fff, 0xc12c,		0x21, 0
	.dw 0x8040, 0xc12c,	0x807f, 0xc12c,		0x21, 0
	.dw 0x80c0, 0xc12c,	0x80ff, 0xc12c,		0x21, 0
	.dw 0x8140, 0xc12c,	0x817f, 0xc12c,		0x21, 0
	.dw 0x81c0, 0xc12c,	0x81ff, 0xc12c,		0x21, 0
	.dw 0x8240, 0xc12c,	0x827f, 0xc12c,		0x21, 0
	.dw 0x82c0, 0xc12c,	0x82ff, 0xc12c,		0x21, 0
	.dw 0x8340, 0xc12c,	0x837f, 0xc12c,		0x21, 0
	.dw 0x83c0, 0xc12c,	0x83ff, 0xc12c,		0x21, 0
	.dw 0x8440, 0xc12c,	0x847f, 0xc12c,		0x21, 0
	.dw 0x84c0, 0xc12c,	0x84ff, 0xc12c,		0x21, 0
	.dw 0x8540, 0xc12c,	0x857f, 0xc12c,		0x21, 0
	.dw 0x85c0, 0xc12c,	0x85ff, 0xc12c,		0x21, 0
	.dw 0x8640, 0xc12c,	0x867f, 0xc12c,		0x21, 0
	.dw 0x86c0, 0xc12c,	0x86ff, 0xc12c,		0x21, 0
	.dw 0x8740, 0xc12c,	0x877f, 0xc12c,		0x21, 0
	.dw 0x87c0, 0xc12c,	0x87ff, 0xc12c,		0x21, 0
	.dw 0x8840, 0xc12c,	0x887f, 0xc12c,		0x21, 0
	.dw 0x88c0, 0xc12c,	0x88ff, 0xc12c,		0x21, 0
	.dw 0x8940, 0xc12c,	0x897f, 0xc12c,		0x21, 0
	.dw 0x89c0, 0xc12c,	0x89ff, 0xc12c,		0x21, 0
	.dw 0x8a40, 0xc12c,	0x8a7f, 0xc12c,		0x21, 0
	.dw 0x8ac0, 0xc12c,	0x8aff, 0xc12c,		0x21, 0
	.dw 0x8b40, 0xc12c,	0x8b7f, 0xc12c,		0x21, 0
	.dw 0x8bc0, 0xc12c,	0x8bff, 0xc12c,		0x21, 0
	.dw 0x8c40, 0xc12c,	0x8c7f, 0xc12c,		0x21, 0
	.dw 0x8cc0, 0xc12c,	0x8cff, 0xc12c,		0x21, 0
	.dw 0x8d40, 0xc12c,	0x8d7f, 0xc12c,		0x21, 0
	.dw 0x8dc0, 0xc12c,	0x8dff, 0xc12c,		0x21, 0
	.dw 0x8e40, 0xc12c,	0x8e7f, 0xc12c,		0x21, 0
	.dw 0x8ec0, 0xc12c,	0x8eff, 0xc12c,		0x21, 0
	.dw 0x8f40, 0xc12c,	0x8f7f, 0xc12c,		0x21, 0
	.dw 0x8fc0, 0xc12c,	0x8fff, 0xc12c,		0x21, 0
	.dw 0x9040, 0xc12c,	0x907f, 0xc12c,		0x21, 0
	.dw 0x90c0, 0xc12c,	0x90ff, 0xc12c,		0x21, 0
	.dw 0x9140, 0xc12c,	0x917f, 0xc12c,		0x21, 0
	.dw 0x91c0, 0xc12c,	0x91ff, 0xc12c,		0x21, 0
	.dw 0x9240, 0xc12c,	0x927f, 0xc12c,		0x21, 0
	.dw 0x92c0, 0xc12c,	0x92ff, 0xc12c,		0x21, 0
	.dw 0x9340, 0xc12c,	0x937f, 0xc12c,		0x21, 0
	.dw 0x93c0, 0xc12c,	0x93ff, 0xc12c,		0x21, 0
	.dw 0x9440, 0xc12c,	0x947f, 0xc12c,		0x21, 0
	.dw 0x94c0, 0xc12c,	0x94ff, 0xc12c,		0x21, 0
	.dw 0x9540, 0xc12c,	0x957f, 0xc12c,		0x21, 0
	.dw 0x95c0, 0xc12c,	0x95ff, 0xc12c,		0x21, 0
	.dw 0x9640, 0xc12c,	0x967f, 0xc12c,		0x21, 0
	.dw 0x96c0, 0xc12c,	0x96ff, 0xc12c,		0x21, 0
	.dw 0x9740, 0xc12c,	0x977f, 0xc12c,		0x21, 0
	.dw 0x97c0, 0xc12c,	0x97ff, 0xc12c,		0x21, 0
	.dw 0x9840, 0xc12c,	0x987f, 0xc12c,		0x21, 0
	.dw 0x98c0, 0xc12c,	0x98ff, 0xc12c,		0x21, 0
	.dw 0x9940, 0xc12c,	0x997f, 0xc12c,		0x21, 0
	.dw 0x99c0, 0xc12c,	0x9fff, 0xc12c,		0x21, 0
	.dw 0xa040, 0xc12c,	0xa07f, 0xc12c,		0x21, 0
	.dw 0xa0c0, 0xc12c,	0xa0ff, 0xc12c,		0x21, 0
	.dw 0xa140, 0xc12c,	0xa17f, 0xc12c,		0x21, 0
	.dw 0xa1c0, 0xc12c,	0xa1ff, 0xc12c,		0x21, 0
	.dw 0xa240, 0xc12c,	0xa27f, 0xc12c,		0x21, 0
	.dw 0xa2c0, 0xc12c,	0xa2ff, 0xc12c,		0x21, 0
	.dw 0xa340, 0xc12c,	0xa37f, 0xc12c,		0x21, 0
	.dw 0xa3c0, 0xc12c,	0xa3ff, 0xc12c,		0x21, 0
	.dw 0xa440, 0xc12c,	0xa47f, 0xc12c,		0x21, 0
	.dw 0xa4c0, 0xc12c,	0xa4ff, 0xc12c,		0x21, 0
	.dw 0xa540, 0xc12c,	0xa57f, 0xc12c,		0x21, 0
	.dw 0xa5c0, 0xc12c,	0xa5ff, 0xc12c,		0x21, 0
	.dw 0xa640, 0xc12c,	0xa67f, 0xc12c,		0x21, 0
	.dw 0xa6c0, 0xc12c,	0xa6ff, 0xc12c,		0x21, 0
	.dw 0xa740, 0xc12c,	0xa77f, 0xc12c,		0x21, 0
	.dw 0xa7c0, 0xc12c,	0xa7ff, 0xc12c,		0x21, 0
	.dw 0xa840, 0xc12c,	0xa87f, 0xc12c,		0x21, 0
	.dw 0xa8c0, 0xc12c,	0xa8ff, 0xc12c,		0x21, 0
	.dw 0xa940, 0xc12c,	0xa97f, 0xc12c,		0x21, 0
	.dw 0xa9c0, 0xc12c,	0xa9ff, 0xc12c,		0x21, 0
	.dw 0xaa40, 0xc12c,	0xaa7f, 0xc12c,		0x21, 0
	.dw 0xaac0, 0xc12c,	0xaaff, 0xc12c,		0x21, 0
	.dw 0xab40, 0xc12c,	0xab7f, 0xc12c,		0x21, 0
	.dw 0xabc0, 0xc12c,	0xabff, 0xc12c,		0x21, 0
	.dw 0xac40, 0xc12c,	0xac7f, 0xc12c,		0x21, 0
	.dw 0xacc0, 0xc12c,	0xacff, 0xc12c,		0x21, 0
	.dw 0xad40, 0xc12c,	0xad7f, 0xc12c,		0x21, 0
	.dw 0xadc0, 0xc12c,	0xadff, 0xc12c,		0x21, 0
	.dw 0xae40, 0xc12c,	0xae7f, 0xc12c,		0x21, 0
	.dw 0xaec0, 0xc12c,	0xaeff, 0xc12c,		0x21, 0
	.dw 0xaf40, 0xc12c,	0xaf7f, 0xc12c,		0x21, 0
	.dw 0xafc0, 0xc12c,	0xafff, 0xc12c,		0x21, 0
	.dw 0xb040, 0xc12c,	0xb07f, 0xc12c,		0x21, 0
	.dw 0xb0c0, 0xc12c,	0xb0ff, 0xc12c,		0x21, 0
	.dw 0xb140, 0xc12c,	0xb17f, 0xc12c,		0x21, 0
	.dw 0xb1c0, 0xc12c,	0xb1ff, 0xc12c,		0x21, 0
	.dw 0xb240, 0xc12c,	0xb27f, 0xc12c,		0x21, 0
	.dw 0xb2c0, 0xc12c,	0xb2ff, 0xc12c,		0x21, 0
	.dw 0xb340, 0xc12c,	0xb37f, 0xc12c,		0x21, 0
	.dw 0xb3c0, 0xc12c,	0xb3ff, 0xc12c,		0x21, 0
	.dw 0xb440, 0xc12c,	0xb47f, 0xc12c,		0x21, 0
	.dw 0xb4c0, 0xc12c,	0xb4ff, 0xc12c,		0x21, 0
	.dw 0xb540, 0xc12c,	0xb57f, 0xc12c,		0x21, 0
	.dw 0xb5c0, 0xc12c,	0xb5ff, 0xc12c,		0x21, 0
	.dw 0xb640, 0xc12c,	0xb67f, 0xc12c,		0x21, 0
	.dw 0xb6c0, 0xc12c,	0xb6ff, 0xc12c,		0x21, 0
	.dw 0xb740, 0xc12c,	0xb77f, 0xc12c,		0x21, 0
	.dw 0xb7c0, 0xc12c,	0xb7ff, 0xc12c,		0x21, 0
	.dw 0xb840, 0xc12c,	0xb87f, 0xc12c,		0x21, 0
	.dw 0xb8c0, 0xc12c,	0xb8ff, 0xc12c,		0x21, 0
	.dw 0xb940, 0xc12c,	0xb97f, 0xc12c,		0x21, 0
	.dw 0xb9c0, 0xc12c,	0xbfff, 0xc12c,		0x21, 0
	.dw 0xc040, 0xc12c,	0xc07f, 0xc12c,		0x21, 0
	.dw 0xc0c0, 0xc12c,	0xc0ff, 0xc12c,		0x21, 0
	.dw 0xc140, 0xc12c,	0xc17f, 0xc12c,		0x21, 0
	.dw 0xc1c0, 0xc12c,	0xc1ff, 0xc12c,		0x21, 0
	.dw 0xc240, 0xc12c,	0xc27f, 0xc12c,		0x21, 0
	.dw 0xc2c0, 0xc12c,	0xc2ff, 0xc12c,		0x21, 0
	.dw 0xc340, 0xc12c,	0xc37f, 0xc12c,		0x21, 0
	.dw 0xc3c0, 0xc12c,	0xc3ff, 0xc12c,		0x21, 0
	.dw 0xc440, 0xc12c,	0xc47f, 0xc12c,		0x21, 0
	.dw 0xc4c0, 0xc12c,	0xc4ff, 0xc12c,		0x21, 0
	.dw 0xc540, 0xc12c,	0xc57f, 0xc12c,		0x21, 0
	.dw 0xc5c0, 0xc12c,	0xc5ff, 0xc12c,		0x21, 0
	.dw 0xc640, 0xc12c,	0xc67f, 0xc12c,		0x21, 0
	.dw 0xc6c0, 0xc12c,	0xc6ff, 0xc12c,		0x21, 0
	.dw 0xc740, 0xc12c,	0xc77f, 0xc12c,		0x21, 0
	.dw 0xc7c0, 0xc12c,	0xc7ff, 0xc12c,		0x21, 0
	.dw 0xc840, 0xc12c,	0xc87f, 0xc12c,		0x21, 0
	.dw 0xc8c0, 0xc12c,	0xc8ff, 0xc12c,		0x21, 0
	.dw 0xc940, 0xc12c,	0xc97f, 0xc12c,		0x21, 0
	.dw 0xc9c0, 0xc12c,	0xc9ff, 0xc12c,		0x21, 0
	.dw 0xca40, 0xc12c,	0xca7f, 0xc12c,		0x21, 0
	.dw 0xcac0, 0xc12c,	0xcaff, 0xc12c,		0x21, 0
	.dw 0xcb40, 0xc12c,	0xcb7f, 0xc12c,		0x21, 0
	.dw 0xcbc0, 0xc12c,	0xcbff, 0xc12c,		0x21, 0
	.dw 0xcc40, 0xc12c,	0xcc7f, 0xc12c,		0x21, 0
	.dw 0xccc0, 0xc12c,	0xccff, 0xc12c,		0x21, 0
	.dw 0xcd40, 0xc12c,	0xcd7f, 0xc12c,		0x21, 0
	.dw 0xcdc0, 0xc12c,	0xcdff, 0xc12c,		0x21, 0
	.dw 0xce40, 0xc12c,	0xce7f, 0xc12c,		0x21, 0
	.dw 0xcec0, 0xc12c,	0xceff, 0xc12c,		0x21, 0
	.dw 0xcf40, 0xc12c,	0xcf7f, 0xc12c,		0x21, 0
	.dw 0xcfc0, 0xc12c,	0xcfff, 0xc12c,		0x21, 0
	.dw 0xd040, 0xc12c,	0xd07f, 0xc12c,		0x21, 0
	.dw 0xd0c0, 0xc12c,	0xd0ff, 0xc12c,		0x21, 0
	.dw 0xd140, 0xc12c,	0xd17f, 0xc12c,		0x21, 0
	.dw 0xd1c0, 0xc12c,	0xd1ff, 0xc12c,		0x21, 0
	.dw 0xd240, 0xc12c,	0xd27f, 0xc12c,		0x21, 0
	.dw 0xd2c0, 0xc12c,	0xd2ff, 0xc12c,		0x21, 0
	.dw 0xd340, 0xc12c,	0xd37f, 0xc12c,		0x21, 0
	.dw 0xd3c0, 0xc12c,	0xd3ff, 0xc12c,		0x21, 0
	.dw 0xd440, 0xc12c,	0xd47f, 0xc12c,		0x21, 0
	.dw 0xd4c0, 0xc12c,	0xd4ff, 0xc12c,		0x21, 0
	.dw 0xd540, 0xc12c,	0xd57f, 0xc12c,		0x21, 0
	.dw 0xd5c0, 0xc12c,	0xd5ff, 0xc12c,		0x21, 0
	.dw 0xd640, 0xc12c,	0xd67f, 0xc12c,		0x21, 0
	.dw 0xd6c0, 0xc12c,	0xd6ff, 0xc12c,		0x21, 0
	.dw 0xd740, 0xc12c,	0xd77f, 0xc12c,		0x21, 0
	.dw 0xd7c0, 0xc12c,	0xd7ff, 0xc12c,		0x21, 0
	.dw 0xd840, 0xc12c,	0xd87f, 0xc12c,		0x21, 0
	.dw 0xd8c0, 0xc12c,	0xd8ff, 0xc12c,		0x21, 0
	.dw 0xd940, 0xc12c,	0xd97f, 0xc12c,		0x21, 0
	.dw 0xd9c0, 0xc12c,	0xdfff, 0xc12c,		0x21, 0
	.dw 0xe040, 0xc12c,	0xe07f, 0xc12c,		0x21, 0
	.dw 0xe0c0, 0xc12c,	0xe0ff, 0xc12c,		0x21, 0
	.dw 0xe140, 0xc12c,	0xe17f, 0xc12c,		0x21, 0
	.dw 0xe1c0, 0xc12c,	0xe1ff, 0xc12c,		0x21, 0
	.dw 0xe240, 0xc12c,	0xe27f, 0xc12c,		0x21, 0
	.dw 0xe2c0, 0xc12c,	0xe2ff, 0xc12c,		0x21, 0
	.dw 0xe340, 0xc12c,	0xe37f, 0xc12c,		0x21, 0
	.dw 0xe3c0, 0xc12c,	0xe3ff, 0xc12c,		0x21, 0
	.dw 0xe440, 0xc12c,	0xe47f, 0xc12c,		0x21, 0
	.dw 0xe4c0, 0xc12c,	0xe4ff, 0xc12c,		0x21, 0
	.dw 0xe540, 0xc12c,	0xe57f, 0xc12c,		0x21, 0
	.dw 0xe5c0, 0xc12c,	0xe5ff, 0xc12c,		0x21, 0
	.dw 0xe640, 0xc12c,	0xe67f, 0xc12c,		0x21, 0
	.dw 0xe6c0, 0xc12c,	0xe6ff, 0xc12c,		0x21, 0
	.dw 0xe740, 0xc12c,	0xe77f, 0xc12c,		0x21, 0
	.dw 0xe7c0, 0xc12c,	0xe7ff, 0xc12c,		0x21, 0
	.dw 0xe840, 0xc12c,	0xe87f, 0xc12c,		0x21, 0
	.dw 0xe8c0, 0xc12c,	0xe8ff, 0xc12c,		0x21, 0
	.dw 0xe940, 0xc12c,	0xe97f, 0xc12c,		0x21, 0
	.dw 0xe9c0, 0xc12c,	0xe9ff, 0xc12c,		0x21, 0
	.dw 0xea40, 0xc12c,	0xea7f, 0xc12c,		0x21, 0
	.dw 0xeac0, 0xc12c,	0xeaff, 0xc12c,		0x21, 0
	.dw 0xeb40, 0xc12c,	0xeb7f, 0xc12c,		0x21, 0
	.dw 0xebc0, 0xc12c,	0xebff, 0xc12c,		0x21, 0
	.dw 0xec40, 0xc12c,	0xec7f, 0xc12c,		0x21, 0
	.dw 0xecc0, 0xc12c,	0xecff, 0xc12c,		0x21, 0
	.dw 0xed40, 0xc12c,	0xed7f, 0xc12c,		0x21, 0
	.dw 0xedc0, 0xc12c,	0xedff, 0xc12c,		0x21, 0
	.dw 0xee40, 0xc12c,	0xee7f, 0xc12c,		0x21, 0
	.dw 0xeec0, 0xc12c,	0xeeff, 0xc12c,		0x21, 0
	.dw 0xef40, 0xc12c,	0xef7f, 0xc12c,		0x21, 0
	.dw 0xefc0, 0xc12c,	0xefff, 0xc12c,		0x21, 0
	.dw 0xf040, 0xc12c,	0xf07f, 0xc12c,		0x21, 0
	.dw 0xf0c0, 0xc12c,	0xf0ff, 0xc12c,		0x21, 0
	.dw 0xf140, 0xc12c,	0xf17f, 0xc12c,		0x21, 0
	.dw 0xf1c0, 0xc12c,	0xf1ff, 0xc12c,		0x21, 0
	.dw 0xf240, 0xc12c,	0xf27f, 0xc12c,		0x21, 0
	.dw 0xf2c0, 0xc12c,	0xf2ff, 0xc12c,		0x21, 0
	.dw 0xf340, 0xc12c,	0xf37f, 0xc12c,		0x21, 0
	.dw 0xf3c0, 0xc12c,	0xf3ff, 0xc12c,		0x21, 0
	.dw 0xf440, 0xc12c,	0xf47f, 0xc12c,		0x21, 0
	.dw 0xf4c0, 0xc12c,	0xf4ff, 0xc12c,		0x21, 0
	.dw 0xf540, 0xc12c,	0xf57f, 0xc12c,		0x21, 0
	.dw 0xf5c0, 0xc12c,	0xf5ff, 0xc12c,		0x21, 0
	.dw 0xf640, 0xc12c,	0xf67f, 0xc12c,		0x21, 0
	.dw 0xf6c0, 0xc12c,	0xf6ff, 0xc12c,		0x21, 0
	.dw 0xf740, 0xc12c,	0xf77f, 0xc12c,		0x21, 0
	.dw 0xf7c0, 0xc12c,	0xf7ff, 0xc12c,		0x21, 0
	.dw 0xf840, 0xc12c,	0xf87f, 0xc12c,		0x21, 0
	.dw 0xf8c0, 0xc12c,	0xf8ff, 0xc12c,		0x21, 0
	.dw 0xf940, 0xc12c,	0xf97f, 0xc12c,		0x21, 0
	.dw 0xf9c0, 0xc12c,	0xffff, 0xc12c,		0x21, 0
	.dw 0x0040, 0xc12d,	0x007f, 0xc12d,		0x21, 0
	.dw 0x00c0, 0xc12d,	0x00ff, 0xc12d,		0x21, 0
	.dw 0x0140, 0xc12d,	0x017f, 0xc12d,		0x21, 0
	.dw 0x01c0, 0xc12d,	0x01ff, 0xc12d,		0x21, 0
	.dw 0x0240, 0xc12d,	0x027f, 0xc12d,		0x21, 0
	.dw 0x02c0, 0xc12d,	0x02ff, 0xc12d,		0x21, 0
	.dw 0x0340, 0xc12d,	0x037f, 0xc12d,		0x21, 0
	.dw 0x03c0, 0xc12d,	0x03ff, 0xc12d,		0x21, 0
	.dw 0x0440, 0xc12d,	0x047f, 0xc12d,		0x21, 0
	.dw 0x04c0, 0xc12d,	0x04ff, 0xc12d,		0x21, 0
	.dw 0x0540, 0xc12d,	0x057f, 0xc12d,		0x21, 0
	.dw 0x05c0, 0xc12d,	0x05ff, 0xc12d,		0x21, 0
	.dw 0x0640, 0xc12d,	0x067f, 0xc12d,		0x21, 0
	.dw 0x06c0, 0xc12d,	0x06ff, 0xc12d,		0x21, 0
	.dw 0x0740, 0xc12d,	0x077f, 0xc12d,		0x21, 0
	.dw 0x07c0, 0xc12d,	0x07ff, 0xc12d,		0x21, 0
	.dw 0x0840, 0xc12d,	0x087f, 0xc12d,		0x21, 0
	.dw 0x08c0, 0xc12d,	0x08ff, 0xc12d,		0x21, 0
	.dw 0x0940, 0xc12d,	0x097f, 0xc12d,		0x21, 0
	.dw 0x09c0, 0xc12d,	0x09ff, 0xc12d,		0x21, 0
	.dw 0x0a40, 0xc12d,	0x0a7f, 0xc12d,		0x21, 0
	.dw 0x0ac0, 0xc12d,	0x0aff, 0xc12d,		0x21, 0
	.dw 0x0b40, 0xc12d,	0x0b7f, 0xc12d,		0x21, 0
	.dw 0x0bc0, 0xc12d,	0x0bff, 0xc12d,		0x21, 0
	.dw 0x0c40, 0xc12d,	0x0c7f, 0xc12d,		0x21, 0
	.dw 0x0cc0, 0xc12d,	0x0cff, 0xc12d,		0x21, 0
	.dw 0x0d40, 0xc12d,	0x0d7f, 0xc12d,		0x21, 0
	.dw 0x0dc0, 0xc12d,	0x0dff, 0xc12d,		0x21, 0
	.dw 0x0e40, 0xc12d,	0x0e7f, 0xc12d,		0x21, 0
	.dw 0x0ec0, 0xc12d,	0x0eff, 0xc12d,		0x21, 0
	.dw 0x0f40, 0xc12d,	0x0f7f, 0xc12d,		0x21, 0
	.dw 0x0fc0, 0xc12d,	0x0fff, 0xc12d,		0x21, 0
	.dw 0x1040, 0xc12d,	0x107f, 0xc12d,		0x21, 0
	.dw 0x10c0, 0xc12d,	0x10ff, 0xc12d,		0x21, 0
	.dw 0x1140, 0xc12d,	0x117f, 0xc12d,		0x21, 0
	.dw 0x11c0, 0xc12d,	0x11ff, 0xc12d,		0x21, 0
	.dw 0x1240, 0xc12d,	0x127f, 0xc12d,		0x21, 0
	.dw 0x12c0, 0xc12d,	0x12ff, 0xc12d,		0x21, 0
	.dw 0x1340, 0xc12d,	0x137f, 0xc12d,		0x21, 0
	.dw 0x13c0, 0xc12d,	0x13ff, 0xc12d,		0x21, 0
	.dw 0x1440, 0xc12d,	0x147f, 0xc12d,		0x21, 0
	.dw 0x14c0, 0xc12d,	0x14ff, 0xc12d,		0x21, 0
	.dw 0x1540, 0xc12d,	0x157f, 0xc12d,		0x21, 0
	.dw 0x15c0, 0xc12d,	0x15ff, 0xc12d,		0x21, 0
	.dw 0x1640, 0xc12d,	0x167f, 0xc12d,		0x21, 0
	.dw 0x16c0, 0xc12d,	0x16ff, 0xc12d,		0x21, 0
	.dw 0x1740, 0xc12d,	0x177f, 0xc12d,		0x21, 0
	.dw 0x17c0, 0xc12d,	0x17ff, 0xc12d,		0x21, 0
	.dw 0x1840, 0xc12d,	0x187f, 0xc12d,		0x21, 0
	.dw 0x18c0, 0xc12d,	0x18ff, 0xc12d,		0x21, 0
	.dw 0x1940, 0xc12d,	0x197f, 0xc12d,		0x21, 0
	.dw 0x19c0, 0xc12d,	0x1fff, 0xc12d,		0x21, 0
	.dw 0x2040, 0xc12d,	0x207f, 0xc12d,		0x21, 0
	.dw 0x20c0, 0xc12d,	0x20ff, 0xc12d,		0x21, 0
	.dw 0x2140, 0xc12d,	0x217f, 0xc12d,		0x21, 0
	.dw 0x21c0, 0xc12d,	0x21ff, 0xc12d,		0x21, 0
	.dw 0x2240, 0xc12d,	0x227f, 0xc12d,		0x21, 0
	.dw 0x22c0, 0xc12d,	0x22ff, 0xc12d,		0x21, 0
	.dw 0x2340, 0xc12d,	0x237f, 0xc12d,		0x21, 0
	.dw 0x23c0, 0xc12d,	0x23ff, 0xc12d,		0x21, 0
	.dw 0x2440, 0xc12d,	0x247f, 0xc12d,		0x21, 0
	.dw 0x24c0, 0xc12d,	0x24ff, 0xc12d,		0x21, 0
	.dw 0x2540, 0xc12d,	0x257f, 0xc12d,		0x21, 0
	.dw 0x25c0, 0xc12d,	0x25ff, 0xc12d,		0x21, 0
	.dw 0x2640, 0xc12d,	0x267f, 0xc12d,		0x21, 0
	.dw 0x26c0, 0xc12d,	0x26ff, 0xc12d,		0x21, 0
	.dw 0x2740, 0xc12d,	0x277f, 0xc12d,		0x21, 0
	.dw 0x27c0, 0xc12d,	0x27ff, 0xc12d,		0x21, 0
	.dw 0x2840, 0xc12d,	0x287f, 0xc12d,		0x21, 0
	.dw 0x28c0, 0xc12d,	0x28ff, 0xc12d,		0x21, 0
	.dw 0x2940, 0xc12d,	0x297f, 0xc12d,		0x21, 0
	.dw 0x29c0, 0xc12d,	0x29ff, 0xc12d,		0x21, 0
	.dw 0x2a40, 0xc12d,	0x2a7f, 0xc12d,		0x21, 0
	.dw 0x2ac0, 0xc12d,	0x2aff, 0xc12d,		0x21, 0
	.dw 0x2b40, 0xc12d,	0x2b7f, 0xc12d,		0x21, 0
	.dw 0x2bc0, 0xc12d,	0x2bff, 0xc12d,		0x21, 0
	.dw 0x2c40, 0xc12d,	0x2c7f, 0xc12d,		0x21, 0
	.dw 0x2cc0, 0xc12d,	0x2cff, 0xc12d,		0x21, 0
	.dw 0x2d40, 0xc12d,	0x2d7f, 0xc12d,		0x21, 0
	.dw 0x2dc0, 0xc12d,	0x2dff, 0xc12d,		0x21, 0
	.dw 0x2e40, 0xc12d,	0x2e7f, 0xc12d,		0x21, 0
	.dw 0x2ec0, 0xc12d,	0x2eff, 0xc12d,		0x21, 0
	.dw 0x2f40, 0xc12d,	0x2f7f, 0xc12d,		0x21, 0
	.dw 0x2fc0, 0xc12d,	0x2fff, 0xc12d,		0x21, 0
	.dw 0x3040, 0xc12d,	0x307f, 0xc12d,		0x21, 0
	.dw 0x30c0, 0xc12d,	0x30ff, 0xc12d,		0x21, 0
	.dw 0x3140, 0xc12d,	0x317f, 0xc12d,		0x21, 0
	.dw 0x31c0, 0xc12d,	0x31ff, 0xc12d,		0x21, 0
	.dw 0x3240, 0xc12d,	0x327f, 0xc12d,		0x21, 0
	.dw 0x32c0, 0xc12d,	0x32ff, 0xc12d,		0x21, 0
	.dw 0x3340, 0xc12d,	0x337f, 0xc12d,		0x21, 0
	.dw 0x33c0, 0xc12d,	0x33ff, 0xc12d,		0x21, 0
	.dw 0x3440, 0xc12d,	0x347f, 0xc12d,		0x21, 0
	.dw 0x34c0, 0xc12d,	0x34ff, 0xc12d,		0x21, 0
	.dw 0x3540, 0xc12d,	0x357f, 0xc12d,		0x21, 0
	.dw 0x35c0, 0xc12d,	0x35ff, 0xc12d,		0x21, 0
	.dw 0x3640, 0xc12d,	0x367f, 0xc12d,		0x21, 0
	.dw 0x36c0, 0xc12d,	0x36ff, 0xc12d,		0x21, 0
	.dw 0x3740, 0xc12d,	0x377f, 0xc12d,		0x21, 0
	.dw 0x37c0, 0xc12d,	0x37ff, 0xc12d,		0x21, 0
	.dw 0x3840, 0xc12d,	0x387f, 0xc12d,		0x21, 0
	.dw 0x38c0, 0xc12d,	0x38ff, 0xc12d,		0x21, 0
	.dw 0x3940, 0xc12d,	0x397f, 0xc12d,		0x21, 0
	.dw 0x39c0, 0xc12d,	0x3fff, 0xc12d,		0x21, 0
	.dw 0x4040, 0xc12d,	0x407f, 0xc12d,		0x21, 0
	.dw 0x40c0, 0xc12d,	0x40ff, 0xc12d,		0x21, 0
	.dw 0x4140, 0xc12d,	0x417f, 0xc12d,		0x21, 0
	.dw 0x41c0, 0xc12d,	0x41ff, 0xc12d,		0x21, 0
	.dw 0x4240, 0xc12d,	0x427f, 0xc12d,		0x21, 0
	.dw 0x42c0, 0xc12d,	0x42ff, 0xc12d,		0x21, 0
	.dw 0x4340, 0xc12d,	0x437f, 0xc12d,		0x21, 0
	.dw 0x43c0, 0xc12d,	0x43ff, 0xc12d,		0x21, 0
	.dw 0x4440, 0xc12d,	0x447f, 0xc12d,		0x21, 0
	.dw 0x44c0, 0xc12d,	0x44ff, 0xc12d,		0x21, 0
	.dw 0x4540, 0xc12d,	0x457f, 0xc12d,		0x21, 0
	.dw 0x45c0, 0xc12d,	0x45ff, 0xc12d,		0x21, 0
	.dw 0x4640, 0xc12d,	0x467f, 0xc12d,		0x21, 0
	.dw 0x46c0, 0xc12d,	0x46ff, 0xc12d,		0x21, 0
	.dw 0x4740, 0xc12d,	0x477f, 0xc12d,		0x21, 0
	.dw 0x47c0, 0xc12d,	0x47ff, 0xc12d,		0x21, 0
	.dw 0x4840, 0xc12d,	0x487f, 0xc12d,		0x21, 0
	.dw 0x48c0, 0xc12d,	0x48ff, 0xc12d,		0x21, 0
	.dw 0x4940, 0xc12d,	0x497f, 0xc12d,		0x21, 0
	.dw 0x49c0, 0xc12d,	0x49ff, 0xc12d,		0x21, 0
	.dw 0x4a40, 0xc12d,	0x4a7f, 0xc12d,		0x21, 0
	.dw 0x4ac0, 0xc12d,	0x4aff, 0xc12d,		0x21, 0
	.dw 0x4b40, 0xc12d,	0x4b7f, 0xc12d,		0x21, 0
	.dw 0x4bc0, 0xc12d,	0x4bff, 0xc12d,		0x21, 0
	.dw 0x4c40, 0xc12d,	0x4c7f, 0xc12d,		0x21, 0
	.dw 0x4cc0, 0xc12d,	0x4cff, 0xc12d,		0x21, 0
	.dw 0x4d40, 0xc12d,	0x4d7f, 0xc12d,		0x21, 0
	.dw 0x4dc0, 0xc12d,	0x4dff, 0xc12d,		0x21, 0
	.dw 0x4e40, 0xc12d,	0x4e7f, 0xc12d,		0x21, 0
	.dw 0x4ec0, 0xc12d,	0x4eff, 0xc12d,		0x21, 0
	.dw 0x4f40, 0xc12d,	0x4f7f, 0xc12d,		0x21, 0
	.dw 0x4fc0, 0xc12d,	0x4fff, 0xc12d,		0x21, 0
	.dw 0x5040, 0xc12d,	0x507f, 0xc12d,		0x21, 0
	.dw 0x50c0, 0xc12d,	0x50ff, 0xc12d,		0x21, 0
	.dw 0x5140, 0xc12d,	0x517f, 0xc12d,		0x21, 0
	.dw 0x51c0, 0xc12d,	0x51ff, 0xc12d,		0x21, 0
	.dw 0x5240, 0xc12d,	0x527f, 0xc12d,		0x21, 0
	.dw 0x52c0, 0xc12d,	0x52ff, 0xc12d,		0x21, 0
	.dw 0x5340, 0xc12d,	0x537f, 0xc12d,		0x21, 0
	.dw 0x53c0, 0xc12d,	0x53ff, 0xc12d,		0x21, 0
	.dw 0x5440, 0xc12d,	0x547f, 0xc12d,		0x21, 0
	.dw 0x54c0, 0xc12d,	0x54ff, 0xc12d,		0x21, 0
	.dw 0x5540, 0xc12d,	0x557f, 0xc12d,		0x21, 0
	.dw 0x55c0, 0xc12d,	0x55ff, 0xc12d,		0x21, 0
	.dw 0x5640, 0xc12d,	0x567f, 0xc12d,		0x21, 0
	.dw 0x56c0, 0xc12d,	0x56ff, 0xc12d,		0x21, 0
	.dw 0x5740, 0xc12d,	0x577f, 0xc12d,		0x21, 0
	.dw 0x57c0, 0xc12d,	0x57ff, 0xc12d,		0x21, 0
	.dw 0x5840, 0xc12d,	0x587f, 0xc12d,		0x21, 0
	.dw 0x58c0, 0xc12d,	0x58ff, 0xc12d,		0x21, 0
	.dw 0x5940, 0xc12d,	0x597f, 0xc12d,		0x21, 0
	.dw 0x59c0, 0xc12d,	0x5fff, 0xc12d,		0x21, 0
	.dw 0x6040, 0xc12d,	0x607f, 0xc12d,		0x21, 0
	.dw 0x60c0, 0xc12d,	0x60ff, 0xc12d,		0x21, 0
	.dw 0x6140, 0xc12d,	0x617f, 0xc12d,		0x21, 0
	.dw 0x61c0, 0xc12d,	0x61ff, 0xc12d,		0x21, 0
	.dw 0x6240, 0xc12d,	0x627f, 0xc12d,		0x21, 0
	.dw 0x62c0, 0xc12d,	0x62ff, 0xc12d,		0x21, 0
	.dw 0x6340, 0xc12d,	0x637f, 0xc12d,		0x21, 0
	.dw 0x63c0, 0xc12d,	0x63ff, 0xc12d,		0x21, 0
	.dw 0x6440, 0xc12d,	0x647f, 0xc12d,		0x21, 0
	.dw 0x64c0, 0xc12d,	0x64ff, 0xc12d,		0x21, 0
	.dw 0x6540, 0xc12d,	0x657f, 0xc12d,		0x21, 0
	.dw 0x65c0, 0xc12d,	0x65ff, 0xc12d,		0x21, 0
	.dw 0x6640, 0xc12d,	0x667f, 0xc12d,		0x21, 0
	.dw 0x66c0, 0xc12d,	0x66ff, 0xc12d,		0x21, 0
	.dw 0x6740, 0xc12d,	0x677f, 0xc12d,		0x21, 0
	.dw 0x67c0, 0xc12d,	0x67ff, 0xc12d,		0x21, 0
	.dw 0x6840, 0xc12d,	0x687f, 0xc12d,		0x21, 0
	.dw 0x68c0, 0xc12d,	0x68ff, 0xc12d,		0x21, 0
	.dw 0x6940, 0xc12d,	0x697f, 0xc12d,		0x21, 0
	.dw 0x69c0, 0xc12d,	0x69ff, 0xc12d,		0x21, 0
	.dw 0x6a40, 0xc12d,	0x6a7f, 0xc12d,		0x21, 0
	.dw 0x6ac0, 0xc12d,	0x6aff, 0xc12d,		0x21, 0
	.dw 0x6b40, 0xc12d,	0x6b7f, 0xc12d,		0x21, 0
	.dw 0x6bc0, 0xc12d,	0x6bff, 0xc12d,		0x21, 0
	.dw 0x6c40, 0xc12d,	0x6c7f, 0xc12d,		0x21, 0
	.dw 0x6cc0, 0xc12d,	0x6cff, 0xc12d,		0x21, 0
	.dw 0x6d40, 0xc12d,	0x6d7f, 0xc12d,		0x21, 0
	.dw 0x6dc0, 0xc12d,	0x6dff, 0xc12d,		0x21, 0
	.dw 0x6e40, 0xc12d,	0x6e7f, 0xc12d,		0x21, 0
	.dw 0x6ec0, 0xc12d,	0x6eff, 0xc12d,		0x21, 0
	.dw 0x6f40, 0xc12d,	0x6f7f, 0xc12d,		0x21, 0
	.dw 0x6fc0, 0xc12d,	0x6fff, 0xc12d,		0x21, 0
	.dw 0x7040, 0xc12d,	0x707f, 0xc12d,		0x21, 0
	.dw 0x70c0, 0xc12d,	0x70ff, 0xc12d,		0x21, 0
	.dw 0x7140, 0xc12d,	0x717f, 0xc12d,		0x21, 0
	.dw 0x71c0, 0xc12d,	0x71ff, 0xc12d,		0x21, 0
	.dw 0x7240, 0xc12d,	0x727f, 0xc12d,		0x21, 0
	.dw 0x72c0, 0xc12d,	0x72ff, 0xc12d,		0x21, 0
	.dw 0x7340, 0xc12d,	0x737f, 0xc12d,		0x21, 0
	.dw 0x73c0, 0xc12d,	0x73ff, 0xc12d,		0x21, 0
	.dw 0x7440, 0xc12d,	0x747f, 0xc12d,		0x21, 0
	.dw 0x74c0, 0xc12d,	0x74ff, 0xc12d,		0x21, 0
	.dw 0x7540, 0xc12d,	0x757f, 0xc12d,		0x21, 0
	.dw 0x75c0, 0xc12d,	0x75ff, 0xc12d,		0x21, 0
	.dw 0x7640, 0xc12d,	0x767f, 0xc12d,		0x21, 0
	.dw 0x76c0, 0xc12d,	0x76ff, 0xc12d,		0x21, 0
	.dw 0x7740, 0xc12d,	0x777f, 0xc12d,		0x21, 0
	.dw 0x77c0, 0xc12d,	0x77ff, 0xc12d,		0x21, 0
	.dw 0x7840, 0xc12d,	0x787f, 0xc12d,		0x21, 0
	.dw 0x78c0, 0xc12d,	0x78ff, 0xc12d,		0x21, 0
	.dw 0x7940, 0xc12d,	0x797f, 0xc12d,		0x21, 0
	.dw 0x79c0, 0xc12d,	0x7fff, 0xc12d,		0x21, 0
	.dw 0x8040, 0xc12d,	0x807f, 0xc12d,		0x21, 0
	.dw 0x80c0, 0xc12d,	0x80ff, 0xc12d,		0x21, 0
	.dw 0x8140, 0xc12d,	0x817f, 0xc12d,		0x21, 0
	.dw 0x81c0, 0xc12d,	0x81ff, 0xc12d,		0x21, 0
	.dw 0x8240, 0xc12d,	0x827f, 0xc12d,		0x21, 0
	.dw 0x82c0, 0xc12d,	0x82ff, 0xc12d,		0x21, 0
	.dw 0x8340, 0xc12d,	0x837f, 0xc12d,		0x21, 0
	.dw 0x83c0, 0xc12d,	0x83ff, 0xc12d,		0x21, 0
	.dw 0x8440, 0xc12d,	0x847f, 0xc12d,		0x21, 0
	.dw 0x84c0, 0xc12d,	0x84ff, 0xc12d,		0x21, 0
	.dw 0x8540, 0xc12d,	0x857f, 0xc12d,		0x21, 0
	.dw 0x85c0, 0xc12d,	0x85ff, 0xc12d,		0x21, 0
	.dw 0x8640, 0xc12d,	0x867f, 0xc12d,		0x21, 0
	.dw 0x86c0, 0xc12d,	0x86ff, 0xc12d,		0x21, 0
	.dw 0x8740, 0xc12d,	0x877f, 0xc12d,		0x21, 0
	.dw 0x87c0, 0xc12d,	0x87ff, 0xc12d,		0x21, 0
	.dw 0x8840, 0xc12d,	0x887f, 0xc12d,		0x21, 0
	.dw 0x88c0, 0xc12d,	0x88ff, 0xc12d,		0x21, 0
	.dw 0x8940, 0xc12d,	0x897f, 0xc12d,		0x21, 0
	.dw 0x89c0, 0xc12d,	0x89ff, 0xc12d,		0x21, 0
	.dw 0x8a40, 0xc12d,	0x8a7f, 0xc12d,		0x21, 0
	.dw 0x8ac0, 0xc12d,	0x8aff, 0xc12d,		0x21, 0
	.dw 0x8b40, 0xc12d,	0x8b7f, 0xc12d,		0x21, 0
	.dw 0x8bc0, 0xc12d,	0x8bff, 0xc12d,		0x21, 0
	.dw 0x8c40, 0xc12d,	0x8c7f, 0xc12d,		0x21, 0
	.dw 0x8cc0, 0xc12d,	0x8cff, 0xc12d,		0x21, 0
	.dw 0x8d40, 0xc12d,	0x8d7f, 0xc12d,		0x21, 0
	.dw 0x8dc0, 0xc12d,	0x8dff, 0xc12d,		0x21, 0
	.dw 0x8e40, 0xc12d,	0x8e7f, 0xc12d,		0x21, 0
	.dw 0x8ec0, 0xc12d,	0x8eff, 0xc12d,		0x21, 0
	.dw 0x8f40, 0xc12d,	0x8f7f, 0xc12d,		0x21, 0
	.dw 0x8fc0, 0xc12d,	0x8fff, 0xc12d,		0x21, 0
	.dw 0x9040, 0xc12d,	0x907f, 0xc12d,		0x21, 0
	.dw 0x90c0, 0xc12d,	0x90ff, 0xc12d,		0x21, 0
	.dw 0x9140, 0xc12d,	0x917f, 0xc12d,		0x21, 0
	.dw 0x91c0, 0xc12d,	0x91ff, 0xc12d,		0x21, 0
	.dw 0x9240, 0xc12d,	0x927f, 0xc12d,		0x21, 0
	.dw 0x92c0, 0xc12d,	0x92ff, 0xc12d,		0x21, 0
	.dw 0x9340, 0xc12d,	0x937f, 0xc12d,		0x21, 0
	.dw 0x93c0, 0xc12d,	0x93ff, 0xc12d,		0x21, 0
	.dw 0x9440, 0xc12d,	0x947f, 0xc12d,		0x21, 0
	.dw 0x94c0, 0xc12d,	0x94ff, 0xc12d,		0x21, 0
	.dw 0x9540, 0xc12d,	0x957f, 0xc12d,		0x21, 0
	.dw 0x95c0, 0xc12d,	0x95ff, 0xc12d,		0x21, 0
	.dw 0x9640, 0xc12d,	0x967f, 0xc12d,		0x21, 0
	.dw 0x96c0, 0xc12d,	0x96ff, 0xc12d,		0x21, 0
	.dw 0x9740, 0xc12d,	0x977f, 0xc12d,		0x21, 0
	.dw 0x97c0, 0xc12d,	0x97ff, 0xc12d,		0x21, 0
	.dw 0x9840, 0xc12d,	0x987f, 0xc12d,		0x21, 0
	.dw 0x98c0, 0xc12d,	0x98ff, 0xc12d,		0x21, 0
	.dw 0x9940, 0xc12d,	0x997f, 0xc12d,		0x21, 0
	.dw 0x99c0, 0xc12d,	0x9fff, 0xc12d,		0x21, 0
	.dw 0xa040, 0xc12d,	0xa07f, 0xc12d,		0x21, 0
	.dw 0xa0c0, 0xc12d,	0xa0ff, 0xc12d,		0x21, 0
	.dw 0xa140, 0xc12d,	0xa17f, 0xc12d,		0x21, 0
	.dw 0xa1c0, 0xc12d,	0xa1ff, 0xc12d,		0x21, 0
	.dw 0xa240, 0xc12d,	0xa27f, 0xc12d,		0x21, 0
	.dw 0xa2c0, 0xc12d,	0xa2ff, 0xc12d,		0x21, 0
	.dw 0xa340, 0xc12d,	0xa37f, 0xc12d,		0x21, 0
	.dw 0xa3c0, 0xc12d,	0xa3ff, 0xc12d,		0x21, 0
	.dw 0xa440, 0xc12d,	0xa47f, 0xc12d,		0x21, 0
	.dw 0xa4c0, 0xc12d,	0xa4ff, 0xc12d,		0x21, 0
	.dw 0xa540, 0xc12d,	0xa57f, 0xc12d,		0x21, 0
	.dw 0xa5c0, 0xc12d,	0xa5ff, 0xc12d,		0x21, 0
	.dw 0xa640, 0xc12d,	0xa67f, 0xc12d,		0x21, 0
	.dw 0xa6c0, 0xc12d,	0xa6ff, 0xc12d,		0x21, 0
	.dw 0xa740, 0xc12d,	0xa77f, 0xc12d,		0x21, 0
	.dw 0xa7c0, 0xc12d,	0xa7ff, 0xc12d,		0x21, 0
	.dw 0xa840, 0xc12d,	0xa87f, 0xc12d,		0x21, 0
	.dw 0xa8c0, 0xc12d,	0xa8ff, 0xc12d,		0x21, 0
	.dw 0xa940, 0xc12d,	0xa97f, 0xc12d,		0x21, 0
	.dw 0xa9c0, 0xc12d,	0xa9ff, 0xc12d,		0x21, 0
	.dw 0xaa40, 0xc12d,	0xaa7f, 0xc12d,		0x21, 0
	.dw 0xaac0, 0xc12d,	0xaaff, 0xc12d,		0x21, 0
	.dw 0xab40, 0xc12d,	0xab7f, 0xc12d,		0x21, 0
	.dw 0xabc0, 0xc12d,	0xabff, 0xc12d,		0x21, 0
	.dw 0xac40, 0xc12d,	0xac7f, 0xc12d,		0x21, 0
	.dw 0xacc0, 0xc12d,	0xacff, 0xc12d,		0x21, 0
	.dw 0xad40, 0xc12d,	0xad7f, 0xc12d,		0x21, 0
	.dw 0xadc0, 0xc12d,	0xadff, 0xc12d,		0x21, 0
	.dw 0xae40, 0xc12d,	0xae7f, 0xc12d,		0x21, 0
	.dw 0xaec0, 0xc12d,	0xaeff, 0xc12d,		0x21, 0
	.dw 0xaf40, 0xc12d,	0xaf7f, 0xc12d,		0x21, 0
	.dw 0xafc0, 0xc12d,	0xafff, 0xc12d,		0x21, 0
	.dw 0xb040, 0xc12d,	0xb07f, 0xc12d,		0x21, 0
	.dw 0xb0c0, 0xc12d,	0xb0ff, 0xc12d,		0x21, 0
	.dw 0xb140, 0xc12d,	0xb17f, 0xc12d,		0x21, 0
	.dw 0xb1c0, 0xc12d,	0xb1ff, 0xc12d,		0x21, 0
	.dw 0xb240, 0xc12d,	0xb27f, 0xc12d,		0x21, 0
	.dw 0xb2c0, 0xc12d,	0xb2ff, 0xc12d,		0x21, 0
	.dw 0xb340, 0xc12d,	0xb37f, 0xc12d,		0x21, 0
	.dw 0xb3c0, 0xc12d,	0xb3ff, 0xc12d,		0x21, 0
	.dw 0xb440, 0xc12d,	0xb47f, 0xc12d,		0x21, 0
	.dw 0xb4c0, 0xc12d,	0xb4ff, 0xc12d,		0x21, 0
	.dw 0xb540, 0xc12d,	0xb57f, 0xc12d,		0x21, 0
	.dw 0xb5c0, 0xc12d,	0xb5ff, 0xc12d,		0x21, 0
	.dw 0xb640, 0xc12d,	0xb67f, 0xc12d,		0x21, 0
	.dw 0xb6c0, 0xc12d,	0xb6ff, 0xc12d,		0x21, 0
	.dw 0xb740, 0xc12d,	0xb77f, 0xc12d,		0x21, 0
	.dw 0xb7c0, 0xc12d,	0xb7ff, 0xc12d,		0x21, 0
	.dw 0xb840, 0xc12d,	0xb87f, 0xc12d,		0x21, 0
	.dw 0xb8c0, 0xc12d,	0xb8ff, 0xc12d,		0x21, 0
	.dw 0xb940, 0xc12d,	0xb97f, 0xc12d,		0x21, 0
	.dw 0xb9c0, 0xc12d,	0xbfff, 0xc12d,		0x21, 0
	.dw 0xc040, 0xc12d,	0xc07f, 0xc12d,		0x21, 0
	.dw 0xc0c0, 0xc12d,	0xc0ff, 0xc12d,		0x21, 0
	.dw 0xc140, 0xc12d,	0xc17f, 0xc12d,		0x21, 0
	.dw 0xc1c0, 0xc12d,	0xc1ff, 0xc12d,		0x21, 0
	.dw 0xc240, 0xc12d,	0xc27f, 0xc12d,		0x21, 0
	.dw 0xc2c0, 0xc12d,	0xc2ff, 0xc12d,		0x21, 0
	.dw 0xc340, 0xc12d,	0xc37f, 0xc12d,		0x21, 0
	.dw 0xc3c0, 0xc12d,	0xc3ff, 0xc12d,		0x21, 0
	.dw 0xc440, 0xc12d,	0xc47f, 0xc12d,		0x21, 0
	.dw 0xc4c0, 0xc12d,	0xc4ff, 0xc12d,		0x21, 0
	.dw 0xc540, 0xc12d,	0xc57f, 0xc12d,		0x21, 0
	.dw 0xc5c0, 0xc12d,	0xc5ff, 0xc12d,		0x21, 0
	.dw 0xc640, 0xc12d,	0xc67f, 0xc12d,		0x21, 0
	.dw 0xc6c0, 0xc12d,	0xc6ff, 0xc12d,		0x21, 0
	.dw 0xc740, 0xc12d,	0xc77f, 0xc12d,		0x21, 0
	.dw 0xc7c0, 0xc12d,	0xc7ff, 0xc12d,		0x21, 0
	.dw 0xc840, 0xc12d,	0xc87f, 0xc12d,		0x21, 0
	.dw 0xc8c0, 0xc12d,	0xc8ff, 0xc12d,		0x21, 0
	.dw 0xc940, 0xc12d,	0xc97f, 0xc12d,		0x21, 0
	.dw 0xc9c0, 0xc12d,	0xc9ff, 0xc12d,		0x21, 0
	.dw 0xca40, 0xc12d,	0xca7f, 0xc12d,		0x21, 0
	.dw 0xcac0, 0xc12d,	0xcaff, 0xc12d,		0x21, 0
	.dw 0xcb40, 0xc12d,	0xcb7f, 0xc12d,		0x21, 0
	.dw 0xcbc0, 0xc12d,	0xcbff, 0xc12d,		0x21, 0
	.dw 0xcc40, 0xc12d,	0xcc7f, 0xc12d,		0x21, 0
	.dw 0xccc0, 0xc12d,	0xccff, 0xc12d,		0x21, 0
	.dw 0xcd40, 0xc12d,	0xcd7f, 0xc12d,		0x21, 0
	.dw 0xcdc0, 0xc12d,	0xcdff, 0xc12d,		0x21, 0
	.dw 0xce40, 0xc12d,	0xce7f, 0xc12d,		0x21, 0
	.dw 0xcec0, 0xc12d,	0xceff, 0xc12d,		0x21, 0
	.dw 0xcf40, 0xc12d,	0xcf7f, 0xc12d,		0x21, 0
	.dw 0xcfc0, 0xc12d,	0xcfff, 0xc12d,		0x21, 0
	.dw 0xd040, 0xc12d,	0xd07f, 0xc12d,		0x21, 0
	.dw 0xd0c0, 0xc12d,	0xd0ff, 0xc12d,		0x21, 0
	.dw 0xd140, 0xc12d,	0xd17f, 0xc12d,		0x21, 0
	.dw 0xd1c0, 0xc12d,	0xd1ff, 0xc12d,		0x21, 0
	.dw 0xd240, 0xc12d,	0xd27f, 0xc12d,		0x21, 0
	.dw 0xd2c0, 0xc12d,	0xd2ff, 0xc12d,		0x21, 0
	.dw 0xd340, 0xc12d,	0xd37f, 0xc12d,		0x21, 0
	.dw 0xd3c0, 0xc12d,	0xd3ff, 0xc12d,		0x21, 0
	.dw 0xd440, 0xc12d,	0xd47f, 0xc12d,		0x21, 0
	.dw 0xd4c0, 0xc12d,	0xd4ff, 0xc12d,		0x21, 0
	.dw 0xd540, 0xc12d,	0xd57f, 0xc12d,		0x21, 0
	.dw 0xd5c0, 0xc12d,	0xd5ff, 0xc12d,		0x21, 0
	.dw 0xd640, 0xc12d,	0xd67f, 0xc12d,		0x21, 0
	.dw 0xd6c0, 0xc12d,	0xd6ff, 0xc12d,		0x21, 0
	.dw 0xd740, 0xc12d,	0xd77f, 0xc12d,		0x21, 0
	.dw 0xd7c0, 0xc12d,	0xd7ff, 0xc12d,		0x21, 0
	.dw 0xd840, 0xc12d,	0xd87f, 0xc12d,		0x21, 0
	.dw 0xd8c0, 0xc12d,	0xd8ff, 0xc12d,		0x21, 0
	.dw 0xd940, 0xc12d,	0xd97f, 0xc12d,		0x21, 0
	.dw 0xd9c0, 0xc12d,	0xdfff, 0xc12d,		0x21, 0
	.dw 0xe040, 0xc12d,	0xe07f, 0xc12d,		0x21, 0
	.dw 0xe0c0, 0xc12d,	0xe0ff, 0xc12d,		0x21, 0
	.dw 0xe140, 0xc12d,	0xe17f, 0xc12d,		0x21, 0
	.dw 0xe1c0, 0xc12d,	0xe1ff, 0xc12d,		0x21, 0
	.dw 0xe240, 0xc12d,	0xe27f, 0xc12d,		0x21, 0
	.dw 0xe2c0, 0xc12d,	0xe2ff, 0xc12d,		0x21, 0
	.dw 0xe340, 0xc12d,	0xe37f, 0xc12d,		0x21, 0
	.dw 0xe3c0, 0xc12d,	0xe3ff, 0xc12d,		0x21, 0
	.dw 0xe440, 0xc12d,	0xe47f, 0xc12d,		0x21, 0
	.dw 0xe4c0, 0xc12d,	0xe4ff, 0xc12d,		0x21, 0
	.dw 0xe540, 0xc12d,	0xe57f, 0xc12d,		0x21, 0
	.dw 0xe5c0, 0xc12d,	0xe5ff, 0xc12d,		0x21, 0
	.dw 0xe640, 0xc12d,	0xe67f, 0xc12d,		0x21, 0
	.dw 0xe6c0, 0xc12d,	0xe6ff, 0xc12d,		0x21, 0
	.dw 0xe740, 0xc12d,	0xe77f, 0xc12d,		0x21, 0
	.dw 0xe7c0, 0xc12d,	0xe7ff, 0xc12d,		0x21, 0
	.dw 0xe840, 0xc12d,	0xe87f, 0xc12d,		0x21, 0
	.dw 0xe8c0, 0xc12d,	0xe8ff, 0xc12d,		0x21, 0
	.dw 0xe940, 0xc12d,	0xe97f, 0xc12d,		0x21, 0
	.dw 0xe9c0, 0xc12d,	0xe9ff, 0xc12d,		0x21, 0
	.dw 0xea40, 0xc12d,	0xea7f, 0xc12d,		0x21, 0
	.dw 0xeac0, 0xc12d,	0xeaff, 0xc12d,		0x21, 0
	.dw 0xeb40, 0xc12d,	0xeb7f, 0xc12d,		0x21, 0
	.dw 0xebc0, 0xc12d,	0xebff, 0xc12d,		0x21, 0
	.dw 0xec40, 0xc12d,	0xec7f, 0xc12d,		0x21, 0
	.dw 0xecc0, 0xc12d,	0xecff, 0xc12d,		0x21, 0
	.dw 0xed40, 0xc12d,	0xed7f, 0xc12d,		0x21, 0
	.dw 0xedc0, 0xc12d,	0xedff, 0xc12d,		0x21, 0
	.dw 0xee40, 0xc12d,	0xee7f, 0xc12d,		0x21, 0
	.dw 0xeec0, 0xc12d,	0xeeff, 0xc12d,		0x21, 0
	.dw 0xef40, 0xc12d,	0xef7f, 0xc12d,		0x21, 0
	.dw 0xefc0, 0xc12d,	0xefff, 0xc12d,		0x21, 0
	.dw 0xf040, 0xc12d,	0xf07f, 0xc12d,		0x21, 0
	.dw 0xf0c0, 0xc12d,	0xf0ff, 0xc12d,		0x21, 0
	.dw 0xf140, 0xc12d,	0xf17f, 0xc12d,		0x21, 0
	.dw 0xf1c0, 0xc12d,	0xf1ff, 0xc12d,		0x21, 0
	.dw 0xf240, 0xc12d,	0xf27f, 0xc12d,		0x21, 0
	.dw 0xf2c0, 0xc12d,	0xf2ff, 0xc12d,		0x21, 0
	.dw 0xf340, 0xc12d,	0xf37f, 0xc12d,		0x21, 0
	.dw 0xf3c0, 0xc12d,	0xf3ff, 0xc12d,		0x21, 0
	.dw 0xf440, 0xc12d,	0xf47f, 0xc12d,		0x21, 0
	.dw 0xf4c0, 0xc12d,	0xf4ff, 0xc12d,		0x21, 0
	.dw 0xf540, 0xc12d,	0xf57f, 0xc12d,		0x21, 0
	.dw 0xf5c0, 0xc12d,	0xf5ff, 0xc12d,		0x21, 0
	.dw 0xf640, 0xc12d,	0xf67f, 0xc12d,		0x21, 0
	.dw 0xf6c0, 0xc12d,	0xf6ff, 0xc12d,		0x21, 0
	.dw 0xf740, 0xc12d,	0xf77f, 0xc12d,		0x21, 0
	.dw 0xf7c0, 0xc12d,	0xf7ff, 0xc12d,		0x21, 0
	.dw 0xf840, 0xc12d,	0xf87f, 0xc12d,		0x21, 0
	.dw 0xf8c0, 0xc12d,	0xf8ff, 0xc12d,		0x21, 0
	.dw 0xf940, 0xc12d,	0xf97f, 0xc12d,		0x21, 0
	.dw 0xf9c0, 0xc12d,	0xffff, 0xc12d,		0x21, 0
	.dw 0x0040, 0xc12e,	0x007f, 0xc12e,		0x21, 0
	.dw 0x00c0, 0xc12e,	0x00ff, 0xc12e,		0x21, 0
	.dw 0x0140, 0xc12e,	0x017f, 0xc12e,		0x21, 0
	.dw 0x01c0, 0xc12e,	0x01ff, 0xc12e,		0x21, 0
	.dw 0x0240, 0xc12e,	0x027f, 0xc12e,		0x21, 0
	.dw 0x02c0, 0xc12e,	0x02ff, 0xc12e,		0x21, 0
	.dw 0x0340, 0xc12e,	0x037f, 0xc12e,		0x21, 0
	.dw 0x03c0, 0xc12e,	0x03ff, 0xc12e,		0x21, 0
	.dw 0x0440, 0xc12e,	0x047f, 0xc12e,		0x21, 0
	.dw 0x04c0, 0xc12e,	0x04ff, 0xc12e,		0x21, 0
	.dw 0x0540, 0xc12e,	0x057f, 0xc12e,		0x21, 0
	.dw 0x05c0, 0xc12e,	0x05ff, 0xc12e,		0x21, 0
	.dw 0x0640, 0xc12e,	0x067f, 0xc12e,		0x21, 0
	.dw 0x06c0, 0xc12e,	0x06ff, 0xc12e,		0x21, 0
	.dw 0x0740, 0xc12e,	0x077f, 0xc12e,		0x21, 0
	.dw 0x07c0, 0xc12e,	0x07ff, 0xc12e,		0x21, 0
	.dw 0x0840, 0xc12e,	0x087f, 0xc12e,		0x21, 0
	.dw 0x08c0, 0xc12e,	0x08ff, 0xc12e,		0x21, 0
	.dw 0x0940, 0xc12e,	0x097f, 0xc12e,		0x21, 0
	.dw 0x09c0, 0xc12e,	0x09ff, 0xc12e,		0x21, 0
	.dw 0x0a40, 0xc12e,	0x0a7f, 0xc12e,		0x21, 0
	.dw 0x0ac0, 0xc12e,	0x0aff, 0xc12e,		0x21, 0
	.dw 0x0b40, 0xc12e,	0x0b7f, 0xc12e,		0x21, 0
	.dw 0x0bc0, 0xc12e,	0x0bff, 0xc12e,		0x21, 0
	.dw 0x0c40, 0xc12e,	0x0c7f, 0xc12e,		0x21, 0
	.dw 0x0cc0, 0xc12e,	0x0cff, 0xc12e,		0x21, 0
	.dw 0x0d40, 0xc12e,	0x0d7f, 0xc12e,		0x21, 0
	.dw 0x0dc0, 0xc12e,	0x0dff, 0xc12e,		0x21, 0
	.dw 0x0e40, 0xc12e,	0x0e7f, 0xc12e,		0x21, 0
	.dw 0x0ec0, 0xc12e,	0x0eff, 0xc12e,		0x21, 0
	.dw 0x0f40, 0xc12e,	0x0f7f, 0xc12e,		0x21, 0
	.dw 0x0fc0, 0xc12e,	0x0fff, 0xc12e,		0x21, 0
	.dw 0x1040, 0xc12e,	0x107f, 0xc12e,		0x21, 0
	.dw 0x10c0, 0xc12e,	0x10ff, 0xc12e,		0x21, 0
	.dw 0x1140, 0xc12e,	0x117f, 0xc12e,		0x21, 0
	.dw 0x11c0, 0xc12e,	0x11ff, 0xc12e,		0x21, 0
	.dw 0x1240, 0xc12e,	0x127f, 0xc12e,		0x21, 0
	.dw 0x12c0, 0xc12e,	0x12ff, 0xc12e,		0x21, 0
	.dw 0x1340, 0xc12e,	0x137f, 0xc12e,		0x21, 0
	.dw 0x13c0, 0xc12e,	0x13ff, 0xc12e,		0x21, 0
	.dw 0x1440, 0xc12e,	0x147f, 0xc12e,		0x21, 0
	.dw 0x14c0, 0xc12e,	0x14ff, 0xc12e,		0x21, 0
	.dw 0x1540, 0xc12e,	0x157f, 0xc12e,		0x21, 0
	.dw 0x15c0, 0xc12e,	0x15ff, 0xc12e,		0x21, 0
	.dw 0x1640, 0xc12e,	0x167f, 0xc12e,		0x21, 0
	.dw 0x16c0, 0xc12e,	0x16ff, 0xc12e,		0x21, 0
	.dw 0x1740, 0xc12e,	0x177f, 0xc12e,		0x21, 0
	.dw 0x17c0, 0xc12e,	0x17ff, 0xc12e,		0x21, 0
	.dw 0x1840, 0xc12e,	0x187f, 0xc12e,		0x21, 0
	.dw 0x18c0, 0xc12e,	0x18ff, 0xc12e,		0x21, 0
	.dw 0x1940, 0xc12e,	0x197f, 0xc12e,		0x21, 0
	.dw 0x19c0, 0xc12e,	0x1fff, 0xc12e,		0x21, 0
	.dw 0x2040, 0xc12e,	0x207f, 0xc12e,		0x21, 0
	.dw 0x20c0, 0xc12e,	0x20ff, 0xc12e,		0x21, 0
	.dw 0x2140, 0xc12e,	0x217f, 0xc12e,		0x21, 0
	.dw 0x21c0, 0xc12e,	0x21ff, 0xc12e,		0x21, 0
	.dw 0x2240, 0xc12e,	0x227f, 0xc12e,		0x21, 0
	.dw 0x22c0, 0xc12e,	0x22ff, 0xc12e,		0x21, 0
	.dw 0x2340, 0xc12e,	0x237f, 0xc12e,		0x21, 0
	.dw 0x23c0, 0xc12e,	0x23ff, 0xc12e,		0x21, 0
	.dw 0x2440, 0xc12e,	0x247f, 0xc12e,		0x21, 0
	.dw 0x24c0, 0xc12e,	0x24ff, 0xc12e,		0x21, 0
	.dw 0x2540, 0xc12e,	0x257f, 0xc12e,		0x21, 0
	.dw 0x25c0, 0xc12e,	0x25ff, 0xc12e,		0x21, 0
	.dw 0x2640, 0xc12e,	0x267f, 0xc12e,		0x21, 0
	.dw 0x26c0, 0xc12e,	0x26ff, 0xc12e,		0x21, 0
	.dw 0x2740, 0xc12e,	0x277f, 0xc12e,		0x21, 0
	.dw 0x27c0, 0xc12e,	0x27ff, 0xc12e,		0x21, 0
	.dw 0x2840, 0xc12e,	0x287f, 0xc12e,		0x21, 0
	.dw 0x28c0, 0xc12e,	0x28ff, 0xc12e,		0x21, 0
	.dw 0x2940, 0xc12e,	0x297f, 0xc12e,		0x21, 0
	.dw 0x29c0, 0xc12e,	0x29ff, 0xc12e,		0x21, 0
	.dw 0x2a40, 0xc12e,	0x2a7f, 0xc12e,		0x21, 0
	.dw 0x2ac0, 0xc12e,	0x2aff, 0xc12e,		0x21, 0
	.dw 0x2b40, 0xc12e,	0x2b7f, 0xc12e,		0x21, 0
	.dw 0x2bc0, 0xc12e,	0x2bff, 0xc12e,		0x21, 0
	.dw 0x2c40, 0xc12e,	0x2c7f, 0xc12e,		0x21, 0
	.dw 0x2cc0, 0xc12e,	0x2cff, 0xc12e,		0x21, 0
	.dw 0x2d40, 0xc12e,	0x2d7f, 0xc12e,		0x21, 0
	.dw 0x2dc0, 0xc12e,	0x2dff, 0xc12e,		0x21, 0
	.dw 0x2e40, 0xc12e,	0x2e7f, 0xc12e,		0x21, 0
	.dw 0x2ec0, 0xc12e,	0x2eff, 0xc12e,		0x21, 0
	.dw 0x2f40, 0xc12e,	0x2f7f, 0xc12e,		0x21, 0
	.dw 0x2fc0, 0xc12e,	0x2fff, 0xc12e,		0x21, 0
	.dw 0x3040, 0xc12e,	0x307f, 0xc12e,		0x21, 0
	.dw 0x30c0, 0xc12e,	0x30ff, 0xc12e,		0x21, 0
	.dw 0x3140, 0xc12e,	0x317f, 0xc12e,		0x21, 0
	.dw 0x31c0, 0xc12e,	0x31ff, 0xc12e,		0x21, 0
	.dw 0x3240, 0xc12e,	0x327f, 0xc12e,		0x21, 0
	.dw 0x32c0, 0xc12e,	0x32ff, 0xc12e,		0x21, 0
	.dw 0x3340, 0xc12e,	0x337f, 0xc12e,		0x21, 0
	.dw 0x33c0, 0xc12e,	0x33ff, 0xc12e,		0x21, 0
	.dw 0x3440, 0xc12e,	0x347f, 0xc12e,		0x21, 0
	.dw 0x34c0, 0xc12e,	0x34ff, 0xc12e,		0x21, 0
	.dw 0x3540, 0xc12e,	0x357f, 0xc12e,		0x21, 0
	.dw 0x35c0, 0xc12e,	0x35ff, 0xc12e,		0x21, 0
	.dw 0x3640, 0xc12e,	0x367f, 0xc12e,		0x21, 0
	.dw 0x36c0, 0xc12e,	0x36ff, 0xc12e,		0x21, 0
	.dw 0x3740, 0xc12e,	0x377f, 0xc12e,		0x21, 0
	.dw 0x37c0, 0xc12e,	0x37ff, 0xc12e,		0x21, 0
	.dw 0x3840, 0xc12e,	0x387f, 0xc12e,		0x21, 0
	.dw 0x38c0, 0xc12e,	0x38ff, 0xc12e,		0x21, 0
	.dw 0x3940, 0xc12e,	0x397f, 0xc12e,		0x21, 0
	.dw 0x39c0, 0xc12e,	0x3fff, 0xc12e,		0x21, 0
	.dw 0x4040, 0xc12e,	0x407f, 0xc12e,		0x21, 0
	.dw 0x40c0, 0xc12e,	0x40ff, 0xc12e,		0x21, 0
	.dw 0x4140, 0xc12e,	0x417f, 0xc12e,		0x21, 0
	.dw 0x41c0, 0xc12e,	0x41ff, 0xc12e,		0x21, 0
	.dw 0x4240, 0xc12e,	0x427f, 0xc12e,		0x21, 0
	.dw 0x42c0, 0xc12e,	0x42ff, 0xc12e,		0x21, 0
	.dw 0x4340, 0xc12e,	0x437f, 0xc12e,		0x21, 0
	.dw 0x43c0, 0xc12e,	0x43ff, 0xc12e,		0x21, 0
	.dw 0x4440, 0xc12e,	0x447f, 0xc12e,		0x21, 0
	.dw 0x44c0, 0xc12e,	0x44ff, 0xc12e,		0x21, 0
	.dw 0x4540, 0xc12e,	0x457f, 0xc12e,		0x21, 0
	.dw 0x45c0, 0xc12e,	0x45ff, 0xc12e,		0x21, 0
	.dw 0x4640, 0xc12e,	0x467f, 0xc12e,		0x21, 0
	.dw 0x46c0, 0xc12e,	0x46ff, 0xc12e,		0x21, 0
	.dw 0x4740, 0xc12e,	0x477f, 0xc12e,		0x21, 0
	.dw 0x47c0, 0xc12e,	0x47ff, 0xc12e,		0x21, 0
	.dw 0x4840, 0xc12e,	0x487f, 0xc12e,		0x21, 0
	.dw 0x48c0, 0xc12e,	0x48ff, 0xc12e,		0x21, 0
	.dw 0x4940, 0xc12e,	0x497f, 0xc12e,		0x21, 0
	.dw 0x49c0, 0xc12e,	0x49ff, 0xc12e,		0x21, 0
	.dw 0x4a40, 0xc12e,	0x4a7f, 0xc12e,		0x21, 0
	.dw 0x4ac0, 0xc12e,	0x4aff, 0xc12e,		0x21, 0
	.dw 0x4b40, 0xc12e,	0x4b7f, 0xc12e,		0x21, 0
	.dw 0x4bc0, 0xc12e,	0x4bff, 0xc12e,		0x21, 0
	.dw 0x4c40, 0xc12e,	0x4c7f, 0xc12e,		0x21, 0
	.dw 0x4cc0, 0xc12e,	0x4cff, 0xc12e,		0x21, 0
	.dw 0x4d40, 0xc12e,	0x4d7f, 0xc12e,		0x21, 0
	.dw 0x4dc0, 0xc12e,	0x4dff, 0xc12e,		0x21, 0
	.dw 0x4e40, 0xc12e,	0x4e7f, 0xc12e,		0x21, 0
	.dw 0x4ec0, 0xc12e,	0x4eff, 0xc12e,		0x21, 0
	.dw 0x4f40, 0xc12e,	0x4f7f, 0xc12e,		0x21, 0
	.dw 0x4fc0, 0xc12e,	0x4fff, 0xc12e,		0x21, 0
	.dw 0x5040, 0xc12e,	0x507f, 0xc12e,		0x21, 0
	.dw 0x50c0, 0xc12e,	0x50ff, 0xc12e,		0x21, 0
	.dw 0x5140, 0xc12e,	0x517f, 0xc12e,		0x21, 0
	.dw 0x51c0, 0xc12e,	0x51ff, 0xc12e,		0x21, 0
	.dw 0x5240, 0xc12e,	0x527f, 0xc12e,		0x21, 0
	.dw 0x52c0, 0xc12e,	0x52ff, 0xc12e,		0x21, 0
	.dw 0x5340, 0xc12e,	0x537f, 0xc12e,		0x21, 0
	.dw 0x53c0, 0xc12e,	0x53ff, 0xc12e,		0x21, 0
	.dw 0x5440, 0xc12e,	0x547f, 0xc12e,		0x21, 0
	.dw 0x54c0, 0xc12e,	0x54ff, 0xc12e,		0x21, 0
	.dw 0x5540, 0xc12e,	0x557f, 0xc12e,		0x21, 0
	.dw 0x55c0, 0xc12e,	0x55ff, 0xc12e,		0x21, 0
	.dw 0x5640, 0xc12e,	0x567f, 0xc12e,		0x21, 0
	.dw 0x56c0, 0xc12e,	0x56ff, 0xc12e,		0x21, 0
	.dw 0x5740, 0xc12e,	0x577f, 0xc12e,		0x21, 0
	.dw 0x57c0, 0xc12e,	0x57ff, 0xc12e,		0x21, 0
	.dw 0x5840, 0xc12e,	0x587f, 0xc12e,		0x21, 0
	.dw 0x58c0, 0xc12e,	0x58ff, 0xc12e,		0x21, 0
	.dw 0x5940, 0xc12e,	0x597f, 0xc12e,		0x21, 0
	.dw 0x59c0, 0xc12e,	0x5fff, 0xc12e,		0x21, 0
	.dw 0x6040, 0xc12e,	0x607f, 0xc12e,		0x21, 0
	.dw 0x60c0, 0xc12e,	0x60ff, 0xc12e,		0x21, 0
	.dw 0x6140, 0xc12e,	0x617f, 0xc12e,		0x21, 0
	.dw 0x61c0, 0xc12e,	0x61ff, 0xc12e,		0x21, 0
	.dw 0x6240, 0xc12e,	0x627f, 0xc12e,		0x21, 0
	.dw 0x62c0, 0xc12e,	0x62ff, 0xc12e,		0x21, 0
	.dw 0x6340, 0xc12e,	0x637f, 0xc12e,		0x21, 0
	.dw 0x63c0, 0xc12e,	0x63ff, 0xc12e,		0x21, 0
	.dw 0x6440, 0xc12e,	0x647f, 0xc12e,		0x21, 0
	.dw 0x64c0, 0xc12e,	0x64ff, 0xc12e,		0x21, 0
	.dw 0x6540, 0xc12e,	0x657f, 0xc12e,		0x21, 0
	.dw 0x65c0, 0xc12e,	0x65ff, 0xc12e,		0x21, 0
	.dw 0x6640, 0xc12e,	0x667f, 0xc12e,		0x21, 0
	.dw 0x66c0, 0xc12e,	0x66ff, 0xc12e,		0x21, 0
	.dw 0x6740, 0xc12e,	0x677f, 0xc12e,		0x21, 0
	.dw 0x67c0, 0xc12e,	0x67ff, 0xc12e,		0x21, 0
	.dw 0x6840, 0xc12e,	0x687f, 0xc12e,		0x21, 0
	.dw 0x68c0, 0xc12e,	0x68ff, 0xc12e,		0x21, 0
	.dw 0x6940, 0xc12e,	0x697f, 0xc12e,		0x21, 0
	.dw 0x69c0, 0xc12e,	0x69ff, 0xc12e,		0x21, 0
	.dw 0x6a40, 0xc12e,	0x6a7f, 0xc12e,		0x21, 0
	.dw 0x6ac0, 0xc12e,	0x6aff, 0xc12e,		0x21, 0
	.dw 0x6b40, 0xc12e,	0x6b7f, 0xc12e,		0x21, 0
	.dw 0x6bc0, 0xc12e,	0x6bff, 0xc12e,		0x21, 0
	.dw 0x6c40, 0xc12e,	0x6c7f, 0xc12e,		0x21, 0
	.dw 0x6cc0, 0xc12e,	0x6cff, 0xc12e,		0x21, 0
	.dw 0x6d40, 0xc12e,	0x6d7f, 0xc12e,		0x21, 0
	.dw 0x6dc0, 0xc12e,	0x6dff, 0xc12e,		0x21, 0
	.dw 0x6e40, 0xc12e,	0x6e7f, 0xc12e,		0x21, 0
	.dw 0x6ec0, 0xc12e,	0x6eff, 0xc12e,		0x21, 0
	.dw 0x6f40, 0xc12e,	0x6f7f, 0xc12e,		0x21, 0
	.dw 0x6fc0, 0xc12e,	0x6fff, 0xc12e,		0x21, 0
	.dw 0x7040, 0xc12e,	0x707f, 0xc12e,		0x21, 0
	.dw 0x70c0, 0xc12e,	0x70ff, 0xc12e,		0x21, 0
	.dw 0x7140, 0xc12e,	0x717f, 0xc12e,		0x21, 0
	.dw 0x71c0, 0xc12e,	0x71ff, 0xc12e,		0x21, 0
	.dw 0x7240, 0xc12e,	0x727f, 0xc12e,		0x21, 0
	.dw 0x72c0, 0xc12e,	0x72ff, 0xc12e,		0x21, 0
	.dw 0x7340, 0xc12e,	0x737f, 0xc12e,		0x21, 0
	.dw 0x73c0, 0xc12e,	0x73ff, 0xc12e,		0x21, 0
	.dw 0x7440, 0xc12e,	0x747f, 0xc12e,		0x21, 0
	.dw 0x74c0, 0xc12e,	0x74ff, 0xc12e,		0x21, 0
	.dw 0x7540, 0xc12e,	0x757f, 0xc12e,		0x21, 0
	.dw 0x75c0, 0xc12e,	0x75ff, 0xc12e,		0x21, 0
	.dw 0x7640, 0xc12e,	0x767f, 0xc12e,		0x21, 0
	.dw 0x76c0, 0xc12e,	0x76ff, 0xc12e,		0x21, 0
	.dw 0x7740, 0xc12e,	0x777f, 0xc12e,		0x21, 0
	.dw 0x77c0, 0xc12e,	0x77ff, 0xc12e,		0x21, 0
	.dw 0x7840, 0xc12e,	0x787f, 0xc12e,		0x21, 0
	.dw 0x78c0, 0xc12e,	0x78ff, 0xc12e,		0x21, 0
	.dw 0x7940, 0xc12e,	0x797f, 0xc12e,		0x21, 0
	.dw 0x79c0, 0xc12e,	0x7fff, 0xc12e,		0x21, 0
	.dw 0x8040, 0xc12e,	0x807f, 0xc12e,		0x21, 0
	.dw 0x80c0, 0xc12e,	0x80ff, 0xc12e,		0x21, 0
	.dw 0x8140, 0xc12e,	0x817f, 0xc12e,		0x21, 0
	.dw 0x81c0, 0xc12e,	0x81ff, 0xc12e,		0x21, 0
	.dw 0x8240, 0xc12e,	0x827f, 0xc12e,		0x21, 0
	.dw 0x82c0, 0xc12e,	0x82ff, 0xc12e,		0x21, 0
	.dw 0x8340, 0xc12e,	0x837f, 0xc12e,		0x21, 0
	.dw 0x83c0, 0xc12e,	0x83ff, 0xc12e,		0x21, 0
	.dw 0x8440, 0xc12e,	0x847f, 0xc12e,		0x21, 0
	.dw 0x84c0, 0xc12e,	0x84ff, 0xc12e,		0x21, 0
	.dw 0x8540, 0xc12e,	0x857f, 0xc12e,		0x21, 0
	.dw 0x85c0, 0xc12e,	0x85ff, 0xc12e,		0x21, 0
	.dw 0x8640, 0xc12e,	0x867f, 0xc12e,		0x21, 0
	.dw 0x86c0, 0xc12e,	0x86ff, 0xc12e,		0x21, 0
	.dw 0x8740, 0xc12e,	0x877f, 0xc12e,		0x21, 0
	.dw 0x87c0, 0xc12e,	0x87ff, 0xc12e,		0x21, 0
	.dw 0x8840, 0xc12e,	0x887f, 0xc12e,		0x21, 0
	.dw 0x88c0, 0xc12e,	0x88ff, 0xc12e,		0x21, 0
	.dw 0x8940, 0xc12e,	0x897f, 0xc12e,		0x21, 0
	.dw 0x89c0, 0xc12e,	0x89ff, 0xc12e,		0x21, 0
	.dw 0x8a40, 0xc12e,	0x8a7f, 0xc12e,		0x21, 0
	.dw 0x8ac0, 0xc12e,	0x8aff, 0xc12e,		0x21, 0
	.dw 0x8b40, 0xc12e,	0x8b7f, 0xc12e,		0x21, 0
	.dw 0x8bc0, 0xc12e,	0x8bff, 0xc12e,		0x21, 0
	.dw 0x8c40, 0xc12e,	0x8c7f, 0xc12e,		0x21, 0
	.dw 0x8cc0, 0xc12e,	0x8cff, 0xc12e,		0x21, 0
	.dw 0x8d40, 0xc12e,	0x8d7f, 0xc12e,		0x21, 0
	.dw 0x8dc0, 0xc12e,	0x8dff, 0xc12e,		0x21, 0
	.dw 0x8e40, 0xc12e,	0x8e7f, 0xc12e,		0x21, 0
	.dw 0x8ec0, 0xc12e,	0x8eff, 0xc12e,		0x21, 0
	.dw 0x8f40, 0xc12e,	0x8f7f, 0xc12e,		0x21, 0
	.dw 0x8fc0, 0xc12e,	0x8fff, 0xc12e,		0x21, 0
	.dw 0x9040, 0xc12e,	0x907f, 0xc12e,		0x21, 0
	.dw 0x90c0, 0xc12e,	0x90ff, 0xc12e,		0x21, 0
	.dw 0x9140, 0xc12e,	0x917f, 0xc12e,		0x21, 0
	.dw 0x91c0, 0xc12e,	0x91ff, 0xc12e,		0x21, 0
	.dw 0x9240, 0xc12e,	0x927f, 0xc12e,		0x21, 0
	.dw 0x92c0, 0xc12e,	0x92ff, 0xc12e,		0x21, 0
	.dw 0x9340, 0xc12e,	0x937f, 0xc12e,		0x21, 0
	.dw 0x93c0, 0xc12e,	0x93ff, 0xc12e,		0x21, 0
	.dw 0x9440, 0xc12e,	0x947f, 0xc12e,		0x21, 0
	.dw 0x94c0, 0xc12e,	0x94ff, 0xc12e,		0x21, 0
	.dw 0x9540, 0xc12e,	0x957f, 0xc12e,		0x21, 0
	.dw 0x95c0, 0xc12e,	0x95ff, 0xc12e,		0x21, 0
	.dw 0x9640, 0xc12e,	0x967f, 0xc12e,		0x21, 0
	.dw 0x96c0, 0xc12e,	0x96ff, 0xc12e,		0x21, 0
	.dw 0x9740, 0xc12e,	0x977f, 0xc12e,		0x21, 0
	.dw 0x97c0, 0xc12e,	0x97ff, 0xc12e,		0x21, 0
	.dw 0x9840, 0xc12e,	0x987f, 0xc12e,		0x21, 0
	.dw 0x98c0, 0xc12e,	0x98ff, 0xc12e,		0x21, 0
	.dw 0x9940, 0xc12e,	0x997f, 0xc12e,		0x21, 0
	.dw 0x99c0, 0xc12e,	0x9fff, 0xc12e,		0x21, 0
	.dw 0xa040, 0xc12e,	0xa07f, 0xc12e,		0x21, 0
	.dw 0xa0c0, 0xc12e,	0xa0ff, 0xc12e,		0x21, 0
	.dw 0xa140, 0xc12e,	0xa17f, 0xc12e,		0x21, 0
	.dw 0xa1c0, 0xc12e,	0xa1ff, 0xc12e,		0x21, 0
	.dw 0xa240, 0xc12e,	0xa27f, 0xc12e,		0x21, 0
	.dw 0xa2c0, 0xc12e,	0xa2ff, 0xc12e,		0x21, 0
	.dw 0xa340, 0xc12e,	0xa37f, 0xc12e,		0x21, 0
	.dw 0xa3c0, 0xc12e,	0xa3ff, 0xc12e,		0x21, 0
	.dw 0xa440, 0xc12e,	0xa47f, 0xc12e,		0x21, 0
	.dw 0xa4c0, 0xc12e,	0xa4ff, 0xc12e,		0x21, 0
	.dw 0xa540, 0xc12e,	0xa57f, 0xc12e,		0x21, 0
	.dw 0xa5c0, 0xc12e,	0xa5ff, 0xc12e,		0x21, 0
	.dw 0xa640, 0xc12e,	0xa67f, 0xc12e,		0x21, 0
	.dw 0xa6c0, 0xc12e,	0xa6ff, 0xc12e,		0x21, 0
	.dw 0xa740, 0xc12e,	0xa77f, 0xc12e,		0x21, 0
	.dw 0xa7c0, 0xc12e,	0xa7ff, 0xc12e,		0x21, 0
	.dw 0xa840, 0xc12e,	0xa87f, 0xc12e,		0x21, 0
	.dw 0xa8c0, 0xc12e,	0xa8ff, 0xc12e,		0x21, 0
	.dw 0xa940, 0xc12e,	0xa97f, 0xc12e,		0x21, 0
	.dw 0xa9c0, 0xc12e,	0xa9ff, 0xc12e,		0x21, 0
	.dw 0xaa40, 0xc12e,	0xaa7f, 0xc12e,		0x21, 0
	.dw 0xaac0, 0xc12e,	0xaaff, 0xc12e,		0x21, 0
	.dw 0xab40, 0xc12e,	0xab7f, 0xc12e,		0x21, 0
	.dw 0xabc0, 0xc12e,	0xabff, 0xc12e,		0x21, 0
	.dw 0xac40, 0xc12e,	0xac7f, 0xc12e,		0x21, 0
	.dw 0xacc0, 0xc12e,	0xacff, 0xc12e,		0x21, 0
	.dw 0xad40, 0xc12e,	0xad7f, 0xc12e,		0x21, 0
	.dw 0xadc0, 0xc12e,	0xadff, 0xc12e,		0x21, 0
	.dw 0xae40, 0xc12e,	0xae7f, 0xc12e,		0x21, 0
	.dw 0xaec0, 0xc12e,	0xaeff, 0xc12e,		0x21, 0
	.dw 0xaf40, 0xc12e,	0xaf7f, 0xc12e,		0x21, 0
	.dw 0xafc0, 0xc12e,	0xafff, 0xc12e,		0x21, 0
	.dw 0xb040, 0xc12e,	0xb07f, 0xc12e,		0x21, 0
	.dw 0xb0c0, 0xc12e,	0xb0ff, 0xc12e,		0x21, 0
	.dw 0xb140, 0xc12e,	0xb17f, 0xc12e,		0x21, 0
	.dw 0xb1c0, 0xc12e,	0xb1ff, 0xc12e,		0x21, 0
	.dw 0xb240, 0xc12e,	0xb27f, 0xc12e,		0x21, 0
	.dw 0xb2c0, 0xc12e,	0xb2ff, 0xc12e,		0x21, 0
	.dw 0xb340, 0xc12e,	0xb37f, 0xc12e,		0x21, 0
	.dw 0xb3c0, 0xc12e,	0xb3ff, 0xc12e,		0x21, 0
	.dw 0xb440, 0xc12e,	0xb47f, 0xc12e,		0x21, 0
	.dw 0xb4c0, 0xc12e,	0xb4ff, 0xc12e,		0x21, 0
	.dw 0xb540, 0xc12e,	0xb57f, 0xc12e,		0x21, 0
	.dw 0xb5c0, 0xc12e,	0xb5ff, 0xc12e,		0x21, 0
	.dw 0xb640, 0xc12e,	0xb67f, 0xc12e,		0x21, 0
	.dw 0xb6c0, 0xc12e,	0xb6ff, 0xc12e,		0x21, 0
	.dw 0xb740, 0xc12e,	0xb77f, 0xc12e,		0x21, 0
	.dw 0xb7c0, 0xc12e,	0xb7ff, 0xc12e,		0x21, 0
	.dw 0xb840, 0xc12e,	0xb87f, 0xc12e,		0x21, 0
	.dw 0xb8c0, 0xc12e,	0xb8ff, 0xc12e,		0x21, 0
	.dw 0xb940, 0xc12e,	0xb97f, 0xc12e,		0x21, 0
	.dw 0xb9c0, 0xc12e,	0xbfff, 0xc12e,		0x21, 0
	.dw 0xc040, 0xc12e,	0xc07f, 0xc12e,		0x21, 0
	.dw 0xc0c0, 0xc12e,	0xc0ff, 0xc12e,		0x21, 0
	.dw 0xc140, 0xc12e,	0xc17f, 0xc12e,		0x21, 0
	.dw 0xc1c0, 0xc12e,	0xc1ff, 0xc12e,		0x21, 0
	.dw 0xc240, 0xc12e,	0xc27f, 0xc12e,		0x21, 0
	.dw 0xc2c0, 0xc12e,	0xc2ff, 0xc12e,		0x21, 0
	.dw 0xc340, 0xc12e,	0xc37f, 0xc12e,		0x21, 0
	.dw 0xc3c0, 0xc12e,	0xc3ff, 0xc12e,		0x21, 0
	.dw 0xc440, 0xc12e,	0xc47f, 0xc12e,		0x21, 0
	.dw 0xc4c0, 0xc12e,	0xc4ff, 0xc12e,		0x21, 0
	.dw 0xc540, 0xc12e,	0xc57f, 0xc12e,		0x21, 0
	.dw 0xc5c0, 0xc12e,	0xc5ff, 0xc12e,		0x21, 0
	.dw 0xc640, 0xc12e,	0xc67f, 0xc12e,		0x21, 0
	.dw 0xc6c0, 0xc12e,	0xc6ff, 0xc12e,		0x21, 0
	.dw 0xc740, 0xc12e,	0xc77f, 0xc12e,		0x21, 0
	.dw 0xc7c0, 0xc12e,	0xc7ff, 0xc12e,		0x21, 0
	.dw 0xc840, 0xc12e,	0xc87f, 0xc12e,		0x21, 0
	.dw 0xc8c0, 0xc12e,	0xc8ff, 0xc12e,		0x21, 0
	.dw 0xc940, 0xc12e,	0xc97f, 0xc12e,		0x21, 0
	.dw 0xc9c0, 0xc12e,	0xc9ff, 0xc12e,		0x21, 0
	.dw 0xca40, 0xc12e,	0xca7f, 0xc12e,		0x21, 0
	.dw 0xcac0, 0xc12e,	0xcaff, 0xc12e,		0x21, 0
	.dw 0xcb40, 0xc12e,	0xcb7f, 0xc12e,		0x21, 0
	.dw 0xcbc0, 0xc12e,	0xcbff, 0xc12e,		0x21, 0
	.dw 0xcc40, 0xc12e,	0xcc7f, 0xc12e,		0x21, 0
	.dw 0xccc0, 0xc12e,	0xccff, 0xc12e,		0x21, 0
	.dw 0xcd40, 0xc12e,	0xcd7f, 0xc12e,		0x21, 0
	.dw 0xcdc0, 0xc12e,	0xcdff, 0xc12e,		0x21, 0
	.dw 0xce40, 0xc12e,	0xce7f, 0xc12e,		0x21, 0
	.dw 0xcec0, 0xc12e,	0xceff, 0xc12e,		0x21, 0
	.dw 0xcf40, 0xc12e,	0xcf7f, 0xc12e,		0x21, 0
	.dw 0xcfc0, 0xc12e,	0xcfff, 0xc12e,		0x21, 0
	.dw 0xd040, 0xc12e,	0xd07f, 0xc12e,		0x21, 0
	.dw 0xd0c0, 0xc12e,	0xd0ff, 0xc12e,		0x21, 0
	.dw 0xd140, 0xc12e,	0xd17f, 0xc12e,		0x21, 0
	.dw 0xd1c0, 0xc12e,	0xd1ff, 0xc12e,		0x21, 0
	.dw 0xd240, 0xc12e,	0xd27f, 0xc12e,		0x21, 0
	.dw 0xd2c0, 0xc12e,	0xd2ff, 0xc12e,		0x21, 0
	.dw 0xd340, 0xc12e,	0xd37f, 0xc12e,		0x21, 0
	.dw 0xd3c0, 0xc12e,	0xd3ff, 0xc12e,		0x21, 0
	.dw 0xd440, 0xc12e,	0xd47f, 0xc12e,		0x21, 0
	.dw 0xd4c0, 0xc12e,	0xd4ff, 0xc12e,		0x21, 0
	.dw 0xd540, 0xc12e,	0xd57f, 0xc12e,		0x21, 0
	.dw 0xd5c0, 0xc12e,	0xd5ff, 0xc12e,		0x21, 0
	.dw 0xd640, 0xc12e,	0xd67f, 0xc12e,		0x21, 0
	.dw 0xd6c0, 0xc12e,	0xd6ff, 0xc12e,		0x21, 0
	.dw 0xd740, 0xc12e,	0xd77f, 0xc12e,		0x21, 0
	.dw 0xd7c0, 0xc12e,	0xd7ff, 0xc12e,		0x21, 0
	.dw 0xd840, 0xc12e,	0xd87f, 0xc12e,		0x21, 0
	.dw 0xd8c0, 0xc12e,	0xd8ff, 0xc12e,		0x21, 0
	.dw 0xd940, 0xc12e,	0xd97f, 0xc12e,		0x21, 0
	.dw 0xd9c0, 0xc12e,	0xdfff, 0xc12e,		0x21, 0
	.dw 0xe040, 0xc12e,	0xe07f, 0xc12e,		0x21, 0
	.dw 0xe0c0, 0xc12e,	0xe0ff, 0xc12e,		0x21, 0
	.dw 0xe140, 0xc12e,	0xe17f, 0xc12e,		0x21, 0
	.dw 0xe1c0, 0xc12e,	0xe1ff, 0xc12e,		0x21, 0
	.dw 0xe240, 0xc12e,	0xe27f, 0xc12e,		0x21, 0
	.dw 0xe2c0, 0xc12e,	0xe2ff, 0xc12e,		0x21, 0
	.dw 0xe340, 0xc12e,	0xe37f, 0xc12e,		0x21, 0
	.dw 0xe3c0, 0xc12e,	0xe3ff, 0xc12e,		0x21, 0
	.dw 0xe440, 0xc12e,	0xe47f, 0xc12e,		0x21, 0
	.dw 0xe4c0, 0xc12e,	0xe4ff, 0xc12e,		0x21, 0
	.dw 0xe540, 0xc12e,	0xe57f, 0xc12e,		0x21, 0
	.dw 0xe5c0, 0xc12e,	0xe5ff, 0xc12e,		0x21, 0
	.dw 0xe640, 0xc12e,	0xe67f, 0xc12e,		0x21, 0
	.dw 0xe6c0, 0xc12e,	0xe6ff, 0xc12e,		0x21, 0
	.dw 0xe740, 0xc12e,	0xe77f, 0xc12e,		0x21, 0
	.dw 0xe7c0, 0xc12e,	0xe7ff, 0xc12e,		0x21, 0
	.dw 0xe840, 0xc12e,	0xe87f, 0xc12e,		0x21, 0
	.dw 0xe8c0, 0xc12e,	0xe8ff, 0xc12e,		0x21, 0
	.dw 0xe940, 0xc12e,	0xe97f, 0xc12e,		0x21, 0
	.dw 0xe9c0, 0xc12e,	0xe9ff, 0xc12e,		0x21, 0
	.dw 0xea40, 0xc12e,	0xea7f, 0xc12e,		0x21, 0
	.dw 0xeac0, 0xc12e,	0xeaff, 0xc12e,		0x21, 0
	.dw 0xeb40, 0xc12e,	0xeb7f, 0xc12e,		0x21, 0
	.dw 0xebc0, 0xc12e,	0xebff, 0xc12e,		0x21, 0
	.dw 0xec40, 0xc12e,	0xec7f, 0xc12e,		0x21, 0
	.dw 0xecc0, 0xc12e,	0xecff, 0xc12e,		0x21, 0
	.dw 0xed40, 0xc12e,	0xed7f, 0xc12e,		0x21, 0
	.dw 0xedc0, 0xc12e,	0xedff, 0xc12e,		0x21, 0
	.dw 0xee40, 0xc12e,	0xee7f, 0xc12e,		0x21, 0
	.dw 0xeec0, 0xc12e,	0xeeff, 0xc12e,		0x21, 0
	.dw 0xef40, 0xc12e,	0xef7f, 0xc12e,		0x21, 0
	.dw 0xefc0, 0xc12e,	0xefff, 0xc12e,		0x21, 0
	.dw 0xf040, 0xc12e,	0xf07f, 0xc12e,		0x21, 0
	.dw 0xf0c0, 0xc12e,	0xf0ff, 0xc12e,		0x21, 0
	.dw 0xf140, 0xc12e,	0xf17f, 0xc12e,		0x21, 0
	.dw 0xf1c0, 0xc12e,	0xf1ff, 0xc12e,		0x21, 0
	.dw 0xf240, 0xc12e,	0xf27f, 0xc12e,		0x21, 0
	.dw 0xf2c0, 0xc12e,	0xf2ff, 0xc12e,		0x21, 0
	.dw 0xf340, 0xc12e,	0xf37f, 0xc12e,		0x21, 0
	.dw 0xf3c0, 0xc12e,	0xf3ff, 0xc12e,		0x21, 0
	.dw 0xf440, 0xc12e,	0xf47f, 0xc12e,		0x21, 0
	.dw 0xf4c0, 0xc12e,	0xf4ff, 0xc12e,		0x21, 0
	.dw 0xf540, 0xc12e,	0xf57f, 0xc12e,		0x21, 0
	.dw 0xf5c0, 0xc12e,	0xf5ff, 0xc12e,		0x21, 0
	.dw 0xf640, 0xc12e,	0xf67f, 0xc12e,		0x21, 0
	.dw 0xf6c0, 0xc12e,	0xf6ff, 0xc12e,		0x21, 0
	.dw 0xf740, 0xc12e,	0xf77f, 0xc12e,		0x21, 0
	.dw 0xf7c0, 0xc12e,	0xf7ff, 0xc12e,		0x21, 0
	.dw 0xf840, 0xc12e,	0xf87f, 0xc12e,		0x21, 0
	.dw 0xf8c0, 0xc12e,	0xf8ff, 0xc12e,		0x21, 0
	.dw 0xf940, 0xc12e,	0xf97f, 0xc12e,		0x21, 0
	.dw 0xf9c0, 0xc12e,	0xffff, 0xc12e,		0x21, 0
	.dw 0x0040, 0xc12f,	0x007f, 0xc12f,		0x21, 0
	.dw 0x00c0, 0xc12f,	0x00ff, 0xc12f,		0x21, 0
	.dw 0x0140, 0xc12f,	0x017f, 0xc12f,		0x21, 0
	.dw 0x01c0, 0xc12f,	0x01ff, 0xc12f,		0x21, 0
	.dw 0x0240, 0xc12f,	0x027f, 0xc12f,		0x21, 0
	.dw 0x02c0, 0xc12f,	0x02ff, 0xc12f,		0x21, 0
	.dw 0x0340, 0xc12f,	0x037f, 0xc12f,		0x21, 0
	.dw 0x03c0, 0xc12f,	0x03ff, 0xc12f,		0x21, 0
	.dw 0x0440, 0xc12f,	0x047f, 0xc12f,		0x21, 0
	.dw 0x04c0, 0xc12f,	0x04ff, 0xc12f,		0x21, 0
	.dw 0x0540, 0xc12f,	0x057f, 0xc12f,		0x21, 0
	.dw 0x05c0, 0xc12f,	0x05ff, 0xc12f,		0x21, 0
	.dw 0x0640, 0xc12f,	0x067f, 0xc12f,		0x21, 0
	.dw 0x06c0, 0xc12f,	0x06ff, 0xc12f,		0x21, 0
	.dw 0x0740, 0xc12f,	0x077f, 0xc12f,		0x21, 0
	.dw 0x07c0, 0xc12f,	0x07ff, 0xc12f,		0x21, 0
	.dw 0x0840, 0xc12f,	0x087f, 0xc12f,		0x21, 0
	.dw 0x08c0, 0xc12f,	0x08ff, 0xc12f,		0x21, 0
	.dw 0x0940, 0xc12f,	0x097f, 0xc12f,		0x21, 0
	.dw 0x09c0, 0xc12f,	0x09ff, 0xc12f,		0x21, 0
	.dw 0x0a40, 0xc12f,	0x0a7f, 0xc12f,		0x21, 0
	.dw 0x0ac0, 0xc12f,	0x0aff, 0xc12f,		0x21, 0
	.dw 0x0b40, 0xc12f,	0x0b7f, 0xc12f,		0x21, 0
	.dw 0x0bc0, 0xc12f,	0x0bff, 0xc12f,		0x21, 0
	.dw 0x0c40, 0xc12f,	0x0c7f, 0xc12f,		0x21, 0
	.dw 0x0cc0, 0xc12f,	0x0cff, 0xc12f,		0x21, 0
	.dw 0x0d40, 0xc12f,	0x0d7f, 0xc12f,		0x21, 0
	.dw 0x0dc0, 0xc12f,	0x0dff, 0xc12f,		0x21, 0
	.dw 0x0e40, 0xc12f,	0x0e7f, 0xc12f,		0x21, 0
	.dw 0x0ec0, 0xc12f,	0x0eff, 0xc12f,		0x21, 0
	.dw 0x0f40, 0xc12f,	0x0f7f, 0xc12f,		0x21, 0
	.dw 0x0fc0, 0xc12f,	0x0fff, 0xc12f,		0x21, 0
	.dw 0x1040, 0xc12f,	0x107f, 0xc12f,		0x21, 0
	.dw 0x10c0, 0xc12f,	0x10ff, 0xc12f,		0x21, 0
	.dw 0x1140, 0xc12f,	0x117f, 0xc12f,		0x21, 0
	.dw 0x11c0, 0xc12f,	0x11ff, 0xc12f,		0x21, 0
	.dw 0x1240, 0xc12f,	0x127f, 0xc12f,		0x21, 0
	.dw 0x12c0, 0xc12f,	0x12ff, 0xc12f,		0x21, 0
	.dw 0x1340, 0xc12f,	0x137f, 0xc12f,		0x21, 0
	.dw 0x13c0, 0xc12f,	0x13ff, 0xc12f,		0x21, 0
	.dw 0x1440, 0xc12f,	0x147f, 0xc12f,		0x21, 0
	.dw 0x14c0, 0xc12f,	0x14ff, 0xc12f,		0x21, 0
	.dw 0x1540, 0xc12f,	0x157f, 0xc12f,		0x21, 0
	.dw 0x15c0, 0xc12f,	0x15ff, 0xc12f,		0x21, 0
	.dw 0x1640, 0xc12f,	0x167f, 0xc12f,		0x21, 0
	.dw 0x16c0, 0xc12f,	0x16ff, 0xc12f,		0x21, 0
	.dw 0x1740, 0xc12f,	0x177f, 0xc12f,		0x21, 0
	.dw 0x17c0, 0xc12f,	0x17ff, 0xc12f,		0x21, 0
	.dw 0x1840, 0xc12f,	0x187f, 0xc12f,		0x21, 0
	.dw 0x18c0, 0xc12f,	0x18ff, 0xc12f,		0x21, 0
	.dw 0x1940, 0xc12f,	0x197f, 0xc12f,		0x21, 0
	.dw 0x19c0, 0xc12f,	0x1fff, 0xc12f,		0x21, 0
	.dw 0x2040, 0xc12f,	0x207f, 0xc12f,		0x21, 0
	.dw 0x20c0, 0xc12f,	0x20ff, 0xc12f,		0x21, 0
	.dw 0x2140, 0xc12f,	0x217f, 0xc12f,		0x21, 0
	.dw 0x21c0, 0xc12f,	0x21ff, 0xc12f,		0x21, 0
	.dw 0x2240, 0xc12f,	0x227f, 0xc12f,		0x21, 0
	.dw 0x22c0, 0xc12f,	0x22ff, 0xc12f,		0x21, 0
	.dw 0x2340, 0xc12f,	0x237f, 0xc12f,		0x21, 0
	.dw 0x23c0, 0xc12f,	0x23ff, 0xc12f,		0x21, 0
	.dw 0x2440, 0xc12f,	0x247f, 0xc12f,		0x21, 0
	.dw 0x24c0, 0xc12f,	0x24ff, 0xc12f,		0x21, 0
	.dw 0x2540, 0xc12f,	0x257f, 0xc12f,		0x21, 0
	.dw 0x25c0, 0xc12f,	0x25ff, 0xc12f,		0x21, 0
	.dw 0x2640, 0xc12f,	0x267f, 0xc12f,		0x21, 0
	.dw 0x26c0, 0xc12f,	0x26ff, 0xc12f,		0x21, 0
	.dw 0x2740, 0xc12f,	0x277f, 0xc12f,		0x21, 0
	.dw 0x27c0, 0xc12f,	0x27ff, 0xc12f,		0x21, 0
	.dw 0x2840, 0xc12f,	0x287f, 0xc12f,		0x21, 0
	.dw 0x28c0, 0xc12f,	0x28ff, 0xc12f,		0x21, 0
	.dw 0x2940, 0xc12f,	0x297f, 0xc12f,		0x21, 0
	.dw 0x29c0, 0xc12f,	0x29ff, 0xc12f,		0x21, 0
	.dw 0x2a40, 0xc12f,	0x2a7f, 0xc12f,		0x21, 0
	.dw 0x2ac0, 0xc12f,	0x2aff, 0xc12f,		0x21, 0
	.dw 0x2b40, 0xc12f,	0x2b7f, 0xc12f,		0x21, 0
	.dw 0x2bc0, 0xc12f,	0x2bff, 0xc12f,		0x21, 0
	.dw 0x2c40, 0xc12f,	0x2c7f, 0xc12f,		0x21, 0
	.dw 0x2cc0, 0xc12f,	0x2cff, 0xc12f,		0x21, 0
	.dw 0x2d40, 0xc12f,	0x2d7f, 0xc12f,		0x21, 0
	.dw 0x2dc0, 0xc12f,	0x2dff, 0xc12f,		0x21, 0
	.dw 0x2e40, 0xc12f,	0x2e7f, 0xc12f,		0x21, 0
	.dw 0x2ec0, 0xc12f,	0x2eff, 0xc12f,		0x21, 0
	.dw 0x2f40, 0xc12f,	0x2f7f, 0xc12f,		0x21, 0
	.dw 0x2fc0, 0xc12f,	0x2fff, 0xc12f,		0x21, 0
	.dw 0x3040, 0xc12f,	0x307f, 0xc12f,		0x21, 0
	.dw 0x30c0, 0xc12f,	0x30ff, 0xc12f,		0x21, 0
	.dw 0x3140, 0xc12f,	0x317f, 0xc12f,		0x21, 0
	.dw 0x31c0, 0xc12f,	0x31ff, 0xc12f,		0x21, 0
	.dw 0x3240, 0xc12f,	0x327f, 0xc12f,		0x21, 0
	.dw 0x32c0, 0xc12f,	0x32ff, 0xc12f,		0x21, 0
	.dw 0x3340, 0xc12f,	0x337f, 0xc12f,		0x21, 0
	.dw 0x33c0, 0xc12f,	0x33ff, 0xc12f,		0x21, 0
	.dw 0x3440, 0xc12f,	0x347f, 0xc12f,		0x21, 0
	.dw 0x34c0, 0xc12f,	0x34ff, 0xc12f,		0x21, 0
	.dw 0x3540, 0xc12f,	0x357f, 0xc12f,		0x21, 0
	.dw 0x35c0, 0xc12f,	0x35ff, 0xc12f,		0x21, 0
	.dw 0x3640, 0xc12f,	0x367f, 0xc12f,		0x21, 0
	.dw 0x36c0, 0xc12f,	0x36ff, 0xc12f,		0x21, 0
	.dw 0x3740, 0xc12f,	0x377f, 0xc12f,		0x21, 0
	.dw 0x37c0, 0xc12f,	0x37ff, 0xc12f,		0x21, 0
	.dw 0x3840, 0xc12f,	0x387f, 0xc12f,		0x21, 0
	.dw 0x38c0, 0xc12f,	0x38ff, 0xc12f,		0x21, 0
	.dw 0x3940, 0xc12f,	0x397f, 0xc12f,		0x21, 0
	.dw 0x39c0, 0xc12f,	0x1fff, 0xc130,		0x21, 0
	.dw 0x3a00, 0xc130,	0x5fff, 0xc130,		0x21, 0
	.dw 0x7a00, 0xc130,	0x9fff, 0xc130,		0x21, 0
	.dw 0xba00, 0xc130,	0xdfff, 0xc130,		0x21, 0
	.dw 0xfa00, 0xc130,	0x1fff, 0xc131,		0x21, 0
	.dw 0x3a00, 0xc131,	0x5fff, 0xc131,		0x21, 0
	.dw 0x7a00, 0xc131,	0x9fff, 0xc131,		0x21, 0
	.dw 0xba00, 0xc131,	0xdfff, 0xc131,		0x21, 0
	.dw 0xfa00, 0xc131,	0x1fff, 0xc132,		0x21, 0
	.dw 0x3a00, 0xc132,	0x5fff, 0xc132,		0x21, 0
	.dw 0x7a00, 0xc132,	0x9fff, 0xc132,		0x21, 0
	.dw 0xba00, 0xc132,	0xdfff, 0xc132,		0x21, 0
	.dw 0xfa00, 0xc132,	0xffff, 0xc133,		0x21, 0
	.dw 0x1a00, 0xc134,	0x1fff, 0xc134,		0x21, 0
	.dw 0x3a00, 0xc134,	0x3fff, 0xc134,		0x21, 0
	.dw 0x5a00, 0xc134,	0x5fff, 0xc134,		0x21, 0
	.dw 0x7a00, 0xc134,	0x7fff, 0xc134,		0x21, 0
	.dw 0x9a00, 0xc134,	0x9fff, 0xc134,		0x21, 0
	.dw 0xba00, 0xc134,	0xbfff, 0xc134,		0x21, 0
	.dw 0xda00, 0xc134,	0xdfff, 0xc134,		0x21, 0
	.dw 0xfa00, 0xc134,	0xffff, 0xc134,		0x21, 0
	.dw 0x1a00, 0xc135,	0x1fff, 0xc135,		0x21, 0
	.dw 0x3a00, 0xc135,	0x3fff, 0xc135,		0x21, 0
	.dw 0x5a00, 0xc135,	0x5fff, 0xc135,		0x21, 0
	.dw 0x7a00, 0xc135,	0x7fff, 0xc135,		0x21, 0
	.dw 0x9a00, 0xc135,	0x9fff, 0xc135,		0x21, 0
	.dw 0xba00, 0xc135,	0xbfff, 0xc135,		0x21, 0
	.dw 0xda00, 0xc135,	0xdfff, 0xc135,		0x21, 0
	.dw 0xfa00, 0xc135,	0xffff, 0xc135,		0x21, 0
	.dw 0x1a00, 0xc136,	0x1fff, 0xc136,		0x21, 0
	.dw 0x3a00, 0xc136,	0x3fff, 0xc136,		0x21, 0
	.dw 0x5a00, 0xc136,	0x5fff, 0xc136,		0x21, 0
	.dw 0x7a00, 0xc136,	0x7fff, 0xc136,		0x21, 0
	.dw 0x9a00, 0xc136,	0x9fff, 0xc136,		0x21, 0
	.dw 0xba00, 0xc136,	0xbfff, 0xc136,		0x21, 0
	.dw 0xda00, 0xc136,	0xdfff, 0xc136,		0x21, 0
	.dw 0xfa00, 0xc136,	0xffff, 0xc136,		0x21, 0
	.dw 0x1a00, 0xc137,	0x1fff, 0xc137,		0x21, 0
	.dw 0x3a00, 0xc137,	0x1fff, 0xc138,		0x21, 0
	.dw 0x2040, 0xc138,	0x207f, 0xc138,		0x21, 0
	.dw 0x20c0, 0xc138,	0x20ff, 0xc138,		0x21, 0
	.dw 0x2140, 0xc138,	0x217f, 0xc138,		0x21, 0
	.dw 0x21c0, 0xc138,	0x21ff, 0xc138,		0x21, 0
	.dw 0x2240, 0xc138,	0x227f, 0xc138,		0x21, 0
	.dw 0x22c0, 0xc138,	0x22ff, 0xc138,		0x21, 0
	.dw 0x2340, 0xc138,	0x237f, 0xc138,		0x21, 0
	.dw 0x23c0, 0xc138,	0x23ff, 0xc138,		0x21, 0
	.dw 0x2440, 0xc138,	0x247f, 0xc138,		0x21, 0
	.dw 0x24c0, 0xc138,	0x24ff, 0xc138,		0x21, 0
	.dw 0x2540, 0xc138,	0x257f, 0xc138,		0x21, 0
	.dw 0x25c0, 0xc138,	0x25ff, 0xc138,		0x21, 0
	.dw 0x2640, 0xc138,	0x267f, 0xc138,		0x21, 0
	.dw 0x26c0, 0xc138,	0x26ff, 0xc138,		0x21, 0
	.dw 0x2740, 0xc138,	0x277f, 0xc138,		0x21, 0
	.dw 0x27c0, 0xc138,	0x27ff, 0xc138,		0x21, 0
	.dw 0x2840, 0xc138,	0x287f, 0xc138,		0x21, 0
	.dw 0x28c0, 0xc138,	0x28ff, 0xc138,		0x21, 0
	.dw 0x2940, 0xc138,	0x297f, 0xc138,		0x21, 0
	.dw 0x29c0, 0xc138,	0x29ff, 0xc138,		0x21, 0
	.dw 0x2a40, 0xc138,	0x2a7f, 0xc138,		0x21, 0
	.dw 0x2ac0, 0xc138,	0x2aff, 0xc138,		0x21, 0
	.dw 0x2b40, 0xc138,	0x2b7f, 0xc138,		0x21, 0
	.dw 0x2bc0, 0xc138,	0x2bff, 0xc138,		0x21, 0
	.dw 0x2c40, 0xc138,	0x2c7f, 0xc138,		0x21, 0
	.dw 0x2cc0, 0xc138,	0x2cff, 0xc138,		0x21, 0
	.dw 0x2d40, 0xc138,	0x2d7f, 0xc138,		0x21, 0
	.dw 0x2dc0, 0xc138,	0x2dff, 0xc138,		0x21, 0
	.dw 0x2e40, 0xc138,	0x2e7f, 0xc138,		0x21, 0
	.dw 0x2ec0, 0xc138,	0x2eff, 0xc138,		0x21, 0
	.dw 0x2f40, 0xc138,	0x2f7f, 0xc138,		0x21, 0
	.dw 0x2fc0, 0xc138,	0x2fff, 0xc138,		0x21, 0
	.dw 0x3040, 0xc138,	0x307f, 0xc138,		0x21, 0
	.dw 0x30c0, 0xc138,	0x30ff, 0xc138,		0x21, 0
	.dw 0x3140, 0xc138,	0x317f, 0xc138,		0x21, 0
	.dw 0x31c0, 0xc138,	0x31ff, 0xc138,		0x21, 0
	.dw 0x3240, 0xc138,	0x327f, 0xc138,		0x21, 0
	.dw 0x32c0, 0xc138,	0x32ff, 0xc138,		0x21, 0
	.dw 0x3340, 0xc138,	0x337f, 0xc138,		0x21, 0
	.dw 0x33c0, 0xc138,	0x33ff, 0xc138,		0x21, 0
	.dw 0x3440, 0xc138,	0x347f, 0xc138,		0x21, 0
	.dw 0x34c0, 0xc138,	0x34ff, 0xc138,		0x21, 0
	.dw 0x3540, 0xc138,	0x357f, 0xc138,		0x21, 0
	.dw 0x35c0, 0xc138,	0x35ff, 0xc138,		0x21, 0
	.dw 0x3640, 0xc138,	0x367f, 0xc138,		0x21, 0
	.dw 0x36c0, 0xc138,	0x36ff, 0xc138,		0x21, 0
	.dw 0x3740, 0xc138,	0x377f, 0xc138,		0x21, 0
	.dw 0x37c0, 0xc138,	0x37ff, 0xc138,		0x21, 0
	.dw 0x3840, 0xc138,	0x387f, 0xc138,		0x21, 0
	.dw 0x38c0, 0xc138,	0x38ff, 0xc138,		0x21, 0
	.dw 0x3940, 0xc138,	0x397f, 0xc138,		0x21, 0
	.dw 0x39c0, 0xc138,	0x5fff, 0xc138,		0x21, 0
	.dw 0x6040, 0xc138,	0x607f, 0xc138,		0x21, 0
	.dw 0x60c0, 0xc138,	0x60ff, 0xc138,		0x21, 0
	.dw 0x6140, 0xc138,	0x617f, 0xc138,		0x21, 0
	.dw 0x61c0, 0xc138,	0x61ff, 0xc138,		0x21, 0
	.dw 0x6240, 0xc138,	0x627f, 0xc138,		0x21, 0
	.dw 0x62c0, 0xc138,	0x62ff, 0xc138,		0x21, 0
	.dw 0x6340, 0xc138,	0x637f, 0xc138,		0x21, 0
	.dw 0x63c0, 0xc138,	0x63ff, 0xc138,		0x21, 0
	.dw 0x6440, 0xc138,	0x647f, 0xc138,		0x21, 0
	.dw 0x64c0, 0xc138,	0x64ff, 0xc138,		0x21, 0
	.dw 0x6540, 0xc138,	0x657f, 0xc138,		0x21, 0
	.dw 0x65c0, 0xc138,	0x65ff, 0xc138,		0x21, 0
	.dw 0x6640, 0xc138,	0x667f, 0xc138,		0x21, 0
	.dw 0x66c0, 0xc138,	0x66ff, 0xc138,		0x21, 0
	.dw 0x6740, 0xc138,	0x677f, 0xc138,		0x21, 0
	.dw 0x67c0, 0xc138,	0x67ff, 0xc138,		0x21, 0
	.dw 0x6840, 0xc138,	0x687f, 0xc138,		0x21, 0
	.dw 0x68c0, 0xc138,	0x68ff, 0xc138,		0x21, 0
	.dw 0x6940, 0xc138,	0x697f, 0xc138,		0x21, 0
	.dw 0x69c0, 0xc138,	0x69ff, 0xc138,		0x21, 0
	.dw 0x6a40, 0xc138,	0x6a7f, 0xc138,		0x21, 0
	.dw 0x6ac0, 0xc138,	0x6aff, 0xc138,		0x21, 0
	.dw 0x6b40, 0xc138,	0x6b7f, 0xc138,		0x21, 0
	.dw 0x6bc0, 0xc138,	0x6bff, 0xc138,		0x21, 0
	.dw 0x6c40, 0xc138,	0x6c7f, 0xc138,		0x21, 0
	.dw 0x6cc0, 0xc138,	0x6cff, 0xc138,		0x21, 0
	.dw 0x6d40, 0xc138,	0x6d7f, 0xc138,		0x21, 0
	.dw 0x6dc0, 0xc138,	0x6dff, 0xc138,		0x21, 0
	.dw 0x6e40, 0xc138,	0x6e7f, 0xc138,		0x21, 0
	.dw 0x6ec0, 0xc138,	0x6eff, 0xc138,		0x21, 0
	.dw 0x6f40, 0xc138,	0x6f7f, 0xc138,		0x21, 0
	.dw 0x6fc0, 0xc138,	0x6fff, 0xc138,		0x21, 0
	.dw 0x7040, 0xc138,	0x707f, 0xc138,		0x21, 0
	.dw 0x70c0, 0xc138,	0x70ff, 0xc138,		0x21, 0
	.dw 0x7140, 0xc138,	0x717f, 0xc138,		0x21, 0
	.dw 0x71c0, 0xc138,	0x71ff, 0xc138,		0x21, 0
	.dw 0x7240, 0xc138,	0x727f, 0xc138,		0x21, 0
	.dw 0x72c0, 0xc138,	0x72ff, 0xc138,		0x21, 0
	.dw 0x7340, 0xc138,	0x737f, 0xc138,		0x21, 0
	.dw 0x73c0, 0xc138,	0x73ff, 0xc138,		0x21, 0
	.dw 0x7440, 0xc138,	0x747f, 0xc138,		0x21, 0
	.dw 0x74c0, 0xc138,	0x74ff, 0xc138,		0x21, 0
	.dw 0x7540, 0xc138,	0x757f, 0xc138,		0x21, 0
	.dw 0x75c0, 0xc138,	0x75ff, 0xc138,		0x21, 0
	.dw 0x7640, 0xc138,	0x767f, 0xc138,		0x21, 0
	.dw 0x76c0, 0xc138,	0x76ff, 0xc138,		0x21, 0
	.dw 0x7740, 0xc138,	0x777f, 0xc138,		0x21, 0
	.dw 0x77c0, 0xc138,	0x77ff, 0xc138,		0x21, 0
	.dw 0x7840, 0xc138,	0x787f, 0xc138,		0x21, 0
	.dw 0x78c0, 0xc138,	0x78ff, 0xc138,		0x21, 0
	.dw 0x7940, 0xc138,	0x797f, 0xc138,		0x21, 0
	.dw 0x79c0, 0xc138,	0x9fff, 0xc138,		0x21, 0
	.dw 0xa040, 0xc138,	0xa07f, 0xc138,		0x21, 0
	.dw 0xa0c0, 0xc138,	0xa0ff, 0xc138,		0x21, 0
	.dw 0xa140, 0xc138,	0xa17f, 0xc138,		0x21, 0
	.dw 0xa1c0, 0xc138,	0xa1ff, 0xc138,		0x21, 0
	.dw 0xa240, 0xc138,	0xa27f, 0xc138,		0x21, 0
	.dw 0xa2c0, 0xc138,	0xa2ff, 0xc138,		0x21, 0
	.dw 0xa340, 0xc138,	0xa37f, 0xc138,		0x21, 0
	.dw 0xa3c0, 0xc138,	0xa3ff, 0xc138,		0x21, 0
	.dw 0xa440, 0xc138,	0xa47f, 0xc138,		0x21, 0
	.dw 0xa4c0, 0xc138,	0xa4ff, 0xc138,		0x21, 0
	.dw 0xa540, 0xc138,	0xa57f, 0xc138,		0x21, 0
	.dw 0xa5c0, 0xc138,	0xa5ff, 0xc138,		0x21, 0
	.dw 0xa640, 0xc138,	0xa67f, 0xc138,		0x21, 0
	.dw 0xa6c0, 0xc138,	0xa6ff, 0xc138,		0x21, 0
	.dw 0xa740, 0xc138,	0xa77f, 0xc138,		0x21, 0
	.dw 0xa7c0, 0xc138,	0xa7ff, 0xc138,		0x21, 0
	.dw 0xa840, 0xc138,	0xa87f, 0xc138,		0x21, 0
	.dw 0xa8c0, 0xc138,	0xa8ff, 0xc138,		0x21, 0
	.dw 0xa940, 0xc138,	0xa97f, 0xc138,		0x21, 0
	.dw 0xa9c0, 0xc138,	0xa9ff, 0xc138,		0x21, 0
	.dw 0xaa40, 0xc138,	0xaa7f, 0xc138,		0x21, 0
	.dw 0xaac0, 0xc138,	0xaaff, 0xc138,		0x21, 0
	.dw 0xab40, 0xc138,	0xab7f, 0xc138,		0x21, 0
	.dw 0xabc0, 0xc138,	0xabff, 0xc138,		0x21, 0
	.dw 0xac40, 0xc138,	0xac7f, 0xc138,		0x21, 0
	.dw 0xacc0, 0xc138,	0xacff, 0xc138,		0x21, 0
	.dw 0xad40, 0xc138,	0xad7f, 0xc138,		0x21, 0
	.dw 0xadc0, 0xc138,	0xadff, 0xc138,		0x21, 0
	.dw 0xae40, 0xc138,	0xae7f, 0xc138,		0x21, 0
	.dw 0xaec0, 0xc138,	0xaeff, 0xc138,		0x21, 0
	.dw 0xaf40, 0xc138,	0xaf7f, 0xc138,		0x21, 0
	.dw 0xafc0, 0xc138,	0xafff, 0xc138,		0x21, 0
	.dw 0xb040, 0xc138,	0xb07f, 0xc138,		0x21, 0
	.dw 0xb0c0, 0xc138,	0xb0ff, 0xc138,		0x21, 0
	.dw 0xb140, 0xc138,	0xb17f, 0xc138,		0x21, 0
	.dw 0xb1c0, 0xc138,	0xb1ff, 0xc138,		0x21, 0
	.dw 0xb240, 0xc138,	0xb27f, 0xc138,		0x21, 0
	.dw 0xb2c0, 0xc138,	0xb2ff, 0xc138,		0x21, 0
	.dw 0xb340, 0xc138,	0xb37f, 0xc138,		0x21, 0
	.dw 0xb3c0, 0xc138,	0xb3ff, 0xc138,		0x21, 0
	.dw 0xb440, 0xc138,	0xb47f, 0xc138,		0x21, 0
	.dw 0xb4c0, 0xc138,	0xb4ff, 0xc138,		0x21, 0
	.dw 0xb540, 0xc138,	0xb57f, 0xc138,		0x21, 0
	.dw 0xb5c0, 0xc138,	0xb5ff, 0xc138,		0x21, 0
	.dw 0xb640, 0xc138,	0xb67f, 0xc138,		0x21, 0
	.dw 0xb6c0, 0xc138,	0xb6ff, 0xc138,		0x21, 0
	.dw 0xb740, 0xc138,	0xb77f, 0xc138,		0x21, 0
	.dw 0xb7c0, 0xc138,	0xb7ff, 0xc138,		0x21, 0
	.dw 0xb840, 0xc138,	0xb87f, 0xc138,		0x21, 0
	.dw 0xb8c0, 0xc138,	0xb8ff, 0xc138,		0x21, 0
	.dw 0xb940, 0xc138,	0xb97f, 0xc138,		0x21, 0
	.dw 0xb9c0, 0xc138,	0xdfff, 0xc138,		0x21, 0
	.dw 0xe040, 0xc138,	0xe07f, 0xc138,		0x21, 0
	.dw 0xe0c0, 0xc138,	0xe0ff, 0xc138,		0x21, 0
	.dw 0xe140, 0xc138,	0xe17f, 0xc138,		0x21, 0
	.dw 0xe1c0, 0xc138,	0xe1ff, 0xc138,		0x21, 0
	.dw 0xe240, 0xc138,	0xe27f, 0xc138,		0x21, 0
	.dw 0xe2c0, 0xc138,	0xe2ff, 0xc138,		0x21, 0
	.dw 0xe340, 0xc138,	0xe37f, 0xc138,		0x21, 0
	.dw 0xe3c0, 0xc138,	0xe3ff, 0xc138,		0x21, 0
	.dw 0xe440, 0xc138,	0xe47f, 0xc138,		0x21, 0
	.dw 0xe4c0, 0xc138,	0xe4ff, 0xc138,		0x21, 0
	.dw 0xe540, 0xc138,	0xe57f, 0xc138,		0x21, 0
	.dw 0xe5c0, 0xc138,	0xe5ff, 0xc138,		0x21, 0
	.dw 0xe640, 0xc138,	0xe67f, 0xc138,		0x21, 0
	.dw 0xe6c0, 0xc138,	0xe6ff, 0xc138,		0x21, 0
	.dw 0xe740, 0xc138,	0xe77f, 0xc138,		0x21, 0
	.dw 0xe7c0, 0xc138,	0xe7ff, 0xc138,		0x21, 0
	.dw 0xe840, 0xc138,	0xe87f, 0xc138,		0x21, 0
	.dw 0xe8c0, 0xc138,	0xe8ff, 0xc138,		0x21, 0
	.dw 0xe940, 0xc138,	0xe97f, 0xc138,		0x21, 0
	.dw 0xe9c0, 0xc138,	0xe9ff, 0xc138,		0x21, 0
	.dw 0xea40, 0xc138,	0xea7f, 0xc138,		0x21, 0
	.dw 0xeac0, 0xc138,	0xeaff, 0xc138,		0x21, 0
	.dw 0xeb40, 0xc138,	0xeb7f, 0xc138,		0x21, 0
	.dw 0xebc0, 0xc138,	0xebff, 0xc138,		0x21, 0
	.dw 0xec40, 0xc138,	0xec7f, 0xc138,		0x21, 0
	.dw 0xecc0, 0xc138,	0xecff, 0xc138,		0x21, 0
	.dw 0xed40, 0xc138,	0xed7f, 0xc138,		0x21, 0
	.dw 0xedc0, 0xc138,	0xedff, 0xc138,		0x21, 0
	.dw 0xee40, 0xc138,	0xee7f, 0xc138,		0x21, 0
	.dw 0xeec0, 0xc138,	0xeeff, 0xc138,		0x21, 0
	.dw 0xef40, 0xc138,	0xef7f, 0xc138,		0x21, 0
	.dw 0xefc0, 0xc138,	0xefff, 0xc138,		0x21, 0
	.dw 0xf040, 0xc138,	0xf07f, 0xc138,		0x21, 0
	.dw 0xf0c0, 0xc138,	0xf0ff, 0xc138,		0x21, 0
	.dw 0xf140, 0xc138,	0xf17f, 0xc138,		0x21, 0
	.dw 0xf1c0, 0xc138,	0xf1ff, 0xc138,		0x21, 0
	.dw 0xf240, 0xc138,	0xf27f, 0xc138,		0x21, 0
	.dw 0xf2c0, 0xc138,	0xf2ff, 0xc138,		0x21, 0
	.dw 0xf340, 0xc138,	0xf37f, 0xc138,		0x21, 0
	.dw 0xf3c0, 0xc138,	0xf3ff, 0xc138,		0x21, 0
	.dw 0xf440, 0xc138,	0xf47f, 0xc138,		0x21, 0
	.dw 0xf4c0, 0xc138,	0xf4ff, 0xc138,		0x21, 0
	.dw 0xf540, 0xc138,	0xf57f, 0xc138,		0x21, 0
	.dw 0xf5c0, 0xc138,	0xf5ff, 0xc138,		0x21, 0
	.dw 0xf640, 0xc138,	0xf67f, 0xc138,		0x21, 0
	.dw 0xf6c0, 0xc138,	0xf6ff, 0xc138,		0x21, 0
	.dw 0xf740, 0xc138,	0xf77f, 0xc138,		0x21, 0
	.dw 0xf7c0, 0xc138,	0xf7ff, 0xc138,		0x21, 0
	.dw 0xf840, 0xc138,	0xf87f, 0xc138,		0x21, 0
	.dw 0xf8c0, 0xc138,	0xf8ff, 0xc138,		0x21, 0
	.dw 0xf940, 0xc138,	0xf97f, 0xc138,		0x21, 0
	.dw 0xf9c0, 0xc138,	0x1fff, 0xc139,		0x21, 0
	.dw 0x2040, 0xc139,	0x207f, 0xc139,		0x21, 0
	.dw 0x20c0, 0xc139,	0x20ff, 0xc139,		0x21, 0
	.dw 0x2140, 0xc139,	0x217f, 0xc139,		0x21, 0
	.dw 0x21c0, 0xc139,	0x21ff, 0xc139,		0x21, 0
	.dw 0x2240, 0xc139,	0x227f, 0xc139,		0x21, 0
	.dw 0x22c0, 0xc139,	0x22ff, 0xc139,		0x21, 0
	.dw 0x2340, 0xc139,	0x237f, 0xc139,		0x21, 0
	.dw 0x23c0, 0xc139,	0x23ff, 0xc139,		0x21, 0
	.dw 0x2440, 0xc139,	0x247f, 0xc139,		0x21, 0
	.dw 0x24c0, 0xc139,	0x24ff, 0xc139,		0x21, 0
	.dw 0x2540, 0xc139,	0x257f, 0xc139,		0x21, 0
	.dw 0x25c0, 0xc139,	0x25ff, 0xc139,		0x21, 0
	.dw 0x2640, 0xc139,	0x267f, 0xc139,		0x21, 0
	.dw 0x26c0, 0xc139,	0x26ff, 0xc139,		0x21, 0
	.dw 0x2740, 0xc139,	0x277f, 0xc139,		0x21, 0
	.dw 0x27c0, 0xc139,	0x27ff, 0xc139,		0x21, 0
	.dw 0x2840, 0xc139,	0x287f, 0xc139,		0x21, 0
	.dw 0x28c0, 0xc139,	0x28ff, 0xc139,		0x21, 0
	.dw 0x2940, 0xc139,	0x297f, 0xc139,		0x21, 0
	.dw 0x29c0, 0xc139,	0x29ff, 0xc139,		0x21, 0
	.dw 0x2a40, 0xc139,	0x2a7f, 0xc139,		0x21, 0
	.dw 0x2ac0, 0xc139,	0x2aff, 0xc139,		0x21, 0
	.dw 0x2b40, 0xc139,	0x2b7f, 0xc139,		0x21, 0
	.dw 0x2bc0, 0xc139,	0x2bff, 0xc139,		0x21, 0
	.dw 0x2c40, 0xc139,	0x2c7f, 0xc139,		0x21, 0
	.dw 0x2cc0, 0xc139,	0x2cff, 0xc139,		0x21, 0
	.dw 0x2d40, 0xc139,	0x2d7f, 0xc139,		0x21, 0
	.dw 0x2dc0, 0xc139,	0x2dff, 0xc139,		0x21, 0
	.dw 0x2e40, 0xc139,	0x2e7f, 0xc139,		0x21, 0
	.dw 0x2ec0, 0xc139,	0x2eff, 0xc139,		0x21, 0
	.dw 0x2f40, 0xc139,	0x2f7f, 0xc139,		0x21, 0
	.dw 0x2fc0, 0xc139,	0x2fff, 0xc139,		0x21, 0
	.dw 0x3040, 0xc139,	0x307f, 0xc139,		0x21, 0
	.dw 0x30c0, 0xc139,	0x30ff, 0xc139,		0x21, 0
	.dw 0x3140, 0xc139,	0x317f, 0xc139,		0x21, 0
	.dw 0x31c0, 0xc139,	0x31ff, 0xc139,		0x21, 0
	.dw 0x3240, 0xc139,	0x327f, 0xc139,		0x21, 0
	.dw 0x32c0, 0xc139,	0x32ff, 0xc139,		0x21, 0
	.dw 0x3340, 0xc139,	0x337f, 0xc139,		0x21, 0
	.dw 0x33c0, 0xc139,	0x33ff, 0xc139,		0x21, 0
	.dw 0x3440, 0xc139,	0x347f, 0xc139,		0x21, 0
	.dw 0x34c0, 0xc139,	0x34ff, 0xc139,		0x21, 0
	.dw 0x3540, 0xc139,	0x357f, 0xc139,		0x21, 0
	.dw 0x35c0, 0xc139,	0x35ff, 0xc139,		0x21, 0
	.dw 0x3640, 0xc139,	0x367f, 0xc139,		0x21, 0
	.dw 0x36c0, 0xc139,	0x36ff, 0xc139,		0x21, 0
	.dw 0x3740, 0xc139,	0x377f, 0xc139,		0x21, 0
	.dw 0x37c0, 0xc139,	0x37ff, 0xc139,		0x21, 0
	.dw 0x3840, 0xc139,	0x387f, 0xc139,		0x21, 0
	.dw 0x38c0, 0xc139,	0x38ff, 0xc139,		0x21, 0
	.dw 0x3940, 0xc139,	0x397f, 0xc139,		0x21, 0
	.dw 0x39c0, 0xc139,	0x5fff, 0xc139,		0x21, 0
	.dw 0x6040, 0xc139,	0x607f, 0xc139,		0x21, 0
	.dw 0x60c0, 0xc139,	0x60ff, 0xc139,		0x21, 0
	.dw 0x6140, 0xc139,	0x617f, 0xc139,		0x21, 0
	.dw 0x61c0, 0xc139,	0x61ff, 0xc139,		0x21, 0
	.dw 0x6240, 0xc139,	0x627f, 0xc139,		0x21, 0
	.dw 0x62c0, 0xc139,	0x62ff, 0xc139,		0x21, 0
	.dw 0x6340, 0xc139,	0x637f, 0xc139,		0x21, 0
	.dw 0x63c0, 0xc139,	0x63ff, 0xc139,		0x21, 0
	.dw 0x6440, 0xc139,	0x647f, 0xc139,		0x21, 0
	.dw 0x64c0, 0xc139,	0x64ff, 0xc139,		0x21, 0
	.dw 0x6540, 0xc139,	0x657f, 0xc139,		0x21, 0
	.dw 0x65c0, 0xc139,	0x65ff, 0xc139,		0x21, 0
	.dw 0x6640, 0xc139,	0x667f, 0xc139,		0x21, 0
	.dw 0x66c0, 0xc139,	0x66ff, 0xc139,		0x21, 0
	.dw 0x6740, 0xc139,	0x677f, 0xc139,		0x21, 0
	.dw 0x67c0, 0xc139,	0x67ff, 0xc139,		0x21, 0
	.dw 0x6840, 0xc139,	0x687f, 0xc139,		0x21, 0
	.dw 0x68c0, 0xc139,	0x68ff, 0xc139,		0x21, 0
	.dw 0x6940, 0xc139,	0x697f, 0xc139,		0x21, 0
	.dw 0x69c0, 0xc139,	0x69ff, 0xc139,		0x21, 0
	.dw 0x6a40, 0xc139,	0x6a7f, 0xc139,		0x21, 0
	.dw 0x6ac0, 0xc139,	0x6aff, 0xc139,		0x21, 0
	.dw 0x6b40, 0xc139,	0x6b7f, 0xc139,		0x21, 0
	.dw 0x6bc0, 0xc139,	0x6bff, 0xc139,		0x21, 0
	.dw 0x6c40, 0xc139,	0x6c7f, 0xc139,		0x21, 0
	.dw 0x6cc0, 0xc139,	0x6cff, 0xc139,		0x21, 0
	.dw 0x6d40, 0xc139,	0x6d7f, 0xc139,		0x21, 0
	.dw 0x6dc0, 0xc139,	0x6dff, 0xc139,		0x21, 0
	.dw 0x6e40, 0xc139,	0x6e7f, 0xc139,		0x21, 0
	.dw 0x6ec0, 0xc139,	0x6eff, 0xc139,		0x21, 0
	.dw 0x6f40, 0xc139,	0x6f7f, 0xc139,		0x21, 0
	.dw 0x6fc0, 0xc139,	0x6fff, 0xc139,		0x21, 0
	.dw 0x7040, 0xc139,	0x707f, 0xc139,		0x21, 0
	.dw 0x70c0, 0xc139,	0x70ff, 0xc139,		0x21, 0
	.dw 0x7140, 0xc139,	0x717f, 0xc139,		0x21, 0
	.dw 0x71c0, 0xc139,	0x71ff, 0xc139,		0x21, 0
	.dw 0x7240, 0xc139,	0x727f, 0xc139,		0x21, 0
	.dw 0x72c0, 0xc139,	0x72ff, 0xc139,		0x21, 0
	.dw 0x7340, 0xc139,	0x737f, 0xc139,		0x21, 0
	.dw 0x73c0, 0xc139,	0x73ff, 0xc139,		0x21, 0
	.dw 0x7440, 0xc139,	0x747f, 0xc139,		0x21, 0
	.dw 0x74c0, 0xc139,	0x74ff, 0xc139,		0x21, 0
	.dw 0x7540, 0xc139,	0x757f, 0xc139,		0x21, 0
	.dw 0x75c0, 0xc139,	0x75ff, 0xc139,		0x21, 0
	.dw 0x7640, 0xc139,	0x767f, 0xc139,		0x21, 0
	.dw 0x76c0, 0xc139,	0x76ff, 0xc139,		0x21, 0
	.dw 0x7740, 0xc139,	0x777f, 0xc139,		0x21, 0
	.dw 0x77c0, 0xc139,	0x77ff, 0xc139,		0x21, 0
	.dw 0x7840, 0xc139,	0x787f, 0xc139,		0x21, 0
	.dw 0x78c0, 0xc139,	0x78ff, 0xc139,		0x21, 0
	.dw 0x7940, 0xc139,	0x797f, 0xc139,		0x21, 0
	.dw 0x79c0, 0xc139,	0x9fff, 0xc139,		0x21, 0
	.dw 0xa040, 0xc139,	0xa07f, 0xc139,		0x21, 0
	.dw 0xa0c0, 0xc139,	0xa0ff, 0xc139,		0x21, 0
	.dw 0xa140, 0xc139,	0xa17f, 0xc139,		0x21, 0
	.dw 0xa1c0, 0xc139,	0xa1ff, 0xc139,		0x21, 0
	.dw 0xa240, 0xc139,	0xa27f, 0xc139,		0x21, 0
	.dw 0xa2c0, 0xc139,	0xa2ff, 0xc139,		0x21, 0
	.dw 0xa340, 0xc139,	0xa37f, 0xc139,		0x21, 0
	.dw 0xa3c0, 0xc139,	0xa3ff, 0xc139,		0x21, 0
	.dw 0xa440, 0xc139,	0xa47f, 0xc139,		0x21, 0
	.dw 0xa4c0, 0xc139,	0xa4ff, 0xc139,		0x21, 0
	.dw 0xa540, 0xc139,	0xa57f, 0xc139,		0x21, 0
	.dw 0xa5c0, 0xc139,	0xa5ff, 0xc139,		0x21, 0
	.dw 0xa640, 0xc139,	0xa67f, 0xc139,		0x21, 0
	.dw 0xa6c0, 0xc139,	0xa6ff, 0xc139,		0x21, 0
	.dw 0xa740, 0xc139,	0xa77f, 0xc139,		0x21, 0
	.dw 0xa7c0, 0xc139,	0xa7ff, 0xc139,		0x21, 0
	.dw 0xa840, 0xc139,	0xa87f, 0xc139,		0x21, 0
	.dw 0xa8c0, 0xc139,	0xa8ff, 0xc139,		0x21, 0
	.dw 0xa940, 0xc139,	0xa97f, 0xc139,		0x21, 0
	.dw 0xa9c0, 0xc139,	0xa9ff, 0xc139,		0x21, 0
	.dw 0xaa40, 0xc139,	0xaa7f, 0xc139,		0x21, 0
	.dw 0xaac0, 0xc139,	0xaaff, 0xc139,		0x21, 0
	.dw 0xab40, 0xc139,	0xab7f, 0xc139,		0x21, 0
	.dw 0xabc0, 0xc139,	0xabff, 0xc139,		0x21, 0
	.dw 0xac40, 0xc139,	0xac7f, 0xc139,		0x21, 0
	.dw 0xacc0, 0xc139,	0xacff, 0xc139,		0x21, 0
	.dw 0xad40, 0xc139,	0xad7f, 0xc139,		0x21, 0
	.dw 0xadc0, 0xc139,	0xadff, 0xc139,		0x21, 0
	.dw 0xae40, 0xc139,	0xae7f, 0xc139,		0x21, 0
	.dw 0xaec0, 0xc139,	0xaeff, 0xc139,		0x21, 0
	.dw 0xaf40, 0xc139,	0xaf7f, 0xc139,		0x21, 0
	.dw 0xafc0, 0xc139,	0xafff, 0xc139,		0x21, 0
	.dw 0xb040, 0xc139,	0xb07f, 0xc139,		0x21, 0
	.dw 0xb0c0, 0xc139,	0xb0ff, 0xc139,		0x21, 0
	.dw 0xb140, 0xc139,	0xb17f, 0xc139,		0x21, 0
	.dw 0xb1c0, 0xc139,	0xb1ff, 0xc139,		0x21, 0
	.dw 0xb240, 0xc139,	0xb27f, 0xc139,		0x21, 0
	.dw 0xb2c0, 0xc139,	0xb2ff, 0xc139,		0x21, 0
	.dw 0xb340, 0xc139,	0xb37f, 0xc139,		0x21, 0
	.dw 0xb3c0, 0xc139,	0xb3ff, 0xc139,		0x21, 0
	.dw 0xb440, 0xc139,	0xb47f, 0xc139,		0x21, 0
	.dw 0xb4c0, 0xc139,	0xb4ff, 0xc139,		0x21, 0
	.dw 0xb540, 0xc139,	0xb57f, 0xc139,		0x21, 0
	.dw 0xb5c0, 0xc139,	0xb5ff, 0xc139,		0x21, 0
	.dw 0xb640, 0xc139,	0xb67f, 0xc139,		0x21, 0
	.dw 0xb6c0, 0xc139,	0xb6ff, 0xc139,		0x21, 0
	.dw 0xb740, 0xc139,	0xb77f, 0xc139,		0x21, 0
	.dw 0xb7c0, 0xc139,	0xb7ff, 0xc139,		0x21, 0
	.dw 0xb840, 0xc139,	0xb87f, 0xc139,		0x21, 0
	.dw 0xb8c0, 0xc139,	0xb8ff, 0xc139,		0x21, 0
	.dw 0xb940, 0xc139,	0xb97f, 0xc139,		0x21, 0
	.dw 0xb9c0, 0xc139,	0xdfff, 0xc139,		0x21, 0
	.dw 0xe040, 0xc139,	0xe07f, 0xc139,		0x21, 0
	.dw 0xe0c0, 0xc139,	0xe0ff, 0xc139,		0x21, 0
	.dw 0xe140, 0xc139,	0xe17f, 0xc139,		0x21, 0
	.dw 0xe1c0, 0xc139,	0xe1ff, 0xc139,		0x21, 0
	.dw 0xe240, 0xc139,	0xe27f, 0xc139,		0x21, 0
	.dw 0xe2c0, 0xc139,	0xe2ff, 0xc139,		0x21, 0
	.dw 0xe340, 0xc139,	0xe37f, 0xc139,		0x21, 0
	.dw 0xe3c0, 0xc139,	0xe3ff, 0xc139,		0x21, 0
	.dw 0xe440, 0xc139,	0xe47f, 0xc139,		0x21, 0
	.dw 0xe4c0, 0xc139,	0xe4ff, 0xc139,		0x21, 0
	.dw 0xe540, 0xc139,	0xe57f, 0xc139,		0x21, 0
	.dw 0xe5c0, 0xc139,	0xe5ff, 0xc139,		0x21, 0
	.dw 0xe640, 0xc139,	0xe67f, 0xc139,		0x21, 0
	.dw 0xe6c0, 0xc139,	0xe6ff, 0xc139,		0x21, 0
	.dw 0xe740, 0xc139,	0xe77f, 0xc139,		0x21, 0
	.dw 0xe7c0, 0xc139,	0xe7ff, 0xc139,		0x21, 0
	.dw 0xe840, 0xc139,	0xe87f, 0xc139,		0x21, 0
	.dw 0xe8c0, 0xc139,	0xe8ff, 0xc139,		0x21, 0
	.dw 0xe940, 0xc139,	0xe97f, 0xc139,		0x21, 0
	.dw 0xe9c0, 0xc139,	0xe9ff, 0xc139,		0x21, 0
	.dw 0xea40, 0xc139,	0xea7f, 0xc139,		0x21, 0
	.dw 0xeac0, 0xc139,	0xeaff, 0xc139,		0x21, 0
	.dw 0xeb40, 0xc139,	0xeb7f, 0xc139,		0x21, 0
	.dw 0xebc0, 0xc139,	0xebff, 0xc139,		0x21, 0
	.dw 0xec40, 0xc139,	0xec7f, 0xc139,		0x21, 0
	.dw 0xecc0, 0xc139,	0xecff, 0xc139,		0x21, 0
	.dw 0xed40, 0xc139,	0xed7f, 0xc139,		0x21, 0
	.dw 0xedc0, 0xc139,	0xedff, 0xc139,		0x21, 0
	.dw 0xee40, 0xc139,	0xee7f, 0xc139,		0x21, 0
	.dw 0xeec0, 0xc139,	0xeeff, 0xc139,		0x21, 0
	.dw 0xef40, 0xc139,	0xef7f, 0xc139,		0x21, 0
	.dw 0xefc0, 0xc139,	0xefff, 0xc139,		0x21, 0
	.dw 0xf040, 0xc139,	0xf07f, 0xc139,		0x21, 0
	.dw 0xf0c0, 0xc139,	0xf0ff, 0xc139,		0x21, 0
	.dw 0xf140, 0xc139,	0xf17f, 0xc139,		0x21, 0
	.dw 0xf1c0, 0xc139,	0xf1ff, 0xc139,		0x21, 0
	.dw 0xf240, 0xc139,	0xf27f, 0xc139,		0x21, 0
	.dw 0xf2c0, 0xc139,	0xf2ff, 0xc139,		0x21, 0
	.dw 0xf340, 0xc139,	0xf37f, 0xc139,		0x21, 0
	.dw 0xf3c0, 0xc139,	0xf3ff, 0xc139,		0x21, 0
	.dw 0xf440, 0xc139,	0xf47f, 0xc139,		0x21, 0
	.dw 0xf4c0, 0xc139,	0xf4ff, 0xc139,		0x21, 0
	.dw 0xf540, 0xc139,	0xf57f, 0xc139,		0x21, 0
	.dw 0xf5c0, 0xc139,	0xf5ff, 0xc139,		0x21, 0
	.dw 0xf640, 0xc139,	0xf67f, 0xc139,		0x21, 0
	.dw 0xf6c0, 0xc139,	0xf6ff, 0xc139,		0x21, 0
	.dw 0xf740, 0xc139,	0xf77f, 0xc139,		0x21, 0
	.dw 0xf7c0, 0xc139,	0xf7ff, 0xc139,		0x21, 0
	.dw 0xf840, 0xc139,	0xf87f, 0xc139,		0x21, 0
	.dw 0xf8c0, 0xc139,	0xf8ff, 0xc139,		0x21, 0
	.dw 0xf940, 0xc139,	0xf97f, 0xc139,		0x21, 0
	.dw 0xf9c0, 0xc139,	0x1fff, 0xc13a,		0x21, 0
	.dw 0x2040, 0xc13a,	0x207f, 0xc13a,		0x21, 0
	.dw 0x20c0, 0xc13a,	0x20ff, 0xc13a,		0x21, 0
	.dw 0x2140, 0xc13a,	0x217f, 0xc13a,		0x21, 0
	.dw 0x21c0, 0xc13a,	0x21ff, 0xc13a,		0x21, 0
	.dw 0x2240, 0xc13a,	0x227f, 0xc13a,		0x21, 0
	.dw 0x22c0, 0xc13a,	0x22ff, 0xc13a,		0x21, 0
	.dw 0x2340, 0xc13a,	0x237f, 0xc13a,		0x21, 0
	.dw 0x23c0, 0xc13a,	0x23ff, 0xc13a,		0x21, 0
	.dw 0x2440, 0xc13a,	0x247f, 0xc13a,		0x21, 0
	.dw 0x24c0, 0xc13a,	0x24ff, 0xc13a,		0x21, 0
	.dw 0x2540, 0xc13a,	0x257f, 0xc13a,		0x21, 0
	.dw 0x25c0, 0xc13a,	0x25ff, 0xc13a,		0x21, 0
	.dw 0x2640, 0xc13a,	0x267f, 0xc13a,		0x21, 0
	.dw 0x26c0, 0xc13a,	0x26ff, 0xc13a,		0x21, 0
	.dw 0x2740, 0xc13a,	0x277f, 0xc13a,		0x21, 0
	.dw 0x27c0, 0xc13a,	0x27ff, 0xc13a,		0x21, 0
	.dw 0x2840, 0xc13a,	0x287f, 0xc13a,		0x21, 0
	.dw 0x28c0, 0xc13a,	0x28ff, 0xc13a,		0x21, 0
	.dw 0x2940, 0xc13a,	0x297f, 0xc13a,		0x21, 0
	.dw 0x29c0, 0xc13a,	0x29ff, 0xc13a,		0x21, 0
	.dw 0x2a40, 0xc13a,	0x2a7f, 0xc13a,		0x21, 0
	.dw 0x2ac0, 0xc13a,	0x2aff, 0xc13a,		0x21, 0
	.dw 0x2b40, 0xc13a,	0x2b7f, 0xc13a,		0x21, 0
	.dw 0x2bc0, 0xc13a,	0x2bff, 0xc13a,		0x21, 0
	.dw 0x2c40, 0xc13a,	0x2c7f, 0xc13a,		0x21, 0
	.dw 0x2cc0, 0xc13a,	0x2cff, 0xc13a,		0x21, 0
	.dw 0x2d40, 0xc13a,	0x2d7f, 0xc13a,		0x21, 0
	.dw 0x2dc0, 0xc13a,	0x2dff, 0xc13a,		0x21, 0
	.dw 0x2e40, 0xc13a,	0x2e7f, 0xc13a,		0x21, 0
	.dw 0x2ec0, 0xc13a,	0x2eff, 0xc13a,		0x21, 0
	.dw 0x2f40, 0xc13a,	0x2f7f, 0xc13a,		0x21, 0
	.dw 0x2fc0, 0xc13a,	0x2fff, 0xc13a,		0x21, 0
	.dw 0x3040, 0xc13a,	0x307f, 0xc13a,		0x21, 0
	.dw 0x30c0, 0xc13a,	0x30ff, 0xc13a,		0x21, 0
	.dw 0x3140, 0xc13a,	0x317f, 0xc13a,		0x21, 0
	.dw 0x31c0, 0xc13a,	0x31ff, 0xc13a,		0x21, 0
	.dw 0x3240, 0xc13a,	0x327f, 0xc13a,		0x21, 0
	.dw 0x32c0, 0xc13a,	0x32ff, 0xc13a,		0x21, 0
	.dw 0x3340, 0xc13a,	0x337f, 0xc13a,		0x21, 0
	.dw 0x33c0, 0xc13a,	0x33ff, 0xc13a,		0x21, 0
	.dw 0x3440, 0xc13a,	0x347f, 0xc13a,		0x21, 0
	.dw 0x34c0, 0xc13a,	0x34ff, 0xc13a,		0x21, 0
	.dw 0x3540, 0xc13a,	0x357f, 0xc13a,		0x21, 0
	.dw 0x35c0, 0xc13a,	0x35ff, 0xc13a,		0x21, 0
	.dw 0x3640, 0xc13a,	0x367f, 0xc13a,		0x21, 0
	.dw 0x36c0, 0xc13a,	0x36ff, 0xc13a,		0x21, 0
	.dw 0x3740, 0xc13a,	0x377f, 0xc13a,		0x21, 0
	.dw 0x37c0, 0xc13a,	0x37ff, 0xc13a,		0x21, 0
	.dw 0x3840, 0xc13a,	0x387f, 0xc13a,		0x21, 0
	.dw 0x38c0, 0xc13a,	0x38ff, 0xc13a,		0x21, 0
	.dw 0x3940, 0xc13a,	0x397f, 0xc13a,		0x21, 0
	.dw 0x39c0, 0xc13a,	0x5fff, 0xc13a,		0x21, 0
	.dw 0x6040, 0xc13a,	0x607f, 0xc13a,		0x21, 0
	.dw 0x60c0, 0xc13a,	0x60ff, 0xc13a,		0x21, 0
	.dw 0x6140, 0xc13a,	0x617f, 0xc13a,		0x21, 0
	.dw 0x61c0, 0xc13a,	0x61ff, 0xc13a,		0x21, 0
	.dw 0x6240, 0xc13a,	0x627f, 0xc13a,		0x21, 0
	.dw 0x62c0, 0xc13a,	0x62ff, 0xc13a,		0x21, 0
	.dw 0x6340, 0xc13a,	0x637f, 0xc13a,		0x21, 0
	.dw 0x63c0, 0xc13a,	0x63ff, 0xc13a,		0x21, 0
	.dw 0x6440, 0xc13a,	0x647f, 0xc13a,		0x21, 0
	.dw 0x64c0, 0xc13a,	0x64ff, 0xc13a,		0x21, 0
	.dw 0x6540, 0xc13a,	0x657f, 0xc13a,		0x21, 0
	.dw 0x65c0, 0xc13a,	0x65ff, 0xc13a,		0x21, 0
	.dw 0x6640, 0xc13a,	0x667f, 0xc13a,		0x21, 0
	.dw 0x66c0, 0xc13a,	0x66ff, 0xc13a,		0x21, 0
	.dw 0x6740, 0xc13a,	0x677f, 0xc13a,		0x21, 0
	.dw 0x67c0, 0xc13a,	0x67ff, 0xc13a,		0x21, 0
	.dw 0x6840, 0xc13a,	0x687f, 0xc13a,		0x21, 0
	.dw 0x68c0, 0xc13a,	0x68ff, 0xc13a,		0x21, 0
	.dw 0x6940, 0xc13a,	0x697f, 0xc13a,		0x21, 0
	.dw 0x69c0, 0xc13a,	0x69ff, 0xc13a,		0x21, 0
	.dw 0x6a40, 0xc13a,	0x6a7f, 0xc13a,		0x21, 0
	.dw 0x6ac0, 0xc13a,	0x6aff, 0xc13a,		0x21, 0
	.dw 0x6b40, 0xc13a,	0x6b7f, 0xc13a,		0x21, 0
	.dw 0x6bc0, 0xc13a,	0x6bff, 0xc13a,		0x21, 0
	.dw 0x6c40, 0xc13a,	0x6c7f, 0xc13a,		0x21, 0
	.dw 0x6cc0, 0xc13a,	0x6cff, 0xc13a,		0x21, 0
	.dw 0x6d40, 0xc13a,	0x6d7f, 0xc13a,		0x21, 0
	.dw 0x6dc0, 0xc13a,	0x6dff, 0xc13a,		0x21, 0
	.dw 0x6e40, 0xc13a,	0x6e7f, 0xc13a,		0x21, 0
	.dw 0x6ec0, 0xc13a,	0x6eff, 0xc13a,		0x21, 0
	.dw 0x6f40, 0xc13a,	0x6f7f, 0xc13a,		0x21, 0
	.dw 0x6fc0, 0xc13a,	0x6fff, 0xc13a,		0x21, 0
	.dw 0x7040, 0xc13a,	0x707f, 0xc13a,		0x21, 0
	.dw 0x70c0, 0xc13a,	0x70ff, 0xc13a,		0x21, 0
	.dw 0x7140, 0xc13a,	0x717f, 0xc13a,		0x21, 0
	.dw 0x71c0, 0xc13a,	0x71ff, 0xc13a,		0x21, 0
	.dw 0x7240, 0xc13a,	0x727f, 0xc13a,		0x21, 0
	.dw 0x72c0, 0xc13a,	0x72ff, 0xc13a,		0x21, 0
	.dw 0x7340, 0xc13a,	0x737f, 0xc13a,		0x21, 0
	.dw 0x73c0, 0xc13a,	0x73ff, 0xc13a,		0x21, 0
	.dw 0x7440, 0xc13a,	0x747f, 0xc13a,		0x21, 0
	.dw 0x74c0, 0xc13a,	0x74ff, 0xc13a,		0x21, 0
	.dw 0x7540, 0xc13a,	0x757f, 0xc13a,		0x21, 0
	.dw 0x75c0, 0xc13a,	0x75ff, 0xc13a,		0x21, 0
	.dw 0x7640, 0xc13a,	0x767f, 0xc13a,		0x21, 0
	.dw 0x76c0, 0xc13a,	0x76ff, 0xc13a,		0x21, 0
	.dw 0x7740, 0xc13a,	0x777f, 0xc13a,		0x21, 0
	.dw 0x77c0, 0xc13a,	0x77ff, 0xc13a,		0x21, 0
	.dw 0x7840, 0xc13a,	0x787f, 0xc13a,		0x21, 0
	.dw 0x78c0, 0xc13a,	0x78ff, 0xc13a,		0x21, 0
	.dw 0x7940, 0xc13a,	0x797f, 0xc13a,		0x21, 0
	.dw 0x79c0, 0xc13a,	0x9fff, 0xc13a,		0x21, 0
	.dw 0xa040, 0xc13a,	0xa07f, 0xc13a,		0x21, 0
	.dw 0xa0c0, 0xc13a,	0xa0ff, 0xc13a,		0x21, 0
	.dw 0xa140, 0xc13a,	0xa17f, 0xc13a,		0x21, 0
	.dw 0xa1c0, 0xc13a,	0xa1ff, 0xc13a,		0x21, 0
	.dw 0xa240, 0xc13a,	0xa27f, 0xc13a,		0x21, 0
	.dw 0xa2c0, 0xc13a,	0xa2ff, 0xc13a,		0x21, 0
	.dw 0xa340, 0xc13a,	0xa37f, 0xc13a,		0x21, 0
	.dw 0xa3c0, 0xc13a,	0xa3ff, 0xc13a,		0x21, 0
	.dw 0xa440, 0xc13a,	0xa47f, 0xc13a,		0x21, 0
	.dw 0xa4c0, 0xc13a,	0xa4ff, 0xc13a,		0x21, 0
	.dw 0xa540, 0xc13a,	0xa57f, 0xc13a,		0x21, 0
	.dw 0xa5c0, 0xc13a,	0xa5ff, 0xc13a,		0x21, 0
	.dw 0xa640, 0xc13a,	0xa67f, 0xc13a,		0x21, 0
	.dw 0xa6c0, 0xc13a,	0xa6ff, 0xc13a,		0x21, 0
	.dw 0xa740, 0xc13a,	0xa77f, 0xc13a,		0x21, 0
	.dw 0xa7c0, 0xc13a,	0xa7ff, 0xc13a,		0x21, 0
	.dw 0xa840, 0xc13a,	0xa87f, 0xc13a,		0x21, 0
	.dw 0xa8c0, 0xc13a,	0xa8ff, 0xc13a,		0x21, 0
	.dw 0xa940, 0xc13a,	0xa97f, 0xc13a,		0x21, 0
	.dw 0xa9c0, 0xc13a,	0xa9ff, 0xc13a,		0x21, 0
	.dw 0xaa40, 0xc13a,	0xaa7f, 0xc13a,		0x21, 0
	.dw 0xaac0, 0xc13a,	0xaaff, 0xc13a,		0x21, 0
	.dw 0xab40, 0xc13a,	0xab7f, 0xc13a,		0x21, 0
	.dw 0xabc0, 0xc13a,	0xabff, 0xc13a,		0x21, 0
	.dw 0xac40, 0xc13a,	0xac7f, 0xc13a,		0x21, 0
	.dw 0xacc0, 0xc13a,	0xacff, 0xc13a,		0x21, 0
	.dw 0xad40, 0xc13a,	0xad7f, 0xc13a,		0x21, 0
	.dw 0xadc0, 0xc13a,	0xadff, 0xc13a,		0x21, 0
	.dw 0xae40, 0xc13a,	0xae7f, 0xc13a,		0x21, 0
	.dw 0xaec0, 0xc13a,	0xaeff, 0xc13a,		0x21, 0
	.dw 0xaf40, 0xc13a,	0xaf7f, 0xc13a,		0x21, 0
	.dw 0xafc0, 0xc13a,	0xafff, 0xc13a,		0x21, 0
	.dw 0xb040, 0xc13a,	0xb07f, 0xc13a,		0x21, 0
	.dw 0xb0c0, 0xc13a,	0xb0ff, 0xc13a,		0x21, 0
	.dw 0xb140, 0xc13a,	0xb17f, 0xc13a,		0x21, 0
	.dw 0xb1c0, 0xc13a,	0xb1ff, 0xc13a,		0x21, 0
	.dw 0xb240, 0xc13a,	0xb27f, 0xc13a,		0x21, 0
	.dw 0xb2c0, 0xc13a,	0xb2ff, 0xc13a,		0x21, 0
	.dw 0xb340, 0xc13a,	0xb37f, 0xc13a,		0x21, 0
	.dw 0xb3c0, 0xc13a,	0xb3ff, 0xc13a,		0x21, 0
	.dw 0xb440, 0xc13a,	0xb47f, 0xc13a,		0x21, 0
	.dw 0xb4c0, 0xc13a,	0xb4ff, 0xc13a,		0x21, 0
	.dw 0xb540, 0xc13a,	0xb57f, 0xc13a,		0x21, 0
	.dw 0xb5c0, 0xc13a,	0xb5ff, 0xc13a,		0x21, 0
	.dw 0xb640, 0xc13a,	0xb67f, 0xc13a,		0x21, 0
	.dw 0xb6c0, 0xc13a,	0xb6ff, 0xc13a,		0x21, 0
	.dw 0xb740, 0xc13a,	0xb77f, 0xc13a,		0x21, 0
	.dw 0xb7c0, 0xc13a,	0xb7ff, 0xc13a,		0x21, 0
	.dw 0xb840, 0xc13a,	0xb87f, 0xc13a,		0x21, 0
	.dw 0xb8c0, 0xc13a,	0xb8ff, 0xc13a,		0x21, 0
	.dw 0xb940, 0xc13a,	0xb97f, 0xc13a,		0x21, 0
	.dw 0xb9c0, 0xc13a,	0xdfff, 0xc13a,		0x21, 0
	.dw 0xe040, 0xc13a,	0xe07f, 0xc13a,		0x21, 0
	.dw 0xe0c0, 0xc13a,	0xe0ff, 0xc13a,		0x21, 0
	.dw 0xe140, 0xc13a,	0xe17f, 0xc13a,		0x21, 0
	.dw 0xe1c0, 0xc13a,	0xe1ff, 0xc13a,		0x21, 0
	.dw 0xe240, 0xc13a,	0xe27f, 0xc13a,		0x21, 0
	.dw 0xe2c0, 0xc13a,	0xe2ff, 0xc13a,		0x21, 0
	.dw 0xe340, 0xc13a,	0xe37f, 0xc13a,		0x21, 0
	.dw 0xe3c0, 0xc13a,	0xe3ff, 0xc13a,		0x21, 0
	.dw 0xe440, 0xc13a,	0xe47f, 0xc13a,		0x21, 0
	.dw 0xe4c0, 0xc13a,	0xe4ff, 0xc13a,		0x21, 0
	.dw 0xe540, 0xc13a,	0xe57f, 0xc13a,		0x21, 0
	.dw 0xe5c0, 0xc13a,	0xe5ff, 0xc13a,		0x21, 0
	.dw 0xe640, 0xc13a,	0xe67f, 0xc13a,		0x21, 0
	.dw 0xe6c0, 0xc13a,	0xe6ff, 0xc13a,		0x21, 0
	.dw 0xe740, 0xc13a,	0xe77f, 0xc13a,		0x21, 0
	.dw 0xe7c0, 0xc13a,	0xe7ff, 0xc13a,		0x21, 0
	.dw 0xe840, 0xc13a,	0xe87f, 0xc13a,		0x21, 0
	.dw 0xe8c0, 0xc13a,	0xe8ff, 0xc13a,		0x21, 0
	.dw 0xe940, 0xc13a,	0xe97f, 0xc13a,		0x21, 0
	.dw 0xe9c0, 0xc13a,	0xe9ff, 0xc13a,		0x21, 0
	.dw 0xea40, 0xc13a,	0xea7f, 0xc13a,		0x21, 0
	.dw 0xeac0, 0xc13a,	0xeaff, 0xc13a,		0x21, 0
	.dw 0xeb40, 0xc13a,	0xeb7f, 0xc13a,		0x21, 0
	.dw 0xebc0, 0xc13a,	0xebff, 0xc13a,		0x21, 0
	.dw 0xec40, 0xc13a,	0xec7f, 0xc13a,		0x21, 0
	.dw 0xecc0, 0xc13a,	0xecff, 0xc13a,		0x21, 0
	.dw 0xed40, 0xc13a,	0xed7f, 0xc13a,		0x21, 0
	.dw 0xedc0, 0xc13a,	0xedff, 0xc13a,		0x21, 0
	.dw 0xee40, 0xc13a,	0xee7f, 0xc13a,		0x21, 0
	.dw 0xeec0, 0xc13a,	0xeeff, 0xc13a,		0x21, 0
	.dw 0xef40, 0xc13a,	0xef7f, 0xc13a,		0x21, 0
	.dw 0xefc0, 0xc13a,	0xefff, 0xc13a,		0x21, 0
	.dw 0xf040, 0xc13a,	0xf07f, 0xc13a,		0x21, 0
	.dw 0xf0c0, 0xc13a,	0xf0ff, 0xc13a,		0x21, 0
	.dw 0xf140, 0xc13a,	0xf17f, 0xc13a,		0x21, 0
	.dw 0xf1c0, 0xc13a,	0xf1ff, 0xc13a,		0x21, 0
	.dw 0xf240, 0xc13a,	0xf27f, 0xc13a,		0x21, 0
	.dw 0xf2c0, 0xc13a,	0xf2ff, 0xc13a,		0x21, 0
	.dw 0xf340, 0xc13a,	0xf37f, 0xc13a,		0x21, 0
	.dw 0xf3c0, 0xc13a,	0xf3ff, 0xc13a,		0x21, 0
	.dw 0xf440, 0xc13a,	0xf47f, 0xc13a,		0x21, 0
	.dw 0xf4c0, 0xc13a,	0xf4ff, 0xc13a,		0x21, 0
	.dw 0xf540, 0xc13a,	0xf57f, 0xc13a,		0x21, 0
	.dw 0xf5c0, 0xc13a,	0xf5ff, 0xc13a,		0x21, 0
	.dw 0xf640, 0xc13a,	0xf67f, 0xc13a,		0x21, 0
	.dw 0xf6c0, 0xc13a,	0xf6ff, 0xc13a,		0x21, 0
	.dw 0xf740, 0xc13a,	0xf77f, 0xc13a,		0x21, 0
	.dw 0xf7c0, 0xc13a,	0xf7ff, 0xc13a,		0x21, 0
	.dw 0xf840, 0xc13a,	0xf87f, 0xc13a,		0x21, 0
	.dw 0xf8c0, 0xc13a,	0xf8ff, 0xc13a,		0x21, 0
	.dw 0xf940, 0xc13a,	0xf97f, 0xc13a,		0x21, 0
	.dw 0xf9c0, 0xc13a,	0xffff, 0xc13b,		0x21, 0
	.dw 0x0040, 0xc13c,	0x007f, 0xc13c,		0x21, 0
	.dw 0x00c0, 0xc13c,	0x00ff, 0xc13c,		0x21, 0
	.dw 0x0140, 0xc13c,	0x017f, 0xc13c,		0x21, 0
	.dw 0x01c0, 0xc13c,	0x01ff, 0xc13c,		0x21, 0
	.dw 0x0240, 0xc13c,	0x027f, 0xc13c,		0x21, 0
	.dw 0x02c0, 0xc13c,	0x02ff, 0xc13c,		0x21, 0
	.dw 0x0340, 0xc13c,	0x037f, 0xc13c,		0x21, 0
	.dw 0x03c0, 0xc13c,	0x03ff, 0xc13c,		0x21, 0
	.dw 0x0440, 0xc13c,	0x047f, 0xc13c,		0x21, 0
	.dw 0x04c0, 0xc13c,	0x04ff, 0xc13c,		0x21, 0
	.dw 0x0540, 0xc13c,	0x057f, 0xc13c,		0x21, 0
	.dw 0x05c0, 0xc13c,	0x05ff, 0xc13c,		0x21, 0
	.dw 0x0640, 0xc13c,	0x067f, 0xc13c,		0x21, 0
	.dw 0x06c0, 0xc13c,	0x06ff, 0xc13c,		0x21, 0
	.dw 0x0740, 0xc13c,	0x077f, 0xc13c,		0x21, 0
	.dw 0x07c0, 0xc13c,	0x07ff, 0xc13c,		0x21, 0
	.dw 0x0840, 0xc13c,	0x087f, 0xc13c,		0x21, 0
	.dw 0x08c0, 0xc13c,	0x08ff, 0xc13c,		0x21, 0
	.dw 0x0940, 0xc13c,	0x097f, 0xc13c,		0x21, 0
	.dw 0x09c0, 0xc13c,	0x09ff, 0xc13c,		0x21, 0
	.dw 0x0a40, 0xc13c,	0x0a7f, 0xc13c,		0x21, 0
	.dw 0x0ac0, 0xc13c,	0x0aff, 0xc13c,		0x21, 0
	.dw 0x0b40, 0xc13c,	0x0b7f, 0xc13c,		0x21, 0
	.dw 0x0bc0, 0xc13c,	0x0bff, 0xc13c,		0x21, 0
	.dw 0x0c40, 0xc13c,	0x0c7f, 0xc13c,		0x21, 0
	.dw 0x0cc0, 0xc13c,	0x0cff, 0xc13c,		0x21, 0
	.dw 0x0d40, 0xc13c,	0x0d7f, 0xc13c,		0x21, 0
	.dw 0x0dc0, 0xc13c,	0x0dff, 0xc13c,		0x21, 0
	.dw 0x0e40, 0xc13c,	0x0e7f, 0xc13c,		0x21, 0
	.dw 0x0ec0, 0xc13c,	0x0eff, 0xc13c,		0x21, 0
	.dw 0x0f40, 0xc13c,	0x0f7f, 0xc13c,		0x21, 0
	.dw 0x0fc0, 0xc13c,	0x0fff, 0xc13c,		0x21, 0
	.dw 0x1040, 0xc13c,	0x107f, 0xc13c,		0x21, 0
	.dw 0x10c0, 0xc13c,	0x10ff, 0xc13c,		0x21, 0
	.dw 0x1140, 0xc13c,	0x117f, 0xc13c,		0x21, 0
	.dw 0x11c0, 0xc13c,	0x11ff, 0xc13c,		0x21, 0
	.dw 0x1240, 0xc13c,	0x127f, 0xc13c,		0x21, 0
	.dw 0x12c0, 0xc13c,	0x12ff, 0xc13c,		0x21, 0
	.dw 0x1340, 0xc13c,	0x137f, 0xc13c,		0x21, 0
	.dw 0x13c0, 0xc13c,	0x13ff, 0xc13c,		0x21, 0
	.dw 0x1440, 0xc13c,	0x147f, 0xc13c,		0x21, 0
	.dw 0x14c0, 0xc13c,	0x14ff, 0xc13c,		0x21, 0
	.dw 0x1540, 0xc13c,	0x157f, 0xc13c,		0x21, 0
	.dw 0x15c0, 0xc13c,	0x15ff, 0xc13c,		0x21, 0
	.dw 0x1640, 0xc13c,	0x167f, 0xc13c,		0x21, 0
	.dw 0x16c0, 0xc13c,	0x16ff, 0xc13c,		0x21, 0
	.dw 0x1740, 0xc13c,	0x177f, 0xc13c,		0x21, 0
	.dw 0x17c0, 0xc13c,	0x17ff, 0xc13c,		0x21, 0
	.dw 0x1840, 0xc13c,	0x187f, 0xc13c,		0x21, 0
	.dw 0x18c0, 0xc13c,	0x18ff, 0xc13c,		0x21, 0
	.dw 0x1940, 0xc13c,	0x197f, 0xc13c,		0x21, 0
	.dw 0x19c0, 0xc13c,	0x1fff, 0xc13c,		0x21, 0
	.dw 0x2040, 0xc13c,	0x207f, 0xc13c,		0x21, 0
	.dw 0x20c0, 0xc13c,	0x20ff, 0xc13c,		0x21, 0
	.dw 0x2140, 0xc13c,	0x217f, 0xc13c,		0x21, 0
	.dw 0x21c0, 0xc13c,	0x21ff, 0xc13c,		0x21, 0
	.dw 0x2240, 0xc13c,	0x227f, 0xc13c,		0x21, 0
	.dw 0x22c0, 0xc13c,	0x22ff, 0xc13c,		0x21, 0
	.dw 0x2340, 0xc13c,	0x237f, 0xc13c,		0x21, 0
	.dw 0x23c0, 0xc13c,	0x23ff, 0xc13c,		0x21, 0
	.dw 0x2440, 0xc13c,	0x247f, 0xc13c,		0x21, 0
	.dw 0x24c0, 0xc13c,	0x24ff, 0xc13c,		0x21, 0
	.dw 0x2540, 0xc13c,	0x257f, 0xc13c,		0x21, 0
	.dw 0x25c0, 0xc13c,	0x25ff, 0xc13c,		0x21, 0
	.dw 0x2640, 0xc13c,	0x267f, 0xc13c,		0x21, 0
	.dw 0x26c0, 0xc13c,	0x26ff, 0xc13c,		0x21, 0
	.dw 0x2740, 0xc13c,	0x277f, 0xc13c,		0x21, 0
	.dw 0x27c0, 0xc13c,	0x27ff, 0xc13c,		0x21, 0
	.dw 0x2840, 0xc13c,	0x287f, 0xc13c,		0x21, 0
	.dw 0x28c0, 0xc13c,	0x28ff, 0xc13c,		0x21, 0
	.dw 0x2940, 0xc13c,	0x297f, 0xc13c,		0x21, 0
	.dw 0x29c0, 0xc13c,	0x29ff, 0xc13c,		0x21, 0
	.dw 0x2a40, 0xc13c,	0x2a7f, 0xc13c,		0x21, 0
	.dw 0x2ac0, 0xc13c,	0x2aff, 0xc13c,		0x21, 0
	.dw 0x2b40, 0xc13c,	0x2b7f, 0xc13c,		0x21, 0
	.dw 0x2bc0, 0xc13c,	0x2bff, 0xc13c,		0x21, 0
	.dw 0x2c40, 0xc13c,	0x2c7f, 0xc13c,		0x21, 0
	.dw 0x2cc0, 0xc13c,	0x2cff, 0xc13c,		0x21, 0
	.dw 0x2d40, 0xc13c,	0x2d7f, 0xc13c,		0x21, 0
	.dw 0x2dc0, 0xc13c,	0x2dff, 0xc13c,		0x21, 0
	.dw 0x2e40, 0xc13c,	0x2e7f, 0xc13c,		0x21, 0
	.dw 0x2ec0, 0xc13c,	0x2eff, 0xc13c,		0x21, 0
	.dw 0x2f40, 0xc13c,	0x2f7f, 0xc13c,		0x21, 0
	.dw 0x2fc0, 0xc13c,	0x2fff, 0xc13c,		0x21, 0
	.dw 0x3040, 0xc13c,	0x307f, 0xc13c,		0x21, 0
	.dw 0x30c0, 0xc13c,	0x30ff, 0xc13c,		0x21, 0
	.dw 0x3140, 0xc13c,	0x317f, 0xc13c,		0x21, 0
	.dw 0x31c0, 0xc13c,	0x31ff, 0xc13c,		0x21, 0
	.dw 0x3240, 0xc13c,	0x327f, 0xc13c,		0x21, 0
	.dw 0x32c0, 0xc13c,	0x32ff, 0xc13c,		0x21, 0
	.dw 0x3340, 0xc13c,	0x337f, 0xc13c,		0x21, 0
	.dw 0x33c0, 0xc13c,	0x33ff, 0xc13c,		0x21, 0
	.dw 0x3440, 0xc13c,	0x347f, 0xc13c,		0x21, 0
	.dw 0x34c0, 0xc13c,	0x34ff, 0xc13c,		0x21, 0
	.dw 0x3540, 0xc13c,	0x357f, 0xc13c,		0x21, 0
	.dw 0x35c0, 0xc13c,	0x35ff, 0xc13c,		0x21, 0
	.dw 0x3640, 0xc13c,	0x367f, 0xc13c,		0x21, 0
	.dw 0x36c0, 0xc13c,	0x36ff, 0xc13c,		0x21, 0
	.dw 0x3740, 0xc13c,	0x377f, 0xc13c,		0x21, 0
	.dw 0x37c0, 0xc13c,	0x37ff, 0xc13c,		0x21, 0
	.dw 0x3840, 0xc13c,	0x387f, 0xc13c,		0x21, 0
	.dw 0x38c0, 0xc13c,	0x38ff, 0xc13c,		0x21, 0
	.dw 0x3940, 0xc13c,	0x397f, 0xc13c,		0x21, 0
	.dw 0x39c0, 0xc13c,	0x3fff, 0xc13c,		0x21, 0
	.dw 0x4040, 0xc13c,	0x407f, 0xc13c,		0x21, 0
	.dw 0x40c0, 0xc13c,	0x40ff, 0xc13c,		0x21, 0
	.dw 0x4140, 0xc13c,	0x417f, 0xc13c,		0x21, 0
	.dw 0x41c0, 0xc13c,	0x41ff, 0xc13c,		0x21, 0
	.dw 0x4240, 0xc13c,	0x427f, 0xc13c,		0x21, 0
	.dw 0x42c0, 0xc13c,	0x42ff, 0xc13c,		0x21, 0
	.dw 0x4340, 0xc13c,	0x437f, 0xc13c,		0x21, 0
	.dw 0x43c0, 0xc13c,	0x43ff, 0xc13c,		0x21, 0
	.dw 0x4440, 0xc13c,	0x447f, 0xc13c,		0x21, 0
	.dw 0x44c0, 0xc13c,	0x44ff, 0xc13c,		0x21, 0
	.dw 0x4540, 0xc13c,	0x457f, 0xc13c,		0x21, 0
	.dw 0x45c0, 0xc13c,	0x45ff, 0xc13c,		0x21, 0
	.dw 0x4640, 0xc13c,	0x467f, 0xc13c,		0x21, 0
	.dw 0x46c0, 0xc13c,	0x46ff, 0xc13c,		0x21, 0
	.dw 0x4740, 0xc13c,	0x477f, 0xc13c,		0x21, 0
	.dw 0x47c0, 0xc13c,	0x47ff, 0xc13c,		0x21, 0
	.dw 0x4840, 0xc13c,	0x487f, 0xc13c,		0x21, 0
	.dw 0x48c0, 0xc13c,	0x48ff, 0xc13c,		0x21, 0
	.dw 0x4940, 0xc13c,	0x497f, 0xc13c,		0x21, 0
	.dw 0x49c0, 0xc13c,	0x49ff, 0xc13c,		0x21, 0
	.dw 0x4a40, 0xc13c,	0x4a7f, 0xc13c,		0x21, 0
	.dw 0x4ac0, 0xc13c,	0x4aff, 0xc13c,		0x21, 0
	.dw 0x4b40, 0xc13c,	0x4b7f, 0xc13c,		0x21, 0
	.dw 0x4bc0, 0xc13c,	0x4bff, 0xc13c,		0x21, 0
	.dw 0x4c40, 0xc13c,	0x4c7f, 0xc13c,		0x21, 0
	.dw 0x4cc0, 0xc13c,	0x4cff, 0xc13c,		0x21, 0
	.dw 0x4d40, 0xc13c,	0x4d7f, 0xc13c,		0x21, 0
	.dw 0x4dc0, 0xc13c,	0x4dff, 0xc13c,		0x21, 0
	.dw 0x4e40, 0xc13c,	0x4e7f, 0xc13c,		0x21, 0
	.dw 0x4ec0, 0xc13c,	0x4eff, 0xc13c,		0x21, 0
	.dw 0x4f40, 0xc13c,	0x4f7f, 0xc13c,		0x21, 0
	.dw 0x4fc0, 0xc13c,	0x4fff, 0xc13c,		0x21, 0
	.dw 0x5040, 0xc13c,	0x507f, 0xc13c,		0x21, 0
	.dw 0x50c0, 0xc13c,	0x50ff, 0xc13c,		0x21, 0
	.dw 0x5140, 0xc13c,	0x517f, 0xc13c,		0x21, 0
	.dw 0x51c0, 0xc13c,	0x51ff, 0xc13c,		0x21, 0
	.dw 0x5240, 0xc13c,	0x527f, 0xc13c,		0x21, 0
	.dw 0x52c0, 0xc13c,	0x52ff, 0xc13c,		0x21, 0
	.dw 0x5340, 0xc13c,	0x537f, 0xc13c,		0x21, 0
	.dw 0x53c0, 0xc13c,	0x53ff, 0xc13c,		0x21, 0
	.dw 0x5440, 0xc13c,	0x547f, 0xc13c,		0x21, 0
	.dw 0x54c0, 0xc13c,	0x54ff, 0xc13c,		0x21, 0
	.dw 0x5540, 0xc13c,	0x557f, 0xc13c,		0x21, 0
	.dw 0x55c0, 0xc13c,	0x55ff, 0xc13c,		0x21, 0
	.dw 0x5640, 0xc13c,	0x567f, 0xc13c,		0x21, 0
	.dw 0x56c0, 0xc13c,	0x56ff, 0xc13c,		0x21, 0
	.dw 0x5740, 0xc13c,	0x577f, 0xc13c,		0x21, 0
	.dw 0x57c0, 0xc13c,	0x57ff, 0xc13c,		0x21, 0
	.dw 0x5840, 0xc13c,	0x587f, 0xc13c,		0x21, 0
	.dw 0x58c0, 0xc13c,	0x58ff, 0xc13c,		0x21, 0
	.dw 0x5940, 0xc13c,	0x597f, 0xc13c,		0x21, 0
	.dw 0x59c0, 0xc13c,	0x5fff, 0xc13c,		0x21, 0
	.dw 0x6040, 0xc13c,	0x607f, 0xc13c,		0x21, 0
	.dw 0x60c0, 0xc13c,	0x60ff, 0xc13c,		0x21, 0
	.dw 0x6140, 0xc13c,	0x617f, 0xc13c,		0x21, 0
	.dw 0x61c0, 0xc13c,	0x61ff, 0xc13c,		0x21, 0
	.dw 0x6240, 0xc13c,	0x627f, 0xc13c,		0x21, 0
	.dw 0x62c0, 0xc13c,	0x62ff, 0xc13c,		0x21, 0
	.dw 0x6340, 0xc13c,	0x637f, 0xc13c,		0x21, 0
	.dw 0x63c0, 0xc13c,	0x63ff, 0xc13c,		0x21, 0
	.dw 0x6440, 0xc13c,	0x647f, 0xc13c,		0x21, 0
	.dw 0x64c0, 0xc13c,	0x64ff, 0xc13c,		0x21, 0
	.dw 0x6540, 0xc13c,	0x657f, 0xc13c,		0x21, 0
	.dw 0x65c0, 0xc13c,	0x65ff, 0xc13c,		0x21, 0
	.dw 0x6640, 0xc13c,	0x667f, 0xc13c,		0x21, 0
	.dw 0x66c0, 0xc13c,	0x66ff, 0xc13c,		0x21, 0
	.dw 0x6740, 0xc13c,	0x677f, 0xc13c,		0x21, 0
	.dw 0x67c0, 0xc13c,	0x67ff, 0xc13c,		0x21, 0
	.dw 0x6840, 0xc13c,	0x687f, 0xc13c,		0x21, 0
	.dw 0x68c0, 0xc13c,	0x68ff, 0xc13c,		0x21, 0
	.dw 0x6940, 0xc13c,	0x697f, 0xc13c,		0x21, 0
	.dw 0x69c0, 0xc13c,	0x69ff, 0xc13c,		0x21, 0
	.dw 0x6a40, 0xc13c,	0x6a7f, 0xc13c,		0x21, 0
	.dw 0x6ac0, 0xc13c,	0x6aff, 0xc13c,		0x21, 0
	.dw 0x6b40, 0xc13c,	0x6b7f, 0xc13c,		0x21, 0
	.dw 0x6bc0, 0xc13c,	0x6bff, 0xc13c,		0x21, 0
	.dw 0x6c40, 0xc13c,	0x6c7f, 0xc13c,		0x21, 0
	.dw 0x6cc0, 0xc13c,	0x6cff, 0xc13c,		0x21, 0
	.dw 0x6d40, 0xc13c,	0x6d7f, 0xc13c,		0x21, 0
	.dw 0x6dc0, 0xc13c,	0x6dff, 0xc13c,		0x21, 0
	.dw 0x6e40, 0xc13c,	0x6e7f, 0xc13c,		0x21, 0
	.dw 0x6ec0, 0xc13c,	0x6eff, 0xc13c,		0x21, 0
	.dw 0x6f40, 0xc13c,	0x6f7f, 0xc13c,		0x21, 0
	.dw 0x6fc0, 0xc13c,	0x6fff, 0xc13c,		0x21, 0
	.dw 0x7040, 0xc13c,	0x707f, 0xc13c,		0x21, 0
	.dw 0x70c0, 0xc13c,	0x70ff, 0xc13c,		0x21, 0
	.dw 0x7140, 0xc13c,	0x717f, 0xc13c,		0x21, 0
	.dw 0x71c0, 0xc13c,	0x71ff, 0xc13c,		0x21, 0
	.dw 0x7240, 0xc13c,	0x727f, 0xc13c,		0x21, 0
	.dw 0x72c0, 0xc13c,	0x72ff, 0xc13c,		0x21, 0
	.dw 0x7340, 0xc13c,	0x737f, 0xc13c,		0x21, 0
	.dw 0x73c0, 0xc13c,	0x73ff, 0xc13c,		0x21, 0
	.dw 0x7440, 0xc13c,	0x747f, 0xc13c,		0x21, 0
	.dw 0x74c0, 0xc13c,	0x74ff, 0xc13c,		0x21, 0
	.dw 0x7540, 0xc13c,	0x757f, 0xc13c,		0x21, 0
	.dw 0x75c0, 0xc13c,	0x75ff, 0xc13c,		0x21, 0
	.dw 0x7640, 0xc13c,	0x767f, 0xc13c,		0x21, 0
	.dw 0x76c0, 0xc13c,	0x76ff, 0xc13c,		0x21, 0
	.dw 0x7740, 0xc13c,	0x777f, 0xc13c,		0x21, 0
	.dw 0x77c0, 0xc13c,	0x77ff, 0xc13c,		0x21, 0
	.dw 0x7840, 0xc13c,	0x787f, 0xc13c,		0x21, 0
	.dw 0x78c0, 0xc13c,	0x78ff, 0xc13c,		0x21, 0
	.dw 0x7940, 0xc13c,	0x797f, 0xc13c,		0x21, 0
	.dw 0x79c0, 0xc13c,	0x7fff, 0xc13c,		0x21, 0
	.dw 0x8040, 0xc13c,	0x807f, 0xc13c,		0x21, 0
	.dw 0x80c0, 0xc13c,	0x80ff, 0xc13c,		0x21, 0
	.dw 0x8140, 0xc13c,	0x817f, 0xc13c,		0x21, 0
	.dw 0x81c0, 0xc13c,	0x81ff, 0xc13c,		0x21, 0
	.dw 0x8240, 0xc13c,	0x827f, 0xc13c,		0x21, 0
	.dw 0x82c0, 0xc13c,	0x82ff, 0xc13c,		0x21, 0
	.dw 0x8340, 0xc13c,	0x837f, 0xc13c,		0x21, 0
	.dw 0x83c0, 0xc13c,	0x83ff, 0xc13c,		0x21, 0
	.dw 0x8440, 0xc13c,	0x847f, 0xc13c,		0x21, 0
	.dw 0x84c0, 0xc13c,	0x84ff, 0xc13c,		0x21, 0
	.dw 0x8540, 0xc13c,	0x857f, 0xc13c,		0x21, 0
	.dw 0x85c0, 0xc13c,	0x85ff, 0xc13c,		0x21, 0
	.dw 0x8640, 0xc13c,	0x867f, 0xc13c,		0x21, 0
	.dw 0x86c0, 0xc13c,	0x86ff, 0xc13c,		0x21, 0
	.dw 0x8740, 0xc13c,	0x877f, 0xc13c,		0x21, 0
	.dw 0x87c0, 0xc13c,	0x87ff, 0xc13c,		0x21, 0
	.dw 0x8840, 0xc13c,	0x887f, 0xc13c,		0x21, 0
	.dw 0x88c0, 0xc13c,	0x88ff, 0xc13c,		0x21, 0
	.dw 0x8940, 0xc13c,	0x897f, 0xc13c,		0x21, 0
	.dw 0x89c0, 0xc13c,	0x89ff, 0xc13c,		0x21, 0
	.dw 0x8a40, 0xc13c,	0x8a7f, 0xc13c,		0x21, 0
	.dw 0x8ac0, 0xc13c,	0x8aff, 0xc13c,		0x21, 0
	.dw 0x8b40, 0xc13c,	0x8b7f, 0xc13c,		0x21, 0
	.dw 0x8bc0, 0xc13c,	0x8bff, 0xc13c,		0x21, 0
	.dw 0x8c40, 0xc13c,	0x8c7f, 0xc13c,		0x21, 0
	.dw 0x8cc0, 0xc13c,	0x8cff, 0xc13c,		0x21, 0
	.dw 0x8d40, 0xc13c,	0x8d7f, 0xc13c,		0x21, 0
	.dw 0x8dc0, 0xc13c,	0x8dff, 0xc13c,		0x21, 0
	.dw 0x8e40, 0xc13c,	0x8e7f, 0xc13c,		0x21, 0
	.dw 0x8ec0, 0xc13c,	0x8eff, 0xc13c,		0x21, 0
	.dw 0x8f40, 0xc13c,	0x8f7f, 0xc13c,		0x21, 0
	.dw 0x8fc0, 0xc13c,	0x8fff, 0xc13c,		0x21, 0
	.dw 0x9040, 0xc13c,	0x907f, 0xc13c,		0x21, 0
	.dw 0x90c0, 0xc13c,	0x90ff, 0xc13c,		0x21, 0
	.dw 0x9140, 0xc13c,	0x917f, 0xc13c,		0x21, 0
	.dw 0x91c0, 0xc13c,	0x91ff, 0xc13c,		0x21, 0
	.dw 0x9240, 0xc13c,	0x927f, 0xc13c,		0x21, 0
	.dw 0x92c0, 0xc13c,	0x92ff, 0xc13c,		0x21, 0
	.dw 0x9340, 0xc13c,	0x937f, 0xc13c,		0x21, 0
	.dw 0x93c0, 0xc13c,	0x93ff, 0xc13c,		0x21, 0
	.dw 0x9440, 0xc13c,	0x947f, 0xc13c,		0x21, 0
	.dw 0x94c0, 0xc13c,	0x94ff, 0xc13c,		0x21, 0
	.dw 0x9540, 0xc13c,	0x957f, 0xc13c,		0x21, 0
	.dw 0x95c0, 0xc13c,	0x95ff, 0xc13c,		0x21, 0
	.dw 0x9640, 0xc13c,	0x967f, 0xc13c,		0x21, 0
	.dw 0x96c0, 0xc13c,	0x96ff, 0xc13c,		0x21, 0
	.dw 0x9740, 0xc13c,	0x977f, 0xc13c,		0x21, 0
	.dw 0x97c0, 0xc13c,	0x97ff, 0xc13c,		0x21, 0
	.dw 0x9840, 0xc13c,	0x987f, 0xc13c,		0x21, 0
	.dw 0x98c0, 0xc13c,	0x98ff, 0xc13c,		0x21, 0
	.dw 0x9940, 0xc13c,	0x997f, 0xc13c,		0x21, 0
	.dw 0x99c0, 0xc13c,	0x9fff, 0xc13c,		0x21, 0
	.dw 0xa040, 0xc13c,	0xa07f, 0xc13c,		0x21, 0
	.dw 0xa0c0, 0xc13c,	0xa0ff, 0xc13c,		0x21, 0
	.dw 0xa140, 0xc13c,	0xa17f, 0xc13c,		0x21, 0
	.dw 0xa1c0, 0xc13c,	0xa1ff, 0xc13c,		0x21, 0
	.dw 0xa240, 0xc13c,	0xa27f, 0xc13c,		0x21, 0
	.dw 0xa2c0, 0xc13c,	0xa2ff, 0xc13c,		0x21, 0
	.dw 0xa340, 0xc13c,	0xa37f, 0xc13c,		0x21, 0
	.dw 0xa3c0, 0xc13c,	0xa3ff, 0xc13c,		0x21, 0
	.dw 0xa440, 0xc13c,	0xa47f, 0xc13c,		0x21, 0
	.dw 0xa4c0, 0xc13c,	0xa4ff, 0xc13c,		0x21, 0
	.dw 0xa540, 0xc13c,	0xa57f, 0xc13c,		0x21, 0
	.dw 0xa5c0, 0xc13c,	0xa5ff, 0xc13c,		0x21, 0
	.dw 0xa640, 0xc13c,	0xa67f, 0xc13c,		0x21, 0
	.dw 0xa6c0, 0xc13c,	0xa6ff, 0xc13c,		0x21, 0
	.dw 0xa740, 0xc13c,	0xa77f, 0xc13c,		0x21, 0
	.dw 0xa7c0, 0xc13c,	0xa7ff, 0xc13c,		0x21, 0
	.dw 0xa840, 0xc13c,	0xa87f, 0xc13c,		0x21, 0
	.dw 0xa8c0, 0xc13c,	0xa8ff, 0xc13c,		0x21, 0
	.dw 0xa940, 0xc13c,	0xa97f, 0xc13c,		0x21, 0
	.dw 0xa9c0, 0xc13c,	0xa9ff, 0xc13c,		0x21, 0
	.dw 0xaa40, 0xc13c,	0xaa7f, 0xc13c,		0x21, 0
	.dw 0xaac0, 0xc13c,	0xaaff, 0xc13c,		0x21, 0
	.dw 0xab40, 0xc13c,	0xab7f, 0xc13c,		0x21, 0
	.dw 0xabc0, 0xc13c,	0xabff, 0xc13c,		0x21, 0
	.dw 0xac40, 0xc13c,	0xac7f, 0xc13c,		0x21, 0
	.dw 0xacc0, 0xc13c,	0xacff, 0xc13c,		0x21, 0
	.dw 0xad40, 0xc13c,	0xad7f, 0xc13c,		0x21, 0
	.dw 0xadc0, 0xc13c,	0xadff, 0xc13c,		0x21, 0
	.dw 0xae40, 0xc13c,	0xae7f, 0xc13c,		0x21, 0
	.dw 0xaec0, 0xc13c,	0xaeff, 0xc13c,		0x21, 0
	.dw 0xaf40, 0xc13c,	0xaf7f, 0xc13c,		0x21, 0
	.dw 0xafc0, 0xc13c,	0xafff, 0xc13c,		0x21, 0
	.dw 0xb040, 0xc13c,	0xb07f, 0xc13c,		0x21, 0
	.dw 0xb0c0, 0xc13c,	0xb0ff, 0xc13c,		0x21, 0
	.dw 0xb140, 0xc13c,	0xb17f, 0xc13c,		0x21, 0
	.dw 0xb1c0, 0xc13c,	0xb1ff, 0xc13c,		0x21, 0
	.dw 0xb240, 0xc13c,	0xb27f, 0xc13c,		0x21, 0
	.dw 0xb2c0, 0xc13c,	0xb2ff, 0xc13c,		0x21, 0
	.dw 0xb340, 0xc13c,	0xb37f, 0xc13c,		0x21, 0
	.dw 0xb3c0, 0xc13c,	0xb3ff, 0xc13c,		0x21, 0
	.dw 0xb440, 0xc13c,	0xb47f, 0xc13c,		0x21, 0
	.dw 0xb4c0, 0xc13c,	0xb4ff, 0xc13c,		0x21, 0
	.dw 0xb540, 0xc13c,	0xb57f, 0xc13c,		0x21, 0
	.dw 0xb5c0, 0xc13c,	0xb5ff, 0xc13c,		0x21, 0
	.dw 0xb640, 0xc13c,	0xb67f, 0xc13c,		0x21, 0
	.dw 0xb6c0, 0xc13c,	0xb6ff, 0xc13c,		0x21, 0
	.dw 0xb740, 0xc13c,	0xb77f, 0xc13c,		0x21, 0
	.dw 0xb7c0, 0xc13c,	0xb7ff, 0xc13c,		0x21, 0
	.dw 0xb840, 0xc13c,	0xb87f, 0xc13c,		0x21, 0
	.dw 0xb8c0, 0xc13c,	0xb8ff, 0xc13c,		0x21, 0
	.dw 0xb940, 0xc13c,	0xb97f, 0xc13c,		0x21, 0
	.dw 0xb9c0, 0xc13c,	0xbfff, 0xc13c,		0x21, 0
	.dw 0xc040, 0xc13c,	0xc07f, 0xc13c,		0x21, 0
	.dw 0xc0c0, 0xc13c,	0xc0ff, 0xc13c,		0x21, 0
	.dw 0xc140, 0xc13c,	0xc17f, 0xc13c,		0x21, 0
	.dw 0xc1c0, 0xc13c,	0xc1ff, 0xc13c,		0x21, 0
	.dw 0xc240, 0xc13c,	0xc27f, 0xc13c,		0x21, 0
	.dw 0xc2c0, 0xc13c,	0xc2ff, 0xc13c,		0x21, 0
	.dw 0xc340, 0xc13c,	0xc37f, 0xc13c,		0x21, 0
	.dw 0xc3c0, 0xc13c,	0xc3ff, 0xc13c,		0x21, 0
	.dw 0xc440, 0xc13c,	0xc47f, 0xc13c,		0x21, 0
	.dw 0xc4c0, 0xc13c,	0xc4ff, 0xc13c,		0x21, 0
	.dw 0xc540, 0xc13c,	0xc57f, 0xc13c,		0x21, 0
	.dw 0xc5c0, 0xc13c,	0xc5ff, 0xc13c,		0x21, 0
	.dw 0xc640, 0xc13c,	0xc67f, 0xc13c,		0x21, 0
	.dw 0xc6c0, 0xc13c,	0xc6ff, 0xc13c,		0x21, 0
	.dw 0xc740, 0xc13c,	0xc77f, 0xc13c,		0x21, 0
	.dw 0xc7c0, 0xc13c,	0xc7ff, 0xc13c,		0x21, 0
	.dw 0xc840, 0xc13c,	0xc87f, 0xc13c,		0x21, 0
	.dw 0xc8c0, 0xc13c,	0xc8ff, 0xc13c,		0x21, 0
	.dw 0xc940, 0xc13c,	0xc97f, 0xc13c,		0x21, 0
	.dw 0xc9c0, 0xc13c,	0xc9ff, 0xc13c,		0x21, 0
	.dw 0xca40, 0xc13c,	0xca7f, 0xc13c,		0x21, 0
	.dw 0xcac0, 0xc13c,	0xcaff, 0xc13c,		0x21, 0
	.dw 0xcb40, 0xc13c,	0xcb7f, 0xc13c,		0x21, 0
	.dw 0xcbc0, 0xc13c,	0xcbff, 0xc13c,		0x21, 0
	.dw 0xcc40, 0xc13c,	0xcc7f, 0xc13c,		0x21, 0
	.dw 0xccc0, 0xc13c,	0xccff, 0xc13c,		0x21, 0
	.dw 0xcd40, 0xc13c,	0xcd7f, 0xc13c,		0x21, 0
	.dw 0xcdc0, 0xc13c,	0xcdff, 0xc13c,		0x21, 0
	.dw 0xce40, 0xc13c,	0xce7f, 0xc13c,		0x21, 0
	.dw 0xcec0, 0xc13c,	0xceff, 0xc13c,		0x21, 0
	.dw 0xcf40, 0xc13c,	0xcf7f, 0xc13c,		0x21, 0
	.dw 0xcfc0, 0xc13c,	0xcfff, 0xc13c,		0x21, 0
	.dw 0xd040, 0xc13c,	0xd07f, 0xc13c,		0x21, 0
	.dw 0xd0c0, 0xc13c,	0xd0ff, 0xc13c,		0x21, 0
	.dw 0xd140, 0xc13c,	0xd17f, 0xc13c,		0x21, 0
	.dw 0xd1c0, 0xc13c,	0xd1ff, 0xc13c,		0x21, 0
	.dw 0xd240, 0xc13c,	0xd27f, 0xc13c,		0x21, 0
	.dw 0xd2c0, 0xc13c,	0xd2ff, 0xc13c,		0x21, 0
	.dw 0xd340, 0xc13c,	0xd37f, 0xc13c,		0x21, 0
	.dw 0xd3c0, 0xc13c,	0xd3ff, 0xc13c,		0x21, 0
	.dw 0xd440, 0xc13c,	0xd47f, 0xc13c,		0x21, 0
	.dw 0xd4c0, 0xc13c,	0xd4ff, 0xc13c,		0x21, 0
	.dw 0xd540, 0xc13c,	0xd57f, 0xc13c,		0x21, 0
	.dw 0xd5c0, 0xc13c,	0xd5ff, 0xc13c,		0x21, 0
	.dw 0xd640, 0xc13c,	0xd67f, 0xc13c,		0x21, 0
	.dw 0xd6c0, 0xc13c,	0xd6ff, 0xc13c,		0x21, 0
	.dw 0xd740, 0xc13c,	0xd77f, 0xc13c,		0x21, 0
	.dw 0xd7c0, 0xc13c,	0xd7ff, 0xc13c,		0x21, 0
	.dw 0xd840, 0xc13c,	0xd87f, 0xc13c,		0x21, 0
	.dw 0xd8c0, 0xc13c,	0xd8ff, 0xc13c,		0x21, 0
	.dw 0xd940, 0xc13c,	0xd97f, 0xc13c,		0x21, 0
	.dw 0xd9c0, 0xc13c,	0xdfff, 0xc13c,		0x21, 0
	.dw 0xe040, 0xc13c,	0xe07f, 0xc13c,		0x21, 0
	.dw 0xe0c0, 0xc13c,	0xe0ff, 0xc13c,		0x21, 0
	.dw 0xe140, 0xc13c,	0xe17f, 0xc13c,		0x21, 0
	.dw 0xe1c0, 0xc13c,	0xe1ff, 0xc13c,		0x21, 0
	.dw 0xe240, 0xc13c,	0xe27f, 0xc13c,		0x21, 0
	.dw 0xe2c0, 0xc13c,	0xe2ff, 0xc13c,		0x21, 0
	.dw 0xe340, 0xc13c,	0xe37f, 0xc13c,		0x21, 0
	.dw 0xe3c0, 0xc13c,	0xe3ff, 0xc13c,		0x21, 0
	.dw 0xe440, 0xc13c,	0xe47f, 0xc13c,		0x21, 0
	.dw 0xe4c0, 0xc13c,	0xe4ff, 0xc13c,		0x21, 0
	.dw 0xe540, 0xc13c,	0xe57f, 0xc13c,		0x21, 0
	.dw 0xe5c0, 0xc13c,	0xe5ff, 0xc13c,		0x21, 0
	.dw 0xe640, 0xc13c,	0xe67f, 0xc13c,		0x21, 0
	.dw 0xe6c0, 0xc13c,	0xe6ff, 0xc13c,		0x21, 0
	.dw 0xe740, 0xc13c,	0xe77f, 0xc13c,		0x21, 0
	.dw 0xe7c0, 0xc13c,	0xe7ff, 0xc13c,		0x21, 0
	.dw 0xe840, 0xc13c,	0xe87f, 0xc13c,		0x21, 0
	.dw 0xe8c0, 0xc13c,	0xe8ff, 0xc13c,		0x21, 0
	.dw 0xe940, 0xc13c,	0xe97f, 0xc13c,		0x21, 0
	.dw 0xe9c0, 0xc13c,	0xe9ff, 0xc13c,		0x21, 0
	.dw 0xea40, 0xc13c,	0xea7f, 0xc13c,		0x21, 0
	.dw 0xeac0, 0xc13c,	0xeaff, 0xc13c,		0x21, 0
	.dw 0xeb40, 0xc13c,	0xeb7f, 0xc13c,		0x21, 0
	.dw 0xebc0, 0xc13c,	0xebff, 0xc13c,		0x21, 0
	.dw 0xec40, 0xc13c,	0xec7f, 0xc13c,		0x21, 0
	.dw 0xecc0, 0xc13c,	0xecff, 0xc13c,		0x21, 0
	.dw 0xed40, 0xc13c,	0xed7f, 0xc13c,		0x21, 0
	.dw 0xedc0, 0xc13c,	0xedff, 0xc13c,		0x21, 0
	.dw 0xee40, 0xc13c,	0xee7f, 0xc13c,		0x21, 0
	.dw 0xeec0, 0xc13c,	0xeeff, 0xc13c,		0x21, 0
	.dw 0xef40, 0xc13c,	0xef7f, 0xc13c,		0x21, 0
	.dw 0xefc0, 0xc13c,	0xefff, 0xc13c,		0x21, 0
	.dw 0xf040, 0xc13c,	0xf07f, 0xc13c,		0x21, 0
	.dw 0xf0c0, 0xc13c,	0xf0ff, 0xc13c,		0x21, 0
	.dw 0xf140, 0xc13c,	0xf17f, 0xc13c,		0x21, 0
	.dw 0xf1c0, 0xc13c,	0xf1ff, 0xc13c,		0x21, 0
	.dw 0xf240, 0xc13c,	0xf27f, 0xc13c,		0x21, 0
	.dw 0xf2c0, 0xc13c,	0xf2ff, 0xc13c,		0x21, 0
	.dw 0xf340, 0xc13c,	0xf37f, 0xc13c,		0x21, 0
	.dw 0xf3c0, 0xc13c,	0xf3ff, 0xc13c,		0x21, 0
	.dw 0xf440, 0xc13c,	0xf47f, 0xc13c,		0x21, 0
	.dw 0xf4c0, 0xc13c,	0xf4ff, 0xc13c,		0x21, 0
	.dw 0xf540, 0xc13c,	0xf57f, 0xc13c,		0x21, 0
	.dw 0xf5c0, 0xc13c,	0xf5ff, 0xc13c,		0x21, 0
	.dw 0xf640, 0xc13c,	0xf67f, 0xc13c,		0x21, 0
	.dw 0xf6c0, 0xc13c,	0xf6ff, 0xc13c,		0x21, 0
	.dw 0xf740, 0xc13c,	0xf77f, 0xc13c,		0x21, 0
	.dw 0xf7c0, 0xc13c,	0xf7ff, 0xc13c,		0x21, 0
	.dw 0xf840, 0xc13c,	0xf87f, 0xc13c,		0x21, 0
	.dw 0xf8c0, 0xc13c,	0xf8ff, 0xc13c,		0x21, 0
	.dw 0xf940, 0xc13c,	0xf97f, 0xc13c,		0x21, 0
	.dw 0xf9c0, 0xc13c,	0xffff, 0xc13c,		0x21, 0
	.dw 0x0040, 0xc13d,	0x007f, 0xc13d,		0x21, 0
	.dw 0x00c0, 0xc13d,	0x00ff, 0xc13d,		0x21, 0
	.dw 0x0140, 0xc13d,	0x017f, 0xc13d,		0x21, 0
	.dw 0x01c0, 0xc13d,	0x01ff, 0xc13d,		0x21, 0
	.dw 0x0240, 0xc13d,	0x027f, 0xc13d,		0x21, 0
	.dw 0x02c0, 0xc13d,	0x02ff, 0xc13d,		0x21, 0
	.dw 0x0340, 0xc13d,	0x037f, 0xc13d,		0x21, 0
	.dw 0x03c0, 0xc13d,	0x03ff, 0xc13d,		0x21, 0
	.dw 0x0440, 0xc13d,	0x047f, 0xc13d,		0x21, 0
	.dw 0x04c0, 0xc13d,	0x04ff, 0xc13d,		0x21, 0
	.dw 0x0540, 0xc13d,	0x057f, 0xc13d,		0x21, 0
	.dw 0x05c0, 0xc13d,	0x05ff, 0xc13d,		0x21, 0
	.dw 0x0640, 0xc13d,	0x067f, 0xc13d,		0x21, 0
	.dw 0x06c0, 0xc13d,	0x06ff, 0xc13d,		0x21, 0
	.dw 0x0740, 0xc13d,	0x077f, 0xc13d,		0x21, 0
	.dw 0x07c0, 0xc13d,	0x07ff, 0xc13d,		0x21, 0
	.dw 0x0840, 0xc13d,	0x087f, 0xc13d,		0x21, 0
	.dw 0x08c0, 0xc13d,	0x08ff, 0xc13d,		0x21, 0
	.dw 0x0940, 0xc13d,	0x097f, 0xc13d,		0x21, 0
	.dw 0x09c0, 0xc13d,	0x09ff, 0xc13d,		0x21, 0
	.dw 0x0a40, 0xc13d,	0x0a7f, 0xc13d,		0x21, 0
	.dw 0x0ac0, 0xc13d,	0x0aff, 0xc13d,		0x21, 0
	.dw 0x0b40, 0xc13d,	0x0b7f, 0xc13d,		0x21, 0
	.dw 0x0bc0, 0xc13d,	0x0bff, 0xc13d,		0x21, 0
	.dw 0x0c40, 0xc13d,	0x0c7f, 0xc13d,		0x21, 0
	.dw 0x0cc0, 0xc13d,	0x0cff, 0xc13d,		0x21, 0
	.dw 0x0d40, 0xc13d,	0x0d7f, 0xc13d,		0x21, 0
	.dw 0x0dc0, 0xc13d,	0x0dff, 0xc13d,		0x21, 0
	.dw 0x0e40, 0xc13d,	0x0e7f, 0xc13d,		0x21, 0
	.dw 0x0ec0, 0xc13d,	0x0eff, 0xc13d,		0x21, 0
	.dw 0x0f40, 0xc13d,	0x0f7f, 0xc13d,		0x21, 0
	.dw 0x0fc0, 0xc13d,	0x0fff, 0xc13d,		0x21, 0
	.dw 0x1040, 0xc13d,	0x107f, 0xc13d,		0x21, 0
	.dw 0x10c0, 0xc13d,	0x10ff, 0xc13d,		0x21, 0
	.dw 0x1140, 0xc13d,	0x117f, 0xc13d,		0x21, 0
	.dw 0x11c0, 0xc13d,	0x11ff, 0xc13d,		0x21, 0
	.dw 0x1240, 0xc13d,	0x127f, 0xc13d,		0x21, 0
	.dw 0x12c0, 0xc13d,	0x12ff, 0xc13d,		0x21, 0
	.dw 0x1340, 0xc13d,	0x137f, 0xc13d,		0x21, 0
	.dw 0x13c0, 0xc13d,	0x13ff, 0xc13d,		0x21, 0
	.dw 0x1440, 0xc13d,	0x147f, 0xc13d,		0x21, 0
	.dw 0x14c0, 0xc13d,	0x14ff, 0xc13d,		0x21, 0
	.dw 0x1540, 0xc13d,	0x157f, 0xc13d,		0x21, 0
	.dw 0x15c0, 0xc13d,	0x15ff, 0xc13d,		0x21, 0
	.dw 0x1640, 0xc13d,	0x167f, 0xc13d,		0x21, 0
	.dw 0x16c0, 0xc13d,	0x16ff, 0xc13d,		0x21, 0
	.dw 0x1740, 0xc13d,	0x177f, 0xc13d,		0x21, 0
	.dw 0x17c0, 0xc13d,	0x17ff, 0xc13d,		0x21, 0
	.dw 0x1840, 0xc13d,	0x187f, 0xc13d,		0x21, 0
	.dw 0x18c0, 0xc13d,	0x18ff, 0xc13d,		0x21, 0
	.dw 0x1940, 0xc13d,	0x197f, 0xc13d,		0x21, 0
	.dw 0x19c0, 0xc13d,	0x1fff, 0xc13d,		0x21, 0
	.dw 0x2040, 0xc13d,	0x207f, 0xc13d,		0x21, 0
	.dw 0x20c0, 0xc13d,	0x20ff, 0xc13d,		0x21, 0
	.dw 0x2140, 0xc13d,	0x217f, 0xc13d,		0x21, 0
	.dw 0x21c0, 0xc13d,	0x21ff, 0xc13d,		0x21, 0
	.dw 0x2240, 0xc13d,	0x227f, 0xc13d,		0x21, 0
	.dw 0x22c0, 0xc13d,	0x22ff, 0xc13d,		0x21, 0
	.dw 0x2340, 0xc13d,	0x237f, 0xc13d,		0x21, 0
	.dw 0x23c0, 0xc13d,	0x23ff, 0xc13d,		0x21, 0
	.dw 0x2440, 0xc13d,	0x247f, 0xc13d,		0x21, 0
	.dw 0x24c0, 0xc13d,	0x24ff, 0xc13d,		0x21, 0
	.dw 0x2540, 0xc13d,	0x257f, 0xc13d,		0x21, 0
	.dw 0x25c0, 0xc13d,	0x25ff, 0xc13d,		0x21, 0
	.dw 0x2640, 0xc13d,	0x267f, 0xc13d,		0x21, 0
	.dw 0x26c0, 0xc13d,	0x26ff, 0xc13d,		0x21, 0
	.dw 0x2740, 0xc13d,	0x277f, 0xc13d,		0x21, 0
	.dw 0x27c0, 0xc13d,	0x27ff, 0xc13d,		0x21, 0
	.dw 0x2840, 0xc13d,	0x287f, 0xc13d,		0x21, 0
	.dw 0x28c0, 0xc13d,	0x28ff, 0xc13d,		0x21, 0
	.dw 0x2940, 0xc13d,	0x297f, 0xc13d,		0x21, 0
	.dw 0x29c0, 0xc13d,	0x29ff, 0xc13d,		0x21, 0
	.dw 0x2a40, 0xc13d,	0x2a7f, 0xc13d,		0x21, 0
	.dw 0x2ac0, 0xc13d,	0x2aff, 0xc13d,		0x21, 0
	.dw 0x2b40, 0xc13d,	0x2b7f, 0xc13d,		0x21, 0
	.dw 0x2bc0, 0xc13d,	0x2bff, 0xc13d,		0x21, 0
	.dw 0x2c40, 0xc13d,	0x2c7f, 0xc13d,		0x21, 0
	.dw 0x2cc0, 0xc13d,	0x2cff, 0xc13d,		0x21, 0
	.dw 0x2d40, 0xc13d,	0x2d7f, 0xc13d,		0x21, 0
	.dw 0x2dc0, 0xc13d,	0x2dff, 0xc13d,		0x21, 0
	.dw 0x2e40, 0xc13d,	0x2e7f, 0xc13d,		0x21, 0
	.dw 0x2ec0, 0xc13d,	0x2eff, 0xc13d,		0x21, 0
	.dw 0x2f40, 0xc13d,	0x2f7f, 0xc13d,		0x21, 0
	.dw 0x2fc0, 0xc13d,	0x2fff, 0xc13d,		0x21, 0
	.dw 0x3040, 0xc13d,	0x307f, 0xc13d,		0x21, 0
	.dw 0x30c0, 0xc13d,	0x30ff, 0xc13d,		0x21, 0
	.dw 0x3140, 0xc13d,	0x317f, 0xc13d,		0x21, 0
	.dw 0x31c0, 0xc13d,	0x31ff, 0xc13d,		0x21, 0
	.dw 0x3240, 0xc13d,	0x327f, 0xc13d,		0x21, 0
	.dw 0x32c0, 0xc13d,	0x32ff, 0xc13d,		0x21, 0
	.dw 0x3340, 0xc13d,	0x337f, 0xc13d,		0x21, 0
	.dw 0x33c0, 0xc13d,	0x33ff, 0xc13d,		0x21, 0
	.dw 0x3440, 0xc13d,	0x347f, 0xc13d,		0x21, 0
	.dw 0x34c0, 0xc13d,	0x34ff, 0xc13d,		0x21, 0
	.dw 0x3540, 0xc13d,	0x357f, 0xc13d,		0x21, 0
	.dw 0x35c0, 0xc13d,	0x35ff, 0xc13d,		0x21, 0
	.dw 0x3640, 0xc13d,	0x367f, 0xc13d,		0x21, 0
	.dw 0x36c0, 0xc13d,	0x36ff, 0xc13d,		0x21, 0
	.dw 0x3740, 0xc13d,	0x377f, 0xc13d,		0x21, 0
	.dw 0x37c0, 0xc13d,	0x37ff, 0xc13d,		0x21, 0
	.dw 0x3840, 0xc13d,	0x387f, 0xc13d,		0x21, 0
	.dw 0x38c0, 0xc13d,	0x38ff, 0xc13d,		0x21, 0
	.dw 0x3940, 0xc13d,	0x397f, 0xc13d,		0x21, 0
	.dw 0x39c0, 0xc13d,	0x3fff, 0xc13d,		0x21, 0
	.dw 0x4040, 0xc13d,	0x407f, 0xc13d,		0x21, 0
	.dw 0x40c0, 0xc13d,	0x40ff, 0xc13d,		0x21, 0
	.dw 0x4140, 0xc13d,	0x417f, 0xc13d,		0x21, 0
	.dw 0x41c0, 0xc13d,	0x41ff, 0xc13d,		0x21, 0
	.dw 0x4240, 0xc13d,	0x427f, 0xc13d,		0x21, 0
	.dw 0x42c0, 0xc13d,	0x42ff, 0xc13d,		0x21, 0
	.dw 0x4340, 0xc13d,	0x437f, 0xc13d,		0x21, 0
	.dw 0x43c0, 0xc13d,	0x43ff, 0xc13d,		0x21, 0
	.dw 0x4440, 0xc13d,	0x447f, 0xc13d,		0x21, 0
	.dw 0x44c0, 0xc13d,	0x44ff, 0xc13d,		0x21, 0
	.dw 0x4540, 0xc13d,	0x457f, 0xc13d,		0x21, 0
	.dw 0x45c0, 0xc13d,	0x45ff, 0xc13d,		0x21, 0
	.dw 0x4640, 0xc13d,	0x467f, 0xc13d,		0x21, 0
	.dw 0x46c0, 0xc13d,	0x46ff, 0xc13d,		0x21, 0
	.dw 0x4740, 0xc13d,	0x477f, 0xc13d,		0x21, 0
	.dw 0x47c0, 0xc13d,	0x47ff, 0xc13d,		0x21, 0
	.dw 0x4840, 0xc13d,	0x487f, 0xc13d,		0x21, 0
	.dw 0x48c0, 0xc13d,	0x48ff, 0xc13d,		0x21, 0
	.dw 0x4940, 0xc13d,	0x497f, 0xc13d,		0x21, 0
	.dw 0x49c0, 0xc13d,	0x49ff, 0xc13d,		0x21, 0
	.dw 0x4a40, 0xc13d,	0x4a7f, 0xc13d,		0x21, 0
	.dw 0x4ac0, 0xc13d,	0x4aff, 0xc13d,		0x21, 0
	.dw 0x4b40, 0xc13d,	0x4b7f, 0xc13d,		0x21, 0
	.dw 0x4bc0, 0xc13d,	0x4bff, 0xc13d,		0x21, 0
	.dw 0x4c40, 0xc13d,	0x4c7f, 0xc13d,		0x21, 0
	.dw 0x4cc0, 0xc13d,	0x4cff, 0xc13d,		0x21, 0
	.dw 0x4d40, 0xc13d,	0x4d7f, 0xc13d,		0x21, 0
	.dw 0x4dc0, 0xc13d,	0x4dff, 0xc13d,		0x21, 0
	.dw 0x4e40, 0xc13d,	0x4e7f, 0xc13d,		0x21, 0
	.dw 0x4ec0, 0xc13d,	0x4eff, 0xc13d,		0x21, 0
	.dw 0x4f40, 0xc13d,	0x4f7f, 0xc13d,		0x21, 0
	.dw 0x4fc0, 0xc13d,	0x4fff, 0xc13d,		0x21, 0
	.dw 0x5040, 0xc13d,	0x507f, 0xc13d,		0x21, 0
	.dw 0x50c0, 0xc13d,	0x50ff, 0xc13d,		0x21, 0
	.dw 0x5140, 0xc13d,	0x517f, 0xc13d,		0x21, 0
	.dw 0x51c0, 0xc13d,	0x51ff, 0xc13d,		0x21, 0
	.dw 0x5240, 0xc13d,	0x527f, 0xc13d,		0x21, 0
	.dw 0x52c0, 0xc13d,	0x52ff, 0xc13d,		0x21, 0
	.dw 0x5340, 0xc13d,	0x537f, 0xc13d,		0x21, 0
	.dw 0x53c0, 0xc13d,	0x53ff, 0xc13d,		0x21, 0
	.dw 0x5440, 0xc13d,	0x547f, 0xc13d,		0x21, 0
	.dw 0x54c0, 0xc13d,	0x54ff, 0xc13d,		0x21, 0
	.dw 0x5540, 0xc13d,	0x557f, 0xc13d,		0x21, 0
	.dw 0x55c0, 0xc13d,	0x55ff, 0xc13d,		0x21, 0
	.dw 0x5640, 0xc13d,	0x567f, 0xc13d,		0x21, 0
	.dw 0x56c0, 0xc13d,	0x56ff, 0xc13d,		0x21, 0
	.dw 0x5740, 0xc13d,	0x577f, 0xc13d,		0x21, 0
	.dw 0x57c0, 0xc13d,	0x57ff, 0xc13d,		0x21, 0
	.dw 0x5840, 0xc13d,	0x587f, 0xc13d,		0x21, 0
	.dw 0x58c0, 0xc13d,	0x58ff, 0xc13d,		0x21, 0
	.dw 0x5940, 0xc13d,	0x597f, 0xc13d,		0x21, 0
	.dw 0x59c0, 0xc13d,	0x5fff, 0xc13d,		0x21, 0
	.dw 0x6040, 0xc13d,	0x607f, 0xc13d,		0x21, 0
	.dw 0x60c0, 0xc13d,	0x60ff, 0xc13d,		0x21, 0
	.dw 0x6140, 0xc13d,	0x617f, 0xc13d,		0x21, 0
	.dw 0x61c0, 0xc13d,	0x61ff, 0xc13d,		0x21, 0
	.dw 0x6240, 0xc13d,	0x627f, 0xc13d,		0x21, 0
	.dw 0x62c0, 0xc13d,	0x62ff, 0xc13d,		0x21, 0
	.dw 0x6340, 0xc13d,	0x637f, 0xc13d,		0x21, 0
	.dw 0x63c0, 0xc13d,	0x63ff, 0xc13d,		0x21, 0
	.dw 0x6440, 0xc13d,	0x647f, 0xc13d,		0x21, 0
	.dw 0x64c0, 0xc13d,	0x64ff, 0xc13d,		0x21, 0
	.dw 0x6540, 0xc13d,	0x657f, 0xc13d,		0x21, 0
	.dw 0x65c0, 0xc13d,	0x65ff, 0xc13d,		0x21, 0
	.dw 0x6640, 0xc13d,	0x667f, 0xc13d,		0x21, 0
	.dw 0x66c0, 0xc13d,	0x66ff, 0xc13d,		0x21, 0
	.dw 0x6740, 0xc13d,	0x677f, 0xc13d,		0x21, 0
	.dw 0x67c0, 0xc13d,	0x67ff, 0xc13d,		0x21, 0
	.dw 0x6840, 0xc13d,	0x687f, 0xc13d,		0x21, 0
	.dw 0x68c0, 0xc13d,	0x68ff, 0xc13d,		0x21, 0
	.dw 0x6940, 0xc13d,	0x697f, 0xc13d,		0x21, 0
	.dw 0x69c0, 0xc13d,	0x69ff, 0xc13d,		0x21, 0
	.dw 0x6a40, 0xc13d,	0x6a7f, 0xc13d,		0x21, 0
	.dw 0x6ac0, 0xc13d,	0x6aff, 0xc13d,		0x21, 0
	.dw 0x6b40, 0xc13d,	0x6b7f, 0xc13d,		0x21, 0
	.dw 0x6bc0, 0xc13d,	0x6bff, 0xc13d,		0x21, 0
	.dw 0x6c40, 0xc13d,	0x6c7f, 0xc13d,		0x21, 0
	.dw 0x6cc0, 0xc13d,	0x6cff, 0xc13d,		0x21, 0
	.dw 0x6d40, 0xc13d,	0x6d7f, 0xc13d,		0x21, 0
	.dw 0x6dc0, 0xc13d,	0x6dff, 0xc13d,		0x21, 0
	.dw 0x6e40, 0xc13d,	0x6e7f, 0xc13d,		0x21, 0
	.dw 0x6ec0, 0xc13d,	0x6eff, 0xc13d,		0x21, 0
	.dw 0x6f40, 0xc13d,	0x6f7f, 0xc13d,		0x21, 0
	.dw 0x6fc0, 0xc13d,	0x6fff, 0xc13d,		0x21, 0
	.dw 0x7040, 0xc13d,	0x707f, 0xc13d,		0x21, 0
	.dw 0x70c0, 0xc13d,	0x70ff, 0xc13d,		0x21, 0
	.dw 0x7140, 0xc13d,	0x717f, 0xc13d,		0x21, 0
	.dw 0x71c0, 0xc13d,	0x71ff, 0xc13d,		0x21, 0
	.dw 0x7240, 0xc13d,	0x727f, 0xc13d,		0x21, 0
	.dw 0x72c0, 0xc13d,	0x72ff, 0xc13d,		0x21, 0
	.dw 0x7340, 0xc13d,	0x737f, 0xc13d,		0x21, 0
	.dw 0x73c0, 0xc13d,	0x73ff, 0xc13d,		0x21, 0
	.dw 0x7440, 0xc13d,	0x747f, 0xc13d,		0x21, 0
	.dw 0x74c0, 0xc13d,	0x74ff, 0xc13d,		0x21, 0
	.dw 0x7540, 0xc13d,	0x757f, 0xc13d,		0x21, 0
	.dw 0x75c0, 0xc13d,	0x75ff, 0xc13d,		0x21, 0
	.dw 0x7640, 0xc13d,	0x767f, 0xc13d,		0x21, 0
	.dw 0x76c0, 0xc13d,	0x76ff, 0xc13d,		0x21, 0
	.dw 0x7740, 0xc13d,	0x777f, 0xc13d,		0x21, 0
	.dw 0x77c0, 0xc13d,	0x77ff, 0xc13d,		0x21, 0
	.dw 0x7840, 0xc13d,	0x787f, 0xc13d,		0x21, 0
	.dw 0x78c0, 0xc13d,	0x78ff, 0xc13d,		0x21, 0
	.dw 0x7940, 0xc13d,	0x797f, 0xc13d,		0x21, 0
	.dw 0x79c0, 0xc13d,	0x7fff, 0xc13d,		0x21, 0
	.dw 0x8040, 0xc13d,	0x807f, 0xc13d,		0x21, 0
	.dw 0x80c0, 0xc13d,	0x80ff, 0xc13d,		0x21, 0
	.dw 0x8140, 0xc13d,	0x817f, 0xc13d,		0x21, 0
	.dw 0x81c0, 0xc13d,	0x81ff, 0xc13d,		0x21, 0
	.dw 0x8240, 0xc13d,	0x827f, 0xc13d,		0x21, 0
	.dw 0x82c0, 0xc13d,	0x82ff, 0xc13d,		0x21, 0
	.dw 0x8340, 0xc13d,	0x837f, 0xc13d,		0x21, 0
	.dw 0x83c0, 0xc13d,	0x83ff, 0xc13d,		0x21, 0
	.dw 0x8440, 0xc13d,	0x847f, 0xc13d,		0x21, 0
	.dw 0x84c0, 0xc13d,	0x84ff, 0xc13d,		0x21, 0
	.dw 0x8540, 0xc13d,	0x857f, 0xc13d,		0x21, 0
	.dw 0x85c0, 0xc13d,	0x85ff, 0xc13d,		0x21, 0
	.dw 0x8640, 0xc13d,	0x867f, 0xc13d,		0x21, 0
	.dw 0x86c0, 0xc13d,	0x86ff, 0xc13d,		0x21, 0
	.dw 0x8740, 0xc13d,	0x877f, 0xc13d,		0x21, 0
	.dw 0x87c0, 0xc13d,	0x87ff, 0xc13d,		0x21, 0
	.dw 0x8840, 0xc13d,	0x887f, 0xc13d,		0x21, 0
	.dw 0x88c0, 0xc13d,	0x88ff, 0xc13d,		0x21, 0
	.dw 0x8940, 0xc13d,	0x897f, 0xc13d,		0x21, 0
	.dw 0x89c0, 0xc13d,	0x89ff, 0xc13d,		0x21, 0
	.dw 0x8a40, 0xc13d,	0x8a7f, 0xc13d,		0x21, 0
	.dw 0x8ac0, 0xc13d,	0x8aff, 0xc13d,		0x21, 0
	.dw 0x8b40, 0xc13d,	0x8b7f, 0xc13d,		0x21, 0
	.dw 0x8bc0, 0xc13d,	0x8bff, 0xc13d,		0x21, 0
	.dw 0x8c40, 0xc13d,	0x8c7f, 0xc13d,		0x21, 0
	.dw 0x8cc0, 0xc13d,	0x8cff, 0xc13d,		0x21, 0
	.dw 0x8d40, 0xc13d,	0x8d7f, 0xc13d,		0x21, 0
	.dw 0x8dc0, 0xc13d,	0x8dff, 0xc13d,		0x21, 0
	.dw 0x8e40, 0xc13d,	0x8e7f, 0xc13d,		0x21, 0
	.dw 0x8ec0, 0xc13d,	0x8eff, 0xc13d,		0x21, 0
	.dw 0x8f40, 0xc13d,	0x8f7f, 0xc13d,		0x21, 0
	.dw 0x8fc0, 0xc13d,	0x8fff, 0xc13d,		0x21, 0
	.dw 0x9040, 0xc13d,	0x907f, 0xc13d,		0x21, 0
	.dw 0x90c0, 0xc13d,	0x90ff, 0xc13d,		0x21, 0
	.dw 0x9140, 0xc13d,	0x917f, 0xc13d,		0x21, 0
	.dw 0x91c0, 0xc13d,	0x91ff, 0xc13d,		0x21, 0
	.dw 0x9240, 0xc13d,	0x927f, 0xc13d,		0x21, 0
	.dw 0x92c0, 0xc13d,	0x92ff, 0xc13d,		0x21, 0
	.dw 0x9340, 0xc13d,	0x937f, 0xc13d,		0x21, 0
	.dw 0x93c0, 0xc13d,	0x93ff, 0xc13d,		0x21, 0
	.dw 0x9440, 0xc13d,	0x947f, 0xc13d,		0x21, 0
	.dw 0x94c0, 0xc13d,	0x94ff, 0xc13d,		0x21, 0
	.dw 0x9540, 0xc13d,	0x957f, 0xc13d,		0x21, 0
	.dw 0x95c0, 0xc13d,	0x95ff, 0xc13d,		0x21, 0
	.dw 0x9640, 0xc13d,	0x967f, 0xc13d,		0x21, 0
	.dw 0x96c0, 0xc13d,	0x96ff, 0xc13d,		0x21, 0
	.dw 0x9740, 0xc13d,	0x977f, 0xc13d,		0x21, 0
	.dw 0x97c0, 0xc13d,	0x97ff, 0xc13d,		0x21, 0
	.dw 0x9840, 0xc13d,	0x987f, 0xc13d,		0x21, 0
	.dw 0x98c0, 0xc13d,	0x98ff, 0xc13d,		0x21, 0
	.dw 0x9940, 0xc13d,	0x997f, 0xc13d,		0x21, 0
	.dw 0x99c0, 0xc13d,	0x9fff, 0xc13d,		0x21, 0
	.dw 0xa040, 0xc13d,	0xa07f, 0xc13d,		0x21, 0
	.dw 0xa0c0, 0xc13d,	0xa0ff, 0xc13d,		0x21, 0
	.dw 0xa140, 0xc13d,	0xa17f, 0xc13d,		0x21, 0
	.dw 0xa1c0, 0xc13d,	0xa1ff, 0xc13d,		0x21, 0
	.dw 0xa240, 0xc13d,	0xa27f, 0xc13d,		0x21, 0
	.dw 0xa2c0, 0xc13d,	0xa2ff, 0xc13d,		0x21, 0
	.dw 0xa340, 0xc13d,	0xa37f, 0xc13d,		0x21, 0
	.dw 0xa3c0, 0xc13d,	0xa3ff, 0xc13d,		0x21, 0
	.dw 0xa440, 0xc13d,	0xa47f, 0xc13d,		0x21, 0
	.dw 0xa4c0, 0xc13d,	0xa4ff, 0xc13d,		0x21, 0
	.dw 0xa540, 0xc13d,	0xa57f, 0xc13d,		0x21, 0
	.dw 0xa5c0, 0xc13d,	0xa5ff, 0xc13d,		0x21, 0
	.dw 0xa640, 0xc13d,	0xa67f, 0xc13d,		0x21, 0
	.dw 0xa6c0, 0xc13d,	0xa6ff, 0xc13d,		0x21, 0
	.dw 0xa740, 0xc13d,	0xa77f, 0xc13d,		0x21, 0
	.dw 0xa7c0, 0xc13d,	0xa7ff, 0xc13d,		0x21, 0
	.dw 0xa840, 0xc13d,	0xa87f, 0xc13d,		0x21, 0
	.dw 0xa8c0, 0xc13d,	0xa8ff, 0xc13d,		0x21, 0
	.dw 0xa940, 0xc13d,	0xa97f, 0xc13d,		0x21, 0
	.dw 0xa9c0, 0xc13d,	0xa9ff, 0xc13d,		0x21, 0
	.dw 0xaa40, 0xc13d,	0xaa7f, 0xc13d,		0x21, 0
	.dw 0xaac0, 0xc13d,	0xaaff, 0xc13d,		0x21, 0
	.dw 0xab40, 0xc13d,	0xab7f, 0xc13d,		0x21, 0
	.dw 0xabc0, 0xc13d,	0xabff, 0xc13d,		0x21, 0
	.dw 0xac40, 0xc13d,	0xac7f, 0xc13d,		0x21, 0
	.dw 0xacc0, 0xc13d,	0xacff, 0xc13d,		0x21, 0
	.dw 0xad40, 0xc13d,	0xad7f, 0xc13d,		0x21, 0
	.dw 0xadc0, 0xc13d,	0xadff, 0xc13d,		0x21, 0
	.dw 0xae40, 0xc13d,	0xae7f, 0xc13d,		0x21, 0
	.dw 0xaec0, 0xc13d,	0xaeff, 0xc13d,		0x21, 0
	.dw 0xaf40, 0xc13d,	0xaf7f, 0xc13d,		0x21, 0
	.dw 0xafc0, 0xc13d,	0xafff, 0xc13d,		0x21, 0
	.dw 0xb040, 0xc13d,	0xb07f, 0xc13d,		0x21, 0
	.dw 0xb0c0, 0xc13d,	0xb0ff, 0xc13d,		0x21, 0
	.dw 0xb140, 0xc13d,	0xb17f, 0xc13d,		0x21, 0
	.dw 0xb1c0, 0xc13d,	0xb1ff, 0xc13d,		0x21, 0
	.dw 0xb240, 0xc13d,	0xb27f, 0xc13d,		0x21, 0
	.dw 0xb2c0, 0xc13d,	0xb2ff, 0xc13d,		0x21, 0
	.dw 0xb340, 0xc13d,	0xb37f, 0xc13d,		0x21, 0
	.dw 0xb3c0, 0xc13d,	0xb3ff, 0xc13d,		0x21, 0
	.dw 0xb440, 0xc13d,	0xb47f, 0xc13d,		0x21, 0
	.dw 0xb4c0, 0xc13d,	0xb4ff, 0xc13d,		0x21, 0
	.dw 0xb540, 0xc13d,	0xb57f, 0xc13d,		0x21, 0
	.dw 0xb5c0, 0xc13d,	0xb5ff, 0xc13d,		0x21, 0
	.dw 0xb640, 0xc13d,	0xb67f, 0xc13d,		0x21, 0
	.dw 0xb6c0, 0xc13d,	0xb6ff, 0xc13d,		0x21, 0
	.dw 0xb740, 0xc13d,	0xb77f, 0xc13d,		0x21, 0
	.dw 0xb7c0, 0xc13d,	0xb7ff, 0xc13d,		0x21, 0
	.dw 0xb840, 0xc13d,	0xb87f, 0xc13d,		0x21, 0
	.dw 0xb8c0, 0xc13d,	0xb8ff, 0xc13d,		0x21, 0
	.dw 0xb940, 0xc13d,	0xb97f, 0xc13d,		0x21, 0
	.dw 0xb9c0, 0xc13d,	0xbfff, 0xc13d,		0x21, 0
	.dw 0xc040, 0xc13d,	0xc07f, 0xc13d,		0x21, 0
	.dw 0xc0c0, 0xc13d,	0xc0ff, 0xc13d,		0x21, 0
	.dw 0xc140, 0xc13d,	0xc17f, 0xc13d,		0x21, 0
	.dw 0xc1c0, 0xc13d,	0xc1ff, 0xc13d,		0x21, 0
	.dw 0xc240, 0xc13d,	0xc27f, 0xc13d,		0x21, 0
	.dw 0xc2c0, 0xc13d,	0xc2ff, 0xc13d,		0x21, 0
	.dw 0xc340, 0xc13d,	0xc37f, 0xc13d,		0x21, 0
	.dw 0xc3c0, 0xc13d,	0xc3ff, 0xc13d,		0x21, 0
	.dw 0xc440, 0xc13d,	0xc47f, 0xc13d,		0x21, 0
	.dw 0xc4c0, 0xc13d,	0xc4ff, 0xc13d,		0x21, 0
	.dw 0xc540, 0xc13d,	0xc57f, 0xc13d,		0x21, 0
	.dw 0xc5c0, 0xc13d,	0xc5ff, 0xc13d,		0x21, 0
	.dw 0xc640, 0xc13d,	0xc67f, 0xc13d,		0x21, 0
	.dw 0xc6c0, 0xc13d,	0xc6ff, 0xc13d,		0x21, 0
	.dw 0xc740, 0xc13d,	0xc77f, 0xc13d,		0x21, 0
	.dw 0xc7c0, 0xc13d,	0xc7ff, 0xc13d,		0x21, 0
	.dw 0xc840, 0xc13d,	0xc87f, 0xc13d,		0x21, 0
	.dw 0xc8c0, 0xc13d,	0xc8ff, 0xc13d,		0x21, 0
	.dw 0xc940, 0xc13d,	0xc97f, 0xc13d,		0x21, 0
	.dw 0xc9c0, 0xc13d,	0xc9ff, 0xc13d,		0x21, 0
	.dw 0xca40, 0xc13d,	0xca7f, 0xc13d,		0x21, 0
	.dw 0xcac0, 0xc13d,	0xcaff, 0xc13d,		0x21, 0
	.dw 0xcb40, 0xc13d,	0xcb7f, 0xc13d,		0x21, 0
	.dw 0xcbc0, 0xc13d,	0xcbff, 0xc13d,		0x21, 0
	.dw 0xcc40, 0xc13d,	0xcc7f, 0xc13d,		0x21, 0
	.dw 0xccc0, 0xc13d,	0xccff, 0xc13d,		0x21, 0
	.dw 0xcd40, 0xc13d,	0xcd7f, 0xc13d,		0x21, 0
	.dw 0xcdc0, 0xc13d,	0xcdff, 0xc13d,		0x21, 0
	.dw 0xce40, 0xc13d,	0xce7f, 0xc13d,		0x21, 0
	.dw 0xcec0, 0xc13d,	0xceff, 0xc13d,		0x21, 0
	.dw 0xcf40, 0xc13d,	0xcf7f, 0xc13d,		0x21, 0
	.dw 0xcfc0, 0xc13d,	0xcfff, 0xc13d,		0x21, 0
	.dw 0xd040, 0xc13d,	0xd07f, 0xc13d,		0x21, 0
	.dw 0xd0c0, 0xc13d,	0xd0ff, 0xc13d,		0x21, 0
	.dw 0xd140, 0xc13d,	0xd17f, 0xc13d,		0x21, 0
	.dw 0xd1c0, 0xc13d,	0xd1ff, 0xc13d,		0x21, 0
	.dw 0xd240, 0xc13d,	0xd27f, 0xc13d,		0x21, 0
	.dw 0xd2c0, 0xc13d,	0xd2ff, 0xc13d,		0x21, 0
	.dw 0xd340, 0xc13d,	0xd37f, 0xc13d,		0x21, 0
	.dw 0xd3c0, 0xc13d,	0xd3ff, 0xc13d,		0x21, 0
	.dw 0xd440, 0xc13d,	0xd47f, 0xc13d,		0x21, 0
	.dw 0xd4c0, 0xc13d,	0xd4ff, 0xc13d,		0x21, 0
	.dw 0xd540, 0xc13d,	0xd57f, 0xc13d,		0x21, 0
	.dw 0xd5c0, 0xc13d,	0xd5ff, 0xc13d,		0x21, 0
	.dw 0xd640, 0xc13d,	0xd67f, 0xc13d,		0x21, 0
	.dw 0xd6c0, 0xc13d,	0xd6ff, 0xc13d,		0x21, 0
	.dw 0xd740, 0xc13d,	0xd77f, 0xc13d,		0x21, 0
	.dw 0xd7c0, 0xc13d,	0xd7ff, 0xc13d,		0x21, 0
	.dw 0xd840, 0xc13d,	0xd87f, 0xc13d,		0x21, 0
	.dw 0xd8c0, 0xc13d,	0xd8ff, 0xc13d,		0x21, 0
	.dw 0xd940, 0xc13d,	0xd97f, 0xc13d,		0x21, 0
	.dw 0xd9c0, 0xc13d,	0xdfff, 0xc13d,		0x21, 0
	.dw 0xe040, 0xc13d,	0xe07f, 0xc13d,		0x21, 0
	.dw 0xe0c0, 0xc13d,	0xe0ff, 0xc13d,		0x21, 0
	.dw 0xe140, 0xc13d,	0xe17f, 0xc13d,		0x21, 0
	.dw 0xe1c0, 0xc13d,	0xe1ff, 0xc13d,		0x21, 0
	.dw 0xe240, 0xc13d,	0xe27f, 0xc13d,		0x21, 0
	.dw 0xe2c0, 0xc13d,	0xe2ff, 0xc13d,		0x21, 0
	.dw 0xe340, 0xc13d,	0xe37f, 0xc13d,		0x21, 0
	.dw 0xe3c0, 0xc13d,	0xe3ff, 0xc13d,		0x21, 0
	.dw 0xe440, 0xc13d,	0xe47f, 0xc13d,		0x21, 0
	.dw 0xe4c0, 0xc13d,	0xe4ff, 0xc13d,		0x21, 0
	.dw 0xe540, 0xc13d,	0xe57f, 0xc13d,		0x21, 0
	.dw 0xe5c0, 0xc13d,	0xe5ff, 0xc13d,		0x21, 0
	.dw 0xe640, 0xc13d,	0xe67f, 0xc13d,		0x21, 0
	.dw 0xe6c0, 0xc13d,	0xe6ff, 0xc13d,		0x21, 0
	.dw 0xe740, 0xc13d,	0xe77f, 0xc13d,		0x21, 0
	.dw 0xe7c0, 0xc13d,	0xe7ff, 0xc13d,		0x21, 0
	.dw 0xe840, 0xc13d,	0xe87f, 0xc13d,		0x21, 0
	.dw 0xe8c0, 0xc13d,	0xe8ff, 0xc13d,		0x21, 0
	.dw 0xe940, 0xc13d,	0xe97f, 0xc13d,		0x21, 0
	.dw 0xe9c0, 0xc13d,	0xe9ff, 0xc13d,		0x21, 0
	.dw 0xea40, 0xc13d,	0xea7f, 0xc13d,		0x21, 0
	.dw 0xeac0, 0xc13d,	0xeaff, 0xc13d,		0x21, 0
	.dw 0xeb40, 0xc13d,	0xeb7f, 0xc13d,		0x21, 0
	.dw 0xebc0, 0xc13d,	0xebff, 0xc13d,		0x21, 0
	.dw 0xec40, 0xc13d,	0xec7f, 0xc13d,		0x21, 0
	.dw 0xecc0, 0xc13d,	0xecff, 0xc13d,		0x21, 0
	.dw 0xed40, 0xc13d,	0xed7f, 0xc13d,		0x21, 0
	.dw 0xedc0, 0xc13d,	0xedff, 0xc13d,		0x21, 0
	.dw 0xee40, 0xc13d,	0xee7f, 0xc13d,		0x21, 0
	.dw 0xeec0, 0xc13d,	0xeeff, 0xc13d,		0x21, 0
	.dw 0xef40, 0xc13d,	0xef7f, 0xc13d,		0x21, 0
	.dw 0xefc0, 0xc13d,	0xefff, 0xc13d,		0x21, 0
	.dw 0xf040, 0xc13d,	0xf07f, 0xc13d,		0x21, 0
	.dw 0xf0c0, 0xc13d,	0xf0ff, 0xc13d,		0x21, 0
	.dw 0xf140, 0xc13d,	0xf17f, 0xc13d,		0x21, 0
	.dw 0xf1c0, 0xc13d,	0xf1ff, 0xc13d,		0x21, 0
	.dw 0xf240, 0xc13d,	0xf27f, 0xc13d,		0x21, 0
	.dw 0xf2c0, 0xc13d,	0xf2ff, 0xc13d,		0x21, 0
	.dw 0xf340, 0xc13d,	0xf37f, 0xc13d,		0x21, 0
	.dw 0xf3c0, 0xc13d,	0xf3ff, 0xc13d,		0x21, 0
	.dw 0xf440, 0xc13d,	0xf47f, 0xc13d,		0x21, 0
	.dw 0xf4c0, 0xc13d,	0xf4ff, 0xc13d,		0x21, 0
	.dw 0xf540, 0xc13d,	0xf57f, 0xc13d,		0x21, 0
	.dw 0xf5c0, 0xc13d,	0xf5ff, 0xc13d,		0x21, 0
	.dw 0xf640, 0xc13d,	0xf67f, 0xc13d,		0x21, 0
	.dw 0xf6c0, 0xc13d,	0xf6ff, 0xc13d,		0x21, 0
	.dw 0xf740, 0xc13d,	0xf77f, 0xc13d,		0x21, 0
	.dw 0xf7c0, 0xc13d,	0xf7ff, 0xc13d,		0x21, 0
	.dw 0xf840, 0xc13d,	0xf87f, 0xc13d,		0x21, 0
	.dw 0xf8c0, 0xc13d,	0xf8ff, 0xc13d,		0x21, 0
	.dw 0xf940, 0xc13d,	0xf97f, 0xc13d,		0x21, 0
	.dw 0xf9c0, 0xc13d,	0xffff, 0xc13d,		0x21, 0
	.dw 0x0040, 0xc13e,	0x007f, 0xc13e,		0x21, 0
	.dw 0x00c0, 0xc13e,	0x00ff, 0xc13e,		0x21, 0
	.dw 0x0140, 0xc13e,	0x017f, 0xc13e,		0x21, 0
	.dw 0x01c0, 0xc13e,	0x01ff, 0xc13e,		0x21, 0
	.dw 0x0240, 0xc13e,	0x027f, 0xc13e,		0x21, 0
	.dw 0x02c0, 0xc13e,	0x02ff, 0xc13e,		0x21, 0
	.dw 0x0340, 0xc13e,	0x037f, 0xc13e,		0x21, 0
	.dw 0x03c0, 0xc13e,	0x03ff, 0xc13e,		0x21, 0
	.dw 0x0440, 0xc13e,	0x047f, 0xc13e,		0x21, 0
	.dw 0x04c0, 0xc13e,	0x04ff, 0xc13e,		0x21, 0
	.dw 0x0540, 0xc13e,	0x057f, 0xc13e,		0x21, 0
	.dw 0x05c0, 0xc13e,	0x05ff, 0xc13e,		0x21, 0
	.dw 0x0640, 0xc13e,	0x067f, 0xc13e,		0x21, 0
	.dw 0x06c0, 0xc13e,	0x06ff, 0xc13e,		0x21, 0
	.dw 0x0740, 0xc13e,	0x077f, 0xc13e,		0x21, 0
	.dw 0x07c0, 0xc13e,	0x07ff, 0xc13e,		0x21, 0
	.dw 0x0840, 0xc13e,	0x087f, 0xc13e,		0x21, 0
	.dw 0x08c0, 0xc13e,	0x08ff, 0xc13e,		0x21, 0
	.dw 0x0940, 0xc13e,	0x097f, 0xc13e,		0x21, 0
	.dw 0x09c0, 0xc13e,	0x09ff, 0xc13e,		0x21, 0
	.dw 0x0a40, 0xc13e,	0x0a7f, 0xc13e,		0x21, 0
	.dw 0x0ac0, 0xc13e,	0x0aff, 0xc13e,		0x21, 0
	.dw 0x0b40, 0xc13e,	0x0b7f, 0xc13e,		0x21, 0
	.dw 0x0bc0, 0xc13e,	0x0bff, 0xc13e,		0x21, 0
	.dw 0x0c40, 0xc13e,	0x0c7f, 0xc13e,		0x21, 0
	.dw 0x0cc0, 0xc13e,	0x0cff, 0xc13e,		0x21, 0
	.dw 0x0d40, 0xc13e,	0x0d7f, 0xc13e,		0x21, 0
	.dw 0x0dc0, 0xc13e,	0x0dff, 0xc13e,		0x21, 0
	.dw 0x0e40, 0xc13e,	0x0e7f, 0xc13e,		0x21, 0
	.dw 0x0ec0, 0xc13e,	0x0eff, 0xc13e,		0x21, 0
	.dw 0x0f40, 0xc13e,	0x0f7f, 0xc13e,		0x21, 0
	.dw 0x0fc0, 0xc13e,	0x0fff, 0xc13e,		0x21, 0
	.dw 0x1040, 0xc13e,	0x107f, 0xc13e,		0x21, 0
	.dw 0x10c0, 0xc13e,	0x10ff, 0xc13e,		0x21, 0
	.dw 0x1140, 0xc13e,	0x117f, 0xc13e,		0x21, 0
	.dw 0x11c0, 0xc13e,	0x11ff, 0xc13e,		0x21, 0
	.dw 0x1240, 0xc13e,	0x127f, 0xc13e,		0x21, 0
	.dw 0x12c0, 0xc13e,	0x12ff, 0xc13e,		0x21, 0
	.dw 0x1340, 0xc13e,	0x137f, 0xc13e,		0x21, 0
	.dw 0x13c0, 0xc13e,	0x13ff, 0xc13e,		0x21, 0
	.dw 0x1440, 0xc13e,	0x147f, 0xc13e,		0x21, 0
	.dw 0x14c0, 0xc13e,	0x14ff, 0xc13e,		0x21, 0
	.dw 0x1540, 0xc13e,	0x157f, 0xc13e,		0x21, 0
	.dw 0x15c0, 0xc13e,	0x15ff, 0xc13e,		0x21, 0
	.dw 0x1640, 0xc13e,	0x167f, 0xc13e,		0x21, 0
	.dw 0x16c0, 0xc13e,	0x16ff, 0xc13e,		0x21, 0
	.dw 0x1740, 0xc13e,	0x177f, 0xc13e,		0x21, 0
	.dw 0x17c0, 0xc13e,	0x17ff, 0xc13e,		0x21, 0
	.dw 0x1840, 0xc13e,	0x187f, 0xc13e,		0x21, 0
	.dw 0x18c0, 0xc13e,	0x18ff, 0xc13e,		0x21, 0
	.dw 0x1940, 0xc13e,	0x197f, 0xc13e,		0x21, 0
	.dw 0x19c0, 0xc13e,	0x1fff, 0xc13e,		0x21, 0
	.dw 0x2040, 0xc13e,	0x207f, 0xc13e,		0x21, 0
	.dw 0x20c0, 0xc13e,	0x20ff, 0xc13e,		0x21, 0
	.dw 0x2140, 0xc13e,	0x217f, 0xc13e,		0x21, 0
	.dw 0x21c0, 0xc13e,	0x21ff, 0xc13e,		0x21, 0
	.dw 0x2240, 0xc13e,	0x227f, 0xc13e,		0x21, 0
	.dw 0x22c0, 0xc13e,	0x22ff, 0xc13e,		0x21, 0
	.dw 0x2340, 0xc13e,	0x237f, 0xc13e,		0x21, 0
	.dw 0x23c0, 0xc13e,	0x23ff, 0xc13e,		0x21, 0
	.dw 0x2440, 0xc13e,	0x247f, 0xc13e,		0x21, 0
	.dw 0x24c0, 0xc13e,	0x24ff, 0xc13e,		0x21, 0
	.dw 0x2540, 0xc13e,	0x257f, 0xc13e,		0x21, 0
	.dw 0x25c0, 0xc13e,	0x25ff, 0xc13e,		0x21, 0
	.dw 0x2640, 0xc13e,	0x267f, 0xc13e,		0x21, 0
	.dw 0x26c0, 0xc13e,	0x26ff, 0xc13e,		0x21, 0
	.dw 0x2740, 0xc13e,	0x277f, 0xc13e,		0x21, 0
	.dw 0x27c0, 0xc13e,	0x27ff, 0xc13e,		0x21, 0
	.dw 0x2840, 0xc13e,	0x287f, 0xc13e,		0x21, 0
	.dw 0x28c0, 0xc13e,	0x28ff, 0xc13e,		0x21, 0
	.dw 0x2940, 0xc13e,	0x297f, 0xc13e,		0x21, 0
	.dw 0x29c0, 0xc13e,	0x29ff, 0xc13e,		0x21, 0
	.dw 0x2a40, 0xc13e,	0x2a7f, 0xc13e,		0x21, 0
	.dw 0x2ac0, 0xc13e,	0x2aff, 0xc13e,		0x21, 0
	.dw 0x2b40, 0xc13e,	0x2b7f, 0xc13e,		0x21, 0
	.dw 0x2bc0, 0xc13e,	0x2bff, 0xc13e,		0x21, 0
	.dw 0x2c40, 0xc13e,	0x2c7f, 0xc13e,		0x21, 0
	.dw 0x2cc0, 0xc13e,	0x2cff, 0xc13e,		0x21, 0
	.dw 0x2d40, 0xc13e,	0x2d7f, 0xc13e,		0x21, 0
	.dw 0x2dc0, 0xc13e,	0x2dff, 0xc13e,		0x21, 0
	.dw 0x2e40, 0xc13e,	0x2e7f, 0xc13e,		0x21, 0
	.dw 0x2ec0, 0xc13e,	0x2eff, 0xc13e,		0x21, 0
	.dw 0x2f40, 0xc13e,	0x2f7f, 0xc13e,		0x21, 0
	.dw 0x2fc0, 0xc13e,	0x2fff, 0xc13e,		0x21, 0
	.dw 0x3040, 0xc13e,	0x307f, 0xc13e,		0x21, 0
	.dw 0x30c0, 0xc13e,	0x30ff, 0xc13e,		0x21, 0
	.dw 0x3140, 0xc13e,	0x317f, 0xc13e,		0x21, 0
	.dw 0x31c0, 0xc13e,	0x31ff, 0xc13e,		0x21, 0
	.dw 0x3240, 0xc13e,	0x327f, 0xc13e,		0x21, 0
	.dw 0x32c0, 0xc13e,	0x32ff, 0xc13e,		0x21, 0
	.dw 0x3340, 0xc13e,	0x337f, 0xc13e,		0x21, 0
	.dw 0x33c0, 0xc13e,	0x33ff, 0xc13e,		0x21, 0
	.dw 0x3440, 0xc13e,	0x347f, 0xc13e,		0x21, 0
	.dw 0x34c0, 0xc13e,	0x34ff, 0xc13e,		0x21, 0
	.dw 0x3540, 0xc13e,	0x357f, 0xc13e,		0x21, 0
	.dw 0x35c0, 0xc13e,	0x35ff, 0xc13e,		0x21, 0
	.dw 0x3640, 0xc13e,	0x367f, 0xc13e,		0x21, 0
	.dw 0x36c0, 0xc13e,	0x36ff, 0xc13e,		0x21, 0
	.dw 0x3740, 0xc13e,	0x377f, 0xc13e,		0x21, 0
	.dw 0x37c0, 0xc13e,	0x37ff, 0xc13e,		0x21, 0
	.dw 0x3840, 0xc13e,	0x387f, 0xc13e,		0x21, 0
	.dw 0x38c0, 0xc13e,	0x38ff, 0xc13e,		0x21, 0
	.dw 0x3940, 0xc13e,	0x397f, 0xc13e,		0x21, 0
	.dw 0x39c0, 0xc13e,	0x3fff, 0xc13e,		0x21, 0
	.dw 0x4040, 0xc13e,	0x407f, 0xc13e,		0x21, 0
	.dw 0x40c0, 0xc13e,	0x40ff, 0xc13e,		0x21, 0
	.dw 0x4140, 0xc13e,	0x417f, 0xc13e,		0x21, 0
	.dw 0x41c0, 0xc13e,	0x41ff, 0xc13e,		0x21, 0
	.dw 0x4240, 0xc13e,	0x427f, 0xc13e,		0x21, 0
	.dw 0x42c0, 0xc13e,	0x42ff, 0xc13e,		0x21, 0
	.dw 0x4340, 0xc13e,	0x437f, 0xc13e,		0x21, 0
	.dw 0x43c0, 0xc13e,	0x43ff, 0xc13e,		0x21, 0
	.dw 0x4440, 0xc13e,	0x447f, 0xc13e,		0x21, 0
	.dw 0x44c0, 0xc13e,	0x44ff, 0xc13e,		0x21, 0
	.dw 0x4540, 0xc13e,	0x457f, 0xc13e,		0x21, 0
	.dw 0x45c0, 0xc13e,	0x45ff, 0xc13e,		0x21, 0
	.dw 0x4640, 0xc13e,	0x467f, 0xc13e,		0x21, 0
	.dw 0x46c0, 0xc13e,	0x46ff, 0xc13e,		0x21, 0
	.dw 0x4740, 0xc13e,	0x477f, 0xc13e,		0x21, 0
	.dw 0x47c0, 0xc13e,	0x47ff, 0xc13e,		0x21, 0
	.dw 0x4840, 0xc13e,	0x487f, 0xc13e,		0x21, 0
	.dw 0x48c0, 0xc13e,	0x48ff, 0xc13e,		0x21, 0
	.dw 0x4940, 0xc13e,	0x497f, 0xc13e,		0x21, 0
	.dw 0x49c0, 0xc13e,	0x49ff, 0xc13e,		0x21, 0
	.dw 0x4a40, 0xc13e,	0x4a7f, 0xc13e,		0x21, 0
	.dw 0x4ac0, 0xc13e,	0x4aff, 0xc13e,		0x21, 0
	.dw 0x4b40, 0xc13e,	0x4b7f, 0xc13e,		0x21, 0
	.dw 0x4bc0, 0xc13e,	0x4bff, 0xc13e,		0x21, 0
	.dw 0x4c40, 0xc13e,	0x4c7f, 0xc13e,		0x21, 0
	.dw 0x4cc0, 0xc13e,	0x4cff, 0xc13e,		0x21, 0
	.dw 0x4d40, 0xc13e,	0x4d7f, 0xc13e,		0x21, 0
	.dw 0x4dc0, 0xc13e,	0x4dff, 0xc13e,		0x21, 0
	.dw 0x4e40, 0xc13e,	0x4e7f, 0xc13e,		0x21, 0
	.dw 0x4ec0, 0xc13e,	0x4eff, 0xc13e,		0x21, 0
	.dw 0x4f40, 0xc13e,	0x4f7f, 0xc13e,		0x21, 0
	.dw 0x4fc0, 0xc13e,	0x4fff, 0xc13e,		0x21, 0
	.dw 0x5040, 0xc13e,	0x507f, 0xc13e,		0x21, 0
	.dw 0x50c0, 0xc13e,	0x50ff, 0xc13e,		0x21, 0
	.dw 0x5140, 0xc13e,	0x517f, 0xc13e,		0x21, 0
	.dw 0x51c0, 0xc13e,	0x51ff, 0xc13e,		0x21, 0
	.dw 0x5240, 0xc13e,	0x527f, 0xc13e,		0x21, 0
	.dw 0x52c0, 0xc13e,	0x52ff, 0xc13e,		0x21, 0
	.dw 0x5340, 0xc13e,	0x537f, 0xc13e,		0x21, 0
	.dw 0x53c0, 0xc13e,	0x53ff, 0xc13e,		0x21, 0
	.dw 0x5440, 0xc13e,	0x547f, 0xc13e,		0x21, 0
	.dw 0x54c0, 0xc13e,	0x54ff, 0xc13e,		0x21, 0
	.dw 0x5540, 0xc13e,	0x557f, 0xc13e,		0x21, 0
	.dw 0x55c0, 0xc13e,	0x55ff, 0xc13e,		0x21, 0
	.dw 0x5640, 0xc13e,	0x567f, 0xc13e,		0x21, 0
	.dw 0x56c0, 0xc13e,	0x56ff, 0xc13e,		0x21, 0
	.dw 0x5740, 0xc13e,	0x577f, 0xc13e,		0x21, 0
	.dw 0x57c0, 0xc13e,	0x57ff, 0xc13e,		0x21, 0
	.dw 0x5840, 0xc13e,	0x587f, 0xc13e,		0x21, 0
	.dw 0x58c0, 0xc13e,	0x58ff, 0xc13e,		0x21, 0
	.dw 0x5940, 0xc13e,	0x597f, 0xc13e,		0x21, 0
	.dw 0x59c0, 0xc13e,	0x5fff, 0xc13e,		0x21, 0
	.dw 0x6040, 0xc13e,	0x607f, 0xc13e,		0x21, 0
	.dw 0x60c0, 0xc13e,	0x60ff, 0xc13e,		0x21, 0
	.dw 0x6140, 0xc13e,	0x617f, 0xc13e,		0x21, 0
	.dw 0x61c0, 0xc13e,	0x61ff, 0xc13e,		0x21, 0
	.dw 0x6240, 0xc13e,	0x627f, 0xc13e,		0x21, 0
	.dw 0x62c0, 0xc13e,	0x62ff, 0xc13e,		0x21, 0
	.dw 0x6340, 0xc13e,	0x637f, 0xc13e,		0x21, 0
	.dw 0x63c0, 0xc13e,	0x63ff, 0xc13e,		0x21, 0
	.dw 0x6440, 0xc13e,	0x647f, 0xc13e,		0x21, 0
	.dw 0x64c0, 0xc13e,	0x64ff, 0xc13e,		0x21, 0
	.dw 0x6540, 0xc13e,	0x657f, 0xc13e,		0x21, 0
	.dw 0x65c0, 0xc13e,	0x65ff, 0xc13e,		0x21, 0
	.dw 0x6640, 0xc13e,	0x667f, 0xc13e,		0x21, 0
	.dw 0x66c0, 0xc13e,	0x66ff, 0xc13e,		0x21, 0
	.dw 0x6740, 0xc13e,	0x677f, 0xc13e,		0x21, 0
	.dw 0x67c0, 0xc13e,	0x67ff, 0xc13e,		0x21, 0
	.dw 0x6840, 0xc13e,	0x687f, 0xc13e,		0x21, 0
	.dw 0x68c0, 0xc13e,	0x68ff, 0xc13e,		0x21, 0
	.dw 0x6940, 0xc13e,	0x697f, 0xc13e,		0x21, 0
	.dw 0x69c0, 0xc13e,	0x69ff, 0xc13e,		0x21, 0
	.dw 0x6a40, 0xc13e,	0x6a7f, 0xc13e,		0x21, 0
	.dw 0x6ac0, 0xc13e,	0x6aff, 0xc13e,		0x21, 0
	.dw 0x6b40, 0xc13e,	0x6b7f, 0xc13e,		0x21, 0
	.dw 0x6bc0, 0xc13e,	0x6bff, 0xc13e,		0x21, 0
	.dw 0x6c40, 0xc13e,	0x6c7f, 0xc13e,		0x21, 0
	.dw 0x6cc0, 0xc13e,	0x6cff, 0xc13e,		0x21, 0
	.dw 0x6d40, 0xc13e,	0x6d7f, 0xc13e,		0x21, 0
	.dw 0x6dc0, 0xc13e,	0x6dff, 0xc13e,		0x21, 0
	.dw 0x6e40, 0xc13e,	0x6e7f, 0xc13e,		0x21, 0
	.dw 0x6ec0, 0xc13e,	0x6eff, 0xc13e,		0x21, 0
	.dw 0x6f40, 0xc13e,	0x6f7f, 0xc13e,		0x21, 0
	.dw 0x6fc0, 0xc13e,	0x6fff, 0xc13e,		0x21, 0
	.dw 0x7040, 0xc13e,	0x707f, 0xc13e,		0x21, 0
	.dw 0x70c0, 0xc13e,	0x70ff, 0xc13e,		0x21, 0
	.dw 0x7140, 0xc13e,	0x717f, 0xc13e,		0x21, 0
	.dw 0x71c0, 0xc13e,	0x71ff, 0xc13e,		0x21, 0
	.dw 0x7240, 0xc13e,	0x727f, 0xc13e,		0x21, 0
	.dw 0x72c0, 0xc13e,	0x72ff, 0xc13e,		0x21, 0
	.dw 0x7340, 0xc13e,	0x737f, 0xc13e,		0x21, 0
	.dw 0x73c0, 0xc13e,	0x73ff, 0xc13e,		0x21, 0
	.dw 0x7440, 0xc13e,	0x747f, 0xc13e,		0x21, 0
	.dw 0x74c0, 0xc13e,	0x74ff, 0xc13e,		0x21, 0
	.dw 0x7540, 0xc13e,	0x757f, 0xc13e,		0x21, 0
	.dw 0x75c0, 0xc13e,	0x75ff, 0xc13e,		0x21, 0
	.dw 0x7640, 0xc13e,	0x767f, 0xc13e,		0x21, 0
	.dw 0x76c0, 0xc13e,	0x76ff, 0xc13e,		0x21, 0
	.dw 0x7740, 0xc13e,	0x777f, 0xc13e,		0x21, 0
	.dw 0x77c0, 0xc13e,	0x77ff, 0xc13e,		0x21, 0
	.dw 0x7840, 0xc13e,	0x787f, 0xc13e,		0x21, 0
	.dw 0x78c0, 0xc13e,	0x78ff, 0xc13e,		0x21, 0
	.dw 0x7940, 0xc13e,	0x797f, 0xc13e,		0x21, 0
	.dw 0x79c0, 0xc13e,	0x7fff, 0xc13e,		0x21, 0
	.dw 0x8040, 0xc13e,	0x807f, 0xc13e,		0x21, 0
	.dw 0x80c0, 0xc13e,	0x80ff, 0xc13e,		0x21, 0
	.dw 0x8140, 0xc13e,	0x817f, 0xc13e,		0x21, 0
	.dw 0x81c0, 0xc13e,	0x81ff, 0xc13e,		0x21, 0
	.dw 0x8240, 0xc13e,	0x827f, 0xc13e,		0x21, 0
	.dw 0x82c0, 0xc13e,	0x82ff, 0xc13e,		0x21, 0
	.dw 0x8340, 0xc13e,	0x837f, 0xc13e,		0x21, 0
	.dw 0x83c0, 0xc13e,	0x83ff, 0xc13e,		0x21, 0
	.dw 0x8440, 0xc13e,	0x847f, 0xc13e,		0x21, 0
	.dw 0x84c0, 0xc13e,	0x84ff, 0xc13e,		0x21, 0
	.dw 0x8540, 0xc13e,	0x857f, 0xc13e,		0x21, 0
	.dw 0x85c0, 0xc13e,	0x85ff, 0xc13e,		0x21, 0
	.dw 0x8640, 0xc13e,	0x867f, 0xc13e,		0x21, 0
	.dw 0x86c0, 0xc13e,	0x86ff, 0xc13e,		0x21, 0
	.dw 0x8740, 0xc13e,	0x877f, 0xc13e,		0x21, 0
	.dw 0x87c0, 0xc13e,	0x87ff, 0xc13e,		0x21, 0
	.dw 0x8840, 0xc13e,	0x887f, 0xc13e,		0x21, 0
	.dw 0x88c0, 0xc13e,	0x88ff, 0xc13e,		0x21, 0
	.dw 0x8940, 0xc13e,	0x897f, 0xc13e,		0x21, 0
	.dw 0x89c0, 0xc13e,	0x89ff, 0xc13e,		0x21, 0
	.dw 0x8a40, 0xc13e,	0x8a7f, 0xc13e,		0x21, 0
	.dw 0x8ac0, 0xc13e,	0x8aff, 0xc13e,		0x21, 0
	.dw 0x8b40, 0xc13e,	0x8b7f, 0xc13e,		0x21, 0
	.dw 0x8bc0, 0xc13e,	0x8bff, 0xc13e,		0x21, 0
	.dw 0x8c40, 0xc13e,	0x8c7f, 0xc13e,		0x21, 0
	.dw 0x8cc0, 0xc13e,	0x8cff, 0xc13e,		0x21, 0
	.dw 0x8d40, 0xc13e,	0x8d7f, 0xc13e,		0x21, 0
	.dw 0x8dc0, 0xc13e,	0x8dff, 0xc13e,		0x21, 0
	.dw 0x8e40, 0xc13e,	0x8e7f, 0xc13e,		0x21, 0
	.dw 0x8ec0, 0xc13e,	0x8eff, 0xc13e,		0x21, 0
	.dw 0x8f40, 0xc13e,	0x8f7f, 0xc13e,		0x21, 0
	.dw 0x8fc0, 0xc13e,	0x8fff, 0xc13e,		0x21, 0
	.dw 0x9040, 0xc13e,	0x907f, 0xc13e,		0x21, 0
	.dw 0x90c0, 0xc13e,	0x90ff, 0xc13e,		0x21, 0
	.dw 0x9140, 0xc13e,	0x917f, 0xc13e,		0x21, 0
	.dw 0x91c0, 0xc13e,	0x91ff, 0xc13e,		0x21, 0
	.dw 0x9240, 0xc13e,	0x927f, 0xc13e,		0x21, 0
	.dw 0x92c0, 0xc13e,	0x92ff, 0xc13e,		0x21, 0
	.dw 0x9340, 0xc13e,	0x937f, 0xc13e,		0x21, 0
	.dw 0x93c0, 0xc13e,	0x93ff, 0xc13e,		0x21, 0
	.dw 0x9440, 0xc13e,	0x947f, 0xc13e,		0x21, 0
	.dw 0x94c0, 0xc13e,	0x94ff, 0xc13e,		0x21, 0
	.dw 0x9540, 0xc13e,	0x957f, 0xc13e,		0x21, 0
	.dw 0x95c0, 0xc13e,	0x95ff, 0xc13e,		0x21, 0
	.dw 0x9640, 0xc13e,	0x967f, 0xc13e,		0x21, 0
	.dw 0x96c0, 0xc13e,	0x96ff, 0xc13e,		0x21, 0
	.dw 0x9740, 0xc13e,	0x977f, 0xc13e,		0x21, 0
	.dw 0x97c0, 0xc13e,	0x97ff, 0xc13e,		0x21, 0
	.dw 0x9840, 0xc13e,	0x987f, 0xc13e,		0x21, 0
	.dw 0x98c0, 0xc13e,	0x98ff, 0xc13e,		0x21, 0
	.dw 0x9940, 0xc13e,	0x997f, 0xc13e,		0x21, 0
	.dw 0x99c0, 0xc13e,	0x9fff, 0xc13e,		0x21, 0
	.dw 0xa040, 0xc13e,	0xa07f, 0xc13e,		0x21, 0
	.dw 0xa0c0, 0xc13e,	0xa0ff, 0xc13e,		0x21, 0
	.dw 0xa140, 0xc13e,	0xa17f, 0xc13e,		0x21, 0
	.dw 0xa1c0, 0xc13e,	0xa1ff, 0xc13e,		0x21, 0
	.dw 0xa240, 0xc13e,	0xa27f, 0xc13e,		0x21, 0
	.dw 0xa2c0, 0xc13e,	0xa2ff, 0xc13e,		0x21, 0
	.dw 0xa340, 0xc13e,	0xa37f, 0xc13e,		0x21, 0
	.dw 0xa3c0, 0xc13e,	0xa3ff, 0xc13e,		0x21, 0
	.dw 0xa440, 0xc13e,	0xa47f, 0xc13e,		0x21, 0
	.dw 0xa4c0, 0xc13e,	0xa4ff, 0xc13e,		0x21, 0
	.dw 0xa540, 0xc13e,	0xa57f, 0xc13e,		0x21, 0
	.dw 0xa5c0, 0xc13e,	0xa5ff, 0xc13e,		0x21, 0
	.dw 0xa640, 0xc13e,	0xa67f, 0xc13e,		0x21, 0
	.dw 0xa6c0, 0xc13e,	0xa6ff, 0xc13e,		0x21, 0
	.dw 0xa740, 0xc13e,	0xa77f, 0xc13e,		0x21, 0
	.dw 0xa7c0, 0xc13e,	0xa7ff, 0xc13e,		0x21, 0
	.dw 0xa840, 0xc13e,	0xa87f, 0xc13e,		0x21, 0
	.dw 0xa8c0, 0xc13e,	0xa8ff, 0xc13e,		0x21, 0
	.dw 0xa940, 0xc13e,	0xa97f, 0xc13e,		0x21, 0
	.dw 0xa9c0, 0xc13e,	0xa9ff, 0xc13e,		0x21, 0
	.dw 0xaa40, 0xc13e,	0xaa7f, 0xc13e,		0x21, 0
	.dw 0xaac0, 0xc13e,	0xaaff, 0xc13e,		0x21, 0
	.dw 0xab40, 0xc13e,	0xab7f, 0xc13e,		0x21, 0
	.dw 0xabc0, 0xc13e,	0xabff, 0xc13e,		0x21, 0
	.dw 0xac40, 0xc13e,	0xac7f, 0xc13e,		0x21, 0
	.dw 0xacc0, 0xc13e,	0xacff, 0xc13e,		0x21, 0
	.dw 0xad40, 0xc13e,	0xad7f, 0xc13e,		0x21, 0
	.dw 0xadc0, 0xc13e,	0xadff, 0xc13e,		0x21, 0
	.dw 0xae40, 0xc13e,	0xae7f, 0xc13e,		0x21, 0
	.dw 0xaec0, 0xc13e,	0xaeff, 0xc13e,		0x21, 0
	.dw 0xaf40, 0xc13e,	0xaf7f, 0xc13e,		0x21, 0
	.dw 0xafc0, 0xc13e,	0xafff, 0xc13e,		0x21, 0
	.dw 0xb040, 0xc13e,	0xb07f, 0xc13e,		0x21, 0
	.dw 0xb0c0, 0xc13e,	0xb0ff, 0xc13e,		0x21, 0
	.dw 0xb140, 0xc13e,	0xb17f, 0xc13e,		0x21, 0
	.dw 0xb1c0, 0xc13e,	0xb1ff, 0xc13e,		0x21, 0
	.dw 0xb240, 0xc13e,	0xb27f, 0xc13e,		0x21, 0
	.dw 0xb2c0, 0xc13e,	0xb2ff, 0xc13e,		0x21, 0
	.dw 0xb340, 0xc13e,	0xb37f, 0xc13e,		0x21, 0
	.dw 0xb3c0, 0xc13e,	0xb3ff, 0xc13e,		0x21, 0
	.dw 0xb440, 0xc13e,	0xb47f, 0xc13e,		0x21, 0
	.dw 0xb4c0, 0xc13e,	0xb4ff, 0xc13e,		0x21, 0
	.dw 0xb540, 0xc13e,	0xb57f, 0xc13e,		0x21, 0
	.dw 0xb5c0, 0xc13e,	0xb5ff, 0xc13e,		0x21, 0
	.dw 0xb640, 0xc13e,	0xb67f, 0xc13e,		0x21, 0
	.dw 0xb6c0, 0xc13e,	0xb6ff, 0xc13e,		0x21, 0
	.dw 0xb740, 0xc13e,	0xb77f, 0xc13e,		0x21, 0
	.dw 0xb7c0, 0xc13e,	0xb7ff, 0xc13e,		0x21, 0
	.dw 0xb840, 0xc13e,	0xb87f, 0xc13e,		0x21, 0
	.dw 0xb8c0, 0xc13e,	0xb8ff, 0xc13e,		0x21, 0
	.dw 0xb940, 0xc13e,	0xb97f, 0xc13e,		0x21, 0
	.dw 0xb9c0, 0xc13e,	0xbfff, 0xc13e,		0x21, 0
	.dw 0xc040, 0xc13e,	0xc07f, 0xc13e,		0x21, 0
	.dw 0xc0c0, 0xc13e,	0xc0ff, 0xc13e,		0x21, 0
	.dw 0xc140, 0xc13e,	0xc17f, 0xc13e,		0x21, 0
	.dw 0xc1c0, 0xc13e,	0xc1ff, 0xc13e,		0x21, 0
	.dw 0xc240, 0xc13e,	0xc27f, 0xc13e,		0x21, 0
	.dw 0xc2c0, 0xc13e,	0xc2ff, 0xc13e,		0x21, 0
	.dw 0xc340, 0xc13e,	0xc37f, 0xc13e,		0x21, 0
	.dw 0xc3c0, 0xc13e,	0xc3ff, 0xc13e,		0x21, 0
	.dw 0xc440, 0xc13e,	0xc47f, 0xc13e,		0x21, 0
	.dw 0xc4c0, 0xc13e,	0xc4ff, 0xc13e,		0x21, 0
	.dw 0xc540, 0xc13e,	0xc57f, 0xc13e,		0x21, 0
	.dw 0xc5c0, 0xc13e,	0xc5ff, 0xc13e,		0x21, 0
	.dw 0xc640, 0xc13e,	0xc67f, 0xc13e,		0x21, 0
	.dw 0xc6c0, 0xc13e,	0xc6ff, 0xc13e,		0x21, 0
	.dw 0xc740, 0xc13e,	0xc77f, 0xc13e,		0x21, 0
	.dw 0xc7c0, 0xc13e,	0xc7ff, 0xc13e,		0x21, 0
	.dw 0xc840, 0xc13e,	0xc87f, 0xc13e,		0x21, 0
	.dw 0xc8c0, 0xc13e,	0xc8ff, 0xc13e,		0x21, 0
	.dw 0xc940, 0xc13e,	0xc97f, 0xc13e,		0x21, 0
	.dw 0xc9c0, 0xc13e,	0xc9ff, 0xc13e,		0x21, 0
	.dw 0xca40, 0xc13e,	0xca7f, 0xc13e,		0x21, 0
	.dw 0xcac0, 0xc13e,	0xcaff, 0xc13e,		0x21, 0
	.dw 0xcb40, 0xc13e,	0xcb7f, 0xc13e,		0x21, 0
	.dw 0xcbc0, 0xc13e,	0xcbff, 0xc13e,		0x21, 0
	.dw 0xcc40, 0xc13e,	0xcc7f, 0xc13e,		0x21, 0
	.dw 0xccc0, 0xc13e,	0xccff, 0xc13e,		0x21, 0
	.dw 0xcd40, 0xc13e,	0xcd7f, 0xc13e,		0x21, 0
	.dw 0xcdc0, 0xc13e,	0xcdff, 0xc13e,		0x21, 0
	.dw 0xce40, 0xc13e,	0xce7f, 0xc13e,		0x21, 0
	.dw 0xcec0, 0xc13e,	0xceff, 0xc13e,		0x21, 0
	.dw 0xcf40, 0xc13e,	0xcf7f, 0xc13e,		0x21, 0
	.dw 0xcfc0, 0xc13e,	0xcfff, 0xc13e,		0x21, 0
	.dw 0xd040, 0xc13e,	0xd07f, 0xc13e,		0x21, 0
	.dw 0xd0c0, 0xc13e,	0xd0ff, 0xc13e,		0x21, 0
	.dw 0xd140, 0xc13e,	0xd17f, 0xc13e,		0x21, 0
	.dw 0xd1c0, 0xc13e,	0xd1ff, 0xc13e,		0x21, 0
	.dw 0xd240, 0xc13e,	0xd27f, 0xc13e,		0x21, 0
	.dw 0xd2c0, 0xc13e,	0xd2ff, 0xc13e,		0x21, 0
	.dw 0xd340, 0xc13e,	0xd37f, 0xc13e,		0x21, 0
	.dw 0xd3c0, 0xc13e,	0xd3ff, 0xc13e,		0x21, 0
	.dw 0xd440, 0xc13e,	0xd47f, 0xc13e,		0x21, 0
	.dw 0xd4c0, 0xc13e,	0xd4ff, 0xc13e,		0x21, 0
	.dw 0xd540, 0xc13e,	0xd57f, 0xc13e,		0x21, 0
	.dw 0xd5c0, 0xc13e,	0xd5ff, 0xc13e,		0x21, 0
	.dw 0xd640, 0xc13e,	0xd67f, 0xc13e,		0x21, 0
	.dw 0xd6c0, 0xc13e,	0xd6ff, 0xc13e,		0x21, 0
	.dw 0xd740, 0xc13e,	0xd77f, 0xc13e,		0x21, 0
	.dw 0xd7c0, 0xc13e,	0xd7ff, 0xc13e,		0x21, 0
	.dw 0xd840, 0xc13e,	0xd87f, 0xc13e,		0x21, 0
	.dw 0xd8c0, 0xc13e,	0xd8ff, 0xc13e,		0x21, 0
	.dw 0xd940, 0xc13e,	0xd97f, 0xc13e,		0x21, 0
	.dw 0xd9c0, 0xc13e,	0xdfff, 0xc13e,		0x21, 0
	.dw 0xe040, 0xc13e,	0xe07f, 0xc13e,		0x21, 0
	.dw 0xe0c0, 0xc13e,	0xe0ff, 0xc13e,		0x21, 0
	.dw 0xe140, 0xc13e,	0xe17f, 0xc13e,		0x21, 0
	.dw 0xe1c0, 0xc13e,	0xe1ff, 0xc13e,		0x21, 0
	.dw 0xe240, 0xc13e,	0xe27f, 0xc13e,		0x21, 0
	.dw 0xe2c0, 0xc13e,	0xe2ff, 0xc13e,		0x21, 0
	.dw 0xe340, 0xc13e,	0xe37f, 0xc13e,		0x21, 0
	.dw 0xe3c0, 0xc13e,	0xe3ff, 0xc13e,		0x21, 0
	.dw 0xe440, 0xc13e,	0xe47f, 0xc13e,		0x21, 0
	.dw 0xe4c0, 0xc13e,	0xe4ff, 0xc13e,		0x21, 0
	.dw 0xe540, 0xc13e,	0xe57f, 0xc13e,		0x21, 0
	.dw 0xe5c0, 0xc13e,	0xe5ff, 0xc13e,		0x21, 0
	.dw 0xe640, 0xc13e,	0xe67f, 0xc13e,		0x21, 0
	.dw 0xe6c0, 0xc13e,	0xe6ff, 0xc13e,		0x21, 0
	.dw 0xe740, 0xc13e,	0xe77f, 0xc13e,		0x21, 0
	.dw 0xe7c0, 0xc13e,	0xe7ff, 0xc13e,		0x21, 0
	.dw 0xe840, 0xc13e,	0xe87f, 0xc13e,		0x21, 0
	.dw 0xe8c0, 0xc13e,	0xe8ff, 0xc13e,		0x21, 0
	.dw 0xe940, 0xc13e,	0xe97f, 0xc13e,		0x21, 0
	.dw 0xe9c0, 0xc13e,	0xe9ff, 0xc13e,		0x21, 0
	.dw 0xea40, 0xc13e,	0xea7f, 0xc13e,		0x21, 0
	.dw 0xeac0, 0xc13e,	0xeaff, 0xc13e,		0x21, 0
	.dw 0xeb40, 0xc13e,	0xeb7f, 0xc13e,		0x21, 0
	.dw 0xebc0, 0xc13e,	0xebff, 0xc13e,		0x21, 0
	.dw 0xec40, 0xc13e,	0xec7f, 0xc13e,		0x21, 0
	.dw 0xecc0, 0xc13e,	0xecff, 0xc13e,		0x21, 0
	.dw 0xed40, 0xc13e,	0xed7f, 0xc13e,		0x21, 0
	.dw 0xedc0, 0xc13e,	0xedff, 0xc13e,		0x21, 0
	.dw 0xee40, 0xc13e,	0xee7f, 0xc13e,		0x21, 0
	.dw 0xeec0, 0xc13e,	0xeeff, 0xc13e,		0x21, 0
	.dw 0xef40, 0xc13e,	0xef7f, 0xc13e,		0x21, 0
	.dw 0xefc0, 0xc13e,	0xefff, 0xc13e,		0x21, 0
	.dw 0xf040, 0xc13e,	0xf07f, 0xc13e,		0x21, 0
	.dw 0xf0c0, 0xc13e,	0xf0ff, 0xc13e,		0x21, 0
	.dw 0xf140, 0xc13e,	0xf17f, 0xc13e,		0x21, 0
	.dw 0xf1c0, 0xc13e,	0xf1ff, 0xc13e,		0x21, 0
	.dw 0xf240, 0xc13e,	0xf27f, 0xc13e,		0x21, 0
	.dw 0xf2c0, 0xc13e,	0xf2ff, 0xc13e,		0x21, 0
	.dw 0xf340, 0xc13e,	0xf37f, 0xc13e,		0x21, 0
	.dw 0xf3c0, 0xc13e,	0xf3ff, 0xc13e,		0x21, 0
	.dw 0xf440, 0xc13e,	0xf47f, 0xc13e,		0x21, 0
	.dw 0xf4c0, 0xc13e,	0xf4ff, 0xc13e,		0x21, 0
	.dw 0xf540, 0xc13e,	0xf57f, 0xc13e,		0x21, 0
	.dw 0xf5c0, 0xc13e,	0xf5ff, 0xc13e,		0x21, 0
	.dw 0xf640, 0xc13e,	0xf67f, 0xc13e,		0x21, 0
	.dw 0xf6c0, 0xc13e,	0xf6ff, 0xc13e,		0x21, 0
	.dw 0xf740, 0xc13e,	0xf77f, 0xc13e,		0x21, 0
	.dw 0xf7c0, 0xc13e,	0xf7ff, 0xc13e,		0x21, 0
	.dw 0xf840, 0xc13e,	0xf87f, 0xc13e,		0x21, 0
	.dw 0xf8c0, 0xc13e,	0xf8ff, 0xc13e,		0x21, 0
	.dw 0xf940, 0xc13e,	0xf97f, 0xc13e,		0x21, 0
	.dw 0xf9c0, 0xc13e,	0xffff, 0xc13e,		0x21, 0
	.dw 0x0040, 0xc13f,	0x007f, 0xc13f,		0x21, 0
	.dw 0x00c0, 0xc13f,	0x00ff, 0xc13f,		0x21, 0
	.dw 0x0140, 0xc13f,	0x017f, 0xc13f,		0x21, 0
	.dw 0x01c0, 0xc13f,	0x01ff, 0xc13f,		0x21, 0
	.dw 0x0240, 0xc13f,	0x027f, 0xc13f,		0x21, 0
	.dw 0x02c0, 0xc13f,	0x02ff, 0xc13f,		0x21, 0
	.dw 0x0340, 0xc13f,	0x037f, 0xc13f,		0x21, 0
	.dw 0x03c0, 0xc13f,	0x03ff, 0xc13f,		0x21, 0
	.dw 0x0440, 0xc13f,	0x047f, 0xc13f,		0x21, 0
	.dw 0x04c0, 0xc13f,	0x04ff, 0xc13f,		0x21, 0
	.dw 0x0540, 0xc13f,	0x057f, 0xc13f,		0x21, 0
	.dw 0x05c0, 0xc13f,	0x05ff, 0xc13f,		0x21, 0
	.dw 0x0640, 0xc13f,	0x067f, 0xc13f,		0x21, 0
	.dw 0x06c0, 0xc13f,	0x06ff, 0xc13f,		0x21, 0
	.dw 0x0740, 0xc13f,	0x077f, 0xc13f,		0x21, 0
	.dw 0x07c0, 0xc13f,	0x07ff, 0xc13f,		0x21, 0
	.dw 0x0840, 0xc13f,	0x087f, 0xc13f,		0x21, 0
	.dw 0x08c0, 0xc13f,	0x08ff, 0xc13f,		0x21, 0
	.dw 0x0940, 0xc13f,	0x097f, 0xc13f,		0x21, 0
	.dw 0x09c0, 0xc13f,	0x09ff, 0xc13f,		0x21, 0
	.dw 0x0a40, 0xc13f,	0x0a7f, 0xc13f,		0x21, 0
	.dw 0x0ac0, 0xc13f,	0x0aff, 0xc13f,		0x21, 0
	.dw 0x0b40, 0xc13f,	0x0b7f, 0xc13f,		0x21, 0
	.dw 0x0bc0, 0xc13f,	0x0bff, 0xc13f,		0x21, 0
	.dw 0x0c40, 0xc13f,	0x0c7f, 0xc13f,		0x21, 0
	.dw 0x0cc0, 0xc13f,	0x0cff, 0xc13f,		0x21, 0
	.dw 0x0d40, 0xc13f,	0x0d7f, 0xc13f,		0x21, 0
	.dw 0x0dc0, 0xc13f,	0x0dff, 0xc13f,		0x21, 0
	.dw 0x0e40, 0xc13f,	0x0e7f, 0xc13f,		0x21, 0
	.dw 0x0ec0, 0xc13f,	0x0eff, 0xc13f,		0x21, 0
	.dw 0x0f40, 0xc13f,	0x0f7f, 0xc13f,		0x21, 0
	.dw 0x0fc0, 0xc13f,	0x0fff, 0xc13f,		0x21, 0
	.dw 0x1040, 0xc13f,	0x107f, 0xc13f,		0x21, 0
	.dw 0x10c0, 0xc13f,	0x10ff, 0xc13f,		0x21, 0
	.dw 0x1140, 0xc13f,	0x117f, 0xc13f,		0x21, 0
	.dw 0x11c0, 0xc13f,	0x11ff, 0xc13f,		0x21, 0
	.dw 0x1240, 0xc13f,	0x127f, 0xc13f,		0x21, 0
	.dw 0x12c0, 0xc13f,	0x12ff, 0xc13f,		0x21, 0
	.dw 0x1340, 0xc13f,	0x137f, 0xc13f,		0x21, 0
	.dw 0x13c0, 0xc13f,	0x13ff, 0xc13f,		0x21, 0
	.dw 0x1440, 0xc13f,	0x147f, 0xc13f,		0x21, 0
	.dw 0x14c0, 0xc13f,	0x14ff, 0xc13f,		0x21, 0
	.dw 0x1540, 0xc13f,	0x157f, 0xc13f,		0x21, 0
	.dw 0x15c0, 0xc13f,	0x15ff, 0xc13f,		0x21, 0
	.dw 0x1640, 0xc13f,	0x167f, 0xc13f,		0x21, 0
	.dw 0x16c0, 0xc13f,	0x16ff, 0xc13f,		0x21, 0
	.dw 0x1740, 0xc13f,	0x177f, 0xc13f,		0x21, 0
	.dw 0x17c0, 0xc13f,	0x17ff, 0xc13f,		0x21, 0
	.dw 0x1840, 0xc13f,	0x187f, 0xc13f,		0x21, 0
	.dw 0x18c0, 0xc13f,	0x18ff, 0xc13f,		0x21, 0
	.dw 0x1940, 0xc13f,	0x197f, 0xc13f,		0x21, 0
	.dw 0x19c0, 0xc13f,	0x1fff, 0xc13f,		0x21, 0
	.dw 0x2040, 0xc13f,	0x207f, 0xc13f,		0x21, 0
	.dw 0x20c0, 0xc13f,	0x20ff, 0xc13f,		0x21, 0
	.dw 0x2140, 0xc13f,	0x217f, 0xc13f,		0x21, 0
	.dw 0x21c0, 0xc13f,	0x21ff, 0xc13f,		0x21, 0
	.dw 0x2240, 0xc13f,	0x227f, 0xc13f,		0x21, 0
	.dw 0x22c0, 0xc13f,	0x22ff, 0xc13f,		0x21, 0
	.dw 0x2340, 0xc13f,	0x237f, 0xc13f,		0x21, 0
	.dw 0x23c0, 0xc13f,	0x23ff, 0xc13f,		0x21, 0
	.dw 0x2440, 0xc13f,	0x247f, 0xc13f,		0x21, 0
	.dw 0x24c0, 0xc13f,	0x24ff, 0xc13f,		0x21, 0
	.dw 0x2540, 0xc13f,	0x257f, 0xc13f,		0x21, 0
	.dw 0x25c0, 0xc13f,	0x25ff, 0xc13f,		0x21, 0
	.dw 0x2640, 0xc13f,	0x267f, 0xc13f,		0x21, 0
	.dw 0x26c0, 0xc13f,	0x26ff, 0xc13f,		0x21, 0
	.dw 0x2740, 0xc13f,	0x277f, 0xc13f,		0x21, 0
	.dw 0x27c0, 0xc13f,	0x27ff, 0xc13f,		0x21, 0
	.dw 0x2840, 0xc13f,	0x287f, 0xc13f,		0x21, 0
	.dw 0x28c0, 0xc13f,	0x28ff, 0xc13f,		0x21, 0
	.dw 0x2940, 0xc13f,	0x297f, 0xc13f,		0x21, 0
	.dw 0x29c0, 0xc13f,	0x29ff, 0xc13f,		0x21, 0
	.dw 0x2a40, 0xc13f,	0x2a7f, 0xc13f,		0x21, 0
	.dw 0x2ac0, 0xc13f,	0x2aff, 0xc13f,		0x21, 0
	.dw 0x2b40, 0xc13f,	0x2b7f, 0xc13f,		0x21, 0
	.dw 0x2bc0, 0xc13f,	0x2bff, 0xc13f,		0x21, 0
	.dw 0x2c40, 0xc13f,	0x2c7f, 0xc13f,		0x21, 0
	.dw 0x2cc0, 0xc13f,	0x2cff, 0xc13f,		0x21, 0
	.dw 0x2d40, 0xc13f,	0x2d7f, 0xc13f,		0x21, 0
	.dw 0x2dc0, 0xc13f,	0x2dff, 0xc13f,		0x21, 0
	.dw 0x2e40, 0xc13f,	0x2e7f, 0xc13f,		0x21, 0
	.dw 0x2ec0, 0xc13f,	0x2eff, 0xc13f,		0x21, 0
	.dw 0x2f40, 0xc13f,	0x2f7f, 0xc13f,		0x21, 0
	.dw 0x2fc0, 0xc13f,	0x2fff, 0xc13f,		0x21, 0
	.dw 0x3040, 0xc13f,	0x307f, 0xc13f,		0x21, 0
	.dw 0x30c0, 0xc13f,	0x30ff, 0xc13f,		0x21, 0
	.dw 0x3140, 0xc13f,	0x317f, 0xc13f,		0x21, 0
	.dw 0x31c0, 0xc13f,	0x31ff, 0xc13f,		0x21, 0
	.dw 0x3240, 0xc13f,	0x327f, 0xc13f,		0x21, 0
	.dw 0x32c0, 0xc13f,	0x32ff, 0xc13f,		0x21, 0
	.dw 0x3340, 0xc13f,	0x337f, 0xc13f,		0x21, 0
	.dw 0x33c0, 0xc13f,	0x33ff, 0xc13f,		0x21, 0
	.dw 0x3440, 0xc13f,	0x347f, 0xc13f,		0x21, 0
	.dw 0x34c0, 0xc13f,	0x34ff, 0xc13f,		0x21, 0
	.dw 0x3540, 0xc13f,	0x357f, 0xc13f,		0x21, 0
	.dw 0x35c0, 0xc13f,	0x35ff, 0xc13f,		0x21, 0
	.dw 0x3640, 0xc13f,	0x367f, 0xc13f,		0x21, 0
	.dw 0x36c0, 0xc13f,	0x36ff, 0xc13f,		0x21, 0
	.dw 0x3740, 0xc13f,	0x377f, 0xc13f,		0x21, 0
	.dw 0x37c0, 0xc13f,	0x37ff, 0xc13f,		0x21, 0
	.dw 0x3840, 0xc13f,	0x387f, 0xc13f,		0x21, 0
	.dw 0x38c0, 0xc13f,	0x38ff, 0xc13f,		0x21, 0
	.dw 0x3940, 0xc13f,	0x397f, 0xc13f,		0x21, 0
	.dw 0x39c0, 0xc13f,	0x1fff, 0xc160,		0x21, 0
	.dw 0x3a00, 0xc160,	0x5fff, 0xc160,		0x21, 0
	.dw 0x7a00, 0xc160,	0x9fff, 0xc160,		0x21, 0
	.dw 0xba00, 0xc160,	0xdfff, 0xc160,		0x21, 0
	.dw 0xfa00, 0xc160,	0x1fff, 0xc161,		0x21, 0
	.dw 0x3a00, 0xc161,	0x5fff, 0xc161,		0x21, 0
	.dw 0x7a00, 0xc161,	0x9fff, 0xc161,		0x21, 0
	.dw 0xba00, 0xc161,	0xdfff, 0xc161,		0x21, 0
	.dw 0xfa00, 0xc161,	0x1fff, 0xc162,		0x21, 0
	.dw 0x3a00, 0xc162,	0x5fff, 0xc162,		0x21, 0
	.dw 0x7a00, 0xc162,	0x9fff, 0xc162,		0x21, 0
	.dw 0xba00, 0xc162,	0xdfff, 0xc162,		0x21, 0
	.dw 0xfa00, 0xc162,	0x1fff, 0xc163,		0x21, 0
	.dw 0x3a00, 0xc163,	0xffff, 0xc163,		0x21, 0
	.dw 0x1a00, 0xc164,	0x1fff, 0xc164,		0x21, 0
	.dw 0x3a00, 0xc164,	0x3fff, 0xc164,		0x21, 0
	.dw 0x5a00, 0xc164,	0x5fff, 0xc164,		0x21, 0
	.dw 0x7a00, 0xc164,	0x7fff, 0xc164,		0x21, 0
	.dw 0x9a00, 0xc164,	0x9fff, 0xc164,		0x21, 0
	.dw 0xba00, 0xc164,	0xbfff, 0xc164,		0x21, 0
	.dw 0xda00, 0xc164,	0xdfff, 0xc164,		0x21, 0
	.dw 0xfa00, 0xc164,	0xffff, 0xc164,		0x21, 0
	.dw 0x1a00, 0xc165,	0x1fff, 0xc165,		0x21, 0
	.dw 0x3a00, 0xc165,	0x3fff, 0xc165,		0x21, 0
	.dw 0x5a00, 0xc165,	0x5fff, 0xc165,		0x21, 0
	.dw 0x7a00, 0xc165,	0x7fff, 0xc165,		0x21, 0
	.dw 0x9a00, 0xc165,	0x9fff, 0xc165,		0x21, 0
	.dw 0xba00, 0xc165,	0xbfff, 0xc165,		0x21, 0
	.dw 0xda00, 0xc165,	0xdfff, 0xc165,		0x21, 0
	.dw 0xfa00, 0xc165,	0xffff, 0xc165,		0x21, 0
	.dw 0x1a00, 0xc166,	0x1fff, 0xc166,		0x21, 0
	.dw 0x3a00, 0xc166,	0x3fff, 0xc166,		0x21, 0
	.dw 0x5a00, 0xc166,	0x5fff, 0xc166,		0x21, 0
	.dw 0x7a00, 0xc166,	0x7fff, 0xc166,		0x21, 0
	.dw 0x9a00, 0xc166,	0x9fff, 0xc166,		0x21, 0
	.dw 0xba00, 0xc166,	0xbfff, 0xc166,		0x21, 0
	.dw 0xda00, 0xc166,	0xdfff, 0xc166,		0x21, 0
	.dw 0xfa00, 0xc166,	0xffff, 0xc166,		0x21, 0
	.dw 0x1a00, 0xc167,	0x1fff, 0xc167,		0x21, 0
	.dw 0x3a00, 0xc167,	0x1fff, 0xc170,		0x21, 0
	.dw 0x3a00, 0xc170,	0x5fff, 0xc170,		0x21, 0
	.dw 0x7a00, 0xc170,	0x9fff, 0xc170,		0x21, 0
	.dw 0xba00, 0xc170,	0xdfff, 0xc170,		0x21, 0
	.dw 0xfa00, 0xc170,	0x1fff, 0xc171,		0x21, 0
	.dw 0x3a00, 0xc171,	0x5fff, 0xc171,		0x21, 0
	.dw 0x7a00, 0xc171,	0x9fff, 0xc171,		0x21, 0
	.dw 0xba00, 0xc171,	0xdfff, 0xc171,		0x21, 0
	.dw 0xfa00, 0xc171,	0x1fff, 0xc172,		0x21, 0
	.dw 0x3a00, 0xc172,	0x5fff, 0xc172,		0x21, 0
	.dw 0x7a00, 0xc172,	0x9fff, 0xc172,		0x21, 0
	.dw 0xba00, 0xc172,	0xdfff, 0xc172,		0x21, 0
	.dw 0xfa00, 0xc172,	0xffff, 0xc173,		0x21, 0
	.dw 0x1a00, 0xc174,	0x1fff, 0xc174,		0x21, 0
	.dw 0x3a00, 0xc174,	0x3fff, 0xc174,		0x21, 0
	.dw 0x5a00, 0xc174,	0x5fff, 0xc174,		0x21, 0
	.dw 0x7a00, 0xc174,	0x7fff, 0xc174,		0x21, 0
	.dw 0x9a00, 0xc174,	0x9fff, 0xc174,		0x21, 0
	.dw 0xba00, 0xc174,	0xbfff, 0xc174,		0x21, 0
	.dw 0xda00, 0xc174,	0xdfff, 0xc174,		0x21, 0
	.dw 0xfa00, 0xc174,	0xffff, 0xc174,		0x21, 0
	.dw 0x1a00, 0xc175,	0x1fff, 0xc175,		0x21, 0
	.dw 0x3a00, 0xc175,	0x3fff, 0xc175,		0x21, 0
	.dw 0x5a00, 0xc175,	0x5fff, 0xc175,		0x21, 0
	.dw 0x7a00, 0xc175,	0x7fff, 0xc175,		0x21, 0
	.dw 0x9a00, 0xc175,	0x9fff, 0xc175,		0x21, 0
	.dw 0xba00, 0xc175,	0xbfff, 0xc175,		0x21, 0
	.dw 0xda00, 0xc175,	0xdfff, 0xc175,		0x21, 0
	.dw 0xfa00, 0xc175,	0xffff, 0xc175,		0x21, 0
	.dw 0x1a00, 0xc176,	0x1fff, 0xc176,		0x21, 0
	.dw 0x3a00, 0xc176,	0x3fff, 0xc176,		0x21, 0
	.dw 0x5a00, 0xc176,	0x5fff, 0xc176,		0x21, 0
	.dw 0x7a00, 0xc176,	0x7fff, 0xc176,		0x21, 0
	.dw 0x9a00, 0xc176,	0x9fff, 0xc176,		0x21, 0
	.dw 0xba00, 0xc176,	0xbfff, 0xc176,		0x21, 0
	.dw 0xda00, 0xc176,	0xdfff, 0xc176,		0x21, 0
	.dw 0xfa00, 0xc176,	0xffff, 0xc176,		0x21, 0
	.dw 0x1a00, 0xc177,	0x1fff, 0xc177,		0x21, 0
	.dw 0x3a00, 0xc177,	0x1fff, 0xc180,		0x21, 0
	.dw 0x3a00, 0xc180,	0x5fff, 0xc180,		0x21, 0
	.dw 0x7a00, 0xc180,	0x9fff, 0xc180,		0x21, 0
	.dw 0xba00, 0xc180,	0xdfff, 0xc180,		0x21, 0
	.dw 0xfa00, 0xc180,	0x1fff, 0xc181,		0x21, 0
	.dw 0x3a00, 0xc181,	0x5fff, 0xc181,		0x21, 0
	.dw 0x7a00, 0xc181,	0x9fff, 0xc181,		0x21, 0
	.dw 0xba00, 0xc181,	0xdfff, 0xc181,		0x21, 0
	.dw 0xfa00, 0xc181,	0x1fff, 0xc182,		0x21, 0
	.dw 0x3a00, 0xc182,	0x5fff, 0xc182,		0x21, 0
	.dw 0x7a00, 0xc182,	0x9fff, 0xc182,		0x21, 0
	.dw 0xba00, 0xc182,	0xdfff, 0xc182,		0x21, 0
	.dw 0xfa00, 0xc182,	0x1fff, 0xc183,		0x21, 0
	.dw 0x3a00, 0xc183,	0xffff, 0xc183,		0x21, 0
	.dw 0x1a00, 0xc184,	0x1fff, 0xc184,		0x21, 0
	.dw 0x3a00, 0xc184,	0x3fff, 0xc184,		0x21, 0
	.dw 0x5a00, 0xc184,	0x5fff, 0xc184,		0x21, 0
	.dw 0x7a00, 0xc184,	0x7fff, 0xc184,		0x21, 0
	.dw 0x9a00, 0xc184,	0x9fff, 0xc184,		0x21, 0
	.dw 0xba00, 0xc184,	0xbfff, 0xc184,		0x21, 0
	.dw 0xda00, 0xc184,	0xdfff, 0xc184,		0x21, 0
	.dw 0xfa00, 0xc184,	0xffff, 0xc184,		0x21, 0
	.dw 0x1a00, 0xc185,	0x1fff, 0xc185,		0x21, 0
	.dw 0x3a00, 0xc185,	0x3fff, 0xc185,		0x21, 0
	.dw 0x5a00, 0xc185,	0x5fff, 0xc185,		0x21, 0
	.dw 0x7a00, 0xc185,	0x7fff, 0xc185,		0x21, 0
	.dw 0x9a00, 0xc185,	0x9fff, 0xc185,		0x21, 0
	.dw 0xba00, 0xc185,	0xbfff, 0xc185,		0x21, 0
	.dw 0xda00, 0xc185,	0xdfff, 0xc185,		0x21, 0
	.dw 0xfa00, 0xc185,	0xffff, 0xc185,		0x21, 0
	.dw 0x1a00, 0xc186,	0x1fff, 0xc186,		0x21, 0
	.dw 0x3a00, 0xc186,	0x3fff, 0xc186,		0x21, 0
	.dw 0x5a00, 0xc186,	0x5fff, 0xc186,		0x21, 0
	.dw 0x7a00, 0xc186,	0x7fff, 0xc186,		0x21, 0
	.dw 0x9a00, 0xc186,	0x9fff, 0xc186,		0x21, 0
	.dw 0xba00, 0xc186,	0xbfff, 0xc186,		0x21, 0
	.dw 0xda00, 0xc186,	0xdfff, 0xc186,		0x21, 0
	.dw 0xfa00, 0xc186,	0xffff, 0xc186,		0x21, 0
	.dw 0x1a00, 0xc187,	0x1fff, 0xc187,		0x21, 0
	.dw 0x3a00, 0xc187,	0x1fff, 0xc188,		0x21, 0
	.dw 0x2040, 0xc188,	0x207f, 0xc188,		0x21, 0
	.dw 0x20c0, 0xc188,	0x20ff, 0xc188,		0x21, 0
	.dw 0x2140, 0xc188,	0x217f, 0xc188,		0x21, 0
	.dw 0x21c0, 0xc188,	0x21ff, 0xc188,		0x21, 0
	.dw 0x2240, 0xc188,	0x227f, 0xc188,		0x21, 0
	.dw 0x22c0, 0xc188,	0x22ff, 0xc188,		0x21, 0
	.dw 0x2340, 0xc188,	0x237f, 0xc188,		0x21, 0
	.dw 0x23c0, 0xc188,	0x23ff, 0xc188,		0x21, 0
	.dw 0x2440, 0xc188,	0x247f, 0xc188,		0x21, 0
	.dw 0x24c0, 0xc188,	0x24ff, 0xc188,		0x21, 0
	.dw 0x2540, 0xc188,	0x257f, 0xc188,		0x21, 0
	.dw 0x25c0, 0xc188,	0x25ff, 0xc188,		0x21, 0
	.dw 0x2640, 0xc188,	0x267f, 0xc188,		0x21, 0
	.dw 0x26c0, 0xc188,	0x26ff, 0xc188,		0x21, 0
	.dw 0x2740, 0xc188,	0x277f, 0xc188,		0x21, 0
	.dw 0x27c0, 0xc188,	0x27ff, 0xc188,		0x21, 0
	.dw 0x2840, 0xc188,	0x287f, 0xc188,		0x21, 0
	.dw 0x28c0, 0xc188,	0x28ff, 0xc188,		0x21, 0
	.dw 0x2940, 0xc188,	0x297f, 0xc188,		0x21, 0
	.dw 0x29c0, 0xc188,	0x29ff, 0xc188,		0x21, 0
	.dw 0x2a40, 0xc188,	0x2a7f, 0xc188,		0x21, 0
	.dw 0x2ac0, 0xc188,	0x2aff, 0xc188,		0x21, 0
	.dw 0x2b40, 0xc188,	0x2b7f, 0xc188,		0x21, 0
	.dw 0x2bc0, 0xc188,	0x2bff, 0xc188,		0x21, 0
	.dw 0x2c40, 0xc188,	0x2c7f, 0xc188,		0x21, 0
	.dw 0x2cc0, 0xc188,	0x2cff, 0xc188,		0x21, 0
	.dw 0x2d40, 0xc188,	0x2d7f, 0xc188,		0x21, 0
	.dw 0x2dc0, 0xc188,	0x2dff, 0xc188,		0x21, 0
	.dw 0x2e40, 0xc188,	0x2e7f, 0xc188,		0x21, 0
	.dw 0x2ec0, 0xc188,	0x2eff, 0xc188,		0x21, 0
	.dw 0x2f40, 0xc188,	0x2f7f, 0xc188,		0x21, 0
	.dw 0x2fc0, 0xc188,	0x2fff, 0xc188,		0x21, 0
	.dw 0x3040, 0xc188,	0x307f, 0xc188,		0x21, 0
	.dw 0x30c0, 0xc188,	0x30ff, 0xc188,		0x21, 0
	.dw 0x3140, 0xc188,	0x317f, 0xc188,		0x21, 0
	.dw 0x31c0, 0xc188,	0x31ff, 0xc188,		0x21, 0
	.dw 0x3240, 0xc188,	0x327f, 0xc188,		0x21, 0
	.dw 0x32c0, 0xc188,	0x32ff, 0xc188,		0x21, 0
	.dw 0x3340, 0xc188,	0x337f, 0xc188,		0x21, 0
	.dw 0x33c0, 0xc188,	0x33ff, 0xc188,		0x21, 0
	.dw 0x3440, 0xc188,	0x347f, 0xc188,		0x21, 0
	.dw 0x34c0, 0xc188,	0x34ff, 0xc188,		0x21, 0
	.dw 0x3540, 0xc188,	0x357f, 0xc188,		0x21, 0
	.dw 0x35c0, 0xc188,	0x35ff, 0xc188,		0x21, 0
	.dw 0x3640, 0xc188,	0x367f, 0xc188,		0x21, 0
	.dw 0x36c0, 0xc188,	0x36ff, 0xc188,		0x21, 0
	.dw 0x3740, 0xc188,	0x377f, 0xc188,		0x21, 0
	.dw 0x37c0, 0xc188,	0x37ff, 0xc188,		0x21, 0
	.dw 0x3840, 0xc188,	0x387f, 0xc188,		0x21, 0
	.dw 0x38c0, 0xc188,	0x38ff, 0xc188,		0x21, 0
	.dw 0x3940, 0xc188,	0x397f, 0xc188,		0x21, 0
	.dw 0x39c0, 0xc188,	0x5fff, 0xc188,		0x21, 0
	.dw 0x6040, 0xc188,	0x607f, 0xc188,		0x21, 0
	.dw 0x60c0, 0xc188,	0x60ff, 0xc188,		0x21, 0
	.dw 0x6140, 0xc188,	0x617f, 0xc188,		0x21, 0
	.dw 0x61c0, 0xc188,	0x61ff, 0xc188,		0x21, 0
	.dw 0x6240, 0xc188,	0x627f, 0xc188,		0x21, 0
	.dw 0x62c0, 0xc188,	0x62ff, 0xc188,		0x21, 0
	.dw 0x6340, 0xc188,	0x637f, 0xc188,		0x21, 0
	.dw 0x63c0, 0xc188,	0x63ff, 0xc188,		0x21, 0
	.dw 0x6440, 0xc188,	0x647f, 0xc188,		0x21, 0
	.dw 0x64c0, 0xc188,	0x64ff, 0xc188,		0x21, 0
	.dw 0x6540, 0xc188,	0x657f, 0xc188,		0x21, 0
	.dw 0x65c0, 0xc188,	0x65ff, 0xc188,		0x21, 0
	.dw 0x6640, 0xc188,	0x667f, 0xc188,		0x21, 0
	.dw 0x66c0, 0xc188,	0x66ff, 0xc188,		0x21, 0
	.dw 0x6740, 0xc188,	0x677f, 0xc188,		0x21, 0
	.dw 0x67c0, 0xc188,	0x67ff, 0xc188,		0x21, 0
	.dw 0x6840, 0xc188,	0x687f, 0xc188,		0x21, 0
	.dw 0x68c0, 0xc188,	0x68ff, 0xc188,		0x21, 0
	.dw 0x6940, 0xc188,	0x697f, 0xc188,		0x21, 0
	.dw 0x69c0, 0xc188,	0x69ff, 0xc188,		0x21, 0
	.dw 0x6a40, 0xc188,	0x6a7f, 0xc188,		0x21, 0
	.dw 0x6ac0, 0xc188,	0x6aff, 0xc188,		0x21, 0
	.dw 0x6b40, 0xc188,	0x6b7f, 0xc188,		0x21, 0
	.dw 0x6bc0, 0xc188,	0x6bff, 0xc188,		0x21, 0
	.dw 0x6c40, 0xc188,	0x6c7f, 0xc188,		0x21, 0
	.dw 0x6cc0, 0xc188,	0x6cff, 0xc188,		0x21, 0
	.dw 0x6d40, 0xc188,	0x6d7f, 0xc188,		0x21, 0
	.dw 0x6dc0, 0xc188,	0x6dff, 0xc188,		0x21, 0
	.dw 0x6e40, 0xc188,	0x6e7f, 0xc188,		0x21, 0
	.dw 0x6ec0, 0xc188,	0x6eff, 0xc188,		0x21, 0
	.dw 0x6f40, 0xc188,	0x6f7f, 0xc188,		0x21, 0
	.dw 0x6fc0, 0xc188,	0x6fff, 0xc188,		0x21, 0
	.dw 0x7040, 0xc188,	0x707f, 0xc188,		0x21, 0
	.dw 0x70c0, 0xc188,	0x70ff, 0xc188,		0x21, 0
	.dw 0x7140, 0xc188,	0x717f, 0xc188,		0x21, 0
	.dw 0x71c0, 0xc188,	0x71ff, 0xc188,		0x21, 0
	.dw 0x7240, 0xc188,	0x727f, 0xc188,		0x21, 0
	.dw 0x72c0, 0xc188,	0x72ff, 0xc188,		0x21, 0
	.dw 0x7340, 0xc188,	0x737f, 0xc188,		0x21, 0
	.dw 0x73c0, 0xc188,	0x73ff, 0xc188,		0x21, 0
	.dw 0x7440, 0xc188,	0x747f, 0xc188,		0x21, 0
	.dw 0x74c0, 0xc188,	0x74ff, 0xc188,		0x21, 0
	.dw 0x7540, 0xc188,	0x757f, 0xc188,		0x21, 0
	.dw 0x75c0, 0xc188,	0x75ff, 0xc188,		0x21, 0
	.dw 0x7640, 0xc188,	0x767f, 0xc188,		0x21, 0
	.dw 0x76c0, 0xc188,	0x76ff, 0xc188,		0x21, 0
	.dw 0x7740, 0xc188,	0x777f, 0xc188,		0x21, 0
	.dw 0x77c0, 0xc188,	0x77ff, 0xc188,		0x21, 0
	.dw 0x7840, 0xc188,	0x787f, 0xc188,		0x21, 0
	.dw 0x78c0, 0xc188,	0x78ff, 0xc188,		0x21, 0
	.dw 0x7940, 0xc188,	0x797f, 0xc188,		0x21, 0
	.dw 0x79c0, 0xc188,	0x9fff, 0xc188,		0x21, 0
	.dw 0xa040, 0xc188,	0xa07f, 0xc188,		0x21, 0
	.dw 0xa0c0, 0xc188,	0xa0ff, 0xc188,		0x21, 0
	.dw 0xa140, 0xc188,	0xa17f, 0xc188,		0x21, 0
	.dw 0xa1c0, 0xc188,	0xa1ff, 0xc188,		0x21, 0
	.dw 0xa240, 0xc188,	0xa27f, 0xc188,		0x21, 0
	.dw 0xa2c0, 0xc188,	0xa2ff, 0xc188,		0x21, 0
	.dw 0xa340, 0xc188,	0xa37f, 0xc188,		0x21, 0
	.dw 0xa3c0, 0xc188,	0xa3ff, 0xc188,		0x21, 0
	.dw 0xa440, 0xc188,	0xa47f, 0xc188,		0x21, 0
	.dw 0xa4c0, 0xc188,	0xa4ff, 0xc188,		0x21, 0
	.dw 0xa540, 0xc188,	0xa57f, 0xc188,		0x21, 0
	.dw 0xa5c0, 0xc188,	0xa5ff, 0xc188,		0x21, 0
	.dw 0xa640, 0xc188,	0xa67f, 0xc188,		0x21, 0
	.dw 0xa6c0, 0xc188,	0xa6ff, 0xc188,		0x21, 0
	.dw 0xa740, 0xc188,	0xa77f, 0xc188,		0x21, 0
	.dw 0xa7c0, 0xc188,	0xa7ff, 0xc188,		0x21, 0
	.dw 0xa840, 0xc188,	0xa87f, 0xc188,		0x21, 0
	.dw 0xa8c0, 0xc188,	0xa8ff, 0xc188,		0x21, 0
	.dw 0xa940, 0xc188,	0xa97f, 0xc188,		0x21, 0
	.dw 0xa9c0, 0xc188,	0xa9ff, 0xc188,		0x21, 0
	.dw 0xaa40, 0xc188,	0xaa7f, 0xc188,		0x21, 0
	.dw 0xaac0, 0xc188,	0xaaff, 0xc188,		0x21, 0
	.dw 0xab40, 0xc188,	0xab7f, 0xc188,		0x21, 0
	.dw 0xabc0, 0xc188,	0xabff, 0xc188,		0x21, 0
	.dw 0xac40, 0xc188,	0xac7f, 0xc188,		0x21, 0
	.dw 0xacc0, 0xc188,	0xacff, 0xc188,		0x21, 0
	.dw 0xad40, 0xc188,	0xad7f, 0xc188,		0x21, 0
	.dw 0xadc0, 0xc188,	0xadff, 0xc188,		0x21, 0
	.dw 0xae40, 0xc188,	0xae7f, 0xc188,		0x21, 0
	.dw 0xaec0, 0xc188,	0xaeff, 0xc188,		0x21, 0
	.dw 0xaf40, 0xc188,	0xaf7f, 0xc188,		0x21, 0
	.dw 0xafc0, 0xc188,	0xafff, 0xc188,		0x21, 0
	.dw 0xb040, 0xc188,	0xb07f, 0xc188,		0x21, 0
	.dw 0xb0c0, 0xc188,	0xb0ff, 0xc188,		0x21, 0
	.dw 0xb140, 0xc188,	0xb17f, 0xc188,		0x21, 0
	.dw 0xb1c0, 0xc188,	0xb1ff, 0xc188,		0x21, 0
	.dw 0xb240, 0xc188,	0xb27f, 0xc188,		0x21, 0
	.dw 0xb2c0, 0xc188,	0xb2ff, 0xc188,		0x21, 0
	.dw 0xb340, 0xc188,	0xb37f, 0xc188,		0x21, 0
	.dw 0xb3c0, 0xc188,	0xb3ff, 0xc188,		0x21, 0
	.dw 0xb440, 0xc188,	0xb47f, 0xc188,		0x21, 0
	.dw 0xb4c0, 0xc188,	0xb4ff, 0xc188,		0x21, 0
	.dw 0xb540, 0xc188,	0xb57f, 0xc188,		0x21, 0
	.dw 0xb5c0, 0xc188,	0xb5ff, 0xc188,		0x21, 0
	.dw 0xb640, 0xc188,	0xb67f, 0xc188,		0x21, 0
	.dw 0xb6c0, 0xc188,	0xb6ff, 0xc188,		0x21, 0
	.dw 0xb740, 0xc188,	0xb77f, 0xc188,		0x21, 0
	.dw 0xb7c0, 0xc188,	0xb7ff, 0xc188,		0x21, 0
	.dw 0xb840, 0xc188,	0xb87f, 0xc188,		0x21, 0
	.dw 0xb8c0, 0xc188,	0xb8ff, 0xc188,		0x21, 0
	.dw 0xb940, 0xc188,	0xb97f, 0xc188,		0x21, 0
	.dw 0xb9c0, 0xc188,	0xdfff, 0xc188,		0x21, 0
	.dw 0xe040, 0xc188,	0xe07f, 0xc188,		0x21, 0
	.dw 0xe0c0, 0xc188,	0xe0ff, 0xc188,		0x21, 0
	.dw 0xe140, 0xc188,	0xe17f, 0xc188,		0x21, 0
	.dw 0xe1c0, 0xc188,	0xe1ff, 0xc188,		0x21, 0
	.dw 0xe240, 0xc188,	0xe27f, 0xc188,		0x21, 0
	.dw 0xe2c0, 0xc188,	0xe2ff, 0xc188,		0x21, 0
	.dw 0xe340, 0xc188,	0xe37f, 0xc188,		0x21, 0
	.dw 0xe3c0, 0xc188,	0xe3ff, 0xc188,		0x21, 0
	.dw 0xe440, 0xc188,	0xe47f, 0xc188,		0x21, 0
	.dw 0xe4c0, 0xc188,	0xe4ff, 0xc188,		0x21, 0
	.dw 0xe540, 0xc188,	0xe57f, 0xc188,		0x21, 0
	.dw 0xe5c0, 0xc188,	0xe5ff, 0xc188,		0x21, 0
	.dw 0xe640, 0xc188,	0xe67f, 0xc188,		0x21, 0
	.dw 0xe6c0, 0xc188,	0xe6ff, 0xc188,		0x21, 0
	.dw 0xe740, 0xc188,	0xe77f, 0xc188,		0x21, 0
	.dw 0xe7c0, 0xc188,	0xe7ff, 0xc188,		0x21, 0
	.dw 0xe840, 0xc188,	0xe87f, 0xc188,		0x21, 0
	.dw 0xe8c0, 0xc188,	0xe8ff, 0xc188,		0x21, 0
	.dw 0xe940, 0xc188,	0xe97f, 0xc188,		0x21, 0
	.dw 0xe9c0, 0xc188,	0xe9ff, 0xc188,		0x21, 0
	.dw 0xea40, 0xc188,	0xea7f, 0xc188,		0x21, 0
	.dw 0xeac0, 0xc188,	0xeaff, 0xc188,		0x21, 0
	.dw 0xeb40, 0xc188,	0xeb7f, 0xc188,		0x21, 0
	.dw 0xebc0, 0xc188,	0xebff, 0xc188,		0x21, 0
	.dw 0xec40, 0xc188,	0xec7f, 0xc188,		0x21, 0
	.dw 0xecc0, 0xc188,	0xecff, 0xc188,		0x21, 0
	.dw 0xed40, 0xc188,	0xed7f, 0xc188,		0x21, 0
	.dw 0xedc0, 0xc188,	0xedff, 0xc188,		0x21, 0
	.dw 0xee40, 0xc188,	0xee7f, 0xc188,		0x21, 0
	.dw 0xeec0, 0xc188,	0xeeff, 0xc188,		0x21, 0
	.dw 0xef40, 0xc188,	0xef7f, 0xc188,		0x21, 0
	.dw 0xefc0, 0xc188,	0xefff, 0xc188,		0x21, 0
	.dw 0xf040, 0xc188,	0xf07f, 0xc188,		0x21, 0
	.dw 0xf0c0, 0xc188,	0xf0ff, 0xc188,		0x21, 0
	.dw 0xf140, 0xc188,	0xf17f, 0xc188,		0x21, 0
	.dw 0xf1c0, 0xc188,	0xf1ff, 0xc188,		0x21, 0
	.dw 0xf240, 0xc188,	0xf27f, 0xc188,		0x21, 0
	.dw 0xf2c0, 0xc188,	0xf2ff, 0xc188,		0x21, 0
	.dw 0xf340, 0xc188,	0xf37f, 0xc188,		0x21, 0
	.dw 0xf3c0, 0xc188,	0xf3ff, 0xc188,		0x21, 0
	.dw 0xf440, 0xc188,	0xf47f, 0xc188,		0x21, 0
	.dw 0xf4c0, 0xc188,	0xf4ff, 0xc188,		0x21, 0
	.dw 0xf540, 0xc188,	0xf57f, 0xc188,		0x21, 0
	.dw 0xf5c0, 0xc188,	0xf5ff, 0xc188,		0x21, 0
	.dw 0xf640, 0xc188,	0xf67f, 0xc188,		0x21, 0
	.dw 0xf6c0, 0xc188,	0xf6ff, 0xc188,		0x21, 0
	.dw 0xf740, 0xc188,	0xf77f, 0xc188,		0x21, 0
	.dw 0xf7c0, 0xc188,	0xf7ff, 0xc188,		0x21, 0
	.dw 0xf840, 0xc188,	0xf87f, 0xc188,		0x21, 0
	.dw 0xf8c0, 0xc188,	0xf8ff, 0xc188,		0x21, 0
	.dw 0xf940, 0xc188,	0xf97f, 0xc188,		0x21, 0
	.dw 0xf9c0, 0xc188,	0x1fff, 0xc189,		0x21, 0
	.dw 0x2040, 0xc189,	0x207f, 0xc189,		0x21, 0
	.dw 0x20c0, 0xc189,	0x20ff, 0xc189,		0x21, 0
	.dw 0x2140, 0xc189,	0x217f, 0xc189,		0x21, 0
	.dw 0x21c0, 0xc189,	0x21ff, 0xc189,		0x21, 0
	.dw 0x2240, 0xc189,	0x227f, 0xc189,		0x21, 0
	.dw 0x22c0, 0xc189,	0x22ff, 0xc189,		0x21, 0
	.dw 0x2340, 0xc189,	0x237f, 0xc189,		0x21, 0
	.dw 0x23c0, 0xc189,	0x23ff, 0xc189,		0x21, 0
	.dw 0x2440, 0xc189,	0x247f, 0xc189,		0x21, 0
	.dw 0x24c0, 0xc189,	0x24ff, 0xc189,		0x21, 0
	.dw 0x2540, 0xc189,	0x257f, 0xc189,		0x21, 0
	.dw 0x25c0, 0xc189,	0x25ff, 0xc189,		0x21, 0
	.dw 0x2640, 0xc189,	0x267f, 0xc189,		0x21, 0
	.dw 0x26c0, 0xc189,	0x26ff, 0xc189,		0x21, 0
	.dw 0x2740, 0xc189,	0x277f, 0xc189,		0x21, 0
	.dw 0x27c0, 0xc189,	0x27ff, 0xc189,		0x21, 0
	.dw 0x2840, 0xc189,	0x287f, 0xc189,		0x21, 0
	.dw 0x28c0, 0xc189,	0x28ff, 0xc189,		0x21, 0
	.dw 0x2940, 0xc189,	0x297f, 0xc189,		0x21, 0
	.dw 0x29c0, 0xc189,	0x29ff, 0xc189,		0x21, 0
	.dw 0x2a40, 0xc189,	0x2a7f, 0xc189,		0x21, 0
	.dw 0x2ac0, 0xc189,	0x2aff, 0xc189,		0x21, 0
	.dw 0x2b40, 0xc189,	0x2b7f, 0xc189,		0x21, 0
	.dw 0x2bc0, 0xc189,	0x2bff, 0xc189,		0x21, 0
	.dw 0x2c40, 0xc189,	0x2c7f, 0xc189,		0x21, 0
	.dw 0x2cc0, 0xc189,	0x2cff, 0xc189,		0x21, 0
	.dw 0x2d40, 0xc189,	0x2d7f, 0xc189,		0x21, 0
	.dw 0x2dc0, 0xc189,	0x2dff, 0xc189,		0x21, 0
	.dw 0x2e40, 0xc189,	0x2e7f, 0xc189,		0x21, 0
	.dw 0x2ec0, 0xc189,	0x2eff, 0xc189,		0x21, 0
	.dw 0x2f40, 0xc189,	0x2f7f, 0xc189,		0x21, 0
	.dw 0x2fc0, 0xc189,	0x2fff, 0xc189,		0x21, 0
	.dw 0x3040, 0xc189,	0x307f, 0xc189,		0x21, 0
	.dw 0x30c0, 0xc189,	0x30ff, 0xc189,		0x21, 0
	.dw 0x3140, 0xc189,	0x317f, 0xc189,		0x21, 0
	.dw 0x31c0, 0xc189,	0x31ff, 0xc189,		0x21, 0
	.dw 0x3240, 0xc189,	0x327f, 0xc189,		0x21, 0
	.dw 0x32c0, 0xc189,	0x32ff, 0xc189,		0x21, 0
	.dw 0x3340, 0xc189,	0x337f, 0xc189,		0x21, 0
	.dw 0x33c0, 0xc189,	0x33ff, 0xc189,		0x21, 0
	.dw 0x3440, 0xc189,	0x347f, 0xc189,		0x21, 0
	.dw 0x34c0, 0xc189,	0x34ff, 0xc189,		0x21, 0
	.dw 0x3540, 0xc189,	0x357f, 0xc189,		0x21, 0
	.dw 0x35c0, 0xc189,	0x35ff, 0xc189,		0x21, 0
	.dw 0x3640, 0xc189,	0x367f, 0xc189,		0x21, 0
	.dw 0x36c0, 0xc189,	0x36ff, 0xc189,		0x21, 0
	.dw 0x3740, 0xc189,	0x377f, 0xc189,		0x21, 0
	.dw 0x37c0, 0xc189,	0x37ff, 0xc189,		0x21, 0
	.dw 0x3840, 0xc189,	0x387f, 0xc189,		0x21, 0
	.dw 0x38c0, 0xc189,	0x38ff, 0xc189,		0x21, 0
	.dw 0x3940, 0xc189,	0x397f, 0xc189,		0x21, 0
	.dw 0x39c0, 0xc189,	0x5fff, 0xc189,		0x21, 0
	.dw 0x6040, 0xc189,	0x607f, 0xc189,		0x21, 0
	.dw 0x60c0, 0xc189,	0x60ff, 0xc189,		0x21, 0
	.dw 0x6140, 0xc189,	0x617f, 0xc189,		0x21, 0
	.dw 0x61c0, 0xc189,	0x61ff, 0xc189,		0x21, 0
	.dw 0x6240, 0xc189,	0x627f, 0xc189,		0x21, 0
	.dw 0x62c0, 0xc189,	0x62ff, 0xc189,		0x21, 0
	.dw 0x6340, 0xc189,	0x637f, 0xc189,		0x21, 0
	.dw 0x63c0, 0xc189,	0x63ff, 0xc189,		0x21, 0
	.dw 0x6440, 0xc189,	0x647f, 0xc189,		0x21, 0
	.dw 0x64c0, 0xc189,	0x64ff, 0xc189,		0x21, 0
	.dw 0x6540, 0xc189,	0x657f, 0xc189,		0x21, 0
	.dw 0x65c0, 0xc189,	0x65ff, 0xc189,		0x21, 0
	.dw 0x6640, 0xc189,	0x667f, 0xc189,		0x21, 0
	.dw 0x66c0, 0xc189,	0x66ff, 0xc189,		0x21, 0
	.dw 0x6740, 0xc189,	0x677f, 0xc189,		0x21, 0
	.dw 0x67c0, 0xc189,	0x67ff, 0xc189,		0x21, 0
	.dw 0x6840, 0xc189,	0x687f, 0xc189,		0x21, 0
	.dw 0x68c0, 0xc189,	0x68ff, 0xc189,		0x21, 0
	.dw 0x6940, 0xc189,	0x697f, 0xc189,		0x21, 0
	.dw 0x69c0, 0xc189,	0x69ff, 0xc189,		0x21, 0
	.dw 0x6a40, 0xc189,	0x6a7f, 0xc189,		0x21, 0
	.dw 0x6ac0, 0xc189,	0x6aff, 0xc189,		0x21, 0
	.dw 0x6b40, 0xc189,	0x6b7f, 0xc189,		0x21, 0
	.dw 0x6bc0, 0xc189,	0x6bff, 0xc189,		0x21, 0
	.dw 0x6c40, 0xc189,	0x6c7f, 0xc189,		0x21, 0
	.dw 0x6cc0, 0xc189,	0x6cff, 0xc189,		0x21, 0
	.dw 0x6d40, 0xc189,	0x6d7f, 0xc189,		0x21, 0
	.dw 0x6dc0, 0xc189,	0x6dff, 0xc189,		0x21, 0
	.dw 0x6e40, 0xc189,	0x6e7f, 0xc189,		0x21, 0
	.dw 0x6ec0, 0xc189,	0x6eff, 0xc189,		0x21, 0
	.dw 0x6f40, 0xc189,	0x6f7f, 0xc189,		0x21, 0
	.dw 0x6fc0, 0xc189,	0x6fff, 0xc189,		0x21, 0
	.dw 0x7040, 0xc189,	0x707f, 0xc189,		0x21, 0
	.dw 0x70c0, 0xc189,	0x70ff, 0xc189,		0x21, 0
	.dw 0x7140, 0xc189,	0x717f, 0xc189,		0x21, 0
	.dw 0x71c0, 0xc189,	0x71ff, 0xc189,		0x21, 0
	.dw 0x7240, 0xc189,	0x727f, 0xc189,		0x21, 0
	.dw 0x72c0, 0xc189,	0x72ff, 0xc189,		0x21, 0
	.dw 0x7340, 0xc189,	0x737f, 0xc189,		0x21, 0
	.dw 0x73c0, 0xc189,	0x73ff, 0xc189,		0x21, 0
	.dw 0x7440, 0xc189,	0x747f, 0xc189,		0x21, 0
	.dw 0x74c0, 0xc189,	0x74ff, 0xc189,		0x21, 0
	.dw 0x7540, 0xc189,	0x757f, 0xc189,		0x21, 0
	.dw 0x75c0, 0xc189,	0x75ff, 0xc189,		0x21, 0
	.dw 0x7640, 0xc189,	0x767f, 0xc189,		0x21, 0
	.dw 0x76c0, 0xc189,	0x76ff, 0xc189,		0x21, 0
	.dw 0x7740, 0xc189,	0x777f, 0xc189,		0x21, 0
	.dw 0x77c0, 0xc189,	0x77ff, 0xc189,		0x21, 0
	.dw 0x7840, 0xc189,	0x787f, 0xc189,		0x21, 0
	.dw 0x78c0, 0xc189,	0x78ff, 0xc189,		0x21, 0
	.dw 0x7940, 0xc189,	0x797f, 0xc189,		0x21, 0
	.dw 0x79c0, 0xc189,	0x9fff, 0xc189,		0x21, 0
	.dw 0xa040, 0xc189,	0xa07f, 0xc189,		0x21, 0
	.dw 0xa0c0, 0xc189,	0xa0ff, 0xc189,		0x21, 0
	.dw 0xa140, 0xc189,	0xa17f, 0xc189,		0x21, 0
	.dw 0xa1c0, 0xc189,	0xa1ff, 0xc189,		0x21, 0
	.dw 0xa240, 0xc189,	0xa27f, 0xc189,		0x21, 0
	.dw 0xa2c0, 0xc189,	0xa2ff, 0xc189,		0x21, 0
	.dw 0xa340, 0xc189,	0xa37f, 0xc189,		0x21, 0
	.dw 0xa3c0, 0xc189,	0xa3ff, 0xc189,		0x21, 0
	.dw 0xa440, 0xc189,	0xa47f, 0xc189,		0x21, 0
	.dw 0xa4c0, 0xc189,	0xa4ff, 0xc189,		0x21, 0
	.dw 0xa540, 0xc189,	0xa57f, 0xc189,		0x21, 0
	.dw 0xa5c0, 0xc189,	0xa5ff, 0xc189,		0x21, 0
	.dw 0xa640, 0xc189,	0xa67f, 0xc189,		0x21, 0
	.dw 0xa6c0, 0xc189,	0xa6ff, 0xc189,		0x21, 0
	.dw 0xa740, 0xc189,	0xa77f, 0xc189,		0x21, 0
	.dw 0xa7c0, 0xc189,	0xa7ff, 0xc189,		0x21, 0
	.dw 0xa840, 0xc189,	0xa87f, 0xc189,		0x21, 0
	.dw 0xa8c0, 0xc189,	0xa8ff, 0xc189,		0x21, 0
	.dw 0xa940, 0xc189,	0xa97f, 0xc189,		0x21, 0
	.dw 0xa9c0, 0xc189,	0xa9ff, 0xc189,		0x21, 0
	.dw 0xaa40, 0xc189,	0xaa7f, 0xc189,		0x21, 0
	.dw 0xaac0, 0xc189,	0xaaff, 0xc189,		0x21, 0
	.dw 0xab40, 0xc189,	0xab7f, 0xc189,		0x21, 0
	.dw 0xabc0, 0xc189,	0xabff, 0xc189,		0x21, 0
	.dw 0xac40, 0xc189,	0xac7f, 0xc189,		0x21, 0
	.dw 0xacc0, 0xc189,	0xacff, 0xc189,		0x21, 0
	.dw 0xad40, 0xc189,	0xad7f, 0xc189,		0x21, 0
	.dw 0xadc0, 0xc189,	0xadff, 0xc189,		0x21, 0
	.dw 0xae40, 0xc189,	0xae7f, 0xc189,		0x21, 0
	.dw 0xaec0, 0xc189,	0xaeff, 0xc189,		0x21, 0
	.dw 0xaf40, 0xc189,	0xaf7f, 0xc189,		0x21, 0
	.dw 0xafc0, 0xc189,	0xafff, 0xc189,		0x21, 0
	.dw 0xb040, 0xc189,	0xb07f, 0xc189,		0x21, 0
	.dw 0xb0c0, 0xc189,	0xb0ff, 0xc189,		0x21, 0
	.dw 0xb140, 0xc189,	0xb17f, 0xc189,		0x21, 0
	.dw 0xb1c0, 0xc189,	0xb1ff, 0xc189,		0x21, 0
	.dw 0xb240, 0xc189,	0xb27f, 0xc189,		0x21, 0
	.dw 0xb2c0, 0xc189,	0xb2ff, 0xc189,		0x21, 0
	.dw 0xb340, 0xc189,	0xb37f, 0xc189,		0x21, 0
	.dw 0xb3c0, 0xc189,	0xb3ff, 0xc189,		0x21, 0
	.dw 0xb440, 0xc189,	0xb47f, 0xc189,		0x21, 0
	.dw 0xb4c0, 0xc189,	0xb4ff, 0xc189,		0x21, 0
	.dw 0xb540, 0xc189,	0xb57f, 0xc189,		0x21, 0
	.dw 0xb5c0, 0xc189,	0xb5ff, 0xc189,		0x21, 0
	.dw 0xb640, 0xc189,	0xb67f, 0xc189,		0x21, 0
	.dw 0xb6c0, 0xc189,	0xb6ff, 0xc189,		0x21, 0
	.dw 0xb740, 0xc189,	0xb77f, 0xc189,		0x21, 0
	.dw 0xb7c0, 0xc189,	0xb7ff, 0xc189,		0x21, 0
	.dw 0xb840, 0xc189,	0xb87f, 0xc189,		0x21, 0
	.dw 0xb8c0, 0xc189,	0xb8ff, 0xc189,		0x21, 0
	.dw 0xb940, 0xc189,	0xb97f, 0xc189,		0x21, 0
	.dw 0xb9c0, 0xc189,	0xdfff, 0xc189,		0x21, 0
	.dw 0xe040, 0xc189,	0xe07f, 0xc189,		0x21, 0
	.dw 0xe0c0, 0xc189,	0xe0ff, 0xc189,		0x21, 0
	.dw 0xe140, 0xc189,	0xe17f, 0xc189,		0x21, 0
	.dw 0xe1c0, 0xc189,	0xe1ff, 0xc189,		0x21, 0
	.dw 0xe240, 0xc189,	0xe27f, 0xc189,		0x21, 0
	.dw 0xe2c0, 0xc189,	0xe2ff, 0xc189,		0x21, 0
	.dw 0xe340, 0xc189,	0xe37f, 0xc189,		0x21, 0
	.dw 0xe3c0, 0xc189,	0xe3ff, 0xc189,		0x21, 0
	.dw 0xe440, 0xc189,	0xe47f, 0xc189,		0x21, 0
	.dw 0xe4c0, 0xc189,	0xe4ff, 0xc189,		0x21, 0
	.dw 0xe540, 0xc189,	0xe57f, 0xc189,		0x21, 0
	.dw 0xe5c0, 0xc189,	0xe5ff, 0xc189,		0x21, 0
	.dw 0xe640, 0xc189,	0xe67f, 0xc189,		0x21, 0
	.dw 0xe6c0, 0xc189,	0xe6ff, 0xc189,		0x21, 0
	.dw 0xe740, 0xc189,	0xe77f, 0xc189,		0x21, 0
	.dw 0xe7c0, 0xc189,	0xe7ff, 0xc189,		0x21, 0
	.dw 0xe840, 0xc189,	0xe87f, 0xc189,		0x21, 0
	.dw 0xe8c0, 0xc189,	0xe8ff, 0xc189,		0x21, 0
	.dw 0xe940, 0xc189,	0xe97f, 0xc189,		0x21, 0
	.dw 0xe9c0, 0xc189,	0xe9ff, 0xc189,		0x21, 0
	.dw 0xea40, 0xc189,	0xea7f, 0xc189,		0x21, 0
	.dw 0xeac0, 0xc189,	0xeaff, 0xc189,		0x21, 0
	.dw 0xeb40, 0xc189,	0xeb7f, 0xc189,		0x21, 0
	.dw 0xebc0, 0xc189,	0xebff, 0xc189,		0x21, 0
	.dw 0xec40, 0xc189,	0xec7f, 0xc189,		0x21, 0
	.dw 0xecc0, 0xc189,	0xecff, 0xc189,		0x21, 0
	.dw 0xed40, 0xc189,	0xed7f, 0xc189,		0x21, 0
	.dw 0xedc0, 0xc189,	0xedff, 0xc189,		0x21, 0
	.dw 0xee40, 0xc189,	0xee7f, 0xc189,		0x21, 0
	.dw 0xeec0, 0xc189,	0xeeff, 0xc189,		0x21, 0
	.dw 0xef40, 0xc189,	0xef7f, 0xc189,		0x21, 0
	.dw 0xefc0, 0xc189,	0xefff, 0xc189,		0x21, 0
	.dw 0xf040, 0xc189,	0xf07f, 0xc189,		0x21, 0
	.dw 0xf0c0, 0xc189,	0xf0ff, 0xc189,		0x21, 0
	.dw 0xf140, 0xc189,	0xf17f, 0xc189,		0x21, 0
	.dw 0xf1c0, 0xc189,	0xf1ff, 0xc189,		0x21, 0
	.dw 0xf240, 0xc189,	0xf27f, 0xc189,		0x21, 0
	.dw 0xf2c0, 0xc189,	0xf2ff, 0xc189,		0x21, 0
	.dw 0xf340, 0xc189,	0xf37f, 0xc189,		0x21, 0
	.dw 0xf3c0, 0xc189,	0xf3ff, 0xc189,		0x21, 0
	.dw 0xf440, 0xc189,	0xf47f, 0xc189,		0x21, 0
	.dw 0xf4c0, 0xc189,	0xf4ff, 0xc189,		0x21, 0
	.dw 0xf540, 0xc189,	0xf57f, 0xc189,		0x21, 0
	.dw 0xf5c0, 0xc189,	0xf5ff, 0xc189,		0x21, 0
	.dw 0xf640, 0xc189,	0xf67f, 0xc189,		0x21, 0
	.dw 0xf6c0, 0xc189,	0xf6ff, 0xc189,		0x21, 0
	.dw 0xf740, 0xc189,	0xf77f, 0xc189,		0x21, 0
	.dw 0xf7c0, 0xc189,	0xf7ff, 0xc189,		0x21, 0
	.dw 0xf840, 0xc189,	0xf87f, 0xc189,		0x21, 0
	.dw 0xf8c0, 0xc189,	0xf8ff, 0xc189,		0x21, 0
	.dw 0xf940, 0xc189,	0xf97f, 0xc189,		0x21, 0
	.dw 0xf9c0, 0xc189,	0x1fff, 0xc18a,		0x21, 0
	.dw 0x2040, 0xc18a,	0x207f, 0xc18a,		0x21, 0
	.dw 0x20c0, 0xc18a,	0x20ff, 0xc18a,		0x21, 0
	.dw 0x2140, 0xc18a,	0x217f, 0xc18a,		0x21, 0
	.dw 0x21c0, 0xc18a,	0x21ff, 0xc18a,		0x21, 0
	.dw 0x2240, 0xc18a,	0x227f, 0xc18a,		0x21, 0
	.dw 0x22c0, 0xc18a,	0x22ff, 0xc18a,		0x21, 0
	.dw 0x2340, 0xc18a,	0x237f, 0xc18a,		0x21, 0
	.dw 0x23c0, 0xc18a,	0x23ff, 0xc18a,		0x21, 0
	.dw 0x2440, 0xc18a,	0x247f, 0xc18a,		0x21, 0
	.dw 0x24c0, 0xc18a,	0x24ff, 0xc18a,		0x21, 0
	.dw 0x2540, 0xc18a,	0x257f, 0xc18a,		0x21, 0
	.dw 0x25c0, 0xc18a,	0x25ff, 0xc18a,		0x21, 0
	.dw 0x2640, 0xc18a,	0x267f, 0xc18a,		0x21, 0
	.dw 0x26c0, 0xc18a,	0x26ff, 0xc18a,		0x21, 0
	.dw 0x2740, 0xc18a,	0x277f, 0xc18a,		0x21, 0
	.dw 0x27c0, 0xc18a,	0x27ff, 0xc18a,		0x21, 0
	.dw 0x2840, 0xc18a,	0x287f, 0xc18a,		0x21, 0
	.dw 0x28c0, 0xc18a,	0x28ff, 0xc18a,		0x21, 0
	.dw 0x2940, 0xc18a,	0x297f, 0xc18a,		0x21, 0
	.dw 0x29c0, 0xc18a,	0x29ff, 0xc18a,		0x21, 0
	.dw 0x2a40, 0xc18a,	0x2a7f, 0xc18a,		0x21, 0
	.dw 0x2ac0, 0xc18a,	0x2aff, 0xc18a,		0x21, 0
	.dw 0x2b40, 0xc18a,	0x2b7f, 0xc18a,		0x21, 0
	.dw 0x2bc0, 0xc18a,	0x2bff, 0xc18a,		0x21, 0
	.dw 0x2c40, 0xc18a,	0x2c7f, 0xc18a,		0x21, 0
	.dw 0x2cc0, 0xc18a,	0x2cff, 0xc18a,		0x21, 0
	.dw 0x2d40, 0xc18a,	0x2d7f, 0xc18a,		0x21, 0
	.dw 0x2dc0, 0xc18a,	0x2dff, 0xc18a,		0x21, 0
	.dw 0x2e40, 0xc18a,	0x2e7f, 0xc18a,		0x21, 0
	.dw 0x2ec0, 0xc18a,	0x2eff, 0xc18a,		0x21, 0
	.dw 0x2f40, 0xc18a,	0x2f7f, 0xc18a,		0x21, 0
	.dw 0x2fc0, 0xc18a,	0x2fff, 0xc18a,		0x21, 0
	.dw 0x3040, 0xc18a,	0x307f, 0xc18a,		0x21, 0
	.dw 0x30c0, 0xc18a,	0x30ff, 0xc18a,		0x21, 0
	.dw 0x3140, 0xc18a,	0x317f, 0xc18a,		0x21, 0
	.dw 0x31c0, 0xc18a,	0x31ff, 0xc18a,		0x21, 0
	.dw 0x3240, 0xc18a,	0x327f, 0xc18a,		0x21, 0
	.dw 0x32c0, 0xc18a,	0x32ff, 0xc18a,		0x21, 0
	.dw 0x3340, 0xc18a,	0x337f, 0xc18a,		0x21, 0
	.dw 0x33c0, 0xc18a,	0x33ff, 0xc18a,		0x21, 0
	.dw 0x3440, 0xc18a,	0x347f, 0xc18a,		0x21, 0
	.dw 0x34c0, 0xc18a,	0x34ff, 0xc18a,		0x21, 0
	.dw 0x3540, 0xc18a,	0x357f, 0xc18a,		0x21, 0
	.dw 0x35c0, 0xc18a,	0x35ff, 0xc18a,		0x21, 0
	.dw 0x3640, 0xc18a,	0x367f, 0xc18a,		0x21, 0
	.dw 0x36c0, 0xc18a,	0x36ff, 0xc18a,		0x21, 0
	.dw 0x3740, 0xc18a,	0x377f, 0xc18a,		0x21, 0
	.dw 0x37c0, 0xc18a,	0x37ff, 0xc18a,		0x21, 0
	.dw 0x3840, 0xc18a,	0x387f, 0xc18a,		0x21, 0
	.dw 0x38c0, 0xc18a,	0x38ff, 0xc18a,		0x21, 0
	.dw 0x3940, 0xc18a,	0x397f, 0xc18a,		0x21, 0
	.dw 0x39c0, 0xc18a,	0x5fff, 0xc18a,		0x21, 0
	.dw 0x6040, 0xc18a,	0x607f, 0xc18a,		0x21, 0
	.dw 0x60c0, 0xc18a,	0x60ff, 0xc18a,		0x21, 0
	.dw 0x6140, 0xc18a,	0x617f, 0xc18a,		0x21, 0
	.dw 0x61c0, 0xc18a,	0x61ff, 0xc18a,		0x21, 0
	.dw 0x6240, 0xc18a,	0x627f, 0xc18a,		0x21, 0
	.dw 0x62c0, 0xc18a,	0x62ff, 0xc18a,		0x21, 0
	.dw 0x6340, 0xc18a,	0x637f, 0xc18a,		0x21, 0
	.dw 0x63c0, 0xc18a,	0x63ff, 0xc18a,		0x21, 0
	.dw 0x6440, 0xc18a,	0x647f, 0xc18a,		0x21, 0
	.dw 0x64c0, 0xc18a,	0x64ff, 0xc18a,		0x21, 0
	.dw 0x6540, 0xc18a,	0x657f, 0xc18a,		0x21, 0
	.dw 0x65c0, 0xc18a,	0x65ff, 0xc18a,		0x21, 0
	.dw 0x6640, 0xc18a,	0x667f, 0xc18a,		0x21, 0
	.dw 0x66c0, 0xc18a,	0x66ff, 0xc18a,		0x21, 0
	.dw 0x6740, 0xc18a,	0x677f, 0xc18a,		0x21, 0
	.dw 0x67c0, 0xc18a,	0x67ff, 0xc18a,		0x21, 0
	.dw 0x6840, 0xc18a,	0x687f, 0xc18a,		0x21, 0
	.dw 0x68c0, 0xc18a,	0x68ff, 0xc18a,		0x21, 0
	.dw 0x6940, 0xc18a,	0x697f, 0xc18a,		0x21, 0
	.dw 0x69c0, 0xc18a,	0x69ff, 0xc18a,		0x21, 0
	.dw 0x6a40, 0xc18a,	0x6a7f, 0xc18a,		0x21, 0
	.dw 0x6ac0, 0xc18a,	0x6aff, 0xc18a,		0x21, 0
	.dw 0x6b40, 0xc18a,	0x6b7f, 0xc18a,		0x21, 0
	.dw 0x6bc0, 0xc18a,	0x6bff, 0xc18a,		0x21, 0
	.dw 0x6c40, 0xc18a,	0x6c7f, 0xc18a,		0x21, 0
	.dw 0x6cc0, 0xc18a,	0x6cff, 0xc18a,		0x21, 0
	.dw 0x6d40, 0xc18a,	0x6d7f, 0xc18a,		0x21, 0
	.dw 0x6dc0, 0xc18a,	0x6dff, 0xc18a,		0x21, 0
	.dw 0x6e40, 0xc18a,	0x6e7f, 0xc18a,		0x21, 0
	.dw 0x6ec0, 0xc18a,	0x6eff, 0xc18a,		0x21, 0
	.dw 0x6f40, 0xc18a,	0x6f7f, 0xc18a,		0x21, 0
	.dw 0x6fc0, 0xc18a,	0x6fff, 0xc18a,		0x21, 0
	.dw 0x7040, 0xc18a,	0x707f, 0xc18a,		0x21, 0
	.dw 0x70c0, 0xc18a,	0x70ff, 0xc18a,		0x21, 0
	.dw 0x7140, 0xc18a,	0x717f, 0xc18a,		0x21, 0
	.dw 0x71c0, 0xc18a,	0x71ff, 0xc18a,		0x21, 0
	.dw 0x7240, 0xc18a,	0x727f, 0xc18a,		0x21, 0
	.dw 0x72c0, 0xc18a,	0x72ff, 0xc18a,		0x21, 0
	.dw 0x7340, 0xc18a,	0x737f, 0xc18a,		0x21, 0
	.dw 0x73c0, 0xc18a,	0x73ff, 0xc18a,		0x21, 0
	.dw 0x7440, 0xc18a,	0x747f, 0xc18a,		0x21, 0
	.dw 0x74c0, 0xc18a,	0x74ff, 0xc18a,		0x21, 0
	.dw 0x7540, 0xc18a,	0x757f, 0xc18a,		0x21, 0
	.dw 0x75c0, 0xc18a,	0x75ff, 0xc18a,		0x21, 0
	.dw 0x7640, 0xc18a,	0x767f, 0xc18a,		0x21, 0
	.dw 0x76c0, 0xc18a,	0x76ff, 0xc18a,		0x21, 0
	.dw 0x7740, 0xc18a,	0x777f, 0xc18a,		0x21, 0
	.dw 0x77c0, 0xc18a,	0x77ff, 0xc18a,		0x21, 0
	.dw 0x7840, 0xc18a,	0x787f, 0xc18a,		0x21, 0
	.dw 0x78c0, 0xc18a,	0x78ff, 0xc18a,		0x21, 0
	.dw 0x7940, 0xc18a,	0x797f, 0xc18a,		0x21, 0
	.dw 0x79c0, 0xc18a,	0x9fff, 0xc18a,		0x21, 0
	.dw 0xa040, 0xc18a,	0xa07f, 0xc18a,		0x21, 0
	.dw 0xa0c0, 0xc18a,	0xa0ff, 0xc18a,		0x21, 0
	.dw 0xa140, 0xc18a,	0xa17f, 0xc18a,		0x21, 0
	.dw 0xa1c0, 0xc18a,	0xa1ff, 0xc18a,		0x21, 0
	.dw 0xa240, 0xc18a,	0xa27f, 0xc18a,		0x21, 0
	.dw 0xa2c0, 0xc18a,	0xa2ff, 0xc18a,		0x21, 0
	.dw 0xa340, 0xc18a,	0xa37f, 0xc18a,		0x21, 0
	.dw 0xa3c0, 0xc18a,	0xa3ff, 0xc18a,		0x21, 0
	.dw 0xa440, 0xc18a,	0xa47f, 0xc18a,		0x21, 0
	.dw 0xa4c0, 0xc18a,	0xa4ff, 0xc18a,		0x21, 0
	.dw 0xa540, 0xc18a,	0xa57f, 0xc18a,		0x21, 0
	.dw 0xa5c0, 0xc18a,	0xa5ff, 0xc18a,		0x21, 0
	.dw 0xa640, 0xc18a,	0xa67f, 0xc18a,		0x21, 0
	.dw 0xa6c0, 0xc18a,	0xa6ff, 0xc18a,		0x21, 0
	.dw 0xa740, 0xc18a,	0xa77f, 0xc18a,		0x21, 0
	.dw 0xa7c0, 0xc18a,	0xa7ff, 0xc18a,		0x21, 0
	.dw 0xa840, 0xc18a,	0xa87f, 0xc18a,		0x21, 0
	.dw 0xa8c0, 0xc18a,	0xa8ff, 0xc18a,		0x21, 0
	.dw 0xa940, 0xc18a,	0xa97f, 0xc18a,		0x21, 0
	.dw 0xa9c0, 0xc18a,	0xa9ff, 0xc18a,		0x21, 0
	.dw 0xaa40, 0xc18a,	0xaa7f, 0xc18a,		0x21, 0
	.dw 0xaac0, 0xc18a,	0xaaff, 0xc18a,		0x21, 0
	.dw 0xab40, 0xc18a,	0xab7f, 0xc18a,		0x21, 0
	.dw 0xabc0, 0xc18a,	0xabff, 0xc18a,		0x21, 0
	.dw 0xac40, 0xc18a,	0xac7f, 0xc18a,		0x21, 0
	.dw 0xacc0, 0xc18a,	0xacff, 0xc18a,		0x21, 0
	.dw 0xad40, 0xc18a,	0xad7f, 0xc18a,		0x21, 0
	.dw 0xadc0, 0xc18a,	0xadff, 0xc18a,		0x21, 0
	.dw 0xae40, 0xc18a,	0xae7f, 0xc18a,		0x21, 0
	.dw 0xaec0, 0xc18a,	0xaeff, 0xc18a,		0x21, 0
	.dw 0xaf40, 0xc18a,	0xaf7f, 0xc18a,		0x21, 0
	.dw 0xafc0, 0xc18a,	0xafff, 0xc18a,		0x21, 0
	.dw 0xb040, 0xc18a,	0xb07f, 0xc18a,		0x21, 0
	.dw 0xb0c0, 0xc18a,	0xb0ff, 0xc18a,		0x21, 0
	.dw 0xb140, 0xc18a,	0xb17f, 0xc18a,		0x21, 0
	.dw 0xb1c0, 0xc18a,	0xb1ff, 0xc18a,		0x21, 0
	.dw 0xb240, 0xc18a,	0xb27f, 0xc18a,		0x21, 0
	.dw 0xb2c0, 0xc18a,	0xb2ff, 0xc18a,		0x21, 0
	.dw 0xb340, 0xc18a,	0xb37f, 0xc18a,		0x21, 0
	.dw 0xb3c0, 0xc18a,	0xb3ff, 0xc18a,		0x21, 0
	.dw 0xb440, 0xc18a,	0xb47f, 0xc18a,		0x21, 0
	.dw 0xb4c0, 0xc18a,	0xb4ff, 0xc18a,		0x21, 0
	.dw 0xb540, 0xc18a,	0xb57f, 0xc18a,		0x21, 0
	.dw 0xb5c0, 0xc18a,	0xb5ff, 0xc18a,		0x21, 0
	.dw 0xb640, 0xc18a,	0xb67f, 0xc18a,		0x21, 0
	.dw 0xb6c0, 0xc18a,	0xb6ff, 0xc18a,		0x21, 0
	.dw 0xb740, 0xc18a,	0xb77f, 0xc18a,		0x21, 0
	.dw 0xb7c0, 0xc18a,	0xb7ff, 0xc18a,		0x21, 0
	.dw 0xb840, 0xc18a,	0xb87f, 0xc18a,		0x21, 0
	.dw 0xb8c0, 0xc18a,	0xb8ff, 0xc18a,		0x21, 0
	.dw 0xb940, 0xc18a,	0xb97f, 0xc18a,		0x21, 0
	.dw 0xb9c0, 0xc18a,	0xdfff, 0xc18a,		0x21, 0
	.dw 0xe040, 0xc18a,	0xe07f, 0xc18a,		0x21, 0
	.dw 0xe0c0, 0xc18a,	0xe0ff, 0xc18a,		0x21, 0
	.dw 0xe140, 0xc18a,	0xe17f, 0xc18a,		0x21, 0
	.dw 0xe1c0, 0xc18a,	0xe1ff, 0xc18a,		0x21, 0
	.dw 0xe240, 0xc18a,	0xe27f, 0xc18a,		0x21, 0
	.dw 0xe2c0, 0xc18a,	0xe2ff, 0xc18a,		0x21, 0
	.dw 0xe340, 0xc18a,	0xe37f, 0xc18a,		0x21, 0
	.dw 0xe3c0, 0xc18a,	0xe3ff, 0xc18a,		0x21, 0
	.dw 0xe440, 0xc18a,	0xe47f, 0xc18a,		0x21, 0
	.dw 0xe4c0, 0xc18a,	0xe4ff, 0xc18a,		0x21, 0
	.dw 0xe540, 0xc18a,	0xe57f, 0xc18a,		0x21, 0
	.dw 0xe5c0, 0xc18a,	0xe5ff, 0xc18a,		0x21, 0
	.dw 0xe640, 0xc18a,	0xe67f, 0xc18a,		0x21, 0
	.dw 0xe6c0, 0xc18a,	0xe6ff, 0xc18a,		0x21, 0
	.dw 0xe740, 0xc18a,	0xe77f, 0xc18a,		0x21, 0
	.dw 0xe7c0, 0xc18a,	0xe7ff, 0xc18a,		0x21, 0
	.dw 0xe840, 0xc18a,	0xe87f, 0xc18a,		0x21, 0
	.dw 0xe8c0, 0xc18a,	0xe8ff, 0xc18a,		0x21, 0
	.dw 0xe940, 0xc18a,	0xe97f, 0xc18a,		0x21, 0
	.dw 0xe9c0, 0xc18a,	0xe9ff, 0xc18a,		0x21, 0
	.dw 0xea40, 0xc18a,	0xea7f, 0xc18a,		0x21, 0
	.dw 0xeac0, 0xc18a,	0xeaff, 0xc18a,		0x21, 0
	.dw 0xeb40, 0xc18a,	0xeb7f, 0xc18a,		0x21, 0
	.dw 0xebc0, 0xc18a,	0xebff, 0xc18a,		0x21, 0
	.dw 0xec40, 0xc18a,	0xec7f, 0xc18a,		0x21, 0
	.dw 0xecc0, 0xc18a,	0xecff, 0xc18a,		0x21, 0
	.dw 0xed40, 0xc18a,	0xed7f, 0xc18a,		0x21, 0
	.dw 0xedc0, 0xc18a,	0xedff, 0xc18a,		0x21, 0
	.dw 0xee40, 0xc18a,	0xee7f, 0xc18a,		0x21, 0
	.dw 0xeec0, 0xc18a,	0xeeff, 0xc18a,		0x21, 0
	.dw 0xef40, 0xc18a,	0xef7f, 0xc18a,		0x21, 0
	.dw 0xefc0, 0xc18a,	0xefff, 0xc18a,		0x21, 0
	.dw 0xf040, 0xc18a,	0xf07f, 0xc18a,		0x21, 0
	.dw 0xf0c0, 0xc18a,	0xf0ff, 0xc18a,		0x21, 0
	.dw 0xf140, 0xc18a,	0xf17f, 0xc18a,		0x21, 0
	.dw 0xf1c0, 0xc18a,	0xf1ff, 0xc18a,		0x21, 0
	.dw 0xf240, 0xc18a,	0xf27f, 0xc18a,		0x21, 0
	.dw 0xf2c0, 0xc18a,	0xf2ff, 0xc18a,		0x21, 0
	.dw 0xf340, 0xc18a,	0xf37f, 0xc18a,		0x21, 0
	.dw 0xf3c0, 0xc18a,	0xf3ff, 0xc18a,		0x21, 0
	.dw 0xf440, 0xc18a,	0xf47f, 0xc18a,		0x21, 0
	.dw 0xf4c0, 0xc18a,	0xf4ff, 0xc18a,		0x21, 0
	.dw 0xf540, 0xc18a,	0xf57f, 0xc18a,		0x21, 0
	.dw 0xf5c0, 0xc18a,	0xf5ff, 0xc18a,		0x21, 0
	.dw 0xf640, 0xc18a,	0xf67f, 0xc18a,		0x21, 0
	.dw 0xf6c0, 0xc18a,	0xf6ff, 0xc18a,		0x21, 0
	.dw 0xf740, 0xc18a,	0xf77f, 0xc18a,		0x21, 0
	.dw 0xf7c0, 0xc18a,	0xf7ff, 0xc18a,		0x21, 0
	.dw 0xf840, 0xc18a,	0xf87f, 0xc18a,		0x21, 0
	.dw 0xf8c0, 0xc18a,	0xf8ff, 0xc18a,		0x21, 0
	.dw 0xf940, 0xc18a,	0xf97f, 0xc18a,		0x21, 0
	.dw 0xf9c0, 0xc18a,	0x1fff, 0xc18b,		0x21, 0
	.dw 0x2040, 0xc18b,	0x207f, 0xc18b,		0x21, 0
	.dw 0x20c0, 0xc18b,	0x20ff, 0xc18b,		0x21, 0
	.dw 0x2140, 0xc18b,	0x217f, 0xc18b,		0x21, 0
	.dw 0x21c0, 0xc18b,	0x21ff, 0xc18b,		0x21, 0
	.dw 0x2240, 0xc18b,	0x227f, 0xc18b,		0x21, 0
	.dw 0x22c0, 0xc18b,	0x22ff, 0xc18b,		0x21, 0
	.dw 0x2340, 0xc18b,	0x237f, 0xc18b,		0x21, 0
	.dw 0x23c0, 0xc18b,	0x23ff, 0xc18b,		0x21, 0
	.dw 0x2440, 0xc18b,	0x247f, 0xc18b,		0x21, 0
	.dw 0x24c0, 0xc18b,	0x24ff, 0xc18b,		0x21, 0
	.dw 0x2540, 0xc18b,	0x257f, 0xc18b,		0x21, 0
	.dw 0x25c0, 0xc18b,	0x25ff, 0xc18b,		0x21, 0
	.dw 0x2640, 0xc18b,	0x267f, 0xc18b,		0x21, 0
	.dw 0x26c0, 0xc18b,	0x26ff, 0xc18b,		0x21, 0
	.dw 0x2740, 0xc18b,	0x277f, 0xc18b,		0x21, 0
	.dw 0x27c0, 0xc18b,	0x27ff, 0xc18b,		0x21, 0
	.dw 0x2840, 0xc18b,	0x287f, 0xc18b,		0x21, 0
	.dw 0x28c0, 0xc18b,	0x28ff, 0xc18b,		0x21, 0
	.dw 0x2940, 0xc18b,	0x297f, 0xc18b,		0x21, 0
	.dw 0x29c0, 0xc18b,	0x29ff, 0xc18b,		0x21, 0
	.dw 0x2a40, 0xc18b,	0x2a7f, 0xc18b,		0x21, 0
	.dw 0x2ac0, 0xc18b,	0x2aff, 0xc18b,		0x21, 0
	.dw 0x2b40, 0xc18b,	0x2b7f, 0xc18b,		0x21, 0
	.dw 0x2bc0, 0xc18b,	0x2bff, 0xc18b,		0x21, 0
	.dw 0x2c40, 0xc18b,	0x2c7f, 0xc18b,		0x21, 0
	.dw 0x2cc0, 0xc18b,	0x2cff, 0xc18b,		0x21, 0
	.dw 0x2d40, 0xc18b,	0x2d7f, 0xc18b,		0x21, 0
	.dw 0x2dc0, 0xc18b,	0x2dff, 0xc18b,		0x21, 0
	.dw 0x2e40, 0xc18b,	0x2e7f, 0xc18b,		0x21, 0
	.dw 0x2ec0, 0xc18b,	0x2eff, 0xc18b,		0x21, 0
	.dw 0x2f40, 0xc18b,	0x2f7f, 0xc18b,		0x21, 0
	.dw 0x2fc0, 0xc18b,	0x2fff, 0xc18b,		0x21, 0
	.dw 0x3040, 0xc18b,	0x307f, 0xc18b,		0x21, 0
	.dw 0x30c0, 0xc18b,	0x30ff, 0xc18b,		0x21, 0
	.dw 0x3140, 0xc18b,	0x317f, 0xc18b,		0x21, 0
	.dw 0x31c0, 0xc18b,	0x31ff, 0xc18b,		0x21, 0
	.dw 0x3240, 0xc18b,	0x327f, 0xc18b,		0x21, 0
	.dw 0x32c0, 0xc18b,	0x32ff, 0xc18b,		0x21, 0
	.dw 0x3340, 0xc18b,	0x337f, 0xc18b,		0x21, 0
	.dw 0x33c0, 0xc18b,	0x33ff, 0xc18b,		0x21, 0
	.dw 0x3440, 0xc18b,	0x347f, 0xc18b,		0x21, 0
	.dw 0x34c0, 0xc18b,	0x34ff, 0xc18b,		0x21, 0
	.dw 0x3540, 0xc18b,	0x357f, 0xc18b,		0x21, 0
	.dw 0x35c0, 0xc18b,	0x35ff, 0xc18b,		0x21, 0
	.dw 0x3640, 0xc18b,	0x367f, 0xc18b,		0x21, 0
	.dw 0x36c0, 0xc18b,	0x36ff, 0xc18b,		0x21, 0
	.dw 0x3740, 0xc18b,	0x377f, 0xc18b,		0x21, 0
	.dw 0x37c0, 0xc18b,	0x37ff, 0xc18b,		0x21, 0
	.dw 0x3840, 0xc18b,	0x387f, 0xc18b,		0x21, 0
	.dw 0x38c0, 0xc18b,	0x38ff, 0xc18b,		0x21, 0
	.dw 0x3940, 0xc18b,	0x397f, 0xc18b,		0x21, 0
	.dw 0x39c0, 0xc18b,	0xffff, 0xc18b,		0x21, 0
	.dw 0x0040, 0xc18c,	0x007f, 0xc18c,		0x21, 0
	.dw 0x00c0, 0xc18c,	0x00ff, 0xc18c,		0x21, 0
	.dw 0x0140, 0xc18c,	0x017f, 0xc18c,		0x21, 0
	.dw 0x01c0, 0xc18c,	0x01ff, 0xc18c,		0x21, 0
	.dw 0x0240, 0xc18c,	0x027f, 0xc18c,		0x21, 0
	.dw 0x02c0, 0xc18c,	0x02ff, 0xc18c,		0x21, 0
	.dw 0x0340, 0xc18c,	0x037f, 0xc18c,		0x21, 0
	.dw 0x03c0, 0xc18c,	0x03ff, 0xc18c,		0x21, 0
	.dw 0x0440, 0xc18c,	0x047f, 0xc18c,		0x21, 0
	.dw 0x04c0, 0xc18c,	0x04ff, 0xc18c,		0x21, 0
	.dw 0x0540, 0xc18c,	0x057f, 0xc18c,		0x21, 0
	.dw 0x05c0, 0xc18c,	0x05ff, 0xc18c,		0x21, 0
	.dw 0x0640, 0xc18c,	0x067f, 0xc18c,		0x21, 0
	.dw 0x06c0, 0xc18c,	0x06ff, 0xc18c,		0x21, 0
	.dw 0x0740, 0xc18c,	0x077f, 0xc18c,		0x21, 0
	.dw 0x07c0, 0xc18c,	0x07ff, 0xc18c,		0x21, 0
	.dw 0x0840, 0xc18c,	0x087f, 0xc18c,		0x21, 0
	.dw 0x08c0, 0xc18c,	0x08ff, 0xc18c,		0x21, 0
	.dw 0x0940, 0xc18c,	0x097f, 0xc18c,		0x21, 0
	.dw 0x09c0, 0xc18c,	0x09ff, 0xc18c,		0x21, 0
	.dw 0x0a40, 0xc18c,	0x0a7f, 0xc18c,		0x21, 0
	.dw 0x0ac0, 0xc18c,	0x0aff, 0xc18c,		0x21, 0
	.dw 0x0b40, 0xc18c,	0x0b7f, 0xc18c,		0x21, 0
	.dw 0x0bc0, 0xc18c,	0x0bff, 0xc18c,		0x21, 0
	.dw 0x0c40, 0xc18c,	0x0c7f, 0xc18c,		0x21, 0
	.dw 0x0cc0, 0xc18c,	0x0cff, 0xc18c,		0x21, 0
	.dw 0x0d40, 0xc18c,	0x0d7f, 0xc18c,		0x21, 0
	.dw 0x0dc0, 0xc18c,	0x0dff, 0xc18c,		0x21, 0
	.dw 0x0e40, 0xc18c,	0x0e7f, 0xc18c,		0x21, 0
	.dw 0x0ec0, 0xc18c,	0x0eff, 0xc18c,		0x21, 0
	.dw 0x0f40, 0xc18c,	0x0f7f, 0xc18c,		0x21, 0
	.dw 0x0fc0, 0xc18c,	0x0fff, 0xc18c,		0x21, 0
	.dw 0x1040, 0xc18c,	0x107f, 0xc18c,		0x21, 0
	.dw 0x10c0, 0xc18c,	0x10ff, 0xc18c,		0x21, 0
	.dw 0x1140, 0xc18c,	0x117f, 0xc18c,		0x21, 0
	.dw 0x11c0, 0xc18c,	0x11ff, 0xc18c,		0x21, 0
	.dw 0x1240, 0xc18c,	0x127f, 0xc18c,		0x21, 0
	.dw 0x12c0, 0xc18c,	0x12ff, 0xc18c,		0x21, 0
	.dw 0x1340, 0xc18c,	0x137f, 0xc18c,		0x21, 0
	.dw 0x13c0, 0xc18c,	0x13ff, 0xc18c,		0x21, 0
	.dw 0x1440, 0xc18c,	0x147f, 0xc18c,		0x21, 0
	.dw 0x14c0, 0xc18c,	0x14ff, 0xc18c,		0x21, 0
	.dw 0x1540, 0xc18c,	0x157f, 0xc18c,		0x21, 0
	.dw 0x15c0, 0xc18c,	0x15ff, 0xc18c,		0x21, 0
	.dw 0x1640, 0xc18c,	0x167f, 0xc18c,		0x21, 0
	.dw 0x16c0, 0xc18c,	0x16ff, 0xc18c,		0x21, 0
	.dw 0x1740, 0xc18c,	0x177f, 0xc18c,		0x21, 0
	.dw 0x17c0, 0xc18c,	0x17ff, 0xc18c,		0x21, 0
	.dw 0x1840, 0xc18c,	0x187f, 0xc18c,		0x21, 0
	.dw 0x18c0, 0xc18c,	0x18ff, 0xc18c,		0x21, 0
	.dw 0x1940, 0xc18c,	0x197f, 0xc18c,		0x21, 0
	.dw 0x19c0, 0xc18c,	0x1fff, 0xc18c,		0x21, 0
	.dw 0x2040, 0xc18c,	0x207f, 0xc18c,		0x21, 0
	.dw 0x20c0, 0xc18c,	0x20ff, 0xc18c,		0x21, 0
	.dw 0x2140, 0xc18c,	0x217f, 0xc18c,		0x21, 0
	.dw 0x21c0, 0xc18c,	0x21ff, 0xc18c,		0x21, 0
	.dw 0x2240, 0xc18c,	0x227f, 0xc18c,		0x21, 0
	.dw 0x22c0, 0xc18c,	0x22ff, 0xc18c,		0x21, 0
	.dw 0x2340, 0xc18c,	0x237f, 0xc18c,		0x21, 0
	.dw 0x23c0, 0xc18c,	0x23ff, 0xc18c,		0x21, 0
	.dw 0x2440, 0xc18c,	0x247f, 0xc18c,		0x21, 0
	.dw 0x24c0, 0xc18c,	0x24ff, 0xc18c,		0x21, 0
	.dw 0x2540, 0xc18c,	0x257f, 0xc18c,		0x21, 0
	.dw 0x25c0, 0xc18c,	0x25ff, 0xc18c,		0x21, 0
	.dw 0x2640, 0xc18c,	0x267f, 0xc18c,		0x21, 0
	.dw 0x26c0, 0xc18c,	0x26ff, 0xc18c,		0x21, 0
	.dw 0x2740, 0xc18c,	0x277f, 0xc18c,		0x21, 0
	.dw 0x27c0, 0xc18c,	0x27ff, 0xc18c,		0x21, 0
	.dw 0x2840, 0xc18c,	0x287f, 0xc18c,		0x21, 0
	.dw 0x28c0, 0xc18c,	0x28ff, 0xc18c,		0x21, 0
	.dw 0x2940, 0xc18c,	0x297f, 0xc18c,		0x21, 0
	.dw 0x29c0, 0xc18c,	0x29ff, 0xc18c,		0x21, 0
	.dw 0x2a40, 0xc18c,	0x2a7f, 0xc18c,		0x21, 0
	.dw 0x2ac0, 0xc18c,	0x2aff, 0xc18c,		0x21, 0
	.dw 0x2b40, 0xc18c,	0x2b7f, 0xc18c,		0x21, 0
	.dw 0x2bc0, 0xc18c,	0x2bff, 0xc18c,		0x21, 0
	.dw 0x2c40, 0xc18c,	0x2c7f, 0xc18c,		0x21, 0
	.dw 0x2cc0, 0xc18c,	0x2cff, 0xc18c,		0x21, 0
	.dw 0x2d40, 0xc18c,	0x2d7f, 0xc18c,		0x21, 0
	.dw 0x2dc0, 0xc18c,	0x2dff, 0xc18c,		0x21, 0
	.dw 0x2e40, 0xc18c,	0x2e7f, 0xc18c,		0x21, 0
	.dw 0x2ec0, 0xc18c,	0x2eff, 0xc18c,		0x21, 0
	.dw 0x2f40, 0xc18c,	0x2f7f, 0xc18c,		0x21, 0
	.dw 0x2fc0, 0xc18c,	0x2fff, 0xc18c,		0x21, 0
	.dw 0x3040, 0xc18c,	0x307f, 0xc18c,		0x21, 0
	.dw 0x30c0, 0xc18c,	0x30ff, 0xc18c,		0x21, 0
	.dw 0x3140, 0xc18c,	0x317f, 0xc18c,		0x21, 0
	.dw 0x31c0, 0xc18c,	0x31ff, 0xc18c,		0x21, 0
	.dw 0x3240, 0xc18c,	0x327f, 0xc18c,		0x21, 0
	.dw 0x32c0, 0xc18c,	0x32ff, 0xc18c,		0x21, 0
	.dw 0x3340, 0xc18c,	0x337f, 0xc18c,		0x21, 0
	.dw 0x33c0, 0xc18c,	0x33ff, 0xc18c,		0x21, 0
	.dw 0x3440, 0xc18c,	0x347f, 0xc18c,		0x21, 0
	.dw 0x34c0, 0xc18c,	0x34ff, 0xc18c,		0x21, 0
	.dw 0x3540, 0xc18c,	0x357f, 0xc18c,		0x21, 0
	.dw 0x35c0, 0xc18c,	0x35ff, 0xc18c,		0x21, 0
	.dw 0x3640, 0xc18c,	0x367f, 0xc18c,		0x21, 0
	.dw 0x36c0, 0xc18c,	0x36ff, 0xc18c,		0x21, 0
	.dw 0x3740, 0xc18c,	0x377f, 0xc18c,		0x21, 0
	.dw 0x37c0, 0xc18c,	0x37ff, 0xc18c,		0x21, 0
	.dw 0x3840, 0xc18c,	0x387f, 0xc18c,		0x21, 0
	.dw 0x38c0, 0xc18c,	0x38ff, 0xc18c,		0x21, 0
	.dw 0x3940, 0xc18c,	0x397f, 0xc18c,		0x21, 0
	.dw 0x39c0, 0xc18c,	0x3fff, 0xc18c,		0x21, 0
	.dw 0x4040, 0xc18c,	0x407f, 0xc18c,		0x21, 0
	.dw 0x40c0, 0xc18c,	0x40ff, 0xc18c,		0x21, 0
	.dw 0x4140, 0xc18c,	0x417f, 0xc18c,		0x21, 0
	.dw 0x41c0, 0xc18c,	0x41ff, 0xc18c,		0x21, 0
	.dw 0x4240, 0xc18c,	0x427f, 0xc18c,		0x21, 0
	.dw 0x42c0, 0xc18c,	0x42ff, 0xc18c,		0x21, 0
	.dw 0x4340, 0xc18c,	0x437f, 0xc18c,		0x21, 0
	.dw 0x43c0, 0xc18c,	0x43ff, 0xc18c,		0x21, 0
	.dw 0x4440, 0xc18c,	0x447f, 0xc18c,		0x21, 0
	.dw 0x44c0, 0xc18c,	0x44ff, 0xc18c,		0x21, 0
	.dw 0x4540, 0xc18c,	0x457f, 0xc18c,		0x21, 0
	.dw 0x45c0, 0xc18c,	0x45ff, 0xc18c,		0x21, 0
	.dw 0x4640, 0xc18c,	0x467f, 0xc18c,		0x21, 0
	.dw 0x46c0, 0xc18c,	0x46ff, 0xc18c,		0x21, 0
	.dw 0x4740, 0xc18c,	0x477f, 0xc18c,		0x21, 0
	.dw 0x47c0, 0xc18c,	0x47ff, 0xc18c,		0x21, 0
	.dw 0x4840, 0xc18c,	0x487f, 0xc18c,		0x21, 0
	.dw 0x48c0, 0xc18c,	0x48ff, 0xc18c,		0x21, 0
	.dw 0x4940, 0xc18c,	0x497f, 0xc18c,		0x21, 0
	.dw 0x49c0, 0xc18c,	0x49ff, 0xc18c,		0x21, 0
	.dw 0x4a40, 0xc18c,	0x4a7f, 0xc18c,		0x21, 0
	.dw 0x4ac0, 0xc18c,	0x4aff, 0xc18c,		0x21, 0
	.dw 0x4b40, 0xc18c,	0x4b7f, 0xc18c,		0x21, 0
	.dw 0x4bc0, 0xc18c,	0x4bff, 0xc18c,		0x21, 0
	.dw 0x4c40, 0xc18c,	0x4c7f, 0xc18c,		0x21, 0
	.dw 0x4cc0, 0xc18c,	0x4cff, 0xc18c,		0x21, 0
	.dw 0x4d40, 0xc18c,	0x4d7f, 0xc18c,		0x21, 0
	.dw 0x4dc0, 0xc18c,	0x4dff, 0xc18c,		0x21, 0
	.dw 0x4e40, 0xc18c,	0x4e7f, 0xc18c,		0x21, 0
	.dw 0x4ec0, 0xc18c,	0x4eff, 0xc18c,		0x21, 0
	.dw 0x4f40, 0xc18c,	0x4f7f, 0xc18c,		0x21, 0
	.dw 0x4fc0, 0xc18c,	0x4fff, 0xc18c,		0x21, 0
	.dw 0x5040, 0xc18c,	0x507f, 0xc18c,		0x21, 0
	.dw 0x50c0, 0xc18c,	0x50ff, 0xc18c,		0x21, 0
	.dw 0x5140, 0xc18c,	0x517f, 0xc18c,		0x21, 0
	.dw 0x51c0, 0xc18c,	0x51ff, 0xc18c,		0x21, 0
	.dw 0x5240, 0xc18c,	0x527f, 0xc18c,		0x21, 0
	.dw 0x52c0, 0xc18c,	0x52ff, 0xc18c,		0x21, 0
	.dw 0x5340, 0xc18c,	0x537f, 0xc18c,		0x21, 0
	.dw 0x53c0, 0xc18c,	0x53ff, 0xc18c,		0x21, 0
	.dw 0x5440, 0xc18c,	0x547f, 0xc18c,		0x21, 0
	.dw 0x54c0, 0xc18c,	0x54ff, 0xc18c,		0x21, 0
	.dw 0x5540, 0xc18c,	0x557f, 0xc18c,		0x21, 0
	.dw 0x55c0, 0xc18c,	0x55ff, 0xc18c,		0x21, 0
	.dw 0x5640, 0xc18c,	0x567f, 0xc18c,		0x21, 0
	.dw 0x56c0, 0xc18c,	0x56ff, 0xc18c,		0x21, 0
	.dw 0x5740, 0xc18c,	0x577f, 0xc18c,		0x21, 0
	.dw 0x57c0, 0xc18c,	0x57ff, 0xc18c,		0x21, 0
	.dw 0x5840, 0xc18c,	0x587f, 0xc18c,		0x21, 0
	.dw 0x58c0, 0xc18c,	0x58ff, 0xc18c,		0x21, 0
	.dw 0x5940, 0xc18c,	0x597f, 0xc18c,		0x21, 0
	.dw 0x59c0, 0xc18c,	0x5fff, 0xc18c,		0x21, 0
	.dw 0x6040, 0xc18c,	0x607f, 0xc18c,		0x21, 0
	.dw 0x60c0, 0xc18c,	0x60ff, 0xc18c,		0x21, 0
	.dw 0x6140, 0xc18c,	0x617f, 0xc18c,		0x21, 0
	.dw 0x61c0, 0xc18c,	0x61ff, 0xc18c,		0x21, 0
	.dw 0x6240, 0xc18c,	0x627f, 0xc18c,		0x21, 0
	.dw 0x62c0, 0xc18c,	0x62ff, 0xc18c,		0x21, 0
	.dw 0x6340, 0xc18c,	0x637f, 0xc18c,		0x21, 0
	.dw 0x63c0, 0xc18c,	0x63ff, 0xc18c,		0x21, 0
	.dw 0x6440, 0xc18c,	0x647f, 0xc18c,		0x21, 0
	.dw 0x64c0, 0xc18c,	0x64ff, 0xc18c,		0x21, 0
	.dw 0x6540, 0xc18c,	0x657f, 0xc18c,		0x21, 0
	.dw 0x65c0, 0xc18c,	0x65ff, 0xc18c,		0x21, 0
	.dw 0x6640, 0xc18c,	0x667f, 0xc18c,		0x21, 0
	.dw 0x66c0, 0xc18c,	0x66ff, 0xc18c,		0x21, 0
	.dw 0x6740, 0xc18c,	0x677f, 0xc18c,		0x21, 0
	.dw 0x67c0, 0xc18c,	0x67ff, 0xc18c,		0x21, 0
	.dw 0x6840, 0xc18c,	0x687f, 0xc18c,		0x21, 0
	.dw 0x68c0, 0xc18c,	0x68ff, 0xc18c,		0x21, 0
	.dw 0x6940, 0xc18c,	0x697f, 0xc18c,		0x21, 0
	.dw 0x69c0, 0xc18c,	0x69ff, 0xc18c,		0x21, 0
	.dw 0x6a40, 0xc18c,	0x6a7f, 0xc18c,		0x21, 0
	.dw 0x6ac0, 0xc18c,	0x6aff, 0xc18c,		0x21, 0
	.dw 0x6b40, 0xc18c,	0x6b7f, 0xc18c,		0x21, 0
	.dw 0x6bc0, 0xc18c,	0x6bff, 0xc18c,		0x21, 0
	.dw 0x6c40, 0xc18c,	0x6c7f, 0xc18c,		0x21, 0
	.dw 0x6cc0, 0xc18c,	0x6cff, 0xc18c,		0x21, 0
	.dw 0x6d40, 0xc18c,	0x6d7f, 0xc18c,		0x21, 0
	.dw 0x6dc0, 0xc18c,	0x6dff, 0xc18c,		0x21, 0
	.dw 0x6e40, 0xc18c,	0x6e7f, 0xc18c,		0x21, 0
	.dw 0x6ec0, 0xc18c,	0x6eff, 0xc18c,		0x21, 0
	.dw 0x6f40, 0xc18c,	0x6f7f, 0xc18c,		0x21, 0
	.dw 0x6fc0, 0xc18c,	0x6fff, 0xc18c,		0x21, 0
	.dw 0x7040, 0xc18c,	0x707f, 0xc18c,		0x21, 0
	.dw 0x70c0, 0xc18c,	0x70ff, 0xc18c,		0x21, 0
	.dw 0x7140, 0xc18c,	0x717f, 0xc18c,		0x21, 0
	.dw 0x71c0, 0xc18c,	0x71ff, 0xc18c,		0x21, 0
	.dw 0x7240, 0xc18c,	0x727f, 0xc18c,		0x21, 0
	.dw 0x72c0, 0xc18c,	0x72ff, 0xc18c,		0x21, 0
	.dw 0x7340, 0xc18c,	0x737f, 0xc18c,		0x21, 0
	.dw 0x73c0, 0xc18c,	0x73ff, 0xc18c,		0x21, 0
	.dw 0x7440, 0xc18c,	0x747f, 0xc18c,		0x21, 0
	.dw 0x74c0, 0xc18c,	0x74ff, 0xc18c,		0x21, 0
	.dw 0x7540, 0xc18c,	0x757f, 0xc18c,		0x21, 0
	.dw 0x75c0, 0xc18c,	0x75ff, 0xc18c,		0x21, 0
	.dw 0x7640, 0xc18c,	0x767f, 0xc18c,		0x21, 0
	.dw 0x76c0, 0xc18c,	0x76ff, 0xc18c,		0x21, 0
	.dw 0x7740, 0xc18c,	0x777f, 0xc18c,		0x21, 0
	.dw 0x77c0, 0xc18c,	0x77ff, 0xc18c,		0x21, 0
	.dw 0x7840, 0xc18c,	0x787f, 0xc18c,		0x21, 0
	.dw 0x78c0, 0xc18c,	0x78ff, 0xc18c,		0x21, 0
	.dw 0x7940, 0xc18c,	0x797f, 0xc18c,		0x21, 0
	.dw 0x79c0, 0xc18c,	0x7fff, 0xc18c,		0x21, 0
	.dw 0x8040, 0xc18c,	0x807f, 0xc18c,		0x21, 0
	.dw 0x80c0, 0xc18c,	0x80ff, 0xc18c,		0x21, 0
	.dw 0x8140, 0xc18c,	0x817f, 0xc18c,		0x21, 0
	.dw 0x81c0, 0xc18c,	0x81ff, 0xc18c,		0x21, 0
	.dw 0x8240, 0xc18c,	0x827f, 0xc18c,		0x21, 0
	.dw 0x82c0, 0xc18c,	0x82ff, 0xc18c,		0x21, 0
	.dw 0x8340, 0xc18c,	0x837f, 0xc18c,		0x21, 0
	.dw 0x83c0, 0xc18c,	0x83ff, 0xc18c,		0x21, 0
	.dw 0x8440, 0xc18c,	0x847f, 0xc18c,		0x21, 0
	.dw 0x84c0, 0xc18c,	0x84ff, 0xc18c,		0x21, 0
	.dw 0x8540, 0xc18c,	0x857f, 0xc18c,		0x21, 0
	.dw 0x85c0, 0xc18c,	0x85ff, 0xc18c,		0x21, 0
	.dw 0x8640, 0xc18c,	0x867f, 0xc18c,		0x21, 0
	.dw 0x86c0, 0xc18c,	0x86ff, 0xc18c,		0x21, 0
	.dw 0x8740, 0xc18c,	0x877f, 0xc18c,		0x21, 0
	.dw 0x87c0, 0xc18c,	0x87ff, 0xc18c,		0x21, 0
	.dw 0x8840, 0xc18c,	0x887f, 0xc18c,		0x21, 0
	.dw 0x88c0, 0xc18c,	0x88ff, 0xc18c,		0x21, 0
	.dw 0x8940, 0xc18c,	0x897f, 0xc18c,		0x21, 0
	.dw 0x89c0, 0xc18c,	0x89ff, 0xc18c,		0x21, 0
	.dw 0x8a40, 0xc18c,	0x8a7f, 0xc18c,		0x21, 0
	.dw 0x8ac0, 0xc18c,	0x8aff, 0xc18c,		0x21, 0
	.dw 0x8b40, 0xc18c,	0x8b7f, 0xc18c,		0x21, 0
	.dw 0x8bc0, 0xc18c,	0x8bff, 0xc18c,		0x21, 0
	.dw 0x8c40, 0xc18c,	0x8c7f, 0xc18c,		0x21, 0
	.dw 0x8cc0, 0xc18c,	0x8cff, 0xc18c,		0x21, 0
	.dw 0x8d40, 0xc18c,	0x8d7f, 0xc18c,		0x21, 0
	.dw 0x8dc0, 0xc18c,	0x8dff, 0xc18c,		0x21, 0
	.dw 0x8e40, 0xc18c,	0x8e7f, 0xc18c,		0x21, 0
	.dw 0x8ec0, 0xc18c,	0x8eff, 0xc18c,		0x21, 0
	.dw 0x8f40, 0xc18c,	0x8f7f, 0xc18c,		0x21, 0
	.dw 0x8fc0, 0xc18c,	0x8fff, 0xc18c,		0x21, 0
	.dw 0x9040, 0xc18c,	0x907f, 0xc18c,		0x21, 0
	.dw 0x90c0, 0xc18c,	0x90ff, 0xc18c,		0x21, 0
	.dw 0x9140, 0xc18c,	0x917f, 0xc18c,		0x21, 0
	.dw 0x91c0, 0xc18c,	0x91ff, 0xc18c,		0x21, 0
	.dw 0x9240, 0xc18c,	0x927f, 0xc18c,		0x21, 0
	.dw 0x92c0, 0xc18c,	0x92ff, 0xc18c,		0x21, 0
	.dw 0x9340, 0xc18c,	0x937f, 0xc18c,		0x21, 0
	.dw 0x93c0, 0xc18c,	0x93ff, 0xc18c,		0x21, 0
	.dw 0x9440, 0xc18c,	0x947f, 0xc18c,		0x21, 0
	.dw 0x94c0, 0xc18c,	0x94ff, 0xc18c,		0x21, 0
	.dw 0x9540, 0xc18c,	0x957f, 0xc18c,		0x21, 0
	.dw 0x95c0, 0xc18c,	0x95ff, 0xc18c,		0x21, 0
	.dw 0x9640, 0xc18c,	0x967f, 0xc18c,		0x21, 0
	.dw 0x96c0, 0xc18c,	0x96ff, 0xc18c,		0x21, 0
	.dw 0x9740, 0xc18c,	0x977f, 0xc18c,		0x21, 0
	.dw 0x97c0, 0xc18c,	0x97ff, 0xc18c,		0x21, 0
	.dw 0x9840, 0xc18c,	0x987f, 0xc18c,		0x21, 0
	.dw 0x98c0, 0xc18c,	0x98ff, 0xc18c,		0x21, 0
	.dw 0x9940, 0xc18c,	0x997f, 0xc18c,		0x21, 0
	.dw 0x99c0, 0xc18c,	0x9fff, 0xc18c,		0x21, 0
	.dw 0xa040, 0xc18c,	0xa07f, 0xc18c,		0x21, 0
	.dw 0xa0c0, 0xc18c,	0xa0ff, 0xc18c,		0x21, 0
	.dw 0xa140, 0xc18c,	0xa17f, 0xc18c,		0x21, 0
	.dw 0xa1c0, 0xc18c,	0xa1ff, 0xc18c,		0x21, 0
	.dw 0xa240, 0xc18c,	0xa27f, 0xc18c,		0x21, 0
	.dw 0xa2c0, 0xc18c,	0xa2ff, 0xc18c,		0x21, 0
	.dw 0xa340, 0xc18c,	0xa37f, 0xc18c,		0x21, 0
	.dw 0xa3c0, 0xc18c,	0xa3ff, 0xc18c,		0x21, 0
	.dw 0xa440, 0xc18c,	0xa47f, 0xc18c,		0x21, 0
	.dw 0xa4c0, 0xc18c,	0xa4ff, 0xc18c,		0x21, 0
	.dw 0xa540, 0xc18c,	0xa57f, 0xc18c,		0x21, 0
	.dw 0xa5c0, 0xc18c,	0xa5ff, 0xc18c,		0x21, 0
	.dw 0xa640, 0xc18c,	0xa67f, 0xc18c,		0x21, 0
	.dw 0xa6c0, 0xc18c,	0xa6ff, 0xc18c,		0x21, 0
	.dw 0xa740, 0xc18c,	0xa77f, 0xc18c,		0x21, 0
	.dw 0xa7c0, 0xc18c,	0xa7ff, 0xc18c,		0x21, 0
	.dw 0xa840, 0xc18c,	0xa87f, 0xc18c,		0x21, 0
	.dw 0xa8c0, 0xc18c,	0xa8ff, 0xc18c,		0x21, 0
	.dw 0xa940, 0xc18c,	0xa97f, 0xc18c,		0x21, 0
	.dw 0xa9c0, 0xc18c,	0xa9ff, 0xc18c,		0x21, 0
	.dw 0xaa40, 0xc18c,	0xaa7f, 0xc18c,		0x21, 0
	.dw 0xaac0, 0xc18c,	0xaaff, 0xc18c,		0x21, 0
	.dw 0xab40, 0xc18c,	0xab7f, 0xc18c,		0x21, 0
	.dw 0xabc0, 0xc18c,	0xabff, 0xc18c,		0x21, 0
	.dw 0xac40, 0xc18c,	0xac7f, 0xc18c,		0x21, 0
	.dw 0xacc0, 0xc18c,	0xacff, 0xc18c,		0x21, 0
	.dw 0xad40, 0xc18c,	0xad7f, 0xc18c,		0x21, 0
	.dw 0xadc0, 0xc18c,	0xadff, 0xc18c,		0x21, 0
	.dw 0xae40, 0xc18c,	0xae7f, 0xc18c,		0x21, 0
	.dw 0xaec0, 0xc18c,	0xaeff, 0xc18c,		0x21, 0
	.dw 0xaf40, 0xc18c,	0xaf7f, 0xc18c,		0x21, 0
	.dw 0xafc0, 0xc18c,	0xafff, 0xc18c,		0x21, 0
	.dw 0xb040, 0xc18c,	0xb07f, 0xc18c,		0x21, 0
	.dw 0xb0c0, 0xc18c,	0xb0ff, 0xc18c,		0x21, 0
	.dw 0xb140, 0xc18c,	0xb17f, 0xc18c,		0x21, 0
	.dw 0xb1c0, 0xc18c,	0xb1ff, 0xc18c,		0x21, 0
	.dw 0xb240, 0xc18c,	0xb27f, 0xc18c,		0x21, 0
	.dw 0xb2c0, 0xc18c,	0xb2ff, 0xc18c,		0x21, 0
	.dw 0xb340, 0xc18c,	0xb37f, 0xc18c,		0x21, 0
	.dw 0xb3c0, 0xc18c,	0xb3ff, 0xc18c,		0x21, 0
	.dw 0xb440, 0xc18c,	0xb47f, 0xc18c,		0x21, 0
	.dw 0xb4c0, 0xc18c,	0xb4ff, 0xc18c,		0x21, 0
	.dw 0xb540, 0xc18c,	0xb57f, 0xc18c,		0x21, 0
	.dw 0xb5c0, 0xc18c,	0xb5ff, 0xc18c,		0x21, 0
	.dw 0xb640, 0xc18c,	0xb67f, 0xc18c,		0x21, 0
	.dw 0xb6c0, 0xc18c,	0xb6ff, 0xc18c,		0x21, 0
	.dw 0xb740, 0xc18c,	0xb77f, 0xc18c,		0x21, 0
	.dw 0xb7c0, 0xc18c,	0xb7ff, 0xc18c,		0x21, 0
	.dw 0xb840, 0xc18c,	0xb87f, 0xc18c,		0x21, 0
	.dw 0xb8c0, 0xc18c,	0xb8ff, 0xc18c,		0x21, 0
	.dw 0xb940, 0xc18c,	0xb97f, 0xc18c,		0x21, 0
	.dw 0xb9c0, 0xc18c,	0xbfff, 0xc18c,		0x21, 0
	.dw 0xc040, 0xc18c,	0xc07f, 0xc18c,		0x21, 0
	.dw 0xc0c0, 0xc18c,	0xc0ff, 0xc18c,		0x21, 0
	.dw 0xc140, 0xc18c,	0xc17f, 0xc18c,		0x21, 0
	.dw 0xc1c0, 0xc18c,	0xc1ff, 0xc18c,		0x21, 0
	.dw 0xc240, 0xc18c,	0xc27f, 0xc18c,		0x21, 0
	.dw 0xc2c0, 0xc18c,	0xc2ff, 0xc18c,		0x21, 0
	.dw 0xc340, 0xc18c,	0xc37f, 0xc18c,		0x21, 0
	.dw 0xc3c0, 0xc18c,	0xc3ff, 0xc18c,		0x21, 0
	.dw 0xc440, 0xc18c,	0xc47f, 0xc18c,		0x21, 0
	.dw 0xc4c0, 0xc18c,	0xc4ff, 0xc18c,		0x21, 0
	.dw 0xc540, 0xc18c,	0xc57f, 0xc18c,		0x21, 0
	.dw 0xc5c0, 0xc18c,	0xc5ff, 0xc18c,		0x21, 0
	.dw 0xc640, 0xc18c,	0xc67f, 0xc18c,		0x21, 0
	.dw 0xc6c0, 0xc18c,	0xc6ff, 0xc18c,		0x21, 0
	.dw 0xc740, 0xc18c,	0xc77f, 0xc18c,		0x21, 0
	.dw 0xc7c0, 0xc18c,	0xc7ff, 0xc18c,		0x21, 0
	.dw 0xc840, 0xc18c,	0xc87f, 0xc18c,		0x21, 0
	.dw 0xc8c0, 0xc18c,	0xc8ff, 0xc18c,		0x21, 0
	.dw 0xc940, 0xc18c,	0xc97f, 0xc18c,		0x21, 0
	.dw 0xc9c0, 0xc18c,	0xc9ff, 0xc18c,		0x21, 0
	.dw 0xca40, 0xc18c,	0xca7f, 0xc18c,		0x21, 0
	.dw 0xcac0, 0xc18c,	0xcaff, 0xc18c,		0x21, 0
	.dw 0xcb40, 0xc18c,	0xcb7f, 0xc18c,		0x21, 0
	.dw 0xcbc0, 0xc18c,	0xcbff, 0xc18c,		0x21, 0
	.dw 0xcc40, 0xc18c,	0xcc7f, 0xc18c,		0x21, 0
	.dw 0xccc0, 0xc18c,	0xccff, 0xc18c,		0x21, 0
	.dw 0xcd40, 0xc18c,	0xcd7f, 0xc18c,		0x21, 0
	.dw 0xcdc0, 0xc18c,	0xcdff, 0xc18c,		0x21, 0
	.dw 0xce40, 0xc18c,	0xce7f, 0xc18c,		0x21, 0
	.dw 0xcec0, 0xc18c,	0xceff, 0xc18c,		0x21, 0
	.dw 0xcf40, 0xc18c,	0xcf7f, 0xc18c,		0x21, 0
	.dw 0xcfc0, 0xc18c,	0xcfff, 0xc18c,		0x21, 0
	.dw 0xd040, 0xc18c,	0xd07f, 0xc18c,		0x21, 0
	.dw 0xd0c0, 0xc18c,	0xd0ff, 0xc18c,		0x21, 0
	.dw 0xd140, 0xc18c,	0xd17f, 0xc18c,		0x21, 0
	.dw 0xd1c0, 0xc18c,	0xd1ff, 0xc18c,		0x21, 0
	.dw 0xd240, 0xc18c,	0xd27f, 0xc18c,		0x21, 0
	.dw 0xd2c0, 0xc18c,	0xd2ff, 0xc18c,		0x21, 0
	.dw 0xd340, 0xc18c,	0xd37f, 0xc18c,		0x21, 0
	.dw 0xd3c0, 0xc18c,	0xd3ff, 0xc18c,		0x21, 0
	.dw 0xd440, 0xc18c,	0xd47f, 0xc18c,		0x21, 0
	.dw 0xd4c0, 0xc18c,	0xd4ff, 0xc18c,		0x21, 0
	.dw 0xd540, 0xc18c,	0xd57f, 0xc18c,		0x21, 0
	.dw 0xd5c0, 0xc18c,	0xd5ff, 0xc18c,		0x21, 0
	.dw 0xd640, 0xc18c,	0xd67f, 0xc18c,		0x21, 0
	.dw 0xd6c0, 0xc18c,	0xd6ff, 0xc18c,		0x21, 0
	.dw 0xd740, 0xc18c,	0xd77f, 0xc18c,		0x21, 0
	.dw 0xd7c0, 0xc18c,	0xd7ff, 0xc18c,		0x21, 0
	.dw 0xd840, 0xc18c,	0xd87f, 0xc18c,		0x21, 0
	.dw 0xd8c0, 0xc18c,	0xd8ff, 0xc18c,		0x21, 0
	.dw 0xd940, 0xc18c,	0xd97f, 0xc18c,		0x21, 0
	.dw 0xd9c0, 0xc18c,	0xdfff, 0xc18c,		0x21, 0
	.dw 0xe040, 0xc18c,	0xe07f, 0xc18c,		0x21, 0
	.dw 0xe0c0, 0xc18c,	0xe0ff, 0xc18c,		0x21, 0
	.dw 0xe140, 0xc18c,	0xe17f, 0xc18c,		0x21, 0
	.dw 0xe1c0, 0xc18c,	0xe1ff, 0xc18c,		0x21, 0
	.dw 0xe240, 0xc18c,	0xe27f, 0xc18c,		0x21, 0
	.dw 0xe2c0, 0xc18c,	0xe2ff, 0xc18c,		0x21, 0
	.dw 0xe340, 0xc18c,	0xe37f, 0xc18c,		0x21, 0
	.dw 0xe3c0, 0xc18c,	0xe3ff, 0xc18c,		0x21, 0
	.dw 0xe440, 0xc18c,	0xe47f, 0xc18c,		0x21, 0
	.dw 0xe4c0, 0xc18c,	0xe4ff, 0xc18c,		0x21, 0
	.dw 0xe540, 0xc18c,	0xe57f, 0xc18c,		0x21, 0
	.dw 0xe5c0, 0xc18c,	0xe5ff, 0xc18c,		0x21, 0
	.dw 0xe640, 0xc18c,	0xe67f, 0xc18c,		0x21, 0
	.dw 0xe6c0, 0xc18c,	0xe6ff, 0xc18c,		0x21, 0
	.dw 0xe740, 0xc18c,	0xe77f, 0xc18c,		0x21, 0
	.dw 0xe7c0, 0xc18c,	0xe7ff, 0xc18c,		0x21, 0
	.dw 0xe840, 0xc18c,	0xe87f, 0xc18c,		0x21, 0
	.dw 0xe8c0, 0xc18c,	0xe8ff, 0xc18c,		0x21, 0
	.dw 0xe940, 0xc18c,	0xe97f, 0xc18c,		0x21, 0
	.dw 0xe9c0, 0xc18c,	0xe9ff, 0xc18c,		0x21, 0
	.dw 0xea40, 0xc18c,	0xea7f, 0xc18c,		0x21, 0
	.dw 0xeac0, 0xc18c,	0xeaff, 0xc18c,		0x21, 0
	.dw 0xeb40, 0xc18c,	0xeb7f, 0xc18c,		0x21, 0
	.dw 0xebc0, 0xc18c,	0xebff, 0xc18c,		0x21, 0
	.dw 0xec40, 0xc18c,	0xec7f, 0xc18c,		0x21, 0
	.dw 0xecc0, 0xc18c,	0xecff, 0xc18c,		0x21, 0
	.dw 0xed40, 0xc18c,	0xed7f, 0xc18c,		0x21, 0
	.dw 0xedc0, 0xc18c,	0xedff, 0xc18c,		0x21, 0
	.dw 0xee40, 0xc18c,	0xee7f, 0xc18c,		0x21, 0
	.dw 0xeec0, 0xc18c,	0xeeff, 0xc18c,		0x21, 0
	.dw 0xef40, 0xc18c,	0xef7f, 0xc18c,		0x21, 0
	.dw 0xefc0, 0xc18c,	0xefff, 0xc18c,		0x21, 0
	.dw 0xf040, 0xc18c,	0xf07f, 0xc18c,		0x21, 0
	.dw 0xf0c0, 0xc18c,	0xf0ff, 0xc18c,		0x21, 0
	.dw 0xf140, 0xc18c,	0xf17f, 0xc18c,		0x21, 0
	.dw 0xf1c0, 0xc18c,	0xf1ff, 0xc18c,		0x21, 0
	.dw 0xf240, 0xc18c,	0xf27f, 0xc18c,		0x21, 0
	.dw 0xf2c0, 0xc18c,	0xf2ff, 0xc18c,		0x21, 0
	.dw 0xf340, 0xc18c,	0xf37f, 0xc18c,		0x21, 0
	.dw 0xf3c0, 0xc18c,	0xf3ff, 0xc18c,		0x21, 0
	.dw 0xf440, 0xc18c,	0xf47f, 0xc18c,		0x21, 0
	.dw 0xf4c0, 0xc18c,	0xf4ff, 0xc18c,		0x21, 0
	.dw 0xf540, 0xc18c,	0xf57f, 0xc18c,		0x21, 0
	.dw 0xf5c0, 0xc18c,	0xf5ff, 0xc18c,		0x21, 0
	.dw 0xf640, 0xc18c,	0xf67f, 0xc18c,		0x21, 0
	.dw 0xf6c0, 0xc18c,	0xf6ff, 0xc18c,		0x21, 0
	.dw 0xf740, 0xc18c,	0xf77f, 0xc18c,		0x21, 0
	.dw 0xf7c0, 0xc18c,	0xf7ff, 0xc18c,		0x21, 0
	.dw 0xf840, 0xc18c,	0xf87f, 0xc18c,		0x21, 0
	.dw 0xf8c0, 0xc18c,	0xf8ff, 0xc18c,		0x21, 0
	.dw 0xf940, 0xc18c,	0xf97f, 0xc18c,		0x21, 0
	.dw 0xf9c0, 0xc18c,	0xffff, 0xc18c,		0x21, 0
	.dw 0x0040, 0xc18d,	0x007f, 0xc18d,		0x21, 0
	.dw 0x00c0, 0xc18d,	0x00ff, 0xc18d,		0x21, 0
	.dw 0x0140, 0xc18d,	0x017f, 0xc18d,		0x21, 0
	.dw 0x01c0, 0xc18d,	0x01ff, 0xc18d,		0x21, 0
	.dw 0x0240, 0xc18d,	0x027f, 0xc18d,		0x21, 0
	.dw 0x02c0, 0xc18d,	0x02ff, 0xc18d,		0x21, 0
	.dw 0x0340, 0xc18d,	0x037f, 0xc18d,		0x21, 0
	.dw 0x03c0, 0xc18d,	0x03ff, 0xc18d,		0x21, 0
	.dw 0x0440, 0xc18d,	0x047f, 0xc18d,		0x21, 0
	.dw 0x04c0, 0xc18d,	0x04ff, 0xc18d,		0x21, 0
	.dw 0x0540, 0xc18d,	0x057f, 0xc18d,		0x21, 0
	.dw 0x05c0, 0xc18d,	0x05ff, 0xc18d,		0x21, 0
	.dw 0x0640, 0xc18d,	0x067f, 0xc18d,		0x21, 0
	.dw 0x06c0, 0xc18d,	0x06ff, 0xc18d,		0x21, 0
	.dw 0x0740, 0xc18d,	0x077f, 0xc18d,		0x21, 0
	.dw 0x07c0, 0xc18d,	0x07ff, 0xc18d,		0x21, 0
	.dw 0x0840, 0xc18d,	0x087f, 0xc18d,		0x21, 0
	.dw 0x08c0, 0xc18d,	0x08ff, 0xc18d,		0x21, 0
	.dw 0x0940, 0xc18d,	0x097f, 0xc18d,		0x21, 0
	.dw 0x09c0, 0xc18d,	0x09ff, 0xc18d,		0x21, 0
	.dw 0x0a40, 0xc18d,	0x0a7f, 0xc18d,		0x21, 0
	.dw 0x0ac0, 0xc18d,	0x0aff, 0xc18d,		0x21, 0
	.dw 0x0b40, 0xc18d,	0x0b7f, 0xc18d,		0x21, 0
	.dw 0x0bc0, 0xc18d,	0x0bff, 0xc18d,		0x21, 0
	.dw 0x0c40, 0xc18d,	0x0c7f, 0xc18d,		0x21, 0
	.dw 0x0cc0, 0xc18d,	0x0cff, 0xc18d,		0x21, 0
	.dw 0x0d40, 0xc18d,	0x0d7f, 0xc18d,		0x21, 0
	.dw 0x0dc0, 0xc18d,	0x0dff, 0xc18d,		0x21, 0
	.dw 0x0e40, 0xc18d,	0x0e7f, 0xc18d,		0x21, 0
	.dw 0x0ec0, 0xc18d,	0x0eff, 0xc18d,		0x21, 0
	.dw 0x0f40, 0xc18d,	0x0f7f, 0xc18d,		0x21, 0
	.dw 0x0fc0, 0xc18d,	0x0fff, 0xc18d,		0x21, 0
	.dw 0x1040, 0xc18d,	0x107f, 0xc18d,		0x21, 0
	.dw 0x10c0, 0xc18d,	0x10ff, 0xc18d,		0x21, 0
	.dw 0x1140, 0xc18d,	0x117f, 0xc18d,		0x21, 0
	.dw 0x11c0, 0xc18d,	0x11ff, 0xc18d,		0x21, 0
	.dw 0x1240, 0xc18d,	0x127f, 0xc18d,		0x21, 0
	.dw 0x12c0, 0xc18d,	0x12ff, 0xc18d,		0x21, 0
	.dw 0x1340, 0xc18d,	0x137f, 0xc18d,		0x21, 0
	.dw 0x13c0, 0xc18d,	0x13ff, 0xc18d,		0x21, 0
	.dw 0x1440, 0xc18d,	0x147f, 0xc18d,		0x21, 0
	.dw 0x14c0, 0xc18d,	0x14ff, 0xc18d,		0x21, 0
	.dw 0x1540, 0xc18d,	0x157f, 0xc18d,		0x21, 0
	.dw 0x15c0, 0xc18d,	0x15ff, 0xc18d,		0x21, 0
	.dw 0x1640, 0xc18d,	0x167f, 0xc18d,		0x21, 0
	.dw 0x16c0, 0xc18d,	0x16ff, 0xc18d,		0x21, 0
	.dw 0x1740, 0xc18d,	0x177f, 0xc18d,		0x21, 0
	.dw 0x17c0, 0xc18d,	0x17ff, 0xc18d,		0x21, 0
	.dw 0x1840, 0xc18d,	0x187f, 0xc18d,		0x21, 0
	.dw 0x18c0, 0xc18d,	0x18ff, 0xc18d,		0x21, 0
	.dw 0x1940, 0xc18d,	0x197f, 0xc18d,		0x21, 0
	.dw 0x19c0, 0xc18d,	0x1fff, 0xc18d,		0x21, 0
	.dw 0x2040, 0xc18d,	0x207f, 0xc18d,		0x21, 0
	.dw 0x20c0, 0xc18d,	0x20ff, 0xc18d,		0x21, 0
	.dw 0x2140, 0xc18d,	0x217f, 0xc18d,		0x21, 0
	.dw 0x21c0, 0xc18d,	0x21ff, 0xc18d,		0x21, 0
	.dw 0x2240, 0xc18d,	0x227f, 0xc18d,		0x21, 0
	.dw 0x22c0, 0xc18d,	0x22ff, 0xc18d,		0x21, 0
	.dw 0x2340, 0xc18d,	0x237f, 0xc18d,		0x21, 0
	.dw 0x23c0, 0xc18d,	0x23ff, 0xc18d,		0x21, 0
	.dw 0x2440, 0xc18d,	0x247f, 0xc18d,		0x21, 0
	.dw 0x24c0, 0xc18d,	0x24ff, 0xc18d,		0x21, 0
	.dw 0x2540, 0xc18d,	0x257f, 0xc18d,		0x21, 0
	.dw 0x25c0, 0xc18d,	0x25ff, 0xc18d,		0x21, 0
	.dw 0x2640, 0xc18d,	0x267f, 0xc18d,		0x21, 0
	.dw 0x26c0, 0xc18d,	0x26ff, 0xc18d,		0x21, 0
	.dw 0x2740, 0xc18d,	0x277f, 0xc18d,		0x21, 0
	.dw 0x27c0, 0xc18d,	0x27ff, 0xc18d,		0x21, 0
	.dw 0x2840, 0xc18d,	0x287f, 0xc18d,		0x21, 0
	.dw 0x28c0, 0xc18d,	0x28ff, 0xc18d,		0x21, 0
	.dw 0x2940, 0xc18d,	0x297f, 0xc18d,		0x21, 0
	.dw 0x29c0, 0xc18d,	0x29ff, 0xc18d,		0x21, 0
	.dw 0x2a40, 0xc18d,	0x2a7f, 0xc18d,		0x21, 0
	.dw 0x2ac0, 0xc18d,	0x2aff, 0xc18d,		0x21, 0
	.dw 0x2b40, 0xc18d,	0x2b7f, 0xc18d,		0x21, 0
	.dw 0x2bc0, 0xc18d,	0x2bff, 0xc18d,		0x21, 0
	.dw 0x2c40, 0xc18d,	0x2c7f, 0xc18d,		0x21, 0
	.dw 0x2cc0, 0xc18d,	0x2cff, 0xc18d,		0x21, 0
	.dw 0x2d40, 0xc18d,	0x2d7f, 0xc18d,		0x21, 0
	.dw 0x2dc0, 0xc18d,	0x2dff, 0xc18d,		0x21, 0
	.dw 0x2e40, 0xc18d,	0x2e7f, 0xc18d,		0x21, 0
	.dw 0x2ec0, 0xc18d,	0x2eff, 0xc18d,		0x21, 0
	.dw 0x2f40, 0xc18d,	0x2f7f, 0xc18d,		0x21, 0
	.dw 0x2fc0, 0xc18d,	0x2fff, 0xc18d,		0x21, 0
	.dw 0x3040, 0xc18d,	0x307f, 0xc18d,		0x21, 0
	.dw 0x30c0, 0xc18d,	0x30ff, 0xc18d,		0x21, 0
	.dw 0x3140, 0xc18d,	0x317f, 0xc18d,		0x21, 0
	.dw 0x31c0, 0xc18d,	0x31ff, 0xc18d,		0x21, 0
	.dw 0x3240, 0xc18d,	0x327f, 0xc18d,		0x21, 0
	.dw 0x32c0, 0xc18d,	0x32ff, 0xc18d,		0x21, 0
	.dw 0x3340, 0xc18d,	0x337f, 0xc18d,		0x21, 0
	.dw 0x33c0, 0xc18d,	0x33ff, 0xc18d,		0x21, 0
	.dw 0x3440, 0xc18d,	0x347f, 0xc18d,		0x21, 0
	.dw 0x34c0, 0xc18d,	0x34ff, 0xc18d,		0x21, 0
	.dw 0x3540, 0xc18d,	0x357f, 0xc18d,		0x21, 0
	.dw 0x35c0, 0xc18d,	0x35ff, 0xc18d,		0x21, 0
	.dw 0x3640, 0xc18d,	0x367f, 0xc18d,		0x21, 0
	.dw 0x36c0, 0xc18d,	0x36ff, 0xc18d,		0x21, 0
	.dw 0x3740, 0xc18d,	0x377f, 0xc18d,		0x21, 0
	.dw 0x37c0, 0xc18d,	0x37ff, 0xc18d,		0x21, 0
	.dw 0x3840, 0xc18d,	0x387f, 0xc18d,		0x21, 0
	.dw 0x38c0, 0xc18d,	0x38ff, 0xc18d,		0x21, 0
	.dw 0x3940, 0xc18d,	0x397f, 0xc18d,		0x21, 0
	.dw 0x39c0, 0xc18d,	0x3fff, 0xc18d,		0x21, 0
	.dw 0x4040, 0xc18d,	0x407f, 0xc18d,		0x21, 0
	.dw 0x40c0, 0xc18d,	0x40ff, 0xc18d,		0x21, 0
	.dw 0x4140, 0xc18d,	0x417f, 0xc18d,		0x21, 0
	.dw 0x41c0, 0xc18d,	0x41ff, 0xc18d,		0x21, 0
	.dw 0x4240, 0xc18d,	0x427f, 0xc18d,		0x21, 0
	.dw 0x42c0, 0xc18d,	0x42ff, 0xc18d,		0x21, 0
	.dw 0x4340, 0xc18d,	0x437f, 0xc18d,		0x21, 0
	.dw 0x43c0, 0xc18d,	0x43ff, 0xc18d,		0x21, 0
	.dw 0x4440, 0xc18d,	0x447f, 0xc18d,		0x21, 0
	.dw 0x44c0, 0xc18d,	0x44ff, 0xc18d,		0x21, 0
	.dw 0x4540, 0xc18d,	0x457f, 0xc18d,		0x21, 0
	.dw 0x45c0, 0xc18d,	0x45ff, 0xc18d,		0x21, 0
	.dw 0x4640, 0xc18d,	0x467f, 0xc18d,		0x21, 0
	.dw 0x46c0, 0xc18d,	0x46ff, 0xc18d,		0x21, 0
	.dw 0x4740, 0xc18d,	0x477f, 0xc18d,		0x21, 0
	.dw 0x47c0, 0xc18d,	0x47ff, 0xc18d,		0x21, 0
	.dw 0x4840, 0xc18d,	0x487f, 0xc18d,		0x21, 0
	.dw 0x48c0, 0xc18d,	0x48ff, 0xc18d,		0x21, 0
	.dw 0x4940, 0xc18d,	0x497f, 0xc18d,		0x21, 0
	.dw 0x49c0, 0xc18d,	0x49ff, 0xc18d,		0x21, 0
	.dw 0x4a40, 0xc18d,	0x4a7f, 0xc18d,		0x21, 0
	.dw 0x4ac0, 0xc18d,	0x4aff, 0xc18d,		0x21, 0
	.dw 0x4b40, 0xc18d,	0x4b7f, 0xc18d,		0x21, 0
	.dw 0x4bc0, 0xc18d,	0x4bff, 0xc18d,		0x21, 0
	.dw 0x4c40, 0xc18d,	0x4c7f, 0xc18d,		0x21, 0
	.dw 0x4cc0, 0xc18d,	0x4cff, 0xc18d,		0x21, 0
	.dw 0x4d40, 0xc18d,	0x4d7f, 0xc18d,		0x21, 0
	.dw 0x4dc0, 0xc18d,	0x4dff, 0xc18d,		0x21, 0
	.dw 0x4e40, 0xc18d,	0x4e7f, 0xc18d,		0x21, 0
	.dw 0x4ec0, 0xc18d,	0x4eff, 0xc18d,		0x21, 0
	.dw 0x4f40, 0xc18d,	0x4f7f, 0xc18d,		0x21, 0
	.dw 0x4fc0, 0xc18d,	0x4fff, 0xc18d,		0x21, 0
	.dw 0x5040, 0xc18d,	0x507f, 0xc18d,		0x21, 0
	.dw 0x50c0, 0xc18d,	0x50ff, 0xc18d,		0x21, 0
	.dw 0x5140, 0xc18d,	0x517f, 0xc18d,		0x21, 0
	.dw 0x51c0, 0xc18d,	0x51ff, 0xc18d,		0x21, 0
	.dw 0x5240, 0xc18d,	0x527f, 0xc18d,		0x21, 0
	.dw 0x52c0, 0xc18d,	0x52ff, 0xc18d,		0x21, 0
	.dw 0x5340, 0xc18d,	0x537f, 0xc18d,		0x21, 0
	.dw 0x53c0, 0xc18d,	0x53ff, 0xc18d,		0x21, 0
	.dw 0x5440, 0xc18d,	0x547f, 0xc18d,		0x21, 0
	.dw 0x54c0, 0xc18d,	0x54ff, 0xc18d,		0x21, 0
	.dw 0x5540, 0xc18d,	0x557f, 0xc18d,		0x21, 0
	.dw 0x55c0, 0xc18d,	0x55ff, 0xc18d,		0x21, 0
	.dw 0x5640, 0xc18d,	0x567f, 0xc18d,		0x21, 0
	.dw 0x56c0, 0xc18d,	0x56ff, 0xc18d,		0x21, 0
	.dw 0x5740, 0xc18d,	0x577f, 0xc18d,		0x21, 0
	.dw 0x57c0, 0xc18d,	0x57ff, 0xc18d,		0x21, 0
	.dw 0x5840, 0xc18d,	0x587f, 0xc18d,		0x21, 0
	.dw 0x58c0, 0xc18d,	0x58ff, 0xc18d,		0x21, 0
	.dw 0x5940, 0xc18d,	0x597f, 0xc18d,		0x21, 0
	.dw 0x59c0, 0xc18d,	0x5fff, 0xc18d,		0x21, 0
	.dw 0x6040, 0xc18d,	0x607f, 0xc18d,		0x21, 0
	.dw 0x60c0, 0xc18d,	0x60ff, 0xc18d,		0x21, 0
	.dw 0x6140, 0xc18d,	0x617f, 0xc18d,		0x21, 0
	.dw 0x61c0, 0xc18d,	0x61ff, 0xc18d,		0x21, 0
	.dw 0x6240, 0xc18d,	0x627f, 0xc18d,		0x21, 0
	.dw 0x62c0, 0xc18d,	0x62ff, 0xc18d,		0x21, 0
	.dw 0x6340, 0xc18d,	0x637f, 0xc18d,		0x21, 0
	.dw 0x63c0, 0xc18d,	0x63ff, 0xc18d,		0x21, 0
	.dw 0x6440, 0xc18d,	0x647f, 0xc18d,		0x21, 0
	.dw 0x64c0, 0xc18d,	0x64ff, 0xc18d,		0x21, 0
	.dw 0x6540, 0xc18d,	0x657f, 0xc18d,		0x21, 0
	.dw 0x65c0, 0xc18d,	0x65ff, 0xc18d,		0x21, 0
	.dw 0x6640, 0xc18d,	0x667f, 0xc18d,		0x21, 0
	.dw 0x66c0, 0xc18d,	0x66ff, 0xc18d,		0x21, 0
	.dw 0x6740, 0xc18d,	0x677f, 0xc18d,		0x21, 0
	.dw 0x67c0, 0xc18d,	0x67ff, 0xc18d,		0x21, 0
	.dw 0x6840, 0xc18d,	0x687f, 0xc18d,		0x21, 0
	.dw 0x68c0, 0xc18d,	0x68ff, 0xc18d,		0x21, 0
	.dw 0x6940, 0xc18d,	0x697f, 0xc18d,		0x21, 0
	.dw 0x69c0, 0xc18d,	0x69ff, 0xc18d,		0x21, 0
	.dw 0x6a40, 0xc18d,	0x6a7f, 0xc18d,		0x21, 0
	.dw 0x6ac0, 0xc18d,	0x6aff, 0xc18d,		0x21, 0
	.dw 0x6b40, 0xc18d,	0x6b7f, 0xc18d,		0x21, 0
	.dw 0x6bc0, 0xc18d,	0x6bff, 0xc18d,		0x21, 0
	.dw 0x6c40, 0xc18d,	0x6c7f, 0xc18d,		0x21, 0
	.dw 0x6cc0, 0xc18d,	0x6cff, 0xc18d,		0x21, 0
	.dw 0x6d40, 0xc18d,	0x6d7f, 0xc18d,		0x21, 0
	.dw 0x6dc0, 0xc18d,	0x6dff, 0xc18d,		0x21, 0
	.dw 0x6e40, 0xc18d,	0x6e7f, 0xc18d,		0x21, 0
	.dw 0x6ec0, 0xc18d,	0x6eff, 0xc18d,		0x21, 0
	.dw 0x6f40, 0xc18d,	0x6f7f, 0xc18d,		0x21, 0
	.dw 0x6fc0, 0xc18d,	0x6fff, 0xc18d,		0x21, 0
	.dw 0x7040, 0xc18d,	0x707f, 0xc18d,		0x21, 0
	.dw 0x70c0, 0xc18d,	0x70ff, 0xc18d,		0x21, 0
	.dw 0x7140, 0xc18d,	0x717f, 0xc18d,		0x21, 0
	.dw 0x71c0, 0xc18d,	0x71ff, 0xc18d,		0x21, 0
	.dw 0x7240, 0xc18d,	0x727f, 0xc18d,		0x21, 0
	.dw 0x72c0, 0xc18d,	0x72ff, 0xc18d,		0x21, 0
	.dw 0x7340, 0xc18d,	0x737f, 0xc18d,		0x21, 0
	.dw 0x73c0, 0xc18d,	0x73ff, 0xc18d,		0x21, 0
	.dw 0x7440, 0xc18d,	0x747f, 0xc18d,		0x21, 0
	.dw 0x74c0, 0xc18d,	0x74ff, 0xc18d,		0x21, 0
	.dw 0x7540, 0xc18d,	0x757f, 0xc18d,		0x21, 0
	.dw 0x75c0, 0xc18d,	0x75ff, 0xc18d,		0x21, 0
	.dw 0x7640, 0xc18d,	0x767f, 0xc18d,		0x21, 0
	.dw 0x76c0, 0xc18d,	0x76ff, 0xc18d,		0x21, 0
	.dw 0x7740, 0xc18d,	0x777f, 0xc18d,		0x21, 0
	.dw 0x77c0, 0xc18d,	0x77ff, 0xc18d,		0x21, 0
	.dw 0x7840, 0xc18d,	0x787f, 0xc18d,		0x21, 0
	.dw 0x78c0, 0xc18d,	0x78ff, 0xc18d,		0x21, 0
	.dw 0x7940, 0xc18d,	0x797f, 0xc18d,		0x21, 0
	.dw 0x79c0, 0xc18d,	0x7fff, 0xc18d,		0x21, 0
	.dw 0x8040, 0xc18d,	0x807f, 0xc18d,		0x21, 0
	.dw 0x80c0, 0xc18d,	0x80ff, 0xc18d,		0x21, 0
	.dw 0x8140, 0xc18d,	0x817f, 0xc18d,		0x21, 0
	.dw 0x81c0, 0xc18d,	0x81ff, 0xc18d,		0x21, 0
	.dw 0x8240, 0xc18d,	0x827f, 0xc18d,		0x21, 0
	.dw 0x82c0, 0xc18d,	0x82ff, 0xc18d,		0x21, 0
	.dw 0x8340, 0xc18d,	0x837f, 0xc18d,		0x21, 0
	.dw 0x83c0, 0xc18d,	0x83ff, 0xc18d,		0x21, 0
	.dw 0x8440, 0xc18d,	0x847f, 0xc18d,		0x21, 0
	.dw 0x84c0, 0xc18d,	0x84ff, 0xc18d,		0x21, 0
	.dw 0x8540, 0xc18d,	0x857f, 0xc18d,		0x21, 0
	.dw 0x85c0, 0xc18d,	0x85ff, 0xc18d,		0x21, 0
	.dw 0x8640, 0xc18d,	0x867f, 0xc18d,		0x21, 0
	.dw 0x86c0, 0xc18d,	0x86ff, 0xc18d,		0x21, 0
	.dw 0x8740, 0xc18d,	0x877f, 0xc18d,		0x21, 0
	.dw 0x87c0, 0xc18d,	0x87ff, 0xc18d,		0x21, 0
	.dw 0x8840, 0xc18d,	0x887f, 0xc18d,		0x21, 0
	.dw 0x88c0, 0xc18d,	0x88ff, 0xc18d,		0x21, 0
	.dw 0x8940, 0xc18d,	0x897f, 0xc18d,		0x21, 0
	.dw 0x89c0, 0xc18d,	0x89ff, 0xc18d,		0x21, 0
	.dw 0x8a40, 0xc18d,	0x8a7f, 0xc18d,		0x21, 0
	.dw 0x8ac0, 0xc18d,	0x8aff, 0xc18d,		0x21, 0
	.dw 0x8b40, 0xc18d,	0x8b7f, 0xc18d,		0x21, 0
	.dw 0x8bc0, 0xc18d,	0x8bff, 0xc18d,		0x21, 0
	.dw 0x8c40, 0xc18d,	0x8c7f, 0xc18d,		0x21, 0
	.dw 0x8cc0, 0xc18d,	0x8cff, 0xc18d,		0x21, 0
	.dw 0x8d40, 0xc18d,	0x8d7f, 0xc18d,		0x21, 0
	.dw 0x8dc0, 0xc18d,	0x8dff, 0xc18d,		0x21, 0
	.dw 0x8e40, 0xc18d,	0x8e7f, 0xc18d,		0x21, 0
	.dw 0x8ec0, 0xc18d,	0x8eff, 0xc18d,		0x21, 0
	.dw 0x8f40, 0xc18d,	0x8f7f, 0xc18d,		0x21, 0
	.dw 0x8fc0, 0xc18d,	0x8fff, 0xc18d,		0x21, 0
	.dw 0x9040, 0xc18d,	0x907f, 0xc18d,		0x21, 0
	.dw 0x90c0, 0xc18d,	0x90ff, 0xc18d,		0x21, 0
	.dw 0x9140, 0xc18d,	0x917f, 0xc18d,		0x21, 0
	.dw 0x91c0, 0xc18d,	0x91ff, 0xc18d,		0x21, 0
	.dw 0x9240, 0xc18d,	0x927f, 0xc18d,		0x21, 0
	.dw 0x92c0, 0xc18d,	0x92ff, 0xc18d,		0x21, 0
	.dw 0x9340, 0xc18d,	0x937f, 0xc18d,		0x21, 0
	.dw 0x93c0, 0xc18d,	0x93ff, 0xc18d,		0x21, 0
	.dw 0x9440, 0xc18d,	0x947f, 0xc18d,		0x21, 0
	.dw 0x94c0, 0xc18d,	0x94ff, 0xc18d,		0x21, 0
	.dw 0x9540, 0xc18d,	0x957f, 0xc18d,		0x21, 0
	.dw 0x95c0, 0xc18d,	0x95ff, 0xc18d,		0x21, 0
	.dw 0x9640, 0xc18d,	0x967f, 0xc18d,		0x21, 0
	.dw 0x96c0, 0xc18d,	0x96ff, 0xc18d,		0x21, 0
	.dw 0x9740, 0xc18d,	0x977f, 0xc18d,		0x21, 0
	.dw 0x97c0, 0xc18d,	0x97ff, 0xc18d,		0x21, 0
	.dw 0x9840, 0xc18d,	0x987f, 0xc18d,		0x21, 0
	.dw 0x98c0, 0xc18d,	0x98ff, 0xc18d,		0x21, 0
	.dw 0x9940, 0xc18d,	0x997f, 0xc18d,		0x21, 0
	.dw 0x99c0, 0xc18d,	0x9fff, 0xc18d,		0x21, 0
	.dw 0xa040, 0xc18d,	0xa07f, 0xc18d,		0x21, 0
	.dw 0xa0c0, 0xc18d,	0xa0ff, 0xc18d,		0x21, 0
	.dw 0xa140, 0xc18d,	0xa17f, 0xc18d,		0x21, 0
	.dw 0xa1c0, 0xc18d,	0xa1ff, 0xc18d,		0x21, 0
	.dw 0xa240, 0xc18d,	0xa27f, 0xc18d,		0x21, 0
	.dw 0xa2c0, 0xc18d,	0xa2ff, 0xc18d,		0x21, 0
	.dw 0xa340, 0xc18d,	0xa37f, 0xc18d,		0x21, 0
	.dw 0xa3c0, 0xc18d,	0xa3ff, 0xc18d,		0x21, 0
	.dw 0xa440, 0xc18d,	0xa47f, 0xc18d,		0x21, 0
	.dw 0xa4c0, 0xc18d,	0xa4ff, 0xc18d,		0x21, 0
	.dw 0xa540, 0xc18d,	0xa57f, 0xc18d,		0x21, 0
	.dw 0xa5c0, 0xc18d,	0xa5ff, 0xc18d,		0x21, 0
	.dw 0xa640, 0xc18d,	0xa67f, 0xc18d,		0x21, 0
	.dw 0xa6c0, 0xc18d,	0xa6ff, 0xc18d,		0x21, 0
	.dw 0xa740, 0xc18d,	0xa77f, 0xc18d,		0x21, 0
	.dw 0xa7c0, 0xc18d,	0xa7ff, 0xc18d,		0x21, 0
	.dw 0xa840, 0xc18d,	0xa87f, 0xc18d,		0x21, 0
	.dw 0xa8c0, 0xc18d,	0xa8ff, 0xc18d,		0x21, 0
	.dw 0xa940, 0xc18d,	0xa97f, 0xc18d,		0x21, 0
	.dw 0xa9c0, 0xc18d,	0xa9ff, 0xc18d,		0x21, 0
	.dw 0xaa40, 0xc18d,	0xaa7f, 0xc18d,		0x21, 0
	.dw 0xaac0, 0xc18d,	0xaaff, 0xc18d,		0x21, 0
	.dw 0xab40, 0xc18d,	0xab7f, 0xc18d,		0x21, 0
	.dw 0xabc0, 0xc18d,	0xabff, 0xc18d,		0x21, 0
	.dw 0xac40, 0xc18d,	0xac7f, 0xc18d,		0x21, 0
	.dw 0xacc0, 0xc18d,	0xacff, 0xc18d,		0x21, 0
	.dw 0xad40, 0xc18d,	0xad7f, 0xc18d,		0x21, 0
	.dw 0xadc0, 0xc18d,	0xadff, 0xc18d,		0x21, 0
	.dw 0xae40, 0xc18d,	0xae7f, 0xc18d,		0x21, 0
	.dw 0xaec0, 0xc18d,	0xaeff, 0xc18d,		0x21, 0
	.dw 0xaf40, 0xc18d,	0xaf7f, 0xc18d,		0x21, 0
	.dw 0xafc0, 0xc18d,	0xafff, 0xc18d,		0x21, 0
	.dw 0xb040, 0xc18d,	0xb07f, 0xc18d,		0x21, 0
	.dw 0xb0c0, 0xc18d,	0xb0ff, 0xc18d,		0x21, 0
	.dw 0xb140, 0xc18d,	0xb17f, 0xc18d,		0x21, 0
	.dw 0xb1c0, 0xc18d,	0xb1ff, 0xc18d,		0x21, 0
	.dw 0xb240, 0xc18d,	0xb27f, 0xc18d,		0x21, 0
	.dw 0xb2c0, 0xc18d,	0xb2ff, 0xc18d,		0x21, 0
	.dw 0xb340, 0xc18d,	0xb37f, 0xc18d,		0x21, 0
	.dw 0xb3c0, 0xc18d,	0xb3ff, 0xc18d,		0x21, 0
	.dw 0xb440, 0xc18d,	0xb47f, 0xc18d,		0x21, 0
	.dw 0xb4c0, 0xc18d,	0xb4ff, 0xc18d,		0x21, 0
	.dw 0xb540, 0xc18d,	0xb57f, 0xc18d,		0x21, 0
	.dw 0xb5c0, 0xc18d,	0xb5ff, 0xc18d,		0x21, 0
	.dw 0xb640, 0xc18d,	0xb67f, 0xc18d,		0x21, 0
	.dw 0xb6c0, 0xc18d,	0xb6ff, 0xc18d,		0x21, 0
	.dw 0xb740, 0xc18d,	0xb77f, 0xc18d,		0x21, 0
	.dw 0xb7c0, 0xc18d,	0xb7ff, 0xc18d,		0x21, 0
	.dw 0xb840, 0xc18d,	0xb87f, 0xc18d,		0x21, 0
	.dw 0xb8c0, 0xc18d,	0xb8ff, 0xc18d,		0x21, 0
	.dw 0xb940, 0xc18d,	0xb97f, 0xc18d,		0x21, 0
	.dw 0xb9c0, 0xc18d,	0xbfff, 0xc18d,		0x21, 0
	.dw 0xc040, 0xc18d,	0xc07f, 0xc18d,		0x21, 0
	.dw 0xc0c0, 0xc18d,	0xc0ff, 0xc18d,		0x21, 0
	.dw 0xc140, 0xc18d,	0xc17f, 0xc18d,		0x21, 0
	.dw 0xc1c0, 0xc18d,	0xc1ff, 0xc18d,		0x21, 0
	.dw 0xc240, 0xc18d,	0xc27f, 0xc18d,		0x21, 0
	.dw 0xc2c0, 0xc18d,	0xc2ff, 0xc18d,		0x21, 0
	.dw 0xc340, 0xc18d,	0xc37f, 0xc18d,		0x21, 0
	.dw 0xc3c0, 0xc18d,	0xc3ff, 0xc18d,		0x21, 0
	.dw 0xc440, 0xc18d,	0xc47f, 0xc18d,		0x21, 0
	.dw 0xc4c0, 0xc18d,	0xc4ff, 0xc18d,		0x21, 0
	.dw 0xc540, 0xc18d,	0xc57f, 0xc18d,		0x21, 0
	.dw 0xc5c0, 0xc18d,	0xc5ff, 0xc18d,		0x21, 0
	.dw 0xc640, 0xc18d,	0xc67f, 0xc18d,		0x21, 0
	.dw 0xc6c0, 0xc18d,	0xc6ff, 0xc18d,		0x21, 0
	.dw 0xc740, 0xc18d,	0xc77f, 0xc18d,		0x21, 0
	.dw 0xc7c0, 0xc18d,	0xc7ff, 0xc18d,		0x21, 0
	.dw 0xc840, 0xc18d,	0xc87f, 0xc18d,		0x21, 0
	.dw 0xc8c0, 0xc18d,	0xc8ff, 0xc18d,		0x21, 0
	.dw 0xc940, 0xc18d,	0xc97f, 0xc18d,		0x21, 0
	.dw 0xc9c0, 0xc18d,	0xc9ff, 0xc18d,		0x21, 0
	.dw 0xca40, 0xc18d,	0xca7f, 0xc18d,		0x21, 0
	.dw 0xcac0, 0xc18d,	0xcaff, 0xc18d,		0x21, 0
	.dw 0xcb40, 0xc18d,	0xcb7f, 0xc18d,		0x21, 0
	.dw 0xcbc0, 0xc18d,	0xcbff, 0xc18d,		0x21, 0
	.dw 0xcc40, 0xc18d,	0xcc7f, 0xc18d,		0x21, 0
	.dw 0xccc0, 0xc18d,	0xccff, 0xc18d,		0x21, 0
	.dw 0xcd40, 0xc18d,	0xcd7f, 0xc18d,		0x21, 0
	.dw 0xcdc0, 0xc18d,	0xcdff, 0xc18d,		0x21, 0
	.dw 0xce40, 0xc18d,	0xce7f, 0xc18d,		0x21, 0
	.dw 0xcec0, 0xc18d,	0xceff, 0xc18d,		0x21, 0
	.dw 0xcf40, 0xc18d,	0xcf7f, 0xc18d,		0x21, 0
	.dw 0xcfc0, 0xc18d,	0xcfff, 0xc18d,		0x21, 0
	.dw 0xd040, 0xc18d,	0xd07f, 0xc18d,		0x21, 0
	.dw 0xd0c0, 0xc18d,	0xd0ff, 0xc18d,		0x21, 0
	.dw 0xd140, 0xc18d,	0xd17f, 0xc18d,		0x21, 0
	.dw 0xd1c0, 0xc18d,	0xd1ff, 0xc18d,		0x21, 0
	.dw 0xd240, 0xc18d,	0xd27f, 0xc18d,		0x21, 0
	.dw 0xd2c0, 0xc18d,	0xd2ff, 0xc18d,		0x21, 0
	.dw 0xd340, 0xc18d,	0xd37f, 0xc18d,		0x21, 0
	.dw 0xd3c0, 0xc18d,	0xd3ff, 0xc18d,		0x21, 0
	.dw 0xd440, 0xc18d,	0xd47f, 0xc18d,		0x21, 0
	.dw 0xd4c0, 0xc18d,	0xd4ff, 0xc18d,		0x21, 0
	.dw 0xd540, 0xc18d,	0xd57f, 0xc18d,		0x21, 0
	.dw 0xd5c0, 0xc18d,	0xd5ff, 0xc18d,		0x21, 0
	.dw 0xd640, 0xc18d,	0xd67f, 0xc18d,		0x21, 0
	.dw 0xd6c0, 0xc18d,	0xd6ff, 0xc18d,		0x21, 0
	.dw 0xd740, 0xc18d,	0xd77f, 0xc18d,		0x21, 0
	.dw 0xd7c0, 0xc18d,	0xd7ff, 0xc18d,		0x21, 0
	.dw 0xd840, 0xc18d,	0xd87f, 0xc18d,		0x21, 0
	.dw 0xd8c0, 0xc18d,	0xd8ff, 0xc18d,		0x21, 0
	.dw 0xd940, 0xc18d,	0xd97f, 0xc18d,		0x21, 0
	.dw 0xd9c0, 0xc18d,	0xdfff, 0xc18d,		0x21, 0
	.dw 0xe040, 0xc18d,	0xe07f, 0xc18d,		0x21, 0
	.dw 0xe0c0, 0xc18d,	0xe0ff, 0xc18d,		0x21, 0
	.dw 0xe140, 0xc18d,	0xe17f, 0xc18d,		0x21, 0
	.dw 0xe1c0, 0xc18d,	0xe1ff, 0xc18d,		0x21, 0
	.dw 0xe240, 0xc18d,	0xe27f, 0xc18d,		0x21, 0
	.dw 0xe2c0, 0xc18d,	0xe2ff, 0xc18d,		0x21, 0
	.dw 0xe340, 0xc18d,	0xe37f, 0xc18d,		0x21, 0
	.dw 0xe3c0, 0xc18d,	0xe3ff, 0xc18d,		0x21, 0
	.dw 0xe440, 0xc18d,	0xe47f, 0xc18d,		0x21, 0
	.dw 0xe4c0, 0xc18d,	0xe4ff, 0xc18d,		0x21, 0
	.dw 0xe540, 0xc18d,	0xe57f, 0xc18d,		0x21, 0
	.dw 0xe5c0, 0xc18d,	0xe5ff, 0xc18d,		0x21, 0
	.dw 0xe640, 0xc18d,	0xe67f, 0xc18d,		0x21, 0
	.dw 0xe6c0, 0xc18d,	0xe6ff, 0xc18d,		0x21, 0
	.dw 0xe740, 0xc18d,	0xe77f, 0xc18d,		0x21, 0
	.dw 0xe7c0, 0xc18d,	0xe7ff, 0xc18d,		0x21, 0
	.dw 0xe840, 0xc18d,	0xe87f, 0xc18d,		0x21, 0
	.dw 0xe8c0, 0xc18d,	0xe8ff, 0xc18d,		0x21, 0
	.dw 0xe940, 0xc18d,	0xe97f, 0xc18d,		0x21, 0
	.dw 0xe9c0, 0xc18d,	0xe9ff, 0xc18d,		0x21, 0
	.dw 0xea40, 0xc18d,	0xea7f, 0xc18d,		0x21, 0
	.dw 0xeac0, 0xc18d,	0xeaff, 0xc18d,		0x21, 0
	.dw 0xeb40, 0xc18d,	0xeb7f, 0xc18d,		0x21, 0
	.dw 0xebc0, 0xc18d,	0xebff, 0xc18d,		0x21, 0
	.dw 0xec40, 0xc18d,	0xec7f, 0xc18d,		0x21, 0
	.dw 0xecc0, 0xc18d,	0xecff, 0xc18d,		0x21, 0
	.dw 0xed40, 0xc18d,	0xed7f, 0xc18d,		0x21, 0
	.dw 0xedc0, 0xc18d,	0xedff, 0xc18d,		0x21, 0
	.dw 0xee40, 0xc18d,	0xee7f, 0xc18d,		0x21, 0
	.dw 0xeec0, 0xc18d,	0xeeff, 0xc18d,		0x21, 0
	.dw 0xef40, 0xc18d,	0xef7f, 0xc18d,		0x21, 0
	.dw 0xefc0, 0xc18d,	0xefff, 0xc18d,		0x21, 0
	.dw 0xf040, 0xc18d,	0xf07f, 0xc18d,		0x21, 0
	.dw 0xf0c0, 0xc18d,	0xf0ff, 0xc18d,		0x21, 0
	.dw 0xf140, 0xc18d,	0xf17f, 0xc18d,		0x21, 0
	.dw 0xf1c0, 0xc18d,	0xf1ff, 0xc18d,		0x21, 0
	.dw 0xf240, 0xc18d,	0xf27f, 0xc18d,		0x21, 0
	.dw 0xf2c0, 0xc18d,	0xf2ff, 0xc18d,		0x21, 0
	.dw 0xf340, 0xc18d,	0xf37f, 0xc18d,		0x21, 0
	.dw 0xf3c0, 0xc18d,	0xf3ff, 0xc18d,		0x21, 0
	.dw 0xf440, 0xc18d,	0xf47f, 0xc18d,		0x21, 0
	.dw 0xf4c0, 0xc18d,	0xf4ff, 0xc18d,		0x21, 0
	.dw 0xf540, 0xc18d,	0xf57f, 0xc18d,		0x21, 0
	.dw 0xf5c0, 0xc18d,	0xf5ff, 0xc18d,		0x21, 0
	.dw 0xf640, 0xc18d,	0xf67f, 0xc18d,		0x21, 0
	.dw 0xf6c0, 0xc18d,	0xf6ff, 0xc18d,		0x21, 0
	.dw 0xf740, 0xc18d,	0xf77f, 0xc18d,		0x21, 0
	.dw 0xf7c0, 0xc18d,	0xf7ff, 0xc18d,		0x21, 0
	.dw 0xf840, 0xc18d,	0xf87f, 0xc18d,		0x21, 0
	.dw 0xf8c0, 0xc18d,	0xf8ff, 0xc18d,		0x21, 0
	.dw 0xf940, 0xc18d,	0xf97f, 0xc18d,		0x21, 0
	.dw 0xf9c0, 0xc18d,	0xffff, 0xc18d,		0x21, 0
	.dw 0x0040, 0xc18e,	0x007f, 0xc18e,		0x21, 0
	.dw 0x00c0, 0xc18e,	0x00ff, 0xc18e,		0x21, 0
	.dw 0x0140, 0xc18e,	0x017f, 0xc18e,		0x21, 0
	.dw 0x01c0, 0xc18e,	0x01ff, 0xc18e,		0x21, 0
	.dw 0x0240, 0xc18e,	0x027f, 0xc18e,		0x21, 0
	.dw 0x02c0, 0xc18e,	0x02ff, 0xc18e,		0x21, 0
	.dw 0x0340, 0xc18e,	0x037f, 0xc18e,		0x21, 0
	.dw 0x03c0, 0xc18e,	0x03ff, 0xc18e,		0x21, 0
	.dw 0x0440, 0xc18e,	0x047f, 0xc18e,		0x21, 0
	.dw 0x04c0, 0xc18e,	0x04ff, 0xc18e,		0x21, 0
	.dw 0x0540, 0xc18e,	0x057f, 0xc18e,		0x21, 0
	.dw 0x05c0, 0xc18e,	0x05ff, 0xc18e,		0x21, 0
	.dw 0x0640, 0xc18e,	0x067f, 0xc18e,		0x21, 0
	.dw 0x06c0, 0xc18e,	0x06ff, 0xc18e,		0x21, 0
	.dw 0x0740, 0xc18e,	0x077f, 0xc18e,		0x21, 0
	.dw 0x07c0, 0xc18e,	0x07ff, 0xc18e,		0x21, 0
	.dw 0x0840, 0xc18e,	0x087f, 0xc18e,		0x21, 0
	.dw 0x08c0, 0xc18e,	0x08ff, 0xc18e,		0x21, 0
	.dw 0x0940, 0xc18e,	0x097f, 0xc18e,		0x21, 0
	.dw 0x09c0, 0xc18e,	0x09ff, 0xc18e,		0x21, 0
	.dw 0x0a40, 0xc18e,	0x0a7f, 0xc18e,		0x21, 0
	.dw 0x0ac0, 0xc18e,	0x0aff, 0xc18e,		0x21, 0
	.dw 0x0b40, 0xc18e,	0x0b7f, 0xc18e,		0x21, 0
	.dw 0x0bc0, 0xc18e,	0x0bff, 0xc18e,		0x21, 0
	.dw 0x0c40, 0xc18e,	0x0c7f, 0xc18e,		0x21, 0
	.dw 0x0cc0, 0xc18e,	0x0cff, 0xc18e,		0x21, 0
	.dw 0x0d40, 0xc18e,	0x0d7f, 0xc18e,		0x21, 0
	.dw 0x0dc0, 0xc18e,	0x0dff, 0xc18e,		0x21, 0
	.dw 0x0e40, 0xc18e,	0x0e7f, 0xc18e,		0x21, 0
	.dw 0x0ec0, 0xc18e,	0x0eff, 0xc18e,		0x21, 0
	.dw 0x0f40, 0xc18e,	0x0f7f, 0xc18e,		0x21, 0
	.dw 0x0fc0, 0xc18e,	0x0fff, 0xc18e,		0x21, 0
	.dw 0x1040, 0xc18e,	0x107f, 0xc18e,		0x21, 0
	.dw 0x10c0, 0xc18e,	0x10ff, 0xc18e,		0x21, 0
	.dw 0x1140, 0xc18e,	0x117f, 0xc18e,		0x21, 0
	.dw 0x11c0, 0xc18e,	0x11ff, 0xc18e,		0x21, 0
	.dw 0x1240, 0xc18e,	0x127f, 0xc18e,		0x21, 0
	.dw 0x12c0, 0xc18e,	0x12ff, 0xc18e,		0x21, 0
	.dw 0x1340, 0xc18e,	0x137f, 0xc18e,		0x21, 0
	.dw 0x13c0, 0xc18e,	0x13ff, 0xc18e,		0x21, 0
	.dw 0x1440, 0xc18e,	0x147f, 0xc18e,		0x21, 0
	.dw 0x14c0, 0xc18e,	0x14ff, 0xc18e,		0x21, 0
	.dw 0x1540, 0xc18e,	0x157f, 0xc18e,		0x21, 0
	.dw 0x15c0, 0xc18e,	0x15ff, 0xc18e,		0x21, 0
	.dw 0x1640, 0xc18e,	0x167f, 0xc18e,		0x21, 0
	.dw 0x16c0, 0xc18e,	0x16ff, 0xc18e,		0x21, 0
	.dw 0x1740, 0xc18e,	0x177f, 0xc18e,		0x21, 0
	.dw 0x17c0, 0xc18e,	0x17ff, 0xc18e,		0x21, 0
	.dw 0x1840, 0xc18e,	0x187f, 0xc18e,		0x21, 0
	.dw 0x18c0, 0xc18e,	0x18ff, 0xc18e,		0x21, 0
	.dw 0x1940, 0xc18e,	0x197f, 0xc18e,		0x21, 0
	.dw 0x19c0, 0xc18e,	0x1fff, 0xc18e,		0x21, 0
	.dw 0x2040, 0xc18e,	0x207f, 0xc18e,		0x21, 0
	.dw 0x20c0, 0xc18e,	0x20ff, 0xc18e,		0x21, 0
	.dw 0x2140, 0xc18e,	0x217f, 0xc18e,		0x21, 0
	.dw 0x21c0, 0xc18e,	0x21ff, 0xc18e,		0x21, 0
	.dw 0x2240, 0xc18e,	0x227f, 0xc18e,		0x21, 0
	.dw 0x22c0, 0xc18e,	0x22ff, 0xc18e,		0x21, 0
	.dw 0x2340, 0xc18e,	0x237f, 0xc18e,		0x21, 0
	.dw 0x23c0, 0xc18e,	0x23ff, 0xc18e,		0x21, 0
	.dw 0x2440, 0xc18e,	0x247f, 0xc18e,		0x21, 0
	.dw 0x24c0, 0xc18e,	0x24ff, 0xc18e,		0x21, 0
	.dw 0x2540, 0xc18e,	0x257f, 0xc18e,		0x21, 0
	.dw 0x25c0, 0xc18e,	0x25ff, 0xc18e,		0x21, 0
	.dw 0x2640, 0xc18e,	0x267f, 0xc18e,		0x21, 0
	.dw 0x26c0, 0xc18e,	0x26ff, 0xc18e,		0x21, 0
	.dw 0x2740, 0xc18e,	0x277f, 0xc18e,		0x21, 0
	.dw 0x27c0, 0xc18e,	0x27ff, 0xc18e,		0x21, 0
	.dw 0x2840, 0xc18e,	0x287f, 0xc18e,		0x21, 0
	.dw 0x28c0, 0xc18e,	0x28ff, 0xc18e,		0x21, 0
	.dw 0x2940, 0xc18e,	0x297f, 0xc18e,		0x21, 0
	.dw 0x29c0, 0xc18e,	0x29ff, 0xc18e,		0x21, 0
	.dw 0x2a40, 0xc18e,	0x2a7f, 0xc18e,		0x21, 0
	.dw 0x2ac0, 0xc18e,	0x2aff, 0xc18e,		0x21, 0
	.dw 0x2b40, 0xc18e,	0x2b7f, 0xc18e,		0x21, 0
	.dw 0x2bc0, 0xc18e,	0x2bff, 0xc18e,		0x21, 0
	.dw 0x2c40, 0xc18e,	0x2c7f, 0xc18e,		0x21, 0
	.dw 0x2cc0, 0xc18e,	0x2cff, 0xc18e,		0x21, 0
	.dw 0x2d40, 0xc18e,	0x2d7f, 0xc18e,		0x21, 0
	.dw 0x2dc0, 0xc18e,	0x2dff, 0xc18e,		0x21, 0
	.dw 0x2e40, 0xc18e,	0x2e7f, 0xc18e,		0x21, 0
	.dw 0x2ec0, 0xc18e,	0x2eff, 0xc18e,		0x21, 0
	.dw 0x2f40, 0xc18e,	0x2f7f, 0xc18e,		0x21, 0
	.dw 0x2fc0, 0xc18e,	0x2fff, 0xc18e,		0x21, 0
	.dw 0x3040, 0xc18e,	0x307f, 0xc18e,		0x21, 0
	.dw 0x30c0, 0xc18e,	0x30ff, 0xc18e,		0x21, 0
	.dw 0x3140, 0xc18e,	0x317f, 0xc18e,		0x21, 0
	.dw 0x31c0, 0xc18e,	0x31ff, 0xc18e,		0x21, 0
	.dw 0x3240, 0xc18e,	0x327f, 0xc18e,		0x21, 0
	.dw 0x32c0, 0xc18e,	0x32ff, 0xc18e,		0x21, 0
	.dw 0x3340, 0xc18e,	0x337f, 0xc18e,		0x21, 0
	.dw 0x33c0, 0xc18e,	0x33ff, 0xc18e,		0x21, 0
	.dw 0x3440, 0xc18e,	0x347f, 0xc18e,		0x21, 0
	.dw 0x34c0, 0xc18e,	0x34ff, 0xc18e,		0x21, 0
	.dw 0x3540, 0xc18e,	0x357f, 0xc18e,		0x21, 0
	.dw 0x35c0, 0xc18e,	0x35ff, 0xc18e,		0x21, 0
	.dw 0x3640, 0xc18e,	0x367f, 0xc18e,		0x21, 0
	.dw 0x36c0, 0xc18e,	0x36ff, 0xc18e,		0x21, 0
	.dw 0x3740, 0xc18e,	0x377f, 0xc18e,		0x21, 0
	.dw 0x37c0, 0xc18e,	0x37ff, 0xc18e,		0x21, 0
	.dw 0x3840, 0xc18e,	0x387f, 0xc18e,		0x21, 0
	.dw 0x38c0, 0xc18e,	0x38ff, 0xc18e,		0x21, 0
	.dw 0x3940, 0xc18e,	0x397f, 0xc18e,		0x21, 0
	.dw 0x39c0, 0xc18e,	0x3fff, 0xc18e,		0x21, 0
	.dw 0x4040, 0xc18e,	0x407f, 0xc18e,		0x21, 0
	.dw 0x40c0, 0xc18e,	0x40ff, 0xc18e,		0x21, 0
	.dw 0x4140, 0xc18e,	0x417f, 0xc18e,		0x21, 0
	.dw 0x41c0, 0xc18e,	0x41ff, 0xc18e,		0x21, 0
	.dw 0x4240, 0xc18e,	0x427f, 0xc18e,		0x21, 0
	.dw 0x42c0, 0xc18e,	0x42ff, 0xc18e,		0x21, 0
	.dw 0x4340, 0xc18e,	0x437f, 0xc18e,		0x21, 0
	.dw 0x43c0, 0xc18e,	0x43ff, 0xc18e,		0x21, 0
	.dw 0x4440, 0xc18e,	0x447f, 0xc18e,		0x21, 0
	.dw 0x44c0, 0xc18e,	0x44ff, 0xc18e,		0x21, 0
	.dw 0x4540, 0xc18e,	0x457f, 0xc18e,		0x21, 0
	.dw 0x45c0, 0xc18e,	0x45ff, 0xc18e,		0x21, 0
	.dw 0x4640, 0xc18e,	0x467f, 0xc18e,		0x21, 0
	.dw 0x46c0, 0xc18e,	0x46ff, 0xc18e,		0x21, 0
	.dw 0x4740, 0xc18e,	0x477f, 0xc18e,		0x21, 0
	.dw 0x47c0, 0xc18e,	0x47ff, 0xc18e,		0x21, 0
	.dw 0x4840, 0xc18e,	0x487f, 0xc18e,		0x21, 0
	.dw 0x48c0, 0xc18e,	0x48ff, 0xc18e,		0x21, 0
	.dw 0x4940, 0xc18e,	0x497f, 0xc18e,		0x21, 0
	.dw 0x49c0, 0xc18e,	0x49ff, 0xc18e,		0x21, 0
	.dw 0x4a40, 0xc18e,	0x4a7f, 0xc18e,		0x21, 0
	.dw 0x4ac0, 0xc18e,	0x4aff, 0xc18e,		0x21, 0
	.dw 0x4b40, 0xc18e,	0x4b7f, 0xc18e,		0x21, 0
	.dw 0x4bc0, 0xc18e,	0x4bff, 0xc18e,		0x21, 0
	.dw 0x4c40, 0xc18e,	0x4c7f, 0xc18e,		0x21, 0
	.dw 0x4cc0, 0xc18e,	0x4cff, 0xc18e,		0x21, 0
	.dw 0x4d40, 0xc18e,	0x4d7f, 0xc18e,		0x21, 0
	.dw 0x4dc0, 0xc18e,	0x4dff, 0xc18e,		0x21, 0
	.dw 0x4e40, 0xc18e,	0x4e7f, 0xc18e,		0x21, 0
	.dw 0x4ec0, 0xc18e,	0x4eff, 0xc18e,		0x21, 0
	.dw 0x4f40, 0xc18e,	0x4f7f, 0xc18e,		0x21, 0
	.dw 0x4fc0, 0xc18e,	0x4fff, 0xc18e,		0x21, 0
	.dw 0x5040, 0xc18e,	0x507f, 0xc18e,		0x21, 0
	.dw 0x50c0, 0xc18e,	0x50ff, 0xc18e,		0x21, 0
	.dw 0x5140, 0xc18e,	0x517f, 0xc18e,		0x21, 0
	.dw 0x51c0, 0xc18e,	0x51ff, 0xc18e,		0x21, 0
	.dw 0x5240, 0xc18e,	0x527f, 0xc18e,		0x21, 0
	.dw 0x52c0, 0xc18e,	0x52ff, 0xc18e,		0x21, 0
	.dw 0x5340, 0xc18e,	0x537f, 0xc18e,		0x21, 0
	.dw 0x53c0, 0xc18e,	0x53ff, 0xc18e,		0x21, 0
	.dw 0x5440, 0xc18e,	0x547f, 0xc18e,		0x21, 0
	.dw 0x54c0, 0xc18e,	0x54ff, 0xc18e,		0x21, 0
	.dw 0x5540, 0xc18e,	0x557f, 0xc18e,		0x21, 0
	.dw 0x55c0, 0xc18e,	0x55ff, 0xc18e,		0x21, 0
	.dw 0x5640, 0xc18e,	0x567f, 0xc18e,		0x21, 0
	.dw 0x56c0, 0xc18e,	0x56ff, 0xc18e,		0x21, 0
	.dw 0x5740, 0xc18e,	0x577f, 0xc18e,		0x21, 0
	.dw 0x57c0, 0xc18e,	0x57ff, 0xc18e,		0x21, 0
	.dw 0x5840, 0xc18e,	0x587f, 0xc18e,		0x21, 0
	.dw 0x58c0, 0xc18e,	0x58ff, 0xc18e,		0x21, 0
	.dw 0x5940, 0xc18e,	0x597f, 0xc18e,		0x21, 0
	.dw 0x59c0, 0xc18e,	0x5fff, 0xc18e,		0x21, 0
	.dw 0x6040, 0xc18e,	0x607f, 0xc18e,		0x21, 0
	.dw 0x60c0, 0xc18e,	0x60ff, 0xc18e,		0x21, 0
	.dw 0x6140, 0xc18e,	0x617f, 0xc18e,		0x21, 0
	.dw 0x61c0, 0xc18e,	0x61ff, 0xc18e,		0x21, 0
	.dw 0x6240, 0xc18e,	0x627f, 0xc18e,		0x21, 0
	.dw 0x62c0, 0xc18e,	0x62ff, 0xc18e,		0x21, 0
	.dw 0x6340, 0xc18e,	0x637f, 0xc18e,		0x21, 0
	.dw 0x63c0, 0xc18e,	0x63ff, 0xc18e,		0x21, 0
	.dw 0x6440, 0xc18e,	0x647f, 0xc18e,		0x21, 0
	.dw 0x64c0, 0xc18e,	0x64ff, 0xc18e,		0x21, 0
	.dw 0x6540, 0xc18e,	0x657f, 0xc18e,		0x21, 0
	.dw 0x65c0, 0xc18e,	0x65ff, 0xc18e,		0x21, 0
	.dw 0x6640, 0xc18e,	0x667f, 0xc18e,		0x21, 0
	.dw 0x66c0, 0xc18e,	0x66ff, 0xc18e,		0x21, 0
	.dw 0x6740, 0xc18e,	0x677f, 0xc18e,		0x21, 0
	.dw 0x67c0, 0xc18e,	0x67ff, 0xc18e,		0x21, 0
	.dw 0x6840, 0xc18e,	0x687f, 0xc18e,		0x21, 0
	.dw 0x68c0, 0xc18e,	0x68ff, 0xc18e,		0x21, 0
	.dw 0x6940, 0xc18e,	0x697f, 0xc18e,		0x21, 0
	.dw 0x69c0, 0xc18e,	0x69ff, 0xc18e,		0x21, 0
	.dw 0x6a40, 0xc18e,	0x6a7f, 0xc18e,		0x21, 0
	.dw 0x6ac0, 0xc18e,	0x6aff, 0xc18e,		0x21, 0
	.dw 0x6b40, 0xc18e,	0x6b7f, 0xc18e,		0x21, 0
	.dw 0x6bc0, 0xc18e,	0x6bff, 0xc18e,		0x21, 0
	.dw 0x6c40, 0xc18e,	0x6c7f, 0xc18e,		0x21, 0
	.dw 0x6cc0, 0xc18e,	0x6cff, 0xc18e,		0x21, 0
	.dw 0x6d40, 0xc18e,	0x6d7f, 0xc18e,		0x21, 0
	.dw 0x6dc0, 0xc18e,	0x6dff, 0xc18e,		0x21, 0
	.dw 0x6e40, 0xc18e,	0x6e7f, 0xc18e,		0x21, 0
	.dw 0x6ec0, 0xc18e,	0x6eff, 0xc18e,		0x21, 0
	.dw 0x6f40, 0xc18e,	0x6f7f, 0xc18e,		0x21, 0
	.dw 0x6fc0, 0xc18e,	0x6fff, 0xc18e,		0x21, 0
	.dw 0x7040, 0xc18e,	0x707f, 0xc18e,		0x21, 0
	.dw 0x70c0, 0xc18e,	0x70ff, 0xc18e,		0x21, 0
	.dw 0x7140, 0xc18e,	0x717f, 0xc18e,		0x21, 0
	.dw 0x71c0, 0xc18e,	0x71ff, 0xc18e,		0x21, 0
	.dw 0x7240, 0xc18e,	0x727f, 0xc18e,		0x21, 0
	.dw 0x72c0, 0xc18e,	0x72ff, 0xc18e,		0x21, 0
	.dw 0x7340, 0xc18e,	0x737f, 0xc18e,		0x21, 0
	.dw 0x73c0, 0xc18e,	0x73ff, 0xc18e,		0x21, 0
	.dw 0x7440, 0xc18e,	0x747f, 0xc18e,		0x21, 0
	.dw 0x74c0, 0xc18e,	0x74ff, 0xc18e,		0x21, 0
	.dw 0x7540, 0xc18e,	0x757f, 0xc18e,		0x21, 0
	.dw 0x75c0, 0xc18e,	0x75ff, 0xc18e,		0x21, 0
	.dw 0x7640, 0xc18e,	0x767f, 0xc18e,		0x21, 0
	.dw 0x76c0, 0xc18e,	0x76ff, 0xc18e,		0x21, 0
	.dw 0x7740, 0xc18e,	0x777f, 0xc18e,		0x21, 0
	.dw 0x77c0, 0xc18e,	0x77ff, 0xc18e,		0x21, 0
	.dw 0x7840, 0xc18e,	0x787f, 0xc18e,		0x21, 0
	.dw 0x78c0, 0xc18e,	0x78ff, 0xc18e,		0x21, 0
	.dw 0x7940, 0xc18e,	0x797f, 0xc18e,		0x21, 0
	.dw 0x79c0, 0xc18e,	0x7fff, 0xc18e,		0x21, 0
	.dw 0x8040, 0xc18e,	0x807f, 0xc18e,		0x21, 0
	.dw 0x80c0, 0xc18e,	0x80ff, 0xc18e,		0x21, 0
	.dw 0x8140, 0xc18e,	0x817f, 0xc18e,		0x21, 0
	.dw 0x81c0, 0xc18e,	0x81ff, 0xc18e,		0x21, 0
	.dw 0x8240, 0xc18e,	0x827f, 0xc18e,		0x21, 0
	.dw 0x82c0, 0xc18e,	0x82ff, 0xc18e,		0x21, 0
	.dw 0x8340, 0xc18e,	0x837f, 0xc18e,		0x21, 0
	.dw 0x83c0, 0xc18e,	0x83ff, 0xc18e,		0x21, 0
	.dw 0x8440, 0xc18e,	0x847f, 0xc18e,		0x21, 0
	.dw 0x84c0, 0xc18e,	0x84ff, 0xc18e,		0x21, 0
	.dw 0x8540, 0xc18e,	0x857f, 0xc18e,		0x21, 0
	.dw 0x85c0, 0xc18e,	0x85ff, 0xc18e,		0x21, 0
	.dw 0x8640, 0xc18e,	0x867f, 0xc18e,		0x21, 0
	.dw 0x86c0, 0xc18e,	0x86ff, 0xc18e,		0x21, 0
	.dw 0x8740, 0xc18e,	0x877f, 0xc18e,		0x21, 0
	.dw 0x87c0, 0xc18e,	0x87ff, 0xc18e,		0x21, 0
	.dw 0x8840, 0xc18e,	0x887f, 0xc18e,		0x21, 0
	.dw 0x88c0, 0xc18e,	0x88ff, 0xc18e,		0x21, 0
	.dw 0x8940, 0xc18e,	0x897f, 0xc18e,		0x21, 0
	.dw 0x89c0, 0xc18e,	0x89ff, 0xc18e,		0x21, 0
	.dw 0x8a40, 0xc18e,	0x8a7f, 0xc18e,		0x21, 0
	.dw 0x8ac0, 0xc18e,	0x8aff, 0xc18e,		0x21, 0
	.dw 0x8b40, 0xc18e,	0x8b7f, 0xc18e,		0x21, 0
	.dw 0x8bc0, 0xc18e,	0x8bff, 0xc18e,		0x21, 0
	.dw 0x8c40, 0xc18e,	0x8c7f, 0xc18e,		0x21, 0
	.dw 0x8cc0, 0xc18e,	0x8cff, 0xc18e,		0x21, 0
	.dw 0x8d40, 0xc18e,	0x8d7f, 0xc18e,		0x21, 0
	.dw 0x8dc0, 0xc18e,	0x8dff, 0xc18e,		0x21, 0
	.dw 0x8e40, 0xc18e,	0x8e7f, 0xc18e,		0x21, 0
	.dw 0x8ec0, 0xc18e,	0x8eff, 0xc18e,		0x21, 0
	.dw 0x8f40, 0xc18e,	0x8f7f, 0xc18e,		0x21, 0
	.dw 0x8fc0, 0xc18e,	0x8fff, 0xc18e,		0x21, 0
	.dw 0x9040, 0xc18e,	0x907f, 0xc18e,		0x21, 0
	.dw 0x90c0, 0xc18e,	0x90ff, 0xc18e,		0x21, 0
	.dw 0x9140, 0xc18e,	0x917f, 0xc18e,		0x21, 0
	.dw 0x91c0, 0xc18e,	0x91ff, 0xc18e,		0x21, 0
	.dw 0x9240, 0xc18e,	0x927f, 0xc18e,		0x21, 0
	.dw 0x92c0, 0xc18e,	0x92ff, 0xc18e,		0x21, 0
	.dw 0x9340, 0xc18e,	0x937f, 0xc18e,		0x21, 0
	.dw 0x93c0, 0xc18e,	0x93ff, 0xc18e,		0x21, 0
	.dw 0x9440, 0xc18e,	0x947f, 0xc18e,		0x21, 0
	.dw 0x94c0, 0xc18e,	0x94ff, 0xc18e,		0x21, 0
	.dw 0x9540, 0xc18e,	0x957f, 0xc18e,		0x21, 0
	.dw 0x95c0, 0xc18e,	0x95ff, 0xc18e,		0x21, 0
	.dw 0x9640, 0xc18e,	0x967f, 0xc18e,		0x21, 0
	.dw 0x96c0, 0xc18e,	0x96ff, 0xc18e,		0x21, 0
	.dw 0x9740, 0xc18e,	0x977f, 0xc18e,		0x21, 0
	.dw 0x97c0, 0xc18e,	0x97ff, 0xc18e,		0x21, 0
	.dw 0x9840, 0xc18e,	0x987f, 0xc18e,		0x21, 0
	.dw 0x98c0, 0xc18e,	0x98ff, 0xc18e,		0x21, 0
	.dw 0x9940, 0xc18e,	0x997f, 0xc18e,		0x21, 0
	.dw 0x99c0, 0xc18e,	0x9fff, 0xc18e,		0x21, 0
	.dw 0xa040, 0xc18e,	0xa07f, 0xc18e,		0x21, 0
	.dw 0xa0c0, 0xc18e,	0xa0ff, 0xc18e,		0x21, 0
	.dw 0xa140, 0xc18e,	0xa17f, 0xc18e,		0x21, 0
	.dw 0xa1c0, 0xc18e,	0xa1ff, 0xc18e,		0x21, 0
	.dw 0xa240, 0xc18e,	0xa27f, 0xc18e,		0x21, 0
	.dw 0xa2c0, 0xc18e,	0xa2ff, 0xc18e,		0x21, 0
	.dw 0xa340, 0xc18e,	0xa37f, 0xc18e,		0x21, 0
	.dw 0xa3c0, 0xc18e,	0xa3ff, 0xc18e,		0x21, 0
	.dw 0xa440, 0xc18e,	0xa47f, 0xc18e,		0x21, 0
	.dw 0xa4c0, 0xc18e,	0xa4ff, 0xc18e,		0x21, 0
	.dw 0xa540, 0xc18e,	0xa57f, 0xc18e,		0x21, 0
	.dw 0xa5c0, 0xc18e,	0xa5ff, 0xc18e,		0x21, 0
	.dw 0xa640, 0xc18e,	0xa67f, 0xc18e,		0x21, 0
	.dw 0xa6c0, 0xc18e,	0xa6ff, 0xc18e,		0x21, 0
	.dw 0xa740, 0xc18e,	0xa77f, 0xc18e,		0x21, 0
	.dw 0xa7c0, 0xc18e,	0xa7ff, 0xc18e,		0x21, 0
	.dw 0xa840, 0xc18e,	0xa87f, 0xc18e,		0x21, 0
	.dw 0xa8c0, 0xc18e,	0xa8ff, 0xc18e,		0x21, 0
	.dw 0xa940, 0xc18e,	0xa97f, 0xc18e,		0x21, 0
	.dw 0xa9c0, 0xc18e,	0xa9ff, 0xc18e,		0x21, 0
	.dw 0xaa40, 0xc18e,	0xaa7f, 0xc18e,		0x21, 0
	.dw 0xaac0, 0xc18e,	0xaaff, 0xc18e,		0x21, 0
	.dw 0xab40, 0xc18e,	0xab7f, 0xc18e,		0x21, 0
	.dw 0xabc0, 0xc18e,	0xabff, 0xc18e,		0x21, 0
	.dw 0xac40, 0xc18e,	0xac7f, 0xc18e,		0x21, 0
	.dw 0xacc0, 0xc18e,	0xacff, 0xc18e,		0x21, 0
	.dw 0xad40, 0xc18e,	0xad7f, 0xc18e,		0x21, 0
	.dw 0xadc0, 0xc18e,	0xadff, 0xc18e,		0x21, 0
	.dw 0xae40, 0xc18e,	0xae7f, 0xc18e,		0x21, 0
	.dw 0xaec0, 0xc18e,	0xaeff, 0xc18e,		0x21, 0
	.dw 0xaf40, 0xc18e,	0xaf7f, 0xc18e,		0x21, 0
	.dw 0xafc0, 0xc18e,	0xafff, 0xc18e,		0x21, 0
	.dw 0xb040, 0xc18e,	0xb07f, 0xc18e,		0x21, 0
	.dw 0xb0c0, 0xc18e,	0xb0ff, 0xc18e,		0x21, 0
	.dw 0xb140, 0xc18e,	0xb17f, 0xc18e,		0x21, 0
	.dw 0xb1c0, 0xc18e,	0xb1ff, 0xc18e,		0x21, 0
	.dw 0xb240, 0xc18e,	0xb27f, 0xc18e,		0x21, 0
	.dw 0xb2c0, 0xc18e,	0xb2ff, 0xc18e,		0x21, 0
	.dw 0xb340, 0xc18e,	0xb37f, 0xc18e,		0x21, 0
	.dw 0xb3c0, 0xc18e,	0xb3ff, 0xc18e,		0x21, 0
	.dw 0xb440, 0xc18e,	0xb47f, 0xc18e,		0x21, 0
	.dw 0xb4c0, 0xc18e,	0xb4ff, 0xc18e,		0x21, 0
	.dw 0xb540, 0xc18e,	0xb57f, 0xc18e,		0x21, 0
	.dw 0xb5c0, 0xc18e,	0xb5ff, 0xc18e,		0x21, 0
	.dw 0xb640, 0xc18e,	0xb67f, 0xc18e,		0x21, 0
	.dw 0xb6c0, 0xc18e,	0xb6ff, 0xc18e,		0x21, 0
	.dw 0xb740, 0xc18e,	0xb77f, 0xc18e,		0x21, 0
	.dw 0xb7c0, 0xc18e,	0xb7ff, 0xc18e,		0x21, 0
	.dw 0xb840, 0xc18e,	0xb87f, 0xc18e,		0x21, 0
	.dw 0xb8c0, 0xc18e,	0xb8ff, 0xc18e,		0x21, 0
	.dw 0xb940, 0xc18e,	0xb97f, 0xc18e,		0x21, 0
	.dw 0xb9c0, 0xc18e,	0xbfff, 0xc18e,		0x21, 0
	.dw 0xc040, 0xc18e,	0xc07f, 0xc18e,		0x21, 0
	.dw 0xc0c0, 0xc18e,	0xc0ff, 0xc18e,		0x21, 0
	.dw 0xc140, 0xc18e,	0xc17f, 0xc18e,		0x21, 0
	.dw 0xc1c0, 0xc18e,	0xc1ff, 0xc18e,		0x21, 0
	.dw 0xc240, 0xc18e,	0xc27f, 0xc18e,		0x21, 0
	.dw 0xc2c0, 0xc18e,	0xc2ff, 0xc18e,		0x21, 0
	.dw 0xc340, 0xc18e,	0xc37f, 0xc18e,		0x21, 0
	.dw 0xc3c0, 0xc18e,	0xc3ff, 0xc18e,		0x21, 0
	.dw 0xc440, 0xc18e,	0xc47f, 0xc18e,		0x21, 0
	.dw 0xc4c0, 0xc18e,	0xc4ff, 0xc18e,		0x21, 0
	.dw 0xc540, 0xc18e,	0xc57f, 0xc18e,		0x21, 0
	.dw 0xc5c0, 0xc18e,	0xc5ff, 0xc18e,		0x21, 0
	.dw 0xc640, 0xc18e,	0xc67f, 0xc18e,		0x21, 0
	.dw 0xc6c0, 0xc18e,	0xc6ff, 0xc18e,		0x21, 0
	.dw 0xc740, 0xc18e,	0xc77f, 0xc18e,		0x21, 0
	.dw 0xc7c0, 0xc18e,	0xc7ff, 0xc18e,		0x21, 0
	.dw 0xc840, 0xc18e,	0xc87f, 0xc18e,		0x21, 0
	.dw 0xc8c0, 0xc18e,	0xc8ff, 0xc18e,		0x21, 0
	.dw 0xc940, 0xc18e,	0xc97f, 0xc18e,		0x21, 0
	.dw 0xc9c0, 0xc18e,	0xc9ff, 0xc18e,		0x21, 0
	.dw 0xca40, 0xc18e,	0xca7f, 0xc18e,		0x21, 0
	.dw 0xcac0, 0xc18e,	0xcaff, 0xc18e,		0x21, 0
	.dw 0xcb40, 0xc18e,	0xcb7f, 0xc18e,		0x21, 0
	.dw 0xcbc0, 0xc18e,	0xcbff, 0xc18e,		0x21, 0
	.dw 0xcc40, 0xc18e,	0xcc7f, 0xc18e,		0x21, 0
	.dw 0xccc0, 0xc18e,	0xccff, 0xc18e,		0x21, 0
	.dw 0xcd40, 0xc18e,	0xcd7f, 0xc18e,		0x21, 0
	.dw 0xcdc0, 0xc18e,	0xcdff, 0xc18e,		0x21, 0
	.dw 0xce40, 0xc18e,	0xce7f, 0xc18e,		0x21, 0
	.dw 0xcec0, 0xc18e,	0xceff, 0xc18e,		0x21, 0
	.dw 0xcf40, 0xc18e,	0xcf7f, 0xc18e,		0x21, 0
	.dw 0xcfc0, 0xc18e,	0xcfff, 0xc18e,		0x21, 0
	.dw 0xd040, 0xc18e,	0xd07f, 0xc18e,		0x21, 0
	.dw 0xd0c0, 0xc18e,	0xd0ff, 0xc18e,		0x21, 0
	.dw 0xd140, 0xc18e,	0xd17f, 0xc18e,		0x21, 0
	.dw 0xd1c0, 0xc18e,	0xd1ff, 0xc18e,		0x21, 0
	.dw 0xd240, 0xc18e,	0xd27f, 0xc18e,		0x21, 0
	.dw 0xd2c0, 0xc18e,	0xd2ff, 0xc18e,		0x21, 0
	.dw 0xd340, 0xc18e,	0xd37f, 0xc18e,		0x21, 0
	.dw 0xd3c0, 0xc18e,	0xd3ff, 0xc18e,		0x21, 0
	.dw 0xd440, 0xc18e,	0xd47f, 0xc18e,		0x21, 0
	.dw 0xd4c0, 0xc18e,	0xd4ff, 0xc18e,		0x21, 0
	.dw 0xd540, 0xc18e,	0xd57f, 0xc18e,		0x21, 0
	.dw 0xd5c0, 0xc18e,	0xd5ff, 0xc18e,		0x21, 0
	.dw 0xd640, 0xc18e,	0xd67f, 0xc18e,		0x21, 0
	.dw 0xd6c0, 0xc18e,	0xd6ff, 0xc18e,		0x21, 0
	.dw 0xd740, 0xc18e,	0xd77f, 0xc18e,		0x21, 0
	.dw 0xd7c0, 0xc18e,	0xd7ff, 0xc18e,		0x21, 0
	.dw 0xd840, 0xc18e,	0xd87f, 0xc18e,		0x21, 0
	.dw 0xd8c0, 0xc18e,	0xd8ff, 0xc18e,		0x21, 0
	.dw 0xd940, 0xc18e,	0xd97f, 0xc18e,		0x21, 0
	.dw 0xd9c0, 0xc18e,	0xdfff, 0xc18e,		0x21, 0
	.dw 0xe040, 0xc18e,	0xe07f, 0xc18e,		0x21, 0
	.dw 0xe0c0, 0xc18e,	0xe0ff, 0xc18e,		0x21, 0
	.dw 0xe140, 0xc18e,	0xe17f, 0xc18e,		0x21, 0
	.dw 0xe1c0, 0xc18e,	0xe1ff, 0xc18e,		0x21, 0
	.dw 0xe240, 0xc18e,	0xe27f, 0xc18e,		0x21, 0
	.dw 0xe2c0, 0xc18e,	0xe2ff, 0xc18e,		0x21, 0
	.dw 0xe340, 0xc18e,	0xe37f, 0xc18e,		0x21, 0
	.dw 0xe3c0, 0xc18e,	0xe3ff, 0xc18e,		0x21, 0
	.dw 0xe440, 0xc18e,	0xe47f, 0xc18e,		0x21, 0
	.dw 0xe4c0, 0xc18e,	0xe4ff, 0xc18e,		0x21, 0
	.dw 0xe540, 0xc18e,	0xe57f, 0xc18e,		0x21, 0
	.dw 0xe5c0, 0xc18e,	0xe5ff, 0xc18e,		0x21, 0
	.dw 0xe640, 0xc18e,	0xe67f, 0xc18e,		0x21, 0
	.dw 0xe6c0, 0xc18e,	0xe6ff, 0xc18e,		0x21, 0
	.dw 0xe740, 0xc18e,	0xe77f, 0xc18e,		0x21, 0
	.dw 0xe7c0, 0xc18e,	0xe7ff, 0xc18e,		0x21, 0
	.dw 0xe840, 0xc18e,	0xe87f, 0xc18e,		0x21, 0
	.dw 0xe8c0, 0xc18e,	0xe8ff, 0xc18e,		0x21, 0
	.dw 0xe940, 0xc18e,	0xe97f, 0xc18e,		0x21, 0
	.dw 0xe9c0, 0xc18e,	0xe9ff, 0xc18e,		0x21, 0
	.dw 0xea40, 0xc18e,	0xea7f, 0xc18e,		0x21, 0
	.dw 0xeac0, 0xc18e,	0xeaff, 0xc18e,		0x21, 0
	.dw 0xeb40, 0xc18e,	0xeb7f, 0xc18e,		0x21, 0
	.dw 0xebc0, 0xc18e,	0xebff, 0xc18e,		0x21, 0
	.dw 0xec40, 0xc18e,	0xec7f, 0xc18e,		0x21, 0
	.dw 0xecc0, 0xc18e,	0xecff, 0xc18e,		0x21, 0
	.dw 0xed40, 0xc18e,	0xed7f, 0xc18e,		0x21, 0
	.dw 0xedc0, 0xc18e,	0xedff, 0xc18e,		0x21, 0
	.dw 0xee40, 0xc18e,	0xee7f, 0xc18e,		0x21, 0
	.dw 0xeec0, 0xc18e,	0xeeff, 0xc18e,		0x21, 0
	.dw 0xef40, 0xc18e,	0xef7f, 0xc18e,		0x21, 0
	.dw 0xefc0, 0xc18e,	0xefff, 0xc18e,		0x21, 0
	.dw 0xf040, 0xc18e,	0xf07f, 0xc18e,		0x21, 0
	.dw 0xf0c0, 0xc18e,	0xf0ff, 0xc18e,		0x21, 0
	.dw 0xf140, 0xc18e,	0xf17f, 0xc18e,		0x21, 0
	.dw 0xf1c0, 0xc18e,	0xf1ff, 0xc18e,		0x21, 0
	.dw 0xf240, 0xc18e,	0xf27f, 0xc18e,		0x21, 0
	.dw 0xf2c0, 0xc18e,	0xf2ff, 0xc18e,		0x21, 0
	.dw 0xf340, 0xc18e,	0xf37f, 0xc18e,		0x21, 0
	.dw 0xf3c0, 0xc18e,	0xf3ff, 0xc18e,		0x21, 0
	.dw 0xf440, 0xc18e,	0xf47f, 0xc18e,		0x21, 0
	.dw 0xf4c0, 0xc18e,	0xf4ff, 0xc18e,		0x21, 0
	.dw 0xf540, 0xc18e,	0xf57f, 0xc18e,		0x21, 0
	.dw 0xf5c0, 0xc18e,	0xf5ff, 0xc18e,		0x21, 0
	.dw 0xf640, 0xc18e,	0xf67f, 0xc18e,		0x21, 0
	.dw 0xf6c0, 0xc18e,	0xf6ff, 0xc18e,		0x21, 0
	.dw 0xf740, 0xc18e,	0xf77f, 0xc18e,		0x21, 0
	.dw 0xf7c0, 0xc18e,	0xf7ff, 0xc18e,		0x21, 0
	.dw 0xf840, 0xc18e,	0xf87f, 0xc18e,		0x21, 0
	.dw 0xf8c0, 0xc18e,	0xf8ff, 0xc18e,		0x21, 0
	.dw 0xf940, 0xc18e,	0xf97f, 0xc18e,		0x21, 0
	.dw 0xf9c0, 0xc18e,	0xffff, 0xc18e,		0x21, 0
	.dw 0x0040, 0xc18f,	0x007f, 0xc18f,		0x21, 0
	.dw 0x00c0, 0xc18f,	0x00ff, 0xc18f,		0x21, 0
	.dw 0x0140, 0xc18f,	0x017f, 0xc18f,		0x21, 0
	.dw 0x01c0, 0xc18f,	0x01ff, 0xc18f,		0x21, 0
	.dw 0x0240, 0xc18f,	0x027f, 0xc18f,		0x21, 0
	.dw 0x02c0, 0xc18f,	0x02ff, 0xc18f,		0x21, 0
	.dw 0x0340, 0xc18f,	0x037f, 0xc18f,		0x21, 0
	.dw 0x03c0, 0xc18f,	0x03ff, 0xc18f,		0x21, 0
	.dw 0x0440, 0xc18f,	0x047f, 0xc18f,		0x21, 0
	.dw 0x04c0, 0xc18f,	0x04ff, 0xc18f,		0x21, 0
	.dw 0x0540, 0xc18f,	0x057f, 0xc18f,		0x21, 0
	.dw 0x05c0, 0xc18f,	0x05ff, 0xc18f,		0x21, 0
	.dw 0x0640, 0xc18f,	0x067f, 0xc18f,		0x21, 0
	.dw 0x06c0, 0xc18f,	0x06ff, 0xc18f,		0x21, 0
	.dw 0x0740, 0xc18f,	0x077f, 0xc18f,		0x21, 0
	.dw 0x07c0, 0xc18f,	0x07ff, 0xc18f,		0x21, 0
	.dw 0x0840, 0xc18f,	0x087f, 0xc18f,		0x21, 0
	.dw 0x08c0, 0xc18f,	0x08ff, 0xc18f,		0x21, 0
	.dw 0x0940, 0xc18f,	0x097f, 0xc18f,		0x21, 0
	.dw 0x09c0, 0xc18f,	0x09ff, 0xc18f,		0x21, 0
	.dw 0x0a40, 0xc18f,	0x0a7f, 0xc18f,		0x21, 0
	.dw 0x0ac0, 0xc18f,	0x0aff, 0xc18f,		0x21, 0
	.dw 0x0b40, 0xc18f,	0x0b7f, 0xc18f,		0x21, 0
	.dw 0x0bc0, 0xc18f,	0x0bff, 0xc18f,		0x21, 0
	.dw 0x0c40, 0xc18f,	0x0c7f, 0xc18f,		0x21, 0
	.dw 0x0cc0, 0xc18f,	0x0cff, 0xc18f,		0x21, 0
	.dw 0x0d40, 0xc18f,	0x0d7f, 0xc18f,		0x21, 0
	.dw 0x0dc0, 0xc18f,	0x0dff, 0xc18f,		0x21, 0
	.dw 0x0e40, 0xc18f,	0x0e7f, 0xc18f,		0x21, 0
	.dw 0x0ec0, 0xc18f,	0x0eff, 0xc18f,		0x21, 0
	.dw 0x0f40, 0xc18f,	0x0f7f, 0xc18f,		0x21, 0
	.dw 0x0fc0, 0xc18f,	0x0fff, 0xc18f,		0x21, 0
	.dw 0x1040, 0xc18f,	0x107f, 0xc18f,		0x21, 0
	.dw 0x10c0, 0xc18f,	0x10ff, 0xc18f,		0x21, 0
	.dw 0x1140, 0xc18f,	0x117f, 0xc18f,		0x21, 0
	.dw 0x11c0, 0xc18f,	0x11ff, 0xc18f,		0x21, 0
	.dw 0x1240, 0xc18f,	0x127f, 0xc18f,		0x21, 0
	.dw 0x12c0, 0xc18f,	0x12ff, 0xc18f,		0x21, 0
	.dw 0x1340, 0xc18f,	0x137f, 0xc18f,		0x21, 0
	.dw 0x13c0, 0xc18f,	0x13ff, 0xc18f,		0x21, 0
	.dw 0x1440, 0xc18f,	0x147f, 0xc18f,		0x21, 0
	.dw 0x14c0, 0xc18f,	0x14ff, 0xc18f,		0x21, 0
	.dw 0x1540, 0xc18f,	0x157f, 0xc18f,		0x21, 0
	.dw 0x15c0, 0xc18f,	0x15ff, 0xc18f,		0x21, 0
	.dw 0x1640, 0xc18f,	0x167f, 0xc18f,		0x21, 0
	.dw 0x16c0, 0xc18f,	0x16ff, 0xc18f,		0x21, 0
	.dw 0x1740, 0xc18f,	0x177f, 0xc18f,		0x21, 0
	.dw 0x17c0, 0xc18f,	0x17ff, 0xc18f,		0x21, 0
	.dw 0x1840, 0xc18f,	0x187f, 0xc18f,		0x21, 0
	.dw 0x18c0, 0xc18f,	0x18ff, 0xc18f,		0x21, 0
	.dw 0x1940, 0xc18f,	0x197f, 0xc18f,		0x21, 0
	.dw 0x19c0, 0xc18f,	0x1fff, 0xc18f,		0x21, 0
	.dw 0x2040, 0xc18f,	0x207f, 0xc18f,		0x21, 0
	.dw 0x20c0, 0xc18f,	0x20ff, 0xc18f,		0x21, 0
	.dw 0x2140, 0xc18f,	0x217f, 0xc18f,		0x21, 0
	.dw 0x21c0, 0xc18f,	0x21ff, 0xc18f,		0x21, 0
	.dw 0x2240, 0xc18f,	0x227f, 0xc18f,		0x21, 0
	.dw 0x22c0, 0xc18f,	0x22ff, 0xc18f,		0x21, 0
	.dw 0x2340, 0xc18f,	0x237f, 0xc18f,		0x21, 0
	.dw 0x23c0, 0xc18f,	0x23ff, 0xc18f,		0x21, 0
	.dw 0x2440, 0xc18f,	0x247f, 0xc18f,		0x21, 0
	.dw 0x24c0, 0xc18f,	0x24ff, 0xc18f,		0x21, 0
	.dw 0x2540, 0xc18f,	0x257f, 0xc18f,		0x21, 0
	.dw 0x25c0, 0xc18f,	0x25ff, 0xc18f,		0x21, 0
	.dw 0x2640, 0xc18f,	0x267f, 0xc18f,		0x21, 0
	.dw 0x26c0, 0xc18f,	0x26ff, 0xc18f,		0x21, 0
	.dw 0x2740, 0xc18f,	0x277f, 0xc18f,		0x21, 0
	.dw 0x27c0, 0xc18f,	0x27ff, 0xc18f,		0x21, 0
	.dw 0x2840, 0xc18f,	0x287f, 0xc18f,		0x21, 0
	.dw 0x28c0, 0xc18f,	0x28ff, 0xc18f,		0x21, 0
	.dw 0x2940, 0xc18f,	0x297f, 0xc18f,		0x21, 0
	.dw 0x29c0, 0xc18f,	0x29ff, 0xc18f,		0x21, 0
	.dw 0x2a40, 0xc18f,	0x2a7f, 0xc18f,		0x21, 0
	.dw 0x2ac0, 0xc18f,	0x2aff, 0xc18f,		0x21, 0
	.dw 0x2b40, 0xc18f,	0x2b7f, 0xc18f,		0x21, 0
	.dw 0x2bc0, 0xc18f,	0x2bff, 0xc18f,		0x21, 0
	.dw 0x2c40, 0xc18f,	0x2c7f, 0xc18f,		0x21, 0
	.dw 0x2cc0, 0xc18f,	0x2cff, 0xc18f,		0x21, 0
	.dw 0x2d40, 0xc18f,	0x2d7f, 0xc18f,		0x21, 0
	.dw 0x2dc0, 0xc18f,	0x2dff, 0xc18f,		0x21, 0
	.dw 0x2e40, 0xc18f,	0x2e7f, 0xc18f,		0x21, 0
	.dw 0x2ec0, 0xc18f,	0x2eff, 0xc18f,		0x21, 0
	.dw 0x2f40, 0xc18f,	0x2f7f, 0xc18f,		0x21, 0
	.dw 0x2fc0, 0xc18f,	0x2fff, 0xc18f,		0x21, 0
	.dw 0x3040, 0xc18f,	0x307f, 0xc18f,		0x21, 0
	.dw 0x30c0, 0xc18f,	0x30ff, 0xc18f,		0x21, 0
	.dw 0x3140, 0xc18f,	0x317f, 0xc18f,		0x21, 0
	.dw 0x31c0, 0xc18f,	0x31ff, 0xc18f,		0x21, 0
	.dw 0x3240, 0xc18f,	0x327f, 0xc18f,		0x21, 0
	.dw 0x32c0, 0xc18f,	0x32ff, 0xc18f,		0x21, 0
	.dw 0x3340, 0xc18f,	0x337f, 0xc18f,		0x21, 0
	.dw 0x33c0, 0xc18f,	0x33ff, 0xc18f,		0x21, 0
	.dw 0x3440, 0xc18f,	0x347f, 0xc18f,		0x21, 0
	.dw 0x34c0, 0xc18f,	0x34ff, 0xc18f,		0x21, 0
	.dw 0x3540, 0xc18f,	0x357f, 0xc18f,		0x21, 0
	.dw 0x35c0, 0xc18f,	0x35ff, 0xc18f,		0x21, 0
	.dw 0x3640, 0xc18f,	0x367f, 0xc18f,		0x21, 0
	.dw 0x36c0, 0xc18f,	0x36ff, 0xc18f,		0x21, 0
	.dw 0x3740, 0xc18f,	0x377f, 0xc18f,		0x21, 0
	.dw 0x37c0, 0xc18f,	0x37ff, 0xc18f,		0x21, 0
	.dw 0x3840, 0xc18f,	0x387f, 0xc18f,		0x21, 0
	.dw 0x38c0, 0xc18f,	0x38ff, 0xc18f,		0x21, 0
	.dw 0x3940, 0xc18f,	0x397f, 0xc18f,		0x21, 0
	.dw 0x39c0, 0xc18f,	0x1fff, 0xc190,		0x21, 0
	.dw 0x3a00, 0xc190,	0x5fff, 0xc190,		0x21, 0
	.dw 0x7a00, 0xc190,	0x9fff, 0xc190,		0x21, 0
	.dw 0xba00, 0xc190,	0xdfff, 0xc190,		0x21, 0
	.dw 0xfa00, 0xc190,	0x1fff, 0xc191,		0x21, 0
	.dw 0x3a00, 0xc191,	0x5fff, 0xc191,		0x21, 0
	.dw 0x7a00, 0xc191,	0x9fff, 0xc191,		0x21, 0
	.dw 0xba00, 0xc191,	0xdfff, 0xc191,		0x21, 0
	.dw 0xfa00, 0xc191,	0x1fff, 0xc192,		0x21, 0
	.dw 0x3a00, 0xc192,	0x5fff, 0xc192,		0x21, 0
	.dw 0x7a00, 0xc192,	0x9fff, 0xc192,		0x21, 0
	.dw 0xba00, 0xc192,	0xdfff, 0xc192,		0x21, 0
	.dw 0xfa00, 0xc192,	0xffff, 0xc193,		0x21, 0
	.dw 0x1a00, 0xc194,	0x1fff, 0xc194,		0x21, 0
	.dw 0x3a00, 0xc194,	0x3fff, 0xc194,		0x21, 0
	.dw 0x5a00, 0xc194,	0x5fff, 0xc194,		0x21, 0
	.dw 0x7a00, 0xc194,	0x7fff, 0xc194,		0x21, 0
	.dw 0x9a00, 0xc194,	0x9fff, 0xc194,		0x21, 0
	.dw 0xba00, 0xc194,	0xbfff, 0xc194,		0x21, 0
	.dw 0xda00, 0xc194,	0xdfff, 0xc194,		0x21, 0
	.dw 0xfa00, 0xc194,	0xffff, 0xc194,		0x21, 0
	.dw 0x1a00, 0xc195,	0x1fff, 0xc195,		0x21, 0
	.dw 0x3a00, 0xc195,	0x3fff, 0xc195,		0x21, 0
	.dw 0x5a00, 0xc195,	0x5fff, 0xc195,		0x21, 0
	.dw 0x7a00, 0xc195,	0x7fff, 0xc195,		0x21, 0
	.dw 0x9a00, 0xc195,	0x9fff, 0xc195,		0x21, 0
	.dw 0xba00, 0xc195,	0xbfff, 0xc195,		0x21, 0
	.dw 0xda00, 0xc195,	0xdfff, 0xc195,		0x21, 0
	.dw 0xfa00, 0xc195,	0xffff, 0xc195,		0x21, 0
	.dw 0x1a00, 0xc196,	0x1fff, 0xc196,		0x21, 0
	.dw 0x3a00, 0xc196,	0x3fff, 0xc196,		0x21, 0
	.dw 0x5a00, 0xc196,	0x5fff, 0xc196,		0x21, 0
	.dw 0x7a00, 0xc196,	0x7fff, 0xc196,		0x21, 0
	.dw 0x9a00, 0xc196,	0x9fff, 0xc196,		0x21, 0
	.dw 0xba00, 0xc196,	0xbfff, 0xc196,		0x21, 0
	.dw 0xda00, 0xc196,	0xdfff, 0xc196,		0x21, 0
	.dw 0xfa00, 0xc196,	0xffff, 0xc196,		0x21, 0
	.dw 0x1a00, 0xc197,	0x1fff, 0xc197,		0x21, 0
	.dw 0x3a00, 0xc197,	0x1fff, 0xc198,		0x21, 0
	.dw 0x2040, 0xc198,	0x207f, 0xc198,		0x21, 0
	.dw 0x20c0, 0xc198,	0x20ff, 0xc198,		0x21, 0
	.dw 0x2140, 0xc198,	0x217f, 0xc198,		0x21, 0
	.dw 0x21c0, 0xc198,	0x21ff, 0xc198,		0x21, 0
	.dw 0x2240, 0xc198,	0x227f, 0xc198,		0x21, 0
	.dw 0x22c0, 0xc198,	0x22ff, 0xc198,		0x21, 0
	.dw 0x2340, 0xc198,	0x237f, 0xc198,		0x21, 0
	.dw 0x23c0, 0xc198,	0x23ff, 0xc198,		0x21, 0
	.dw 0x2440, 0xc198,	0x247f, 0xc198,		0x21, 0
	.dw 0x24c0, 0xc198,	0x24ff, 0xc198,		0x21, 0
	.dw 0x2540, 0xc198,	0x257f, 0xc198,		0x21, 0
	.dw 0x25c0, 0xc198,	0x25ff, 0xc198,		0x21, 0
	.dw 0x2640, 0xc198,	0x267f, 0xc198,		0x21, 0
	.dw 0x26c0, 0xc198,	0x26ff, 0xc198,		0x21, 0
	.dw 0x2740, 0xc198,	0x277f, 0xc198,		0x21, 0
	.dw 0x27c0, 0xc198,	0x27ff, 0xc198,		0x21, 0
	.dw 0x2840, 0xc198,	0x287f, 0xc198,		0x21, 0
	.dw 0x28c0, 0xc198,	0x28ff, 0xc198,		0x21, 0
	.dw 0x2940, 0xc198,	0x297f, 0xc198,		0x21, 0
	.dw 0x29c0, 0xc198,	0x29ff, 0xc198,		0x21, 0
	.dw 0x2a40, 0xc198,	0x2a7f, 0xc198,		0x21, 0
	.dw 0x2ac0, 0xc198,	0x2aff, 0xc198,		0x21, 0
	.dw 0x2b40, 0xc198,	0x2b7f, 0xc198,		0x21, 0
	.dw 0x2bc0, 0xc198,	0x2bff, 0xc198,		0x21, 0
	.dw 0x2c40, 0xc198,	0x2c7f, 0xc198,		0x21, 0
	.dw 0x2cc0, 0xc198,	0x2cff, 0xc198,		0x21, 0
	.dw 0x2d40, 0xc198,	0x2d7f, 0xc198,		0x21, 0
	.dw 0x2dc0, 0xc198,	0x2dff, 0xc198,		0x21, 0
	.dw 0x2e40, 0xc198,	0x2e7f, 0xc198,		0x21, 0
	.dw 0x2ec0, 0xc198,	0x2eff, 0xc198,		0x21, 0
	.dw 0x2f40, 0xc198,	0x2f7f, 0xc198,		0x21, 0
	.dw 0x2fc0, 0xc198,	0x2fff, 0xc198,		0x21, 0
	.dw 0x3040, 0xc198,	0x307f, 0xc198,		0x21, 0
	.dw 0x30c0, 0xc198,	0x30ff, 0xc198,		0x21, 0
	.dw 0x3140, 0xc198,	0x317f, 0xc198,		0x21, 0
	.dw 0x31c0, 0xc198,	0x31ff, 0xc198,		0x21, 0
	.dw 0x3240, 0xc198,	0x327f, 0xc198,		0x21, 0
	.dw 0x32c0, 0xc198,	0x32ff, 0xc198,		0x21, 0
	.dw 0x3340, 0xc198,	0x337f, 0xc198,		0x21, 0
	.dw 0x33c0, 0xc198,	0x33ff, 0xc198,		0x21, 0
	.dw 0x3440, 0xc198,	0x347f, 0xc198,		0x21, 0
	.dw 0x34c0, 0xc198,	0x34ff, 0xc198,		0x21, 0
	.dw 0x3540, 0xc198,	0x357f, 0xc198,		0x21, 0
	.dw 0x35c0, 0xc198,	0x35ff, 0xc198,		0x21, 0
	.dw 0x3640, 0xc198,	0x367f, 0xc198,		0x21, 0
	.dw 0x36c0, 0xc198,	0x36ff, 0xc198,		0x21, 0
	.dw 0x3740, 0xc198,	0x377f, 0xc198,		0x21, 0
	.dw 0x37c0, 0xc198,	0x37ff, 0xc198,		0x21, 0
	.dw 0x3840, 0xc198,	0x387f, 0xc198,		0x21, 0
	.dw 0x38c0, 0xc198,	0x38ff, 0xc198,		0x21, 0
	.dw 0x3940, 0xc198,	0x397f, 0xc198,		0x21, 0
	.dw 0x39c0, 0xc198,	0x5fff, 0xc198,		0x21, 0
	.dw 0x6040, 0xc198,	0x607f, 0xc198,		0x21, 0
	.dw 0x60c0, 0xc198,	0x60ff, 0xc198,		0x21, 0
	.dw 0x6140, 0xc198,	0x617f, 0xc198,		0x21, 0
	.dw 0x61c0, 0xc198,	0x61ff, 0xc198,		0x21, 0
	.dw 0x6240, 0xc198,	0x627f, 0xc198,		0x21, 0
	.dw 0x62c0, 0xc198,	0x62ff, 0xc198,		0x21, 0
	.dw 0x6340, 0xc198,	0x637f, 0xc198,		0x21, 0
	.dw 0x63c0, 0xc198,	0x63ff, 0xc198,		0x21, 0
	.dw 0x6440, 0xc198,	0x647f, 0xc198,		0x21, 0
	.dw 0x64c0, 0xc198,	0x64ff, 0xc198,		0x21, 0
	.dw 0x6540, 0xc198,	0x657f, 0xc198,		0x21, 0
	.dw 0x65c0, 0xc198,	0x65ff, 0xc198,		0x21, 0
	.dw 0x6640, 0xc198,	0x667f, 0xc198,		0x21, 0
	.dw 0x66c0, 0xc198,	0x66ff, 0xc198,		0x21, 0
	.dw 0x6740, 0xc198,	0x677f, 0xc198,		0x21, 0
	.dw 0x67c0, 0xc198,	0x67ff, 0xc198,		0x21, 0
	.dw 0x6840, 0xc198,	0x687f, 0xc198,		0x21, 0
	.dw 0x68c0, 0xc198,	0x68ff, 0xc198,		0x21, 0
	.dw 0x6940, 0xc198,	0x697f, 0xc198,		0x21, 0
	.dw 0x69c0, 0xc198,	0x69ff, 0xc198,		0x21, 0
	.dw 0x6a40, 0xc198,	0x6a7f, 0xc198,		0x21, 0
	.dw 0x6ac0, 0xc198,	0x6aff, 0xc198,		0x21, 0
	.dw 0x6b40, 0xc198,	0x6b7f, 0xc198,		0x21, 0
	.dw 0x6bc0, 0xc198,	0x6bff, 0xc198,		0x21, 0
	.dw 0x6c40, 0xc198,	0x6c7f, 0xc198,		0x21, 0
	.dw 0x6cc0, 0xc198,	0x6cff, 0xc198,		0x21, 0
	.dw 0x6d40, 0xc198,	0x6d7f, 0xc198,		0x21, 0
	.dw 0x6dc0, 0xc198,	0x6dff, 0xc198,		0x21, 0
	.dw 0x6e40, 0xc198,	0x6e7f, 0xc198,		0x21, 0
	.dw 0x6ec0, 0xc198,	0x6eff, 0xc198,		0x21, 0
	.dw 0x6f40, 0xc198,	0x6f7f, 0xc198,		0x21, 0
	.dw 0x6fc0, 0xc198,	0x6fff, 0xc198,		0x21, 0
	.dw 0x7040, 0xc198,	0x707f, 0xc198,		0x21, 0
	.dw 0x70c0, 0xc198,	0x70ff, 0xc198,		0x21, 0
	.dw 0x7140, 0xc198,	0x717f, 0xc198,		0x21, 0
	.dw 0x71c0, 0xc198,	0x71ff, 0xc198,		0x21, 0
	.dw 0x7240, 0xc198,	0x727f, 0xc198,		0x21, 0
	.dw 0x72c0, 0xc198,	0x72ff, 0xc198,		0x21, 0
	.dw 0x7340, 0xc198,	0x737f, 0xc198,		0x21, 0
	.dw 0x73c0, 0xc198,	0x73ff, 0xc198,		0x21, 0
	.dw 0x7440, 0xc198,	0x747f, 0xc198,		0x21, 0
	.dw 0x74c0, 0xc198,	0x74ff, 0xc198,		0x21, 0
	.dw 0x7540, 0xc198,	0x757f, 0xc198,		0x21, 0
	.dw 0x75c0, 0xc198,	0x75ff, 0xc198,		0x21, 0
	.dw 0x7640, 0xc198,	0x767f, 0xc198,		0x21, 0
	.dw 0x76c0, 0xc198,	0x76ff, 0xc198,		0x21, 0
	.dw 0x7740, 0xc198,	0x777f, 0xc198,		0x21, 0
	.dw 0x77c0, 0xc198,	0x77ff, 0xc198,		0x21, 0
	.dw 0x7840, 0xc198,	0x787f, 0xc198,		0x21, 0
	.dw 0x78c0, 0xc198,	0x78ff, 0xc198,		0x21, 0
	.dw 0x7940, 0xc198,	0x797f, 0xc198,		0x21, 0
	.dw 0x79c0, 0xc198,	0x9fff, 0xc198,		0x21, 0
	.dw 0xa040, 0xc198,	0xa07f, 0xc198,		0x21, 0
	.dw 0xa0c0, 0xc198,	0xa0ff, 0xc198,		0x21, 0
	.dw 0xa140, 0xc198,	0xa17f, 0xc198,		0x21, 0
	.dw 0xa1c0, 0xc198,	0xa1ff, 0xc198,		0x21, 0
	.dw 0xa240, 0xc198,	0xa27f, 0xc198,		0x21, 0
	.dw 0xa2c0, 0xc198,	0xa2ff, 0xc198,		0x21, 0
	.dw 0xa340, 0xc198,	0xa37f, 0xc198,		0x21, 0
	.dw 0xa3c0, 0xc198,	0xa3ff, 0xc198,		0x21, 0
	.dw 0xa440, 0xc198,	0xa47f, 0xc198,		0x21, 0
	.dw 0xa4c0, 0xc198,	0xa4ff, 0xc198,		0x21, 0
	.dw 0xa540, 0xc198,	0xa57f, 0xc198,		0x21, 0
	.dw 0xa5c0, 0xc198,	0xa5ff, 0xc198,		0x21, 0
	.dw 0xa640, 0xc198,	0xa67f, 0xc198,		0x21, 0
	.dw 0xa6c0, 0xc198,	0xa6ff, 0xc198,		0x21, 0
	.dw 0xa740, 0xc198,	0xa77f, 0xc198,		0x21, 0
	.dw 0xa7c0, 0xc198,	0xa7ff, 0xc198,		0x21, 0
	.dw 0xa840, 0xc198,	0xa87f, 0xc198,		0x21, 0
	.dw 0xa8c0, 0xc198,	0xa8ff, 0xc198,		0x21, 0
	.dw 0xa940, 0xc198,	0xa97f, 0xc198,		0x21, 0
	.dw 0xa9c0, 0xc198,	0xa9ff, 0xc198,		0x21, 0
	.dw 0xaa40, 0xc198,	0xaa7f, 0xc198,		0x21, 0
	.dw 0xaac0, 0xc198,	0xaaff, 0xc198,		0x21, 0
	.dw 0xab40, 0xc198,	0xab7f, 0xc198,		0x21, 0
	.dw 0xabc0, 0xc198,	0xabff, 0xc198,		0x21, 0
	.dw 0xac40, 0xc198,	0xac7f, 0xc198,		0x21, 0
	.dw 0xacc0, 0xc198,	0xacff, 0xc198,		0x21, 0
	.dw 0xad40, 0xc198,	0xad7f, 0xc198,		0x21, 0
	.dw 0xadc0, 0xc198,	0xadff, 0xc198,		0x21, 0
	.dw 0xae40, 0xc198,	0xae7f, 0xc198,		0x21, 0
	.dw 0xaec0, 0xc198,	0xaeff, 0xc198,		0x21, 0
	.dw 0xaf40, 0xc198,	0xaf7f, 0xc198,		0x21, 0
	.dw 0xafc0, 0xc198,	0xafff, 0xc198,		0x21, 0
	.dw 0xb040, 0xc198,	0xb07f, 0xc198,		0x21, 0
	.dw 0xb0c0, 0xc198,	0xb0ff, 0xc198,		0x21, 0
	.dw 0xb140, 0xc198,	0xb17f, 0xc198,		0x21, 0
	.dw 0xb1c0, 0xc198,	0xb1ff, 0xc198,		0x21, 0
	.dw 0xb240, 0xc198,	0xb27f, 0xc198,		0x21, 0
	.dw 0xb2c0, 0xc198,	0xb2ff, 0xc198,		0x21, 0
	.dw 0xb340, 0xc198,	0xb37f, 0xc198,		0x21, 0
	.dw 0xb3c0, 0xc198,	0xb3ff, 0xc198,		0x21, 0
	.dw 0xb440, 0xc198,	0xb47f, 0xc198,		0x21, 0
	.dw 0xb4c0, 0xc198,	0xb4ff, 0xc198,		0x21, 0
	.dw 0xb540, 0xc198,	0xb57f, 0xc198,		0x21, 0
	.dw 0xb5c0, 0xc198,	0xb5ff, 0xc198,		0x21, 0
	.dw 0xb640, 0xc198,	0xb67f, 0xc198,		0x21, 0
	.dw 0xb6c0, 0xc198,	0xb6ff, 0xc198,		0x21, 0
	.dw 0xb740, 0xc198,	0xb77f, 0xc198,		0x21, 0
	.dw 0xb7c0, 0xc198,	0xb7ff, 0xc198,		0x21, 0
	.dw 0xb840, 0xc198,	0xb87f, 0xc198,		0x21, 0
	.dw 0xb8c0, 0xc198,	0xb8ff, 0xc198,		0x21, 0
	.dw 0xb940, 0xc198,	0xb97f, 0xc198,		0x21, 0
	.dw 0xb9c0, 0xc198,	0xdfff, 0xc198,		0x21, 0
	.dw 0xe040, 0xc198,	0xe07f, 0xc198,		0x21, 0
	.dw 0xe0c0, 0xc198,	0xe0ff, 0xc198,		0x21, 0
	.dw 0xe140, 0xc198,	0xe17f, 0xc198,		0x21, 0
	.dw 0xe1c0, 0xc198,	0xe1ff, 0xc198,		0x21, 0
	.dw 0xe240, 0xc198,	0xe27f, 0xc198,		0x21, 0
	.dw 0xe2c0, 0xc198,	0xe2ff, 0xc198,		0x21, 0
	.dw 0xe340, 0xc198,	0xe37f, 0xc198,		0x21, 0
	.dw 0xe3c0, 0xc198,	0xe3ff, 0xc198,		0x21, 0
	.dw 0xe440, 0xc198,	0xe47f, 0xc198,		0x21, 0
	.dw 0xe4c0, 0xc198,	0xe4ff, 0xc198,		0x21, 0
	.dw 0xe540, 0xc198,	0xe57f, 0xc198,		0x21, 0
	.dw 0xe5c0, 0xc198,	0xe5ff, 0xc198,		0x21, 0
	.dw 0xe640, 0xc198,	0xe67f, 0xc198,		0x21, 0
	.dw 0xe6c0, 0xc198,	0xe6ff, 0xc198,		0x21, 0
	.dw 0xe740, 0xc198,	0xe77f, 0xc198,		0x21, 0
	.dw 0xe7c0, 0xc198,	0xe7ff, 0xc198,		0x21, 0
	.dw 0xe840, 0xc198,	0xe87f, 0xc198,		0x21, 0
	.dw 0xe8c0, 0xc198,	0xe8ff, 0xc198,		0x21, 0
	.dw 0xe940, 0xc198,	0xe97f, 0xc198,		0x21, 0
	.dw 0xe9c0, 0xc198,	0xe9ff, 0xc198,		0x21, 0
	.dw 0xea40, 0xc198,	0xea7f, 0xc198,		0x21, 0
	.dw 0xeac0, 0xc198,	0xeaff, 0xc198,		0x21, 0
	.dw 0xeb40, 0xc198,	0xeb7f, 0xc198,		0x21, 0
	.dw 0xebc0, 0xc198,	0xebff, 0xc198,		0x21, 0
	.dw 0xec40, 0xc198,	0xec7f, 0xc198,		0x21, 0
	.dw 0xecc0, 0xc198,	0xecff, 0xc198,		0x21, 0
	.dw 0xed40, 0xc198,	0xed7f, 0xc198,		0x21, 0
	.dw 0xedc0, 0xc198,	0xedff, 0xc198,		0x21, 0
	.dw 0xee40, 0xc198,	0xee7f, 0xc198,		0x21, 0
	.dw 0xeec0, 0xc198,	0xeeff, 0xc198,		0x21, 0
	.dw 0xef40, 0xc198,	0xef7f, 0xc198,		0x21, 0
	.dw 0xefc0, 0xc198,	0xefff, 0xc198,		0x21, 0
	.dw 0xf040, 0xc198,	0xf07f, 0xc198,		0x21, 0
	.dw 0xf0c0, 0xc198,	0xf0ff, 0xc198,		0x21, 0
	.dw 0xf140, 0xc198,	0xf17f, 0xc198,		0x21, 0
	.dw 0xf1c0, 0xc198,	0xf1ff, 0xc198,		0x21, 0
	.dw 0xf240, 0xc198,	0xf27f, 0xc198,		0x21, 0
	.dw 0xf2c0, 0xc198,	0xf2ff, 0xc198,		0x21, 0
	.dw 0xf340, 0xc198,	0xf37f, 0xc198,		0x21, 0
	.dw 0xf3c0, 0xc198,	0xf3ff, 0xc198,		0x21, 0
	.dw 0xf440, 0xc198,	0xf47f, 0xc198,		0x21, 0
	.dw 0xf4c0, 0xc198,	0xf4ff, 0xc198,		0x21, 0
	.dw 0xf540, 0xc198,	0xf57f, 0xc198,		0x21, 0
	.dw 0xf5c0, 0xc198,	0xf5ff, 0xc198,		0x21, 0
	.dw 0xf640, 0xc198,	0xf67f, 0xc198,		0x21, 0
	.dw 0xf6c0, 0xc198,	0xf6ff, 0xc198,		0x21, 0
	.dw 0xf740, 0xc198,	0xf77f, 0xc198,		0x21, 0
	.dw 0xf7c0, 0xc198,	0xf7ff, 0xc198,		0x21, 0
	.dw 0xf840, 0xc198,	0xf87f, 0xc198,		0x21, 0
	.dw 0xf8c0, 0xc198,	0xf8ff, 0xc198,		0x21, 0
	.dw 0xf940, 0xc198,	0xf97f, 0xc198,		0x21, 0
	.dw 0xf9c0, 0xc198,	0x1fff, 0xc199,		0x21, 0
	.dw 0x2040, 0xc199,	0x207f, 0xc199,		0x21, 0
	.dw 0x20c0, 0xc199,	0x20ff, 0xc199,		0x21, 0
	.dw 0x2140, 0xc199,	0x217f, 0xc199,		0x21, 0
	.dw 0x21c0, 0xc199,	0x21ff, 0xc199,		0x21, 0
	.dw 0x2240, 0xc199,	0x227f, 0xc199,		0x21, 0
	.dw 0x22c0, 0xc199,	0x22ff, 0xc199,		0x21, 0
	.dw 0x2340, 0xc199,	0x237f, 0xc199,		0x21, 0
	.dw 0x23c0, 0xc199,	0x23ff, 0xc199,		0x21, 0
	.dw 0x2440, 0xc199,	0x247f, 0xc199,		0x21, 0
	.dw 0x24c0, 0xc199,	0x24ff, 0xc199,		0x21, 0
	.dw 0x2540, 0xc199,	0x257f, 0xc199,		0x21, 0
	.dw 0x25c0, 0xc199,	0x25ff, 0xc199,		0x21, 0
	.dw 0x2640, 0xc199,	0x267f, 0xc199,		0x21, 0
	.dw 0x26c0, 0xc199,	0x26ff, 0xc199,		0x21, 0
	.dw 0x2740, 0xc199,	0x277f, 0xc199,		0x21, 0
	.dw 0x27c0, 0xc199,	0x27ff, 0xc199,		0x21, 0
	.dw 0x2840, 0xc199,	0x287f, 0xc199,		0x21, 0
	.dw 0x28c0, 0xc199,	0x28ff, 0xc199,		0x21, 0
	.dw 0x2940, 0xc199,	0x297f, 0xc199,		0x21, 0
	.dw 0x29c0, 0xc199,	0x29ff, 0xc199,		0x21, 0
	.dw 0x2a40, 0xc199,	0x2a7f, 0xc199,		0x21, 0
	.dw 0x2ac0, 0xc199,	0x2aff, 0xc199,		0x21, 0
	.dw 0x2b40, 0xc199,	0x2b7f, 0xc199,		0x21, 0
	.dw 0x2bc0, 0xc199,	0x2bff, 0xc199,		0x21, 0
	.dw 0x2c40, 0xc199,	0x2c7f, 0xc199,		0x21, 0
	.dw 0x2cc0, 0xc199,	0x2cff, 0xc199,		0x21, 0
	.dw 0x2d40, 0xc199,	0x2d7f, 0xc199,		0x21, 0
	.dw 0x2dc0, 0xc199,	0x2dff, 0xc199,		0x21, 0
	.dw 0x2e40, 0xc199,	0x2e7f, 0xc199,		0x21, 0
	.dw 0x2ec0, 0xc199,	0x2eff, 0xc199,		0x21, 0
	.dw 0x2f40, 0xc199,	0x2f7f, 0xc199,		0x21, 0
	.dw 0x2fc0, 0xc199,	0x2fff, 0xc199,		0x21, 0
	.dw 0x3040, 0xc199,	0x307f, 0xc199,		0x21, 0
	.dw 0x30c0, 0xc199,	0x30ff, 0xc199,		0x21, 0
	.dw 0x3140, 0xc199,	0x317f, 0xc199,		0x21, 0
	.dw 0x31c0, 0xc199,	0x31ff, 0xc199,		0x21, 0
	.dw 0x3240, 0xc199,	0x327f, 0xc199,		0x21, 0
	.dw 0x32c0, 0xc199,	0x32ff, 0xc199,		0x21, 0
	.dw 0x3340, 0xc199,	0x337f, 0xc199,		0x21, 0
	.dw 0x33c0, 0xc199,	0x33ff, 0xc199,		0x21, 0
	.dw 0x3440, 0xc199,	0x347f, 0xc199,		0x21, 0
	.dw 0x34c0, 0xc199,	0x34ff, 0xc199,		0x21, 0
	.dw 0x3540, 0xc199,	0x357f, 0xc199,		0x21, 0
	.dw 0x35c0, 0xc199,	0x35ff, 0xc199,		0x21, 0
	.dw 0x3640, 0xc199,	0x367f, 0xc199,		0x21, 0
	.dw 0x36c0, 0xc199,	0x36ff, 0xc199,		0x21, 0
	.dw 0x3740, 0xc199,	0x377f, 0xc199,		0x21, 0
	.dw 0x37c0, 0xc199,	0x37ff, 0xc199,		0x21, 0
	.dw 0x3840, 0xc199,	0x387f, 0xc199,		0x21, 0
	.dw 0x38c0, 0xc199,	0x38ff, 0xc199,		0x21, 0
	.dw 0x3940, 0xc199,	0x397f, 0xc199,		0x21, 0
	.dw 0x39c0, 0xc199,	0x5fff, 0xc199,		0x21, 0
	.dw 0x6040, 0xc199,	0x607f, 0xc199,		0x21, 0
	.dw 0x60c0, 0xc199,	0x60ff, 0xc199,		0x21, 0
	.dw 0x6140, 0xc199,	0x617f, 0xc199,		0x21, 0
	.dw 0x61c0, 0xc199,	0x61ff, 0xc199,		0x21, 0
	.dw 0x6240, 0xc199,	0x627f, 0xc199,		0x21, 0
	.dw 0x62c0, 0xc199,	0x62ff, 0xc199,		0x21, 0
	.dw 0x6340, 0xc199,	0x637f, 0xc199,		0x21, 0
	.dw 0x63c0, 0xc199,	0x63ff, 0xc199,		0x21, 0
	.dw 0x6440, 0xc199,	0x647f, 0xc199,		0x21, 0
	.dw 0x64c0, 0xc199,	0x64ff, 0xc199,		0x21, 0
	.dw 0x6540, 0xc199,	0x657f, 0xc199,		0x21, 0
	.dw 0x65c0, 0xc199,	0x65ff, 0xc199,		0x21, 0
	.dw 0x6640, 0xc199,	0x667f, 0xc199,		0x21, 0
	.dw 0x66c0, 0xc199,	0x66ff, 0xc199,		0x21, 0
	.dw 0x6740, 0xc199,	0x677f, 0xc199,		0x21, 0
	.dw 0x67c0, 0xc199,	0x67ff, 0xc199,		0x21, 0
	.dw 0x6840, 0xc199,	0x687f, 0xc199,		0x21, 0
	.dw 0x68c0, 0xc199,	0x68ff, 0xc199,		0x21, 0
	.dw 0x6940, 0xc199,	0x697f, 0xc199,		0x21, 0
	.dw 0x69c0, 0xc199,	0x69ff, 0xc199,		0x21, 0
	.dw 0x6a40, 0xc199,	0x6a7f, 0xc199,		0x21, 0
	.dw 0x6ac0, 0xc199,	0x6aff, 0xc199,		0x21, 0
	.dw 0x6b40, 0xc199,	0x6b7f, 0xc199,		0x21, 0
	.dw 0x6bc0, 0xc199,	0x6bff, 0xc199,		0x21, 0
	.dw 0x6c40, 0xc199,	0x6c7f, 0xc199,		0x21, 0
	.dw 0x6cc0, 0xc199,	0x6cff, 0xc199,		0x21, 0
	.dw 0x6d40, 0xc199,	0x6d7f, 0xc199,		0x21, 0
	.dw 0x6dc0, 0xc199,	0x6dff, 0xc199,		0x21, 0
	.dw 0x6e40, 0xc199,	0x6e7f, 0xc199,		0x21, 0
	.dw 0x6ec0, 0xc199,	0x6eff, 0xc199,		0x21, 0
	.dw 0x6f40, 0xc199,	0x6f7f, 0xc199,		0x21, 0
	.dw 0x6fc0, 0xc199,	0x6fff, 0xc199,		0x21, 0
	.dw 0x7040, 0xc199,	0x707f, 0xc199,		0x21, 0
	.dw 0x70c0, 0xc199,	0x70ff, 0xc199,		0x21, 0
	.dw 0x7140, 0xc199,	0x717f, 0xc199,		0x21, 0
	.dw 0x71c0, 0xc199,	0x71ff, 0xc199,		0x21, 0
	.dw 0x7240, 0xc199,	0x727f, 0xc199,		0x21, 0
	.dw 0x72c0, 0xc199,	0x72ff, 0xc199,		0x21, 0
	.dw 0x7340, 0xc199,	0x737f, 0xc199,		0x21, 0
	.dw 0x73c0, 0xc199,	0x73ff, 0xc199,		0x21, 0
	.dw 0x7440, 0xc199,	0x747f, 0xc199,		0x21, 0
	.dw 0x74c0, 0xc199,	0x74ff, 0xc199,		0x21, 0
	.dw 0x7540, 0xc199,	0x757f, 0xc199,		0x21, 0
	.dw 0x75c0, 0xc199,	0x75ff, 0xc199,		0x21, 0
	.dw 0x7640, 0xc199,	0x767f, 0xc199,		0x21, 0
	.dw 0x76c0, 0xc199,	0x76ff, 0xc199,		0x21, 0
	.dw 0x7740, 0xc199,	0x777f, 0xc199,		0x21, 0
	.dw 0x77c0, 0xc199,	0x77ff, 0xc199,		0x21, 0
	.dw 0x7840, 0xc199,	0x787f, 0xc199,		0x21, 0
	.dw 0x78c0, 0xc199,	0x78ff, 0xc199,		0x21, 0
	.dw 0x7940, 0xc199,	0x797f, 0xc199,		0x21, 0
	.dw 0x79c0, 0xc199,	0x9fff, 0xc199,		0x21, 0
	.dw 0xa040, 0xc199,	0xa07f, 0xc199,		0x21, 0
	.dw 0xa0c0, 0xc199,	0xa0ff, 0xc199,		0x21, 0
	.dw 0xa140, 0xc199,	0xa17f, 0xc199,		0x21, 0
	.dw 0xa1c0, 0xc199,	0xa1ff, 0xc199,		0x21, 0
	.dw 0xa240, 0xc199,	0xa27f, 0xc199,		0x21, 0
	.dw 0xa2c0, 0xc199,	0xa2ff, 0xc199,		0x21, 0
	.dw 0xa340, 0xc199,	0xa37f, 0xc199,		0x21, 0
	.dw 0xa3c0, 0xc199,	0xa3ff, 0xc199,		0x21, 0
	.dw 0xa440, 0xc199,	0xa47f, 0xc199,		0x21, 0
	.dw 0xa4c0, 0xc199,	0xa4ff, 0xc199,		0x21, 0
	.dw 0xa540, 0xc199,	0xa57f, 0xc199,		0x21, 0
	.dw 0xa5c0, 0xc199,	0xa5ff, 0xc199,		0x21, 0
	.dw 0xa640, 0xc199,	0xa67f, 0xc199,		0x21, 0
	.dw 0xa6c0, 0xc199,	0xa6ff, 0xc199,		0x21, 0
	.dw 0xa740, 0xc199,	0xa77f, 0xc199,		0x21, 0
	.dw 0xa7c0, 0xc199,	0xa7ff, 0xc199,		0x21, 0
	.dw 0xa840, 0xc199,	0xa87f, 0xc199,		0x21, 0
	.dw 0xa8c0, 0xc199,	0xa8ff, 0xc199,		0x21, 0
	.dw 0xa940, 0xc199,	0xa97f, 0xc199,		0x21, 0
	.dw 0xa9c0, 0xc199,	0xa9ff, 0xc199,		0x21, 0
	.dw 0xaa40, 0xc199,	0xaa7f, 0xc199,		0x21, 0
	.dw 0xaac0, 0xc199,	0xaaff, 0xc199,		0x21, 0
	.dw 0xab40, 0xc199,	0xab7f, 0xc199,		0x21, 0
	.dw 0xabc0, 0xc199,	0xabff, 0xc199,		0x21, 0
	.dw 0xac40, 0xc199,	0xac7f, 0xc199,		0x21, 0
	.dw 0xacc0, 0xc199,	0xacff, 0xc199,		0x21, 0
	.dw 0xad40, 0xc199,	0xad7f, 0xc199,		0x21, 0
	.dw 0xadc0, 0xc199,	0xadff, 0xc199,		0x21, 0
	.dw 0xae40, 0xc199,	0xae7f, 0xc199,		0x21, 0
	.dw 0xaec0, 0xc199,	0xaeff, 0xc199,		0x21, 0
	.dw 0xaf40, 0xc199,	0xaf7f, 0xc199,		0x21, 0
	.dw 0xafc0, 0xc199,	0xafff, 0xc199,		0x21, 0
	.dw 0xb040, 0xc199,	0xb07f, 0xc199,		0x21, 0
	.dw 0xb0c0, 0xc199,	0xb0ff, 0xc199,		0x21, 0
	.dw 0xb140, 0xc199,	0xb17f, 0xc199,		0x21, 0
	.dw 0xb1c0, 0xc199,	0xb1ff, 0xc199,		0x21, 0
	.dw 0xb240, 0xc199,	0xb27f, 0xc199,		0x21, 0
	.dw 0xb2c0, 0xc199,	0xb2ff, 0xc199,		0x21, 0
	.dw 0xb340, 0xc199,	0xb37f, 0xc199,		0x21, 0
	.dw 0xb3c0, 0xc199,	0xb3ff, 0xc199,		0x21, 0
	.dw 0xb440, 0xc199,	0xb47f, 0xc199,		0x21, 0
	.dw 0xb4c0, 0xc199,	0xb4ff, 0xc199,		0x21, 0
	.dw 0xb540, 0xc199,	0xb57f, 0xc199,		0x21, 0
	.dw 0xb5c0, 0xc199,	0xb5ff, 0xc199,		0x21, 0
	.dw 0xb640, 0xc199,	0xb67f, 0xc199,		0x21, 0
	.dw 0xb6c0, 0xc199,	0xb6ff, 0xc199,		0x21, 0
	.dw 0xb740, 0xc199,	0xb77f, 0xc199,		0x21, 0
	.dw 0xb7c0, 0xc199,	0xb7ff, 0xc199,		0x21, 0
	.dw 0xb840, 0xc199,	0xb87f, 0xc199,		0x21, 0
	.dw 0xb8c0, 0xc199,	0xb8ff, 0xc199,		0x21, 0
	.dw 0xb940, 0xc199,	0xb97f, 0xc199,		0x21, 0
	.dw 0xb9c0, 0xc199,	0xdfff, 0xc199,		0x21, 0
	.dw 0xe040, 0xc199,	0xe07f, 0xc199,		0x21, 0
	.dw 0xe0c0, 0xc199,	0xe0ff, 0xc199,		0x21, 0
	.dw 0xe140, 0xc199,	0xe17f, 0xc199,		0x21, 0
	.dw 0xe1c0, 0xc199,	0xe1ff, 0xc199,		0x21, 0
	.dw 0xe240, 0xc199,	0xe27f, 0xc199,		0x21, 0
	.dw 0xe2c0, 0xc199,	0xe2ff, 0xc199,		0x21, 0
	.dw 0xe340, 0xc199,	0xe37f, 0xc199,		0x21, 0
	.dw 0xe3c0, 0xc199,	0xe3ff, 0xc199,		0x21, 0
	.dw 0xe440, 0xc199,	0xe47f, 0xc199,		0x21, 0
	.dw 0xe4c0, 0xc199,	0xe4ff, 0xc199,		0x21, 0
	.dw 0xe540, 0xc199,	0xe57f, 0xc199,		0x21, 0
	.dw 0xe5c0, 0xc199,	0xe5ff, 0xc199,		0x21, 0
	.dw 0xe640, 0xc199,	0xe67f, 0xc199,		0x21, 0
	.dw 0xe6c0, 0xc199,	0xe6ff, 0xc199,		0x21, 0
	.dw 0xe740, 0xc199,	0xe77f, 0xc199,		0x21, 0
	.dw 0xe7c0, 0xc199,	0xe7ff, 0xc199,		0x21, 0
	.dw 0xe840, 0xc199,	0xe87f, 0xc199,		0x21, 0
	.dw 0xe8c0, 0xc199,	0xe8ff, 0xc199,		0x21, 0
	.dw 0xe940, 0xc199,	0xe97f, 0xc199,		0x21, 0
	.dw 0xe9c0, 0xc199,	0xe9ff, 0xc199,		0x21, 0
	.dw 0xea40, 0xc199,	0xea7f, 0xc199,		0x21, 0
	.dw 0xeac0, 0xc199,	0xeaff, 0xc199,		0x21, 0
	.dw 0xeb40, 0xc199,	0xeb7f, 0xc199,		0x21, 0
	.dw 0xebc0, 0xc199,	0xebff, 0xc199,		0x21, 0
	.dw 0xec40, 0xc199,	0xec7f, 0xc199,		0x21, 0
	.dw 0xecc0, 0xc199,	0xecff, 0xc199,		0x21, 0
	.dw 0xed40, 0xc199,	0xed7f, 0xc199,		0x21, 0
	.dw 0xedc0, 0xc199,	0xedff, 0xc199,		0x21, 0
	.dw 0xee40, 0xc199,	0xee7f, 0xc199,		0x21, 0
	.dw 0xeec0, 0xc199,	0xeeff, 0xc199,		0x21, 0
	.dw 0xef40, 0xc199,	0xef7f, 0xc199,		0x21, 0
	.dw 0xefc0, 0xc199,	0xefff, 0xc199,		0x21, 0
	.dw 0xf040, 0xc199,	0xf07f, 0xc199,		0x21, 0
	.dw 0xf0c0, 0xc199,	0xf0ff, 0xc199,		0x21, 0
	.dw 0xf140, 0xc199,	0xf17f, 0xc199,		0x21, 0
	.dw 0xf1c0, 0xc199,	0xf1ff, 0xc199,		0x21, 0
	.dw 0xf240, 0xc199,	0xf27f, 0xc199,		0x21, 0
	.dw 0xf2c0, 0xc199,	0xf2ff, 0xc199,		0x21, 0
	.dw 0xf340, 0xc199,	0xf37f, 0xc199,		0x21, 0
	.dw 0xf3c0, 0xc199,	0xf3ff, 0xc199,		0x21, 0
	.dw 0xf440, 0xc199,	0xf47f, 0xc199,		0x21, 0
	.dw 0xf4c0, 0xc199,	0xf4ff, 0xc199,		0x21, 0
	.dw 0xf540, 0xc199,	0xf57f, 0xc199,		0x21, 0
	.dw 0xf5c0, 0xc199,	0xf5ff, 0xc199,		0x21, 0
	.dw 0xf640, 0xc199,	0xf67f, 0xc199,		0x21, 0
	.dw 0xf6c0, 0xc199,	0xf6ff, 0xc199,		0x21, 0
	.dw 0xf740, 0xc199,	0xf77f, 0xc199,		0x21, 0
	.dw 0xf7c0, 0xc199,	0xf7ff, 0xc199,		0x21, 0
	.dw 0xf840, 0xc199,	0xf87f, 0xc199,		0x21, 0
	.dw 0xf8c0, 0xc199,	0xf8ff, 0xc199,		0x21, 0
	.dw 0xf940, 0xc199,	0xf97f, 0xc199,		0x21, 0
	.dw 0xf9c0, 0xc199,	0x1fff, 0xc19a,		0x21, 0
	.dw 0x2040, 0xc19a,	0x207f, 0xc19a,		0x21, 0
	.dw 0x20c0, 0xc19a,	0x20ff, 0xc19a,		0x21, 0
	.dw 0x2140, 0xc19a,	0x217f, 0xc19a,		0x21, 0
	.dw 0x21c0, 0xc19a,	0x21ff, 0xc19a,		0x21, 0
	.dw 0x2240, 0xc19a,	0x227f, 0xc19a,		0x21, 0
	.dw 0x22c0, 0xc19a,	0x22ff, 0xc19a,		0x21, 0
	.dw 0x2340, 0xc19a,	0x237f, 0xc19a,		0x21, 0
	.dw 0x23c0, 0xc19a,	0x23ff, 0xc19a,		0x21, 0
	.dw 0x2440, 0xc19a,	0x247f, 0xc19a,		0x21, 0
	.dw 0x24c0, 0xc19a,	0x24ff, 0xc19a,		0x21, 0
	.dw 0x2540, 0xc19a,	0x257f, 0xc19a,		0x21, 0
	.dw 0x25c0, 0xc19a,	0x25ff, 0xc19a,		0x21, 0
	.dw 0x2640, 0xc19a,	0x267f, 0xc19a,		0x21, 0
	.dw 0x26c0, 0xc19a,	0x26ff, 0xc19a,		0x21, 0
	.dw 0x2740, 0xc19a,	0x277f, 0xc19a,		0x21, 0
	.dw 0x27c0, 0xc19a,	0x27ff, 0xc19a,		0x21, 0
	.dw 0x2840, 0xc19a,	0x287f, 0xc19a,		0x21, 0
	.dw 0x28c0, 0xc19a,	0x28ff, 0xc19a,		0x21, 0
	.dw 0x2940, 0xc19a,	0x297f, 0xc19a,		0x21, 0
	.dw 0x29c0, 0xc19a,	0x29ff, 0xc19a,		0x21, 0
	.dw 0x2a40, 0xc19a,	0x2a7f, 0xc19a,		0x21, 0
	.dw 0x2ac0, 0xc19a,	0x2aff, 0xc19a,		0x21, 0
	.dw 0x2b40, 0xc19a,	0x2b7f, 0xc19a,		0x21, 0
	.dw 0x2bc0, 0xc19a,	0x2bff, 0xc19a,		0x21, 0
	.dw 0x2c40, 0xc19a,	0x2c7f, 0xc19a,		0x21, 0
	.dw 0x2cc0, 0xc19a,	0x2cff, 0xc19a,		0x21, 0
	.dw 0x2d40, 0xc19a,	0x2d7f, 0xc19a,		0x21, 0
	.dw 0x2dc0, 0xc19a,	0x2dff, 0xc19a,		0x21, 0
	.dw 0x2e40, 0xc19a,	0x2e7f, 0xc19a,		0x21, 0
	.dw 0x2ec0, 0xc19a,	0x2eff, 0xc19a,		0x21, 0
	.dw 0x2f40, 0xc19a,	0x2f7f, 0xc19a,		0x21, 0
	.dw 0x2fc0, 0xc19a,	0x2fff, 0xc19a,		0x21, 0
	.dw 0x3040, 0xc19a,	0x307f, 0xc19a,		0x21, 0
	.dw 0x30c0, 0xc19a,	0x30ff, 0xc19a,		0x21, 0
	.dw 0x3140, 0xc19a,	0x317f, 0xc19a,		0x21, 0
	.dw 0x31c0, 0xc19a,	0x31ff, 0xc19a,		0x21, 0
	.dw 0x3240, 0xc19a,	0x327f, 0xc19a,		0x21, 0
	.dw 0x32c0, 0xc19a,	0x32ff, 0xc19a,		0x21, 0
	.dw 0x3340, 0xc19a,	0x337f, 0xc19a,		0x21, 0
	.dw 0x33c0, 0xc19a,	0x33ff, 0xc19a,		0x21, 0
	.dw 0x3440, 0xc19a,	0x347f, 0xc19a,		0x21, 0
	.dw 0x34c0, 0xc19a,	0x34ff, 0xc19a,		0x21, 0
	.dw 0x3540, 0xc19a,	0x357f, 0xc19a,		0x21, 0
	.dw 0x35c0, 0xc19a,	0x35ff, 0xc19a,		0x21, 0
	.dw 0x3640, 0xc19a,	0x367f, 0xc19a,		0x21, 0
	.dw 0x36c0, 0xc19a,	0x36ff, 0xc19a,		0x21, 0
	.dw 0x3740, 0xc19a,	0x377f, 0xc19a,		0x21, 0
	.dw 0x37c0, 0xc19a,	0x37ff, 0xc19a,		0x21, 0
	.dw 0x3840, 0xc19a,	0x387f, 0xc19a,		0x21, 0
	.dw 0x38c0, 0xc19a,	0x38ff, 0xc19a,		0x21, 0
	.dw 0x3940, 0xc19a,	0x397f, 0xc19a,		0x21, 0
	.dw 0x39c0, 0xc19a,	0x5fff, 0xc19a,		0x21, 0
	.dw 0x6040, 0xc19a,	0x607f, 0xc19a,		0x21, 0
	.dw 0x60c0, 0xc19a,	0x60ff, 0xc19a,		0x21, 0
	.dw 0x6140, 0xc19a,	0x617f, 0xc19a,		0x21, 0
	.dw 0x61c0, 0xc19a,	0x61ff, 0xc19a,		0x21, 0
	.dw 0x6240, 0xc19a,	0x627f, 0xc19a,		0x21, 0
	.dw 0x62c0, 0xc19a,	0x62ff, 0xc19a,		0x21, 0
	.dw 0x6340, 0xc19a,	0x637f, 0xc19a,		0x21, 0
	.dw 0x63c0, 0xc19a,	0x63ff, 0xc19a,		0x21, 0
	.dw 0x6440, 0xc19a,	0x647f, 0xc19a,		0x21, 0
	.dw 0x64c0, 0xc19a,	0x64ff, 0xc19a,		0x21, 0
	.dw 0x6540, 0xc19a,	0x657f, 0xc19a,		0x21, 0
	.dw 0x65c0, 0xc19a,	0x65ff, 0xc19a,		0x21, 0
	.dw 0x6640, 0xc19a,	0x667f, 0xc19a,		0x21, 0
	.dw 0x66c0, 0xc19a,	0x66ff, 0xc19a,		0x21, 0
	.dw 0x6740, 0xc19a,	0x677f, 0xc19a,		0x21, 0
	.dw 0x67c0, 0xc19a,	0x67ff, 0xc19a,		0x21, 0
	.dw 0x6840, 0xc19a,	0x687f, 0xc19a,		0x21, 0
	.dw 0x68c0, 0xc19a,	0x68ff, 0xc19a,		0x21, 0
	.dw 0x6940, 0xc19a,	0x697f, 0xc19a,		0x21, 0
	.dw 0x69c0, 0xc19a,	0x69ff, 0xc19a,		0x21, 0
	.dw 0x6a40, 0xc19a,	0x6a7f, 0xc19a,		0x21, 0
	.dw 0x6ac0, 0xc19a,	0x6aff, 0xc19a,		0x21, 0
	.dw 0x6b40, 0xc19a,	0x6b7f, 0xc19a,		0x21, 0
	.dw 0x6bc0, 0xc19a,	0x6bff, 0xc19a,		0x21, 0
	.dw 0x6c40, 0xc19a,	0x6c7f, 0xc19a,		0x21, 0
	.dw 0x6cc0, 0xc19a,	0x6cff, 0xc19a,		0x21, 0
	.dw 0x6d40, 0xc19a,	0x6d7f, 0xc19a,		0x21, 0
	.dw 0x6dc0, 0xc19a,	0x6dff, 0xc19a,		0x21, 0
	.dw 0x6e40, 0xc19a,	0x6e7f, 0xc19a,		0x21, 0
	.dw 0x6ec0, 0xc19a,	0x6eff, 0xc19a,		0x21, 0
	.dw 0x6f40, 0xc19a,	0x6f7f, 0xc19a,		0x21, 0
	.dw 0x6fc0, 0xc19a,	0x6fff, 0xc19a,		0x21, 0
	.dw 0x7040, 0xc19a,	0x707f, 0xc19a,		0x21, 0
	.dw 0x70c0, 0xc19a,	0x70ff, 0xc19a,		0x21, 0
	.dw 0x7140, 0xc19a,	0x717f, 0xc19a,		0x21, 0
	.dw 0x71c0, 0xc19a,	0x71ff, 0xc19a,		0x21, 0
	.dw 0x7240, 0xc19a,	0x727f, 0xc19a,		0x21, 0
	.dw 0x72c0, 0xc19a,	0x72ff, 0xc19a,		0x21, 0
	.dw 0x7340, 0xc19a,	0x737f, 0xc19a,		0x21, 0
	.dw 0x73c0, 0xc19a,	0x73ff, 0xc19a,		0x21, 0
	.dw 0x7440, 0xc19a,	0x747f, 0xc19a,		0x21, 0
	.dw 0x74c0, 0xc19a,	0x74ff, 0xc19a,		0x21, 0
	.dw 0x7540, 0xc19a,	0x757f, 0xc19a,		0x21, 0
	.dw 0x75c0, 0xc19a,	0x75ff, 0xc19a,		0x21, 0
	.dw 0x7640, 0xc19a,	0x767f, 0xc19a,		0x21, 0
	.dw 0x76c0, 0xc19a,	0x76ff, 0xc19a,		0x21, 0
	.dw 0x7740, 0xc19a,	0x777f, 0xc19a,		0x21, 0
	.dw 0x77c0, 0xc19a,	0x77ff, 0xc19a,		0x21, 0
	.dw 0x7840, 0xc19a,	0x787f, 0xc19a,		0x21, 0
	.dw 0x78c0, 0xc19a,	0x78ff, 0xc19a,		0x21, 0
	.dw 0x7940, 0xc19a,	0x797f, 0xc19a,		0x21, 0
	.dw 0x79c0, 0xc19a,	0x9fff, 0xc19a,		0x21, 0
	.dw 0xa040, 0xc19a,	0xa07f, 0xc19a,		0x21, 0
	.dw 0xa0c0, 0xc19a,	0xa0ff, 0xc19a,		0x21, 0
	.dw 0xa140, 0xc19a,	0xa17f, 0xc19a,		0x21, 0
	.dw 0xa1c0, 0xc19a,	0xa1ff, 0xc19a,		0x21, 0
	.dw 0xa240, 0xc19a,	0xa27f, 0xc19a,		0x21, 0
	.dw 0xa2c0, 0xc19a,	0xa2ff, 0xc19a,		0x21, 0
	.dw 0xa340, 0xc19a,	0xa37f, 0xc19a,		0x21, 0
	.dw 0xa3c0, 0xc19a,	0xa3ff, 0xc19a,		0x21, 0
	.dw 0xa440, 0xc19a,	0xa47f, 0xc19a,		0x21, 0
	.dw 0xa4c0, 0xc19a,	0xa4ff, 0xc19a,		0x21, 0
	.dw 0xa540, 0xc19a,	0xa57f, 0xc19a,		0x21, 0
	.dw 0xa5c0, 0xc19a,	0xa5ff, 0xc19a,		0x21, 0
	.dw 0xa640, 0xc19a,	0xa67f, 0xc19a,		0x21, 0
	.dw 0xa6c0, 0xc19a,	0xa6ff, 0xc19a,		0x21, 0
	.dw 0xa740, 0xc19a,	0xa77f, 0xc19a,		0x21, 0
	.dw 0xa7c0, 0xc19a,	0xa7ff, 0xc19a,		0x21, 0
	.dw 0xa840, 0xc19a,	0xa87f, 0xc19a,		0x21, 0
	.dw 0xa8c0, 0xc19a,	0xa8ff, 0xc19a,		0x21, 0
	.dw 0xa940, 0xc19a,	0xa97f, 0xc19a,		0x21, 0
	.dw 0xa9c0, 0xc19a,	0xa9ff, 0xc19a,		0x21, 0
	.dw 0xaa40, 0xc19a,	0xaa7f, 0xc19a,		0x21, 0
	.dw 0xaac0, 0xc19a,	0xaaff, 0xc19a,		0x21, 0
	.dw 0xab40, 0xc19a,	0xab7f, 0xc19a,		0x21, 0
	.dw 0xabc0, 0xc19a,	0xabff, 0xc19a,		0x21, 0
	.dw 0xac40, 0xc19a,	0xac7f, 0xc19a,		0x21, 0
	.dw 0xacc0, 0xc19a,	0xacff, 0xc19a,		0x21, 0
	.dw 0xad40, 0xc19a,	0xad7f, 0xc19a,		0x21, 0
	.dw 0xadc0, 0xc19a,	0xadff, 0xc19a,		0x21, 0
	.dw 0xae40, 0xc19a,	0xae7f, 0xc19a,		0x21, 0
	.dw 0xaec0, 0xc19a,	0xaeff, 0xc19a,		0x21, 0
	.dw 0xaf40, 0xc19a,	0xaf7f, 0xc19a,		0x21, 0
	.dw 0xafc0, 0xc19a,	0xafff, 0xc19a,		0x21, 0
	.dw 0xb040, 0xc19a,	0xb07f, 0xc19a,		0x21, 0
	.dw 0xb0c0, 0xc19a,	0xb0ff, 0xc19a,		0x21, 0
	.dw 0xb140, 0xc19a,	0xb17f, 0xc19a,		0x21, 0
	.dw 0xb1c0, 0xc19a,	0xb1ff, 0xc19a,		0x21, 0
	.dw 0xb240, 0xc19a,	0xb27f, 0xc19a,		0x21, 0
	.dw 0xb2c0, 0xc19a,	0xb2ff, 0xc19a,		0x21, 0
	.dw 0xb340, 0xc19a,	0xb37f, 0xc19a,		0x21, 0
	.dw 0xb3c0, 0xc19a,	0xb3ff, 0xc19a,		0x21, 0
	.dw 0xb440, 0xc19a,	0xb47f, 0xc19a,		0x21, 0
	.dw 0xb4c0, 0xc19a,	0xb4ff, 0xc19a,		0x21, 0
	.dw 0xb540, 0xc19a,	0xb57f, 0xc19a,		0x21, 0
	.dw 0xb5c0, 0xc19a,	0xb5ff, 0xc19a,		0x21, 0
	.dw 0xb640, 0xc19a,	0xb67f, 0xc19a,		0x21, 0
	.dw 0xb6c0, 0xc19a,	0xb6ff, 0xc19a,		0x21, 0
	.dw 0xb740, 0xc19a,	0xb77f, 0xc19a,		0x21, 0
	.dw 0xb7c0, 0xc19a,	0xb7ff, 0xc19a,		0x21, 0
	.dw 0xb840, 0xc19a,	0xb87f, 0xc19a,		0x21, 0
	.dw 0xb8c0, 0xc19a,	0xb8ff, 0xc19a,		0x21, 0
	.dw 0xb940, 0xc19a,	0xb97f, 0xc19a,		0x21, 0
	.dw 0xb9c0, 0xc19a,	0xdfff, 0xc19a,		0x21, 0
	.dw 0xe040, 0xc19a,	0xe07f, 0xc19a,		0x21, 0
	.dw 0xe0c0, 0xc19a,	0xe0ff, 0xc19a,		0x21, 0
	.dw 0xe140, 0xc19a,	0xe17f, 0xc19a,		0x21, 0
	.dw 0xe1c0, 0xc19a,	0xe1ff, 0xc19a,		0x21, 0
	.dw 0xe240, 0xc19a,	0xe27f, 0xc19a,		0x21, 0
	.dw 0xe2c0, 0xc19a,	0xe2ff, 0xc19a,		0x21, 0
	.dw 0xe340, 0xc19a,	0xe37f, 0xc19a,		0x21, 0
	.dw 0xe3c0, 0xc19a,	0xe3ff, 0xc19a,		0x21, 0
	.dw 0xe440, 0xc19a,	0xe47f, 0xc19a,		0x21, 0
	.dw 0xe4c0, 0xc19a,	0xe4ff, 0xc19a,		0x21, 0
	.dw 0xe540, 0xc19a,	0xe57f, 0xc19a,		0x21, 0
	.dw 0xe5c0, 0xc19a,	0xe5ff, 0xc19a,		0x21, 0
	.dw 0xe640, 0xc19a,	0xe67f, 0xc19a,		0x21, 0
	.dw 0xe6c0, 0xc19a,	0xe6ff, 0xc19a,		0x21, 0
	.dw 0xe740, 0xc19a,	0xe77f, 0xc19a,		0x21, 0
	.dw 0xe7c0, 0xc19a,	0xe7ff, 0xc19a,		0x21, 0
	.dw 0xe840, 0xc19a,	0xe87f, 0xc19a,		0x21, 0
	.dw 0xe8c0, 0xc19a,	0xe8ff, 0xc19a,		0x21, 0
	.dw 0xe940, 0xc19a,	0xe97f, 0xc19a,		0x21, 0
	.dw 0xe9c0, 0xc19a,	0xe9ff, 0xc19a,		0x21, 0
	.dw 0xea40, 0xc19a,	0xea7f, 0xc19a,		0x21, 0
	.dw 0xeac0, 0xc19a,	0xeaff, 0xc19a,		0x21, 0
	.dw 0xeb40, 0xc19a,	0xeb7f, 0xc19a,		0x21, 0
	.dw 0xebc0, 0xc19a,	0xebff, 0xc19a,		0x21, 0
	.dw 0xec40, 0xc19a,	0xec7f, 0xc19a,		0x21, 0
	.dw 0xecc0, 0xc19a,	0xecff, 0xc19a,		0x21, 0
	.dw 0xed40, 0xc19a,	0xed7f, 0xc19a,		0x21, 0
	.dw 0xedc0, 0xc19a,	0xedff, 0xc19a,		0x21, 0
	.dw 0xee40, 0xc19a,	0xee7f, 0xc19a,		0x21, 0
	.dw 0xeec0, 0xc19a,	0xeeff, 0xc19a,		0x21, 0
	.dw 0xef40, 0xc19a,	0xef7f, 0xc19a,		0x21, 0
	.dw 0xefc0, 0xc19a,	0xefff, 0xc19a,		0x21, 0
	.dw 0xf040, 0xc19a,	0xf07f, 0xc19a,		0x21, 0
	.dw 0xf0c0, 0xc19a,	0xf0ff, 0xc19a,		0x21, 0
	.dw 0xf140, 0xc19a,	0xf17f, 0xc19a,		0x21, 0
	.dw 0xf1c0, 0xc19a,	0xf1ff, 0xc19a,		0x21, 0
	.dw 0xf240, 0xc19a,	0xf27f, 0xc19a,		0x21, 0
	.dw 0xf2c0, 0xc19a,	0xf2ff, 0xc19a,		0x21, 0
	.dw 0xf340, 0xc19a,	0xf37f, 0xc19a,		0x21, 0
	.dw 0xf3c0, 0xc19a,	0xf3ff, 0xc19a,		0x21, 0
	.dw 0xf440, 0xc19a,	0xf47f, 0xc19a,		0x21, 0
	.dw 0xf4c0, 0xc19a,	0xf4ff, 0xc19a,		0x21, 0
	.dw 0xf540, 0xc19a,	0xf57f, 0xc19a,		0x21, 0
	.dw 0xf5c0, 0xc19a,	0xf5ff, 0xc19a,		0x21, 0
	.dw 0xf640, 0xc19a,	0xf67f, 0xc19a,		0x21, 0
	.dw 0xf6c0, 0xc19a,	0xf6ff, 0xc19a,		0x21, 0
	.dw 0xf740, 0xc19a,	0xf77f, 0xc19a,		0x21, 0
	.dw 0xf7c0, 0xc19a,	0xf7ff, 0xc19a,		0x21, 0
	.dw 0xf840, 0xc19a,	0xf87f, 0xc19a,		0x21, 0
	.dw 0xf8c0, 0xc19a,	0xf8ff, 0xc19a,		0x21, 0
	.dw 0xf940, 0xc19a,	0xf97f, 0xc19a,		0x21, 0
	.dw 0xf9c0, 0xc19a,	0xffff, 0xc19b,		0x21, 0
	.dw 0x0040, 0xc19c,	0x007f, 0xc19c,		0x21, 0
	.dw 0x00c0, 0xc19c,	0x00ff, 0xc19c,		0x21, 0
	.dw 0x0140, 0xc19c,	0x017f, 0xc19c,		0x21, 0
	.dw 0x01c0, 0xc19c,	0x01ff, 0xc19c,		0x21, 0
	.dw 0x0240, 0xc19c,	0x027f, 0xc19c,		0x21, 0
	.dw 0x02c0, 0xc19c,	0x02ff, 0xc19c,		0x21, 0
	.dw 0x0340, 0xc19c,	0x037f, 0xc19c,		0x21, 0
	.dw 0x03c0, 0xc19c,	0x03ff, 0xc19c,		0x21, 0
	.dw 0x0440, 0xc19c,	0x047f, 0xc19c,		0x21, 0
	.dw 0x04c0, 0xc19c,	0x04ff, 0xc19c,		0x21, 0
	.dw 0x0540, 0xc19c,	0x057f, 0xc19c,		0x21, 0
	.dw 0x05c0, 0xc19c,	0x05ff, 0xc19c,		0x21, 0
	.dw 0x0640, 0xc19c,	0x067f, 0xc19c,		0x21, 0
	.dw 0x06c0, 0xc19c,	0x06ff, 0xc19c,		0x21, 0
	.dw 0x0740, 0xc19c,	0x077f, 0xc19c,		0x21, 0
	.dw 0x07c0, 0xc19c,	0x07ff, 0xc19c,		0x21, 0
	.dw 0x0840, 0xc19c,	0x087f, 0xc19c,		0x21, 0
	.dw 0x08c0, 0xc19c,	0x08ff, 0xc19c,		0x21, 0
	.dw 0x0940, 0xc19c,	0x097f, 0xc19c,		0x21, 0
	.dw 0x09c0, 0xc19c,	0x09ff, 0xc19c,		0x21, 0
	.dw 0x0a40, 0xc19c,	0x0a7f, 0xc19c,		0x21, 0
	.dw 0x0ac0, 0xc19c,	0x0aff, 0xc19c,		0x21, 0
	.dw 0x0b40, 0xc19c,	0x0b7f, 0xc19c,		0x21, 0
	.dw 0x0bc0, 0xc19c,	0x0bff, 0xc19c,		0x21, 0
	.dw 0x0c40, 0xc19c,	0x0c7f, 0xc19c,		0x21, 0
	.dw 0x0cc0, 0xc19c,	0x0cff, 0xc19c,		0x21, 0
	.dw 0x0d40, 0xc19c,	0x0d7f, 0xc19c,		0x21, 0
	.dw 0x0dc0, 0xc19c,	0x0dff, 0xc19c,		0x21, 0
	.dw 0x0e40, 0xc19c,	0x0e7f, 0xc19c,		0x21, 0
	.dw 0x0ec0, 0xc19c,	0x0eff, 0xc19c,		0x21, 0
	.dw 0x0f40, 0xc19c,	0x0f7f, 0xc19c,		0x21, 0
	.dw 0x0fc0, 0xc19c,	0x0fff, 0xc19c,		0x21, 0
	.dw 0x1040, 0xc19c,	0x107f, 0xc19c,		0x21, 0
	.dw 0x10c0, 0xc19c,	0x10ff, 0xc19c,		0x21, 0
	.dw 0x1140, 0xc19c,	0x117f, 0xc19c,		0x21, 0
	.dw 0x11c0, 0xc19c,	0x11ff, 0xc19c,		0x21, 0
	.dw 0x1240, 0xc19c,	0x127f, 0xc19c,		0x21, 0
	.dw 0x12c0, 0xc19c,	0x12ff, 0xc19c,		0x21, 0
	.dw 0x1340, 0xc19c,	0x137f, 0xc19c,		0x21, 0
	.dw 0x13c0, 0xc19c,	0x13ff, 0xc19c,		0x21, 0
	.dw 0x1440, 0xc19c,	0x147f, 0xc19c,		0x21, 0
	.dw 0x14c0, 0xc19c,	0x14ff, 0xc19c,		0x21, 0
	.dw 0x1540, 0xc19c,	0x157f, 0xc19c,		0x21, 0
	.dw 0x15c0, 0xc19c,	0x15ff, 0xc19c,		0x21, 0
	.dw 0x1640, 0xc19c,	0x167f, 0xc19c,		0x21, 0
	.dw 0x16c0, 0xc19c,	0x16ff, 0xc19c,		0x21, 0
	.dw 0x1740, 0xc19c,	0x177f, 0xc19c,		0x21, 0
	.dw 0x17c0, 0xc19c,	0x17ff, 0xc19c,		0x21, 0
	.dw 0x1840, 0xc19c,	0x187f, 0xc19c,		0x21, 0
	.dw 0x18c0, 0xc19c,	0x18ff, 0xc19c,		0x21, 0
	.dw 0x1940, 0xc19c,	0x197f, 0xc19c,		0x21, 0
	.dw 0x19c0, 0xc19c,	0x1fff, 0xc19c,		0x21, 0
	.dw 0x2040, 0xc19c,	0x207f, 0xc19c,		0x21, 0
	.dw 0x20c0, 0xc19c,	0x20ff, 0xc19c,		0x21, 0
	.dw 0x2140, 0xc19c,	0x217f, 0xc19c,		0x21, 0
	.dw 0x21c0, 0xc19c,	0x21ff, 0xc19c,		0x21, 0
	.dw 0x2240, 0xc19c,	0x227f, 0xc19c,		0x21, 0
	.dw 0x22c0, 0xc19c,	0x22ff, 0xc19c,		0x21, 0
	.dw 0x2340, 0xc19c,	0x237f, 0xc19c,		0x21, 0
	.dw 0x23c0, 0xc19c,	0x23ff, 0xc19c,		0x21, 0
	.dw 0x2440, 0xc19c,	0x247f, 0xc19c,		0x21, 0
	.dw 0x24c0, 0xc19c,	0x24ff, 0xc19c,		0x21, 0
	.dw 0x2540, 0xc19c,	0x257f, 0xc19c,		0x21, 0
	.dw 0x25c0, 0xc19c,	0x25ff, 0xc19c,		0x21, 0
	.dw 0x2640, 0xc19c,	0x267f, 0xc19c,		0x21, 0
	.dw 0x26c0, 0xc19c,	0x26ff, 0xc19c,		0x21, 0
	.dw 0x2740, 0xc19c,	0x277f, 0xc19c,		0x21, 0
	.dw 0x27c0, 0xc19c,	0x27ff, 0xc19c,		0x21, 0
	.dw 0x2840, 0xc19c,	0x287f, 0xc19c,		0x21, 0
	.dw 0x28c0, 0xc19c,	0x28ff, 0xc19c,		0x21, 0
	.dw 0x2940, 0xc19c,	0x297f, 0xc19c,		0x21, 0
	.dw 0x29c0, 0xc19c,	0x29ff, 0xc19c,		0x21, 0
	.dw 0x2a40, 0xc19c,	0x2a7f, 0xc19c,		0x21, 0
	.dw 0x2ac0, 0xc19c,	0x2aff, 0xc19c,		0x21, 0
	.dw 0x2b40, 0xc19c,	0x2b7f, 0xc19c,		0x21, 0
	.dw 0x2bc0, 0xc19c,	0x2bff, 0xc19c,		0x21, 0
	.dw 0x2c40, 0xc19c,	0x2c7f, 0xc19c,		0x21, 0
	.dw 0x2cc0, 0xc19c,	0x2cff, 0xc19c,		0x21, 0
	.dw 0x2d40, 0xc19c,	0x2d7f, 0xc19c,		0x21, 0
	.dw 0x2dc0, 0xc19c,	0x2dff, 0xc19c,		0x21, 0
	.dw 0x2e40, 0xc19c,	0x2e7f, 0xc19c,		0x21, 0
	.dw 0x2ec0, 0xc19c,	0x2eff, 0xc19c,		0x21, 0
	.dw 0x2f40, 0xc19c,	0x2f7f, 0xc19c,		0x21, 0
	.dw 0x2fc0, 0xc19c,	0x2fff, 0xc19c,		0x21, 0
	.dw 0x3040, 0xc19c,	0x307f, 0xc19c,		0x21, 0
	.dw 0x30c0, 0xc19c,	0x30ff, 0xc19c,		0x21, 0
	.dw 0x3140, 0xc19c,	0x317f, 0xc19c,		0x21, 0
	.dw 0x31c0, 0xc19c,	0x31ff, 0xc19c,		0x21, 0
	.dw 0x3240, 0xc19c,	0x327f, 0xc19c,		0x21, 0
	.dw 0x32c0, 0xc19c,	0x32ff, 0xc19c,		0x21, 0
	.dw 0x3340, 0xc19c,	0x337f, 0xc19c,		0x21, 0
	.dw 0x33c0, 0xc19c,	0x33ff, 0xc19c,		0x21, 0
	.dw 0x3440, 0xc19c,	0x347f, 0xc19c,		0x21, 0
	.dw 0x34c0, 0xc19c,	0x34ff, 0xc19c,		0x21, 0
	.dw 0x3540, 0xc19c,	0x357f, 0xc19c,		0x21, 0
	.dw 0x35c0, 0xc19c,	0x35ff, 0xc19c,		0x21, 0
	.dw 0x3640, 0xc19c,	0x367f, 0xc19c,		0x21, 0
	.dw 0x36c0, 0xc19c,	0x36ff, 0xc19c,		0x21, 0
	.dw 0x3740, 0xc19c,	0x377f, 0xc19c,		0x21, 0
	.dw 0x37c0, 0xc19c,	0x37ff, 0xc19c,		0x21, 0
	.dw 0x3840, 0xc19c,	0x387f, 0xc19c,		0x21, 0
	.dw 0x38c0, 0xc19c,	0x38ff, 0xc19c,		0x21, 0
	.dw 0x3940, 0xc19c,	0x397f, 0xc19c,		0x21, 0
	.dw 0x39c0, 0xc19c,	0x3fff, 0xc19c,		0x21, 0
	.dw 0x4040, 0xc19c,	0x407f, 0xc19c,		0x21, 0
	.dw 0x40c0, 0xc19c,	0x40ff, 0xc19c,		0x21, 0
	.dw 0x4140, 0xc19c,	0x417f, 0xc19c,		0x21, 0
	.dw 0x41c0, 0xc19c,	0x41ff, 0xc19c,		0x21, 0
	.dw 0x4240, 0xc19c,	0x427f, 0xc19c,		0x21, 0
	.dw 0x42c0, 0xc19c,	0x42ff, 0xc19c,		0x21, 0
	.dw 0x4340, 0xc19c,	0x437f, 0xc19c,		0x21, 0
	.dw 0x43c0, 0xc19c,	0x43ff, 0xc19c,		0x21, 0
	.dw 0x4440, 0xc19c,	0x447f, 0xc19c,		0x21, 0
	.dw 0x44c0, 0xc19c,	0x44ff, 0xc19c,		0x21, 0
	.dw 0x4540, 0xc19c,	0x457f, 0xc19c,		0x21, 0
	.dw 0x45c0, 0xc19c,	0x45ff, 0xc19c,		0x21, 0
	.dw 0x4640, 0xc19c,	0x467f, 0xc19c,		0x21, 0
	.dw 0x46c0, 0xc19c,	0x46ff, 0xc19c,		0x21, 0
	.dw 0x4740, 0xc19c,	0x477f, 0xc19c,		0x21, 0
	.dw 0x47c0, 0xc19c,	0x47ff, 0xc19c,		0x21, 0
	.dw 0x4840, 0xc19c,	0x487f, 0xc19c,		0x21, 0
	.dw 0x48c0, 0xc19c,	0x48ff, 0xc19c,		0x21, 0
	.dw 0x4940, 0xc19c,	0x497f, 0xc19c,		0x21, 0
	.dw 0x49c0, 0xc19c,	0x49ff, 0xc19c,		0x21, 0
	.dw 0x4a40, 0xc19c,	0x4a7f, 0xc19c,		0x21, 0
	.dw 0x4ac0, 0xc19c,	0x4aff, 0xc19c,		0x21, 0
	.dw 0x4b40, 0xc19c,	0x4b7f, 0xc19c,		0x21, 0
	.dw 0x4bc0, 0xc19c,	0x4bff, 0xc19c,		0x21, 0
	.dw 0x4c40, 0xc19c,	0x4c7f, 0xc19c,		0x21, 0
	.dw 0x4cc0, 0xc19c,	0x4cff, 0xc19c,		0x21, 0
	.dw 0x4d40, 0xc19c,	0x4d7f, 0xc19c,		0x21, 0
	.dw 0x4dc0, 0xc19c,	0x4dff, 0xc19c,		0x21, 0
	.dw 0x4e40, 0xc19c,	0x4e7f, 0xc19c,		0x21, 0
	.dw 0x4ec0, 0xc19c,	0x4eff, 0xc19c,		0x21, 0
	.dw 0x4f40, 0xc19c,	0x4f7f, 0xc19c,		0x21, 0
	.dw 0x4fc0, 0xc19c,	0x4fff, 0xc19c,		0x21, 0
	.dw 0x5040, 0xc19c,	0x507f, 0xc19c,		0x21, 0
	.dw 0x50c0, 0xc19c,	0x50ff, 0xc19c,		0x21, 0
	.dw 0x5140, 0xc19c,	0x517f, 0xc19c,		0x21, 0
	.dw 0x51c0, 0xc19c,	0x51ff, 0xc19c,		0x21, 0
	.dw 0x5240, 0xc19c,	0x527f, 0xc19c,		0x21, 0
	.dw 0x52c0, 0xc19c,	0x52ff, 0xc19c,		0x21, 0
	.dw 0x5340, 0xc19c,	0x537f, 0xc19c,		0x21, 0
	.dw 0x53c0, 0xc19c,	0x53ff, 0xc19c,		0x21, 0
	.dw 0x5440, 0xc19c,	0x547f, 0xc19c,		0x21, 0
	.dw 0x54c0, 0xc19c,	0x54ff, 0xc19c,		0x21, 0
	.dw 0x5540, 0xc19c,	0x557f, 0xc19c,		0x21, 0
	.dw 0x55c0, 0xc19c,	0x55ff, 0xc19c,		0x21, 0
	.dw 0x5640, 0xc19c,	0x567f, 0xc19c,		0x21, 0
	.dw 0x56c0, 0xc19c,	0x56ff, 0xc19c,		0x21, 0
	.dw 0x5740, 0xc19c,	0x577f, 0xc19c,		0x21, 0
	.dw 0x57c0, 0xc19c,	0x57ff, 0xc19c,		0x21, 0
	.dw 0x5840, 0xc19c,	0x587f, 0xc19c,		0x21, 0
	.dw 0x58c0, 0xc19c,	0x58ff, 0xc19c,		0x21, 0
	.dw 0x5940, 0xc19c,	0x597f, 0xc19c,		0x21, 0
	.dw 0x59c0, 0xc19c,	0x5fff, 0xc19c,		0x21, 0
	.dw 0x6040, 0xc19c,	0x607f, 0xc19c,		0x21, 0
	.dw 0x60c0, 0xc19c,	0x60ff, 0xc19c,		0x21, 0
	.dw 0x6140, 0xc19c,	0x617f, 0xc19c,		0x21, 0
	.dw 0x61c0, 0xc19c,	0x61ff, 0xc19c,		0x21, 0
	.dw 0x6240, 0xc19c,	0x627f, 0xc19c,		0x21, 0
	.dw 0x62c0, 0xc19c,	0x62ff, 0xc19c,		0x21, 0
	.dw 0x6340, 0xc19c,	0x637f, 0xc19c,		0x21, 0
	.dw 0x63c0, 0xc19c,	0x63ff, 0xc19c,		0x21, 0
	.dw 0x6440, 0xc19c,	0x647f, 0xc19c,		0x21, 0
	.dw 0x64c0, 0xc19c,	0x64ff, 0xc19c,		0x21, 0
	.dw 0x6540, 0xc19c,	0x657f, 0xc19c,		0x21, 0
	.dw 0x65c0, 0xc19c,	0x65ff, 0xc19c,		0x21, 0
	.dw 0x6640, 0xc19c,	0x667f, 0xc19c,		0x21, 0
	.dw 0x66c0, 0xc19c,	0x66ff, 0xc19c,		0x21, 0
	.dw 0x6740, 0xc19c,	0x677f, 0xc19c,		0x21, 0
	.dw 0x67c0, 0xc19c,	0x67ff, 0xc19c,		0x21, 0
	.dw 0x6840, 0xc19c,	0x687f, 0xc19c,		0x21, 0
	.dw 0x68c0, 0xc19c,	0x68ff, 0xc19c,		0x21, 0
	.dw 0x6940, 0xc19c,	0x697f, 0xc19c,		0x21, 0
	.dw 0x69c0, 0xc19c,	0x69ff, 0xc19c,		0x21, 0
	.dw 0x6a40, 0xc19c,	0x6a7f, 0xc19c,		0x21, 0
	.dw 0x6ac0, 0xc19c,	0x6aff, 0xc19c,		0x21, 0
	.dw 0x6b40, 0xc19c,	0x6b7f, 0xc19c,		0x21, 0
	.dw 0x6bc0, 0xc19c,	0x6bff, 0xc19c,		0x21, 0
	.dw 0x6c40, 0xc19c,	0x6c7f, 0xc19c,		0x21, 0
	.dw 0x6cc0, 0xc19c,	0x6cff, 0xc19c,		0x21, 0
	.dw 0x6d40, 0xc19c,	0x6d7f, 0xc19c,		0x21, 0
	.dw 0x6dc0, 0xc19c,	0x6dff, 0xc19c,		0x21, 0
	.dw 0x6e40, 0xc19c,	0x6e7f, 0xc19c,		0x21, 0
	.dw 0x6ec0, 0xc19c,	0x6eff, 0xc19c,		0x21, 0
	.dw 0x6f40, 0xc19c,	0x6f7f, 0xc19c,		0x21, 0
	.dw 0x6fc0, 0xc19c,	0x6fff, 0xc19c,		0x21, 0
	.dw 0x7040, 0xc19c,	0x707f, 0xc19c,		0x21, 0
	.dw 0x70c0, 0xc19c,	0x70ff, 0xc19c,		0x21, 0
	.dw 0x7140, 0xc19c,	0x717f, 0xc19c,		0x21, 0
	.dw 0x71c0, 0xc19c,	0x71ff, 0xc19c,		0x21, 0
	.dw 0x7240, 0xc19c,	0x727f, 0xc19c,		0x21, 0
	.dw 0x72c0, 0xc19c,	0x72ff, 0xc19c,		0x21, 0
	.dw 0x7340, 0xc19c,	0x737f, 0xc19c,		0x21, 0
	.dw 0x73c0, 0xc19c,	0x73ff, 0xc19c,		0x21, 0
	.dw 0x7440, 0xc19c,	0x747f, 0xc19c,		0x21, 0
	.dw 0x74c0, 0xc19c,	0x74ff, 0xc19c,		0x21, 0
	.dw 0x7540, 0xc19c,	0x757f, 0xc19c,		0x21, 0
	.dw 0x75c0, 0xc19c,	0x75ff, 0xc19c,		0x21, 0
	.dw 0x7640, 0xc19c,	0x767f, 0xc19c,		0x21, 0
	.dw 0x76c0, 0xc19c,	0x76ff, 0xc19c,		0x21, 0
	.dw 0x7740, 0xc19c,	0x777f, 0xc19c,		0x21, 0
	.dw 0x77c0, 0xc19c,	0x77ff, 0xc19c,		0x21, 0
	.dw 0x7840, 0xc19c,	0x787f, 0xc19c,		0x21, 0
	.dw 0x78c0, 0xc19c,	0x78ff, 0xc19c,		0x21, 0
	.dw 0x7940, 0xc19c,	0x797f, 0xc19c,		0x21, 0
	.dw 0x79c0, 0xc19c,	0x7fff, 0xc19c,		0x21, 0
	.dw 0x8040, 0xc19c,	0x807f, 0xc19c,		0x21, 0
	.dw 0x80c0, 0xc19c,	0x80ff, 0xc19c,		0x21, 0
	.dw 0x8140, 0xc19c,	0x817f, 0xc19c,		0x21, 0
	.dw 0x81c0, 0xc19c,	0x81ff, 0xc19c,		0x21, 0
	.dw 0x8240, 0xc19c,	0x827f, 0xc19c,		0x21, 0
	.dw 0x82c0, 0xc19c,	0x82ff, 0xc19c,		0x21, 0
	.dw 0x8340, 0xc19c,	0x837f, 0xc19c,		0x21, 0
	.dw 0x83c0, 0xc19c,	0x83ff, 0xc19c,		0x21, 0
	.dw 0x8440, 0xc19c,	0x847f, 0xc19c,		0x21, 0
	.dw 0x84c0, 0xc19c,	0x84ff, 0xc19c,		0x21, 0
	.dw 0x8540, 0xc19c,	0x857f, 0xc19c,		0x21, 0
	.dw 0x85c0, 0xc19c,	0x85ff, 0xc19c,		0x21, 0
	.dw 0x8640, 0xc19c,	0x867f, 0xc19c,		0x21, 0
	.dw 0x86c0, 0xc19c,	0x86ff, 0xc19c,		0x21, 0
	.dw 0x8740, 0xc19c,	0x877f, 0xc19c,		0x21, 0
	.dw 0x87c0, 0xc19c,	0x87ff, 0xc19c,		0x21, 0
	.dw 0x8840, 0xc19c,	0x887f, 0xc19c,		0x21, 0
	.dw 0x88c0, 0xc19c,	0x88ff, 0xc19c,		0x21, 0
	.dw 0x8940, 0xc19c,	0x897f, 0xc19c,		0x21, 0
	.dw 0x89c0, 0xc19c,	0x89ff, 0xc19c,		0x21, 0
	.dw 0x8a40, 0xc19c,	0x8a7f, 0xc19c,		0x21, 0
	.dw 0x8ac0, 0xc19c,	0x8aff, 0xc19c,		0x21, 0
	.dw 0x8b40, 0xc19c,	0x8b7f, 0xc19c,		0x21, 0
	.dw 0x8bc0, 0xc19c,	0x8bff, 0xc19c,		0x21, 0
	.dw 0x8c40, 0xc19c,	0x8c7f, 0xc19c,		0x21, 0
	.dw 0x8cc0, 0xc19c,	0x8cff, 0xc19c,		0x21, 0
	.dw 0x8d40, 0xc19c,	0x8d7f, 0xc19c,		0x21, 0
	.dw 0x8dc0, 0xc19c,	0x8dff, 0xc19c,		0x21, 0
	.dw 0x8e40, 0xc19c,	0x8e7f, 0xc19c,		0x21, 0
	.dw 0x8ec0, 0xc19c,	0x8eff, 0xc19c,		0x21, 0
	.dw 0x8f40, 0xc19c,	0x8f7f, 0xc19c,		0x21, 0
	.dw 0x8fc0, 0xc19c,	0x8fff, 0xc19c,		0x21, 0
	.dw 0x9040, 0xc19c,	0x907f, 0xc19c,		0x21, 0
	.dw 0x90c0, 0xc19c,	0x90ff, 0xc19c,		0x21, 0
	.dw 0x9140, 0xc19c,	0x917f, 0xc19c,		0x21, 0
	.dw 0x91c0, 0xc19c,	0x91ff, 0xc19c,		0x21, 0
	.dw 0x9240, 0xc19c,	0x927f, 0xc19c,		0x21, 0
	.dw 0x92c0, 0xc19c,	0x92ff, 0xc19c,		0x21, 0
	.dw 0x9340, 0xc19c,	0x937f, 0xc19c,		0x21, 0
	.dw 0x93c0, 0xc19c,	0x93ff, 0xc19c,		0x21, 0
	.dw 0x9440, 0xc19c,	0x947f, 0xc19c,		0x21, 0
	.dw 0x94c0, 0xc19c,	0x94ff, 0xc19c,		0x21, 0
	.dw 0x9540, 0xc19c,	0x957f, 0xc19c,		0x21, 0
	.dw 0x95c0, 0xc19c,	0x95ff, 0xc19c,		0x21, 0
	.dw 0x9640, 0xc19c,	0x967f, 0xc19c,		0x21, 0
	.dw 0x96c0, 0xc19c,	0x96ff, 0xc19c,		0x21, 0
	.dw 0x9740, 0xc19c,	0x977f, 0xc19c,		0x21, 0
	.dw 0x97c0, 0xc19c,	0x97ff, 0xc19c,		0x21, 0
	.dw 0x9840, 0xc19c,	0x987f, 0xc19c,		0x21, 0
	.dw 0x98c0, 0xc19c,	0x98ff, 0xc19c,		0x21, 0
	.dw 0x9940, 0xc19c,	0x997f, 0xc19c,		0x21, 0
	.dw 0x99c0, 0xc19c,	0x9fff, 0xc19c,		0x21, 0
	.dw 0xa040, 0xc19c,	0xa07f, 0xc19c,		0x21, 0
	.dw 0xa0c0, 0xc19c,	0xa0ff, 0xc19c,		0x21, 0
	.dw 0xa140, 0xc19c,	0xa17f, 0xc19c,		0x21, 0
	.dw 0xa1c0, 0xc19c,	0xa1ff, 0xc19c,		0x21, 0
	.dw 0xa240, 0xc19c,	0xa27f, 0xc19c,		0x21, 0
	.dw 0xa2c0, 0xc19c,	0xa2ff, 0xc19c,		0x21, 0
	.dw 0xa340, 0xc19c,	0xa37f, 0xc19c,		0x21, 0
	.dw 0xa3c0, 0xc19c,	0xa3ff, 0xc19c,		0x21, 0
	.dw 0xa440, 0xc19c,	0xa47f, 0xc19c,		0x21, 0
	.dw 0xa4c0, 0xc19c,	0xa4ff, 0xc19c,		0x21, 0
	.dw 0xa540, 0xc19c,	0xa57f, 0xc19c,		0x21, 0
	.dw 0xa5c0, 0xc19c,	0xa5ff, 0xc19c,		0x21, 0
	.dw 0xa640, 0xc19c,	0xa67f, 0xc19c,		0x21, 0
	.dw 0xa6c0, 0xc19c,	0xa6ff, 0xc19c,		0x21, 0
	.dw 0xa740, 0xc19c,	0xa77f, 0xc19c,		0x21, 0
	.dw 0xa7c0, 0xc19c,	0xa7ff, 0xc19c,		0x21, 0
	.dw 0xa840, 0xc19c,	0xa87f, 0xc19c,		0x21, 0
	.dw 0xa8c0, 0xc19c,	0xa8ff, 0xc19c,		0x21, 0
	.dw 0xa940, 0xc19c,	0xa97f, 0xc19c,		0x21, 0
	.dw 0xa9c0, 0xc19c,	0xa9ff, 0xc19c,		0x21, 0
	.dw 0xaa40, 0xc19c,	0xaa7f, 0xc19c,		0x21, 0
	.dw 0xaac0, 0xc19c,	0xaaff, 0xc19c,		0x21, 0
	.dw 0xab40, 0xc19c,	0xab7f, 0xc19c,		0x21, 0
	.dw 0xabc0, 0xc19c,	0xabff, 0xc19c,		0x21, 0
	.dw 0xac40, 0xc19c,	0xac7f, 0xc19c,		0x21, 0
	.dw 0xacc0, 0xc19c,	0xacff, 0xc19c,		0x21, 0
	.dw 0xad40, 0xc19c,	0xad7f, 0xc19c,		0x21, 0
	.dw 0xadc0, 0xc19c,	0xadff, 0xc19c,		0x21, 0
	.dw 0xae40, 0xc19c,	0xae7f, 0xc19c,		0x21, 0
	.dw 0xaec0, 0xc19c,	0xaeff, 0xc19c,		0x21, 0
	.dw 0xaf40, 0xc19c,	0xaf7f, 0xc19c,		0x21, 0
	.dw 0xafc0, 0xc19c,	0xafff, 0xc19c,		0x21, 0
	.dw 0xb040, 0xc19c,	0xb07f, 0xc19c,		0x21, 0
	.dw 0xb0c0, 0xc19c,	0xb0ff, 0xc19c,		0x21, 0
	.dw 0xb140, 0xc19c,	0xb17f, 0xc19c,		0x21, 0
	.dw 0xb1c0, 0xc19c,	0xb1ff, 0xc19c,		0x21, 0
	.dw 0xb240, 0xc19c,	0xb27f, 0xc19c,		0x21, 0
	.dw 0xb2c0, 0xc19c,	0xb2ff, 0xc19c,		0x21, 0
	.dw 0xb340, 0xc19c,	0xb37f, 0xc19c,		0x21, 0
	.dw 0xb3c0, 0xc19c,	0xb3ff, 0xc19c,		0x21, 0
	.dw 0xb440, 0xc19c,	0xb47f, 0xc19c,		0x21, 0
	.dw 0xb4c0, 0xc19c,	0xb4ff, 0xc19c,		0x21, 0
	.dw 0xb540, 0xc19c,	0xb57f, 0xc19c,		0x21, 0
	.dw 0xb5c0, 0xc19c,	0xb5ff, 0xc19c,		0x21, 0
	.dw 0xb640, 0xc19c,	0xb67f, 0xc19c,		0x21, 0
	.dw 0xb6c0, 0xc19c,	0xb6ff, 0xc19c,		0x21, 0
	.dw 0xb740, 0xc19c,	0xb77f, 0xc19c,		0x21, 0
	.dw 0xb7c0, 0xc19c,	0xb7ff, 0xc19c,		0x21, 0
	.dw 0xb840, 0xc19c,	0xb87f, 0xc19c,		0x21, 0
	.dw 0xb8c0, 0xc19c,	0xb8ff, 0xc19c,		0x21, 0
	.dw 0xb940, 0xc19c,	0xb97f, 0xc19c,		0x21, 0
	.dw 0xb9c0, 0xc19c,	0xbfff, 0xc19c,		0x21, 0
	.dw 0xc040, 0xc19c,	0xc07f, 0xc19c,		0x21, 0
	.dw 0xc0c0, 0xc19c,	0xc0ff, 0xc19c,		0x21, 0
	.dw 0xc140, 0xc19c,	0xc17f, 0xc19c,		0x21, 0
	.dw 0xc1c0, 0xc19c,	0xc1ff, 0xc19c,		0x21, 0
	.dw 0xc240, 0xc19c,	0xc27f, 0xc19c,		0x21, 0
	.dw 0xc2c0, 0xc19c,	0xc2ff, 0xc19c,		0x21, 0
	.dw 0xc340, 0xc19c,	0xc37f, 0xc19c,		0x21, 0
	.dw 0xc3c0, 0xc19c,	0xc3ff, 0xc19c,		0x21, 0
	.dw 0xc440, 0xc19c,	0xc47f, 0xc19c,		0x21, 0
	.dw 0xc4c0, 0xc19c,	0xc4ff, 0xc19c,		0x21, 0
	.dw 0xc540, 0xc19c,	0xc57f, 0xc19c,		0x21, 0
	.dw 0xc5c0, 0xc19c,	0xc5ff, 0xc19c,		0x21, 0
	.dw 0xc640, 0xc19c,	0xc67f, 0xc19c,		0x21, 0
	.dw 0xc6c0, 0xc19c,	0xc6ff, 0xc19c,		0x21, 0
	.dw 0xc740, 0xc19c,	0xc77f, 0xc19c,		0x21, 0
	.dw 0xc7c0, 0xc19c,	0xc7ff, 0xc19c,		0x21, 0
	.dw 0xc840, 0xc19c,	0xc87f, 0xc19c,		0x21, 0
	.dw 0xc8c0, 0xc19c,	0xc8ff, 0xc19c,		0x21, 0
	.dw 0xc940, 0xc19c,	0xc97f, 0xc19c,		0x21, 0
	.dw 0xc9c0, 0xc19c,	0xc9ff, 0xc19c,		0x21, 0
	.dw 0xca40, 0xc19c,	0xca7f, 0xc19c,		0x21, 0
	.dw 0xcac0, 0xc19c,	0xcaff, 0xc19c,		0x21, 0
	.dw 0xcb40, 0xc19c,	0xcb7f, 0xc19c,		0x21, 0
	.dw 0xcbc0, 0xc19c,	0xcbff, 0xc19c,		0x21, 0
	.dw 0xcc40, 0xc19c,	0xcc7f, 0xc19c,		0x21, 0
	.dw 0xccc0, 0xc19c,	0xccff, 0xc19c,		0x21, 0
	.dw 0xcd40, 0xc19c,	0xcd7f, 0xc19c,		0x21, 0
	.dw 0xcdc0, 0xc19c,	0xcdff, 0xc19c,		0x21, 0
	.dw 0xce40, 0xc19c,	0xce7f, 0xc19c,		0x21, 0
	.dw 0xcec0, 0xc19c,	0xceff, 0xc19c,		0x21, 0
	.dw 0xcf40, 0xc19c,	0xcf7f, 0xc19c,		0x21, 0
	.dw 0xcfc0, 0xc19c,	0xcfff, 0xc19c,		0x21, 0
	.dw 0xd040, 0xc19c,	0xd07f, 0xc19c,		0x21, 0
	.dw 0xd0c0, 0xc19c,	0xd0ff, 0xc19c,		0x21, 0
	.dw 0xd140, 0xc19c,	0xd17f, 0xc19c,		0x21, 0
	.dw 0xd1c0, 0xc19c,	0xd1ff, 0xc19c,		0x21, 0
	.dw 0xd240, 0xc19c,	0xd27f, 0xc19c,		0x21, 0
	.dw 0xd2c0, 0xc19c,	0xd2ff, 0xc19c,		0x21, 0
	.dw 0xd340, 0xc19c,	0xd37f, 0xc19c,		0x21, 0
	.dw 0xd3c0, 0xc19c,	0xd3ff, 0xc19c,		0x21, 0
	.dw 0xd440, 0xc19c,	0xd47f, 0xc19c,		0x21, 0
	.dw 0xd4c0, 0xc19c,	0xd4ff, 0xc19c,		0x21, 0
	.dw 0xd540, 0xc19c,	0xd57f, 0xc19c,		0x21, 0
	.dw 0xd5c0, 0xc19c,	0xd5ff, 0xc19c,		0x21, 0
	.dw 0xd640, 0xc19c,	0xd67f, 0xc19c,		0x21, 0
	.dw 0xd6c0, 0xc19c,	0xd6ff, 0xc19c,		0x21, 0
	.dw 0xd740, 0xc19c,	0xd77f, 0xc19c,		0x21, 0
	.dw 0xd7c0, 0xc19c,	0xd7ff, 0xc19c,		0x21, 0
	.dw 0xd840, 0xc19c,	0xd87f, 0xc19c,		0x21, 0
	.dw 0xd8c0, 0xc19c,	0xd8ff, 0xc19c,		0x21, 0
	.dw 0xd940, 0xc19c,	0xd97f, 0xc19c,		0x21, 0
	.dw 0xd9c0, 0xc19c,	0xdfff, 0xc19c,		0x21, 0
	.dw 0xe040, 0xc19c,	0xe07f, 0xc19c,		0x21, 0
	.dw 0xe0c0, 0xc19c,	0xe0ff, 0xc19c,		0x21, 0
	.dw 0xe140, 0xc19c,	0xe17f, 0xc19c,		0x21, 0
	.dw 0xe1c0, 0xc19c,	0xe1ff, 0xc19c,		0x21, 0
	.dw 0xe240, 0xc19c,	0xe27f, 0xc19c,		0x21, 0
	.dw 0xe2c0, 0xc19c,	0xe2ff, 0xc19c,		0x21, 0
	.dw 0xe340, 0xc19c,	0xe37f, 0xc19c,		0x21, 0
	.dw 0xe3c0, 0xc19c,	0xe3ff, 0xc19c,		0x21, 0
	.dw 0xe440, 0xc19c,	0xe47f, 0xc19c,		0x21, 0
	.dw 0xe4c0, 0xc19c,	0xe4ff, 0xc19c,		0x21, 0
	.dw 0xe540, 0xc19c,	0xe57f, 0xc19c,		0x21, 0
	.dw 0xe5c0, 0xc19c,	0xe5ff, 0xc19c,		0x21, 0
	.dw 0xe640, 0xc19c,	0xe67f, 0xc19c,		0x21, 0
	.dw 0xe6c0, 0xc19c,	0xe6ff, 0xc19c,		0x21, 0
	.dw 0xe740, 0xc19c,	0xe77f, 0xc19c,		0x21, 0
	.dw 0xe7c0, 0xc19c,	0xe7ff, 0xc19c,		0x21, 0
	.dw 0xe840, 0xc19c,	0xe87f, 0xc19c,		0x21, 0
	.dw 0xe8c0, 0xc19c,	0xe8ff, 0xc19c,		0x21, 0
	.dw 0xe940, 0xc19c,	0xe97f, 0xc19c,		0x21, 0
	.dw 0xe9c0, 0xc19c,	0xe9ff, 0xc19c,		0x21, 0
	.dw 0xea40, 0xc19c,	0xea7f, 0xc19c,		0x21, 0
	.dw 0xeac0, 0xc19c,	0xeaff, 0xc19c,		0x21, 0
	.dw 0xeb40, 0xc19c,	0xeb7f, 0xc19c,		0x21, 0
	.dw 0xebc0, 0xc19c,	0xebff, 0xc19c,		0x21, 0
	.dw 0xec40, 0xc19c,	0xec7f, 0xc19c,		0x21, 0
	.dw 0xecc0, 0xc19c,	0xecff, 0xc19c,		0x21, 0
	.dw 0xed40, 0xc19c,	0xed7f, 0xc19c,		0x21, 0
	.dw 0xedc0, 0xc19c,	0xedff, 0xc19c,		0x21, 0
	.dw 0xee40, 0xc19c,	0xee7f, 0xc19c,		0x21, 0
	.dw 0xeec0, 0xc19c,	0xeeff, 0xc19c,		0x21, 0
	.dw 0xef40, 0xc19c,	0xef7f, 0xc19c,		0x21, 0
	.dw 0xefc0, 0xc19c,	0xefff, 0xc19c,		0x21, 0
	.dw 0xf040, 0xc19c,	0xf07f, 0xc19c,		0x21, 0
	.dw 0xf0c0, 0xc19c,	0xf0ff, 0xc19c,		0x21, 0
	.dw 0xf140, 0xc19c,	0xf17f, 0xc19c,		0x21, 0
	.dw 0xf1c0, 0xc19c,	0xf1ff, 0xc19c,		0x21, 0
	.dw 0xf240, 0xc19c,	0xf27f, 0xc19c,		0x21, 0
	.dw 0xf2c0, 0xc19c,	0xf2ff, 0xc19c,		0x21, 0
	.dw 0xf340, 0xc19c,	0xf37f, 0xc19c,		0x21, 0
	.dw 0xf3c0, 0xc19c,	0xf3ff, 0xc19c,		0x21, 0
	.dw 0xf440, 0xc19c,	0xf47f, 0xc19c,		0x21, 0
	.dw 0xf4c0, 0xc19c,	0xf4ff, 0xc19c,		0x21, 0
	.dw 0xf540, 0xc19c,	0xf57f, 0xc19c,		0x21, 0
	.dw 0xf5c0, 0xc19c,	0xf5ff, 0xc19c,		0x21, 0
	.dw 0xf640, 0xc19c,	0xf67f, 0xc19c,		0x21, 0
	.dw 0xf6c0, 0xc19c,	0xf6ff, 0xc19c,		0x21, 0
	.dw 0xf740, 0xc19c,	0xf77f, 0xc19c,		0x21, 0
	.dw 0xf7c0, 0xc19c,	0xf7ff, 0xc19c,		0x21, 0
	.dw 0xf840, 0xc19c,	0xf87f, 0xc19c,		0x21, 0
	.dw 0xf8c0, 0xc19c,	0xf8ff, 0xc19c,		0x21, 0
	.dw 0xf940, 0xc19c,	0xf97f, 0xc19c,		0x21, 0
	.dw 0xf9c0, 0xc19c,	0xffff, 0xc19c,		0x21, 0
	.dw 0x0040, 0xc19d,	0x007f, 0xc19d,		0x21, 0
	.dw 0x00c0, 0xc19d,	0x00ff, 0xc19d,		0x21, 0
	.dw 0x0140, 0xc19d,	0x017f, 0xc19d,		0x21, 0
	.dw 0x01c0, 0xc19d,	0x01ff, 0xc19d,		0x21, 0
	.dw 0x0240, 0xc19d,	0x027f, 0xc19d,		0x21, 0
	.dw 0x02c0, 0xc19d,	0x02ff, 0xc19d,		0x21, 0
	.dw 0x0340, 0xc19d,	0x037f, 0xc19d,		0x21, 0
	.dw 0x03c0, 0xc19d,	0x03ff, 0xc19d,		0x21, 0
	.dw 0x0440, 0xc19d,	0x047f, 0xc19d,		0x21, 0
	.dw 0x04c0, 0xc19d,	0x04ff, 0xc19d,		0x21, 0
	.dw 0x0540, 0xc19d,	0x057f, 0xc19d,		0x21, 0
	.dw 0x05c0, 0xc19d,	0x05ff, 0xc19d,		0x21, 0
	.dw 0x0640, 0xc19d,	0x067f, 0xc19d,		0x21, 0
	.dw 0x06c0, 0xc19d,	0x06ff, 0xc19d,		0x21, 0
	.dw 0x0740, 0xc19d,	0x077f, 0xc19d,		0x21, 0
	.dw 0x07c0, 0xc19d,	0x07ff, 0xc19d,		0x21, 0
	.dw 0x0840, 0xc19d,	0x087f, 0xc19d,		0x21, 0
	.dw 0x08c0, 0xc19d,	0x08ff, 0xc19d,		0x21, 0
	.dw 0x0940, 0xc19d,	0x097f, 0xc19d,		0x21, 0
	.dw 0x09c0, 0xc19d,	0x09ff, 0xc19d,		0x21, 0
	.dw 0x0a40, 0xc19d,	0x0a7f, 0xc19d,		0x21, 0
	.dw 0x0ac0, 0xc19d,	0x0aff, 0xc19d,		0x21, 0
	.dw 0x0b40, 0xc19d,	0x0b7f, 0xc19d,		0x21, 0
	.dw 0x0bc0, 0xc19d,	0x0bff, 0xc19d,		0x21, 0
	.dw 0x0c40, 0xc19d,	0x0c7f, 0xc19d,		0x21, 0
	.dw 0x0cc0, 0xc19d,	0x0cff, 0xc19d,		0x21, 0
	.dw 0x0d40, 0xc19d,	0x0d7f, 0xc19d,		0x21, 0
	.dw 0x0dc0, 0xc19d,	0x0dff, 0xc19d,		0x21, 0
	.dw 0x0e40, 0xc19d,	0x0e7f, 0xc19d,		0x21, 0
	.dw 0x0ec0, 0xc19d,	0x0eff, 0xc19d,		0x21, 0
	.dw 0x0f40, 0xc19d,	0x0f7f, 0xc19d,		0x21, 0
	.dw 0x0fc0, 0xc19d,	0x0fff, 0xc19d,		0x21, 0
	.dw 0x1040, 0xc19d,	0x107f, 0xc19d,		0x21, 0
	.dw 0x10c0, 0xc19d,	0x10ff, 0xc19d,		0x21, 0
	.dw 0x1140, 0xc19d,	0x117f, 0xc19d,		0x21, 0
	.dw 0x11c0, 0xc19d,	0x11ff, 0xc19d,		0x21, 0
	.dw 0x1240, 0xc19d,	0x127f, 0xc19d,		0x21, 0
	.dw 0x12c0, 0xc19d,	0x12ff, 0xc19d,		0x21, 0
	.dw 0x1340, 0xc19d,	0x137f, 0xc19d,		0x21, 0
	.dw 0x13c0, 0xc19d,	0x13ff, 0xc19d,		0x21, 0
	.dw 0x1440, 0xc19d,	0x147f, 0xc19d,		0x21, 0
	.dw 0x14c0, 0xc19d,	0x14ff, 0xc19d,		0x21, 0
	.dw 0x1540, 0xc19d,	0x157f, 0xc19d,		0x21, 0
	.dw 0x15c0, 0xc19d,	0x15ff, 0xc19d,		0x21, 0
	.dw 0x1640, 0xc19d,	0x167f, 0xc19d,		0x21, 0
	.dw 0x16c0, 0xc19d,	0x16ff, 0xc19d,		0x21, 0
	.dw 0x1740, 0xc19d,	0x177f, 0xc19d,		0x21, 0
	.dw 0x17c0, 0xc19d,	0x17ff, 0xc19d,		0x21, 0
	.dw 0x1840, 0xc19d,	0x187f, 0xc19d,		0x21, 0
	.dw 0x18c0, 0xc19d,	0x18ff, 0xc19d,		0x21, 0
	.dw 0x1940, 0xc19d,	0x197f, 0xc19d,		0x21, 0
	.dw 0x19c0, 0xc19d,	0x1fff, 0xc19d,		0x21, 0
	.dw 0x2040, 0xc19d,	0x207f, 0xc19d,		0x21, 0
	.dw 0x20c0, 0xc19d,	0x20ff, 0xc19d,		0x21, 0
	.dw 0x2140, 0xc19d,	0x217f, 0xc19d,		0x21, 0
	.dw 0x21c0, 0xc19d,	0x21ff, 0xc19d,		0x21, 0
	.dw 0x2240, 0xc19d,	0x227f, 0xc19d,		0x21, 0
	.dw 0x22c0, 0xc19d,	0x22ff, 0xc19d,		0x21, 0
	.dw 0x2340, 0xc19d,	0x237f, 0xc19d,		0x21, 0
	.dw 0x23c0, 0xc19d,	0x23ff, 0xc19d,		0x21, 0
	.dw 0x2440, 0xc19d,	0x247f, 0xc19d,		0x21, 0
	.dw 0x24c0, 0xc19d,	0x24ff, 0xc19d,		0x21, 0
	.dw 0x2540, 0xc19d,	0x257f, 0xc19d,		0x21, 0
	.dw 0x25c0, 0xc19d,	0x25ff, 0xc19d,		0x21, 0
	.dw 0x2640, 0xc19d,	0x267f, 0xc19d,		0x21, 0
	.dw 0x26c0, 0xc19d,	0x26ff, 0xc19d,		0x21, 0
	.dw 0x2740, 0xc19d,	0x277f, 0xc19d,		0x21, 0
	.dw 0x27c0, 0xc19d,	0x27ff, 0xc19d,		0x21, 0
	.dw 0x2840, 0xc19d,	0x287f, 0xc19d,		0x21, 0
	.dw 0x28c0, 0xc19d,	0x28ff, 0xc19d,		0x21, 0
	.dw 0x2940, 0xc19d,	0x297f, 0xc19d,		0x21, 0
	.dw 0x29c0, 0xc19d,	0x29ff, 0xc19d,		0x21, 0
	.dw 0x2a40, 0xc19d,	0x2a7f, 0xc19d,		0x21, 0
	.dw 0x2ac0, 0xc19d,	0x2aff, 0xc19d,		0x21, 0
	.dw 0x2b40, 0xc19d,	0x2b7f, 0xc19d,		0x21, 0
	.dw 0x2bc0, 0xc19d,	0x2bff, 0xc19d,		0x21, 0
	.dw 0x2c40, 0xc19d,	0x2c7f, 0xc19d,		0x21, 0
	.dw 0x2cc0, 0xc19d,	0x2cff, 0xc19d,		0x21, 0
	.dw 0x2d40, 0xc19d,	0x2d7f, 0xc19d,		0x21, 0
	.dw 0x2dc0, 0xc19d,	0x2dff, 0xc19d,		0x21, 0
	.dw 0x2e40, 0xc19d,	0x2e7f, 0xc19d,		0x21, 0
	.dw 0x2ec0, 0xc19d,	0x2eff, 0xc19d,		0x21, 0
	.dw 0x2f40, 0xc19d,	0x2f7f, 0xc19d,		0x21, 0
	.dw 0x2fc0, 0xc19d,	0x2fff, 0xc19d,		0x21, 0
	.dw 0x3040, 0xc19d,	0x307f, 0xc19d,		0x21, 0
	.dw 0x30c0, 0xc19d,	0x30ff, 0xc19d,		0x21, 0
	.dw 0x3140, 0xc19d,	0x317f, 0xc19d,		0x21, 0
	.dw 0x31c0, 0xc19d,	0x31ff, 0xc19d,		0x21, 0
	.dw 0x3240, 0xc19d,	0x327f, 0xc19d,		0x21, 0
	.dw 0x32c0, 0xc19d,	0x32ff, 0xc19d,		0x21, 0
	.dw 0x3340, 0xc19d,	0x337f, 0xc19d,		0x21, 0
	.dw 0x33c0, 0xc19d,	0x33ff, 0xc19d,		0x21, 0
	.dw 0x3440, 0xc19d,	0x347f, 0xc19d,		0x21, 0
	.dw 0x34c0, 0xc19d,	0x34ff, 0xc19d,		0x21, 0
	.dw 0x3540, 0xc19d,	0x357f, 0xc19d,		0x21, 0
	.dw 0x35c0, 0xc19d,	0x35ff, 0xc19d,		0x21, 0
	.dw 0x3640, 0xc19d,	0x367f, 0xc19d,		0x21, 0
	.dw 0x36c0, 0xc19d,	0x36ff, 0xc19d,		0x21, 0
	.dw 0x3740, 0xc19d,	0x377f, 0xc19d,		0x21, 0
	.dw 0x37c0, 0xc19d,	0x37ff, 0xc19d,		0x21, 0
	.dw 0x3840, 0xc19d,	0x387f, 0xc19d,		0x21, 0
	.dw 0x38c0, 0xc19d,	0x38ff, 0xc19d,		0x21, 0
	.dw 0x3940, 0xc19d,	0x397f, 0xc19d,		0x21, 0
	.dw 0x39c0, 0xc19d,	0x3fff, 0xc19d,		0x21, 0
	.dw 0x4040, 0xc19d,	0x407f, 0xc19d,		0x21, 0
	.dw 0x40c0, 0xc19d,	0x40ff, 0xc19d,		0x21, 0
	.dw 0x4140, 0xc19d,	0x417f, 0xc19d,		0x21, 0
	.dw 0x41c0, 0xc19d,	0x41ff, 0xc19d,		0x21, 0
	.dw 0x4240, 0xc19d,	0x427f, 0xc19d,		0x21, 0
	.dw 0x42c0, 0xc19d,	0x42ff, 0xc19d,		0x21, 0
	.dw 0x4340, 0xc19d,	0x437f, 0xc19d,		0x21, 0
	.dw 0x43c0, 0xc19d,	0x43ff, 0xc19d,		0x21, 0
	.dw 0x4440, 0xc19d,	0x447f, 0xc19d,		0x21, 0
	.dw 0x44c0, 0xc19d,	0x44ff, 0xc19d,		0x21, 0
	.dw 0x4540, 0xc19d,	0x457f, 0xc19d,		0x21, 0
	.dw 0x45c0, 0xc19d,	0x45ff, 0xc19d,		0x21, 0
	.dw 0x4640, 0xc19d,	0x467f, 0xc19d,		0x21, 0
	.dw 0x46c0, 0xc19d,	0x46ff, 0xc19d,		0x21, 0
	.dw 0x4740, 0xc19d,	0x477f, 0xc19d,		0x21, 0
	.dw 0x47c0, 0xc19d,	0x47ff, 0xc19d,		0x21, 0
	.dw 0x4840, 0xc19d,	0x487f, 0xc19d,		0x21, 0
	.dw 0x48c0, 0xc19d,	0x48ff, 0xc19d,		0x21, 0
	.dw 0x4940, 0xc19d,	0x497f, 0xc19d,		0x21, 0
	.dw 0x49c0, 0xc19d,	0x49ff, 0xc19d,		0x21, 0
	.dw 0x4a40, 0xc19d,	0x4a7f, 0xc19d,		0x21, 0
	.dw 0x4ac0, 0xc19d,	0x4aff, 0xc19d,		0x21, 0
	.dw 0x4b40, 0xc19d,	0x4b7f, 0xc19d,		0x21, 0
	.dw 0x4bc0, 0xc19d,	0x4bff, 0xc19d,		0x21, 0
	.dw 0x4c40, 0xc19d,	0x4c7f, 0xc19d,		0x21, 0
	.dw 0x4cc0, 0xc19d,	0x4cff, 0xc19d,		0x21, 0
	.dw 0x4d40, 0xc19d,	0x4d7f, 0xc19d,		0x21, 0
	.dw 0x4dc0, 0xc19d,	0x4dff, 0xc19d,		0x21, 0
	.dw 0x4e40, 0xc19d,	0x4e7f, 0xc19d,		0x21, 0
	.dw 0x4ec0, 0xc19d,	0x4eff, 0xc19d,		0x21, 0
	.dw 0x4f40, 0xc19d,	0x4f7f, 0xc19d,		0x21, 0
	.dw 0x4fc0, 0xc19d,	0x4fff, 0xc19d,		0x21, 0
	.dw 0x5040, 0xc19d,	0x507f, 0xc19d,		0x21, 0
	.dw 0x50c0, 0xc19d,	0x50ff, 0xc19d,		0x21, 0
	.dw 0x5140, 0xc19d,	0x517f, 0xc19d,		0x21, 0
	.dw 0x51c0, 0xc19d,	0x51ff, 0xc19d,		0x21, 0
	.dw 0x5240, 0xc19d,	0x527f, 0xc19d,		0x21, 0
	.dw 0x52c0, 0xc19d,	0x52ff, 0xc19d,		0x21, 0
	.dw 0x5340, 0xc19d,	0x537f, 0xc19d,		0x21, 0
	.dw 0x53c0, 0xc19d,	0x53ff, 0xc19d,		0x21, 0
	.dw 0x5440, 0xc19d,	0x547f, 0xc19d,		0x21, 0
	.dw 0x54c0, 0xc19d,	0x54ff, 0xc19d,		0x21, 0
	.dw 0x5540, 0xc19d,	0x557f, 0xc19d,		0x21, 0
	.dw 0x55c0, 0xc19d,	0x55ff, 0xc19d,		0x21, 0
	.dw 0x5640, 0xc19d,	0x567f, 0xc19d,		0x21, 0
	.dw 0x56c0, 0xc19d,	0x56ff, 0xc19d,		0x21, 0
	.dw 0x5740, 0xc19d,	0x577f, 0xc19d,		0x21, 0
	.dw 0x57c0, 0xc19d,	0x57ff, 0xc19d,		0x21, 0
	.dw 0x5840, 0xc19d,	0x587f, 0xc19d,		0x21, 0
	.dw 0x58c0, 0xc19d,	0x58ff, 0xc19d,		0x21, 0
	.dw 0x5940, 0xc19d,	0x597f, 0xc19d,		0x21, 0
	.dw 0x59c0, 0xc19d,	0x5fff, 0xc19d,		0x21, 0
	.dw 0x6040, 0xc19d,	0x607f, 0xc19d,		0x21, 0
	.dw 0x60c0, 0xc19d,	0x60ff, 0xc19d,		0x21, 0
	.dw 0x6140, 0xc19d,	0x617f, 0xc19d,		0x21, 0
	.dw 0x61c0, 0xc19d,	0x61ff, 0xc19d,		0x21, 0
	.dw 0x6240, 0xc19d,	0x627f, 0xc19d,		0x21, 0
	.dw 0x62c0, 0xc19d,	0x62ff, 0xc19d,		0x21, 0
	.dw 0x6340, 0xc19d,	0x637f, 0xc19d,		0x21, 0
	.dw 0x63c0, 0xc19d,	0x63ff, 0xc19d,		0x21, 0
	.dw 0x6440, 0xc19d,	0x647f, 0xc19d,		0x21, 0
	.dw 0x64c0, 0xc19d,	0x64ff, 0xc19d,		0x21, 0
	.dw 0x6540, 0xc19d,	0x657f, 0xc19d,		0x21, 0
	.dw 0x65c0, 0xc19d,	0x65ff, 0xc19d,		0x21, 0
	.dw 0x6640, 0xc19d,	0x667f, 0xc19d,		0x21, 0
	.dw 0x66c0, 0xc19d,	0x66ff, 0xc19d,		0x21, 0
	.dw 0x6740, 0xc19d,	0x677f, 0xc19d,		0x21, 0
	.dw 0x67c0, 0xc19d,	0x67ff, 0xc19d,		0x21, 0
	.dw 0x6840, 0xc19d,	0x687f, 0xc19d,		0x21, 0
	.dw 0x68c0, 0xc19d,	0x68ff, 0xc19d,		0x21, 0
	.dw 0x6940, 0xc19d,	0x697f, 0xc19d,		0x21, 0
	.dw 0x69c0, 0xc19d,	0x69ff, 0xc19d,		0x21, 0
	.dw 0x6a40, 0xc19d,	0x6a7f, 0xc19d,		0x21, 0
	.dw 0x6ac0, 0xc19d,	0x6aff, 0xc19d,		0x21, 0
	.dw 0x6b40, 0xc19d,	0x6b7f, 0xc19d,		0x21, 0
	.dw 0x6bc0, 0xc19d,	0x6bff, 0xc19d,		0x21, 0
	.dw 0x6c40, 0xc19d,	0x6c7f, 0xc19d,		0x21, 0
	.dw 0x6cc0, 0xc19d,	0x6cff, 0xc19d,		0x21, 0
	.dw 0x6d40, 0xc19d,	0x6d7f, 0xc19d,		0x21, 0
	.dw 0x6dc0, 0xc19d,	0x6dff, 0xc19d,		0x21, 0
	.dw 0x6e40, 0xc19d,	0x6e7f, 0xc19d,		0x21, 0
	.dw 0x6ec0, 0xc19d,	0x6eff, 0xc19d,		0x21, 0
	.dw 0x6f40, 0xc19d,	0x6f7f, 0xc19d,		0x21, 0
	.dw 0x6fc0, 0xc19d,	0x6fff, 0xc19d,		0x21, 0
	.dw 0x7040, 0xc19d,	0x707f, 0xc19d,		0x21, 0
	.dw 0x70c0, 0xc19d,	0x70ff, 0xc19d,		0x21, 0
	.dw 0x7140, 0xc19d,	0x717f, 0xc19d,		0x21, 0
	.dw 0x71c0, 0xc19d,	0x71ff, 0xc19d,		0x21, 0
	.dw 0x7240, 0xc19d,	0x727f, 0xc19d,		0x21, 0
	.dw 0x72c0, 0xc19d,	0x72ff, 0xc19d,		0x21, 0
	.dw 0x7340, 0xc19d,	0x737f, 0xc19d,		0x21, 0
	.dw 0x73c0, 0xc19d,	0x73ff, 0xc19d,		0x21, 0
	.dw 0x7440, 0xc19d,	0x747f, 0xc19d,		0x21, 0
	.dw 0x74c0, 0xc19d,	0x74ff, 0xc19d,		0x21, 0
	.dw 0x7540, 0xc19d,	0x757f, 0xc19d,		0x21, 0
	.dw 0x75c0, 0xc19d,	0x75ff, 0xc19d,		0x21, 0
	.dw 0x7640, 0xc19d,	0x767f, 0xc19d,		0x21, 0
	.dw 0x76c0, 0xc19d,	0x76ff, 0xc19d,		0x21, 0
	.dw 0x7740, 0xc19d,	0x777f, 0xc19d,		0x21, 0
	.dw 0x77c0, 0xc19d,	0x77ff, 0xc19d,		0x21, 0
	.dw 0x7840, 0xc19d,	0x787f, 0xc19d,		0x21, 0
	.dw 0x78c0, 0xc19d,	0x78ff, 0xc19d,		0x21, 0
	.dw 0x7940, 0xc19d,	0x797f, 0xc19d,		0x21, 0
	.dw 0x79c0, 0xc19d,	0x7fff, 0xc19d,		0x21, 0
	.dw 0x8040, 0xc19d,	0x807f, 0xc19d,		0x21, 0
	.dw 0x80c0, 0xc19d,	0x80ff, 0xc19d,		0x21, 0
	.dw 0x8140, 0xc19d,	0x817f, 0xc19d,		0x21, 0
	.dw 0x81c0, 0xc19d,	0x81ff, 0xc19d,		0x21, 0
	.dw 0x8240, 0xc19d,	0x827f, 0xc19d,		0x21, 0
	.dw 0x82c0, 0xc19d,	0x82ff, 0xc19d,		0x21, 0
	.dw 0x8340, 0xc19d,	0x837f, 0xc19d,		0x21, 0
	.dw 0x83c0, 0xc19d,	0x83ff, 0xc19d,		0x21, 0
	.dw 0x8440, 0xc19d,	0x847f, 0xc19d,		0x21, 0
	.dw 0x84c0, 0xc19d,	0x84ff, 0xc19d,		0x21, 0
	.dw 0x8540, 0xc19d,	0x857f, 0xc19d,		0x21, 0
	.dw 0x85c0, 0xc19d,	0x85ff, 0xc19d,		0x21, 0
	.dw 0x8640, 0xc19d,	0x867f, 0xc19d,		0x21, 0
	.dw 0x86c0, 0xc19d,	0x86ff, 0xc19d,		0x21, 0
	.dw 0x8740, 0xc19d,	0x877f, 0xc19d,		0x21, 0
	.dw 0x87c0, 0xc19d,	0x87ff, 0xc19d,		0x21, 0
	.dw 0x8840, 0xc19d,	0x887f, 0xc19d,		0x21, 0
	.dw 0x88c0, 0xc19d,	0x88ff, 0xc19d,		0x21, 0
	.dw 0x8940, 0xc19d,	0x897f, 0xc19d,		0x21, 0
	.dw 0x89c0, 0xc19d,	0x89ff, 0xc19d,		0x21, 0
	.dw 0x8a40, 0xc19d,	0x8a7f, 0xc19d,		0x21, 0
	.dw 0x8ac0, 0xc19d,	0x8aff, 0xc19d,		0x21, 0
	.dw 0x8b40, 0xc19d,	0x8b7f, 0xc19d,		0x21, 0
	.dw 0x8bc0, 0xc19d,	0x8bff, 0xc19d,		0x21, 0
	.dw 0x8c40, 0xc19d,	0x8c7f, 0xc19d,		0x21, 0
	.dw 0x8cc0, 0xc19d,	0x8cff, 0xc19d,		0x21, 0
	.dw 0x8d40, 0xc19d,	0x8d7f, 0xc19d,		0x21, 0
	.dw 0x8dc0, 0xc19d,	0x8dff, 0xc19d,		0x21, 0
	.dw 0x8e40, 0xc19d,	0x8e7f, 0xc19d,		0x21, 0
	.dw 0x8ec0, 0xc19d,	0x8eff, 0xc19d,		0x21, 0
	.dw 0x8f40, 0xc19d,	0x8f7f, 0xc19d,		0x21, 0
	.dw 0x8fc0, 0xc19d,	0x8fff, 0xc19d,		0x21, 0
	.dw 0x9040, 0xc19d,	0x907f, 0xc19d,		0x21, 0
	.dw 0x90c0, 0xc19d,	0x90ff, 0xc19d,		0x21, 0
	.dw 0x9140, 0xc19d,	0x917f, 0xc19d,		0x21, 0
	.dw 0x91c0, 0xc19d,	0x91ff, 0xc19d,		0x21, 0
	.dw 0x9240, 0xc19d,	0x927f, 0xc19d,		0x21, 0
	.dw 0x92c0, 0xc19d,	0x92ff, 0xc19d,		0x21, 0
	.dw 0x9340, 0xc19d,	0x937f, 0xc19d,		0x21, 0
	.dw 0x93c0, 0xc19d,	0x93ff, 0xc19d,		0x21, 0
	.dw 0x9440, 0xc19d,	0x947f, 0xc19d,		0x21, 0
	.dw 0x94c0, 0xc19d,	0x94ff, 0xc19d,		0x21, 0
	.dw 0x9540, 0xc19d,	0x957f, 0xc19d,		0x21, 0
	.dw 0x95c0, 0xc19d,	0x95ff, 0xc19d,		0x21, 0
	.dw 0x9640, 0xc19d,	0x967f, 0xc19d,		0x21, 0
	.dw 0x96c0, 0xc19d,	0x96ff, 0xc19d,		0x21, 0
	.dw 0x9740, 0xc19d,	0x977f, 0xc19d,		0x21, 0
	.dw 0x97c0, 0xc19d,	0x97ff, 0xc19d,		0x21, 0
	.dw 0x9840, 0xc19d,	0x987f, 0xc19d,		0x21, 0
	.dw 0x98c0, 0xc19d,	0x98ff, 0xc19d,		0x21, 0
	.dw 0x9940, 0xc19d,	0x997f, 0xc19d,		0x21, 0
	.dw 0x99c0, 0xc19d,	0x9fff, 0xc19d,		0x21, 0
	.dw 0xa040, 0xc19d,	0xa07f, 0xc19d,		0x21, 0
	.dw 0xa0c0, 0xc19d,	0xa0ff, 0xc19d,		0x21, 0
	.dw 0xa140, 0xc19d,	0xa17f, 0xc19d,		0x21, 0
	.dw 0xa1c0, 0xc19d,	0xa1ff, 0xc19d,		0x21, 0
	.dw 0xa240, 0xc19d,	0xa27f, 0xc19d,		0x21, 0
	.dw 0xa2c0, 0xc19d,	0xa2ff, 0xc19d,		0x21, 0
	.dw 0xa340, 0xc19d,	0xa37f, 0xc19d,		0x21, 0
	.dw 0xa3c0, 0xc19d,	0xa3ff, 0xc19d,		0x21, 0
	.dw 0xa440, 0xc19d,	0xa47f, 0xc19d,		0x21, 0
	.dw 0xa4c0, 0xc19d,	0xa4ff, 0xc19d,		0x21, 0
	.dw 0xa540, 0xc19d,	0xa57f, 0xc19d,		0x21, 0
	.dw 0xa5c0, 0xc19d,	0xa5ff, 0xc19d,		0x21, 0
	.dw 0xa640, 0xc19d,	0xa67f, 0xc19d,		0x21, 0
	.dw 0xa6c0, 0xc19d,	0xa6ff, 0xc19d,		0x21, 0
	.dw 0xa740, 0xc19d,	0xa77f, 0xc19d,		0x21, 0
	.dw 0xa7c0, 0xc19d,	0xa7ff, 0xc19d,		0x21, 0
	.dw 0xa840, 0xc19d,	0xa87f, 0xc19d,		0x21, 0
	.dw 0xa8c0, 0xc19d,	0xa8ff, 0xc19d,		0x21, 0
	.dw 0xa940, 0xc19d,	0xa97f, 0xc19d,		0x21, 0
	.dw 0xa9c0, 0xc19d,	0xa9ff, 0xc19d,		0x21, 0
	.dw 0xaa40, 0xc19d,	0xaa7f, 0xc19d,		0x21, 0
	.dw 0xaac0, 0xc19d,	0xaaff, 0xc19d,		0x21, 0
	.dw 0xab40, 0xc19d,	0xab7f, 0xc19d,		0x21, 0
	.dw 0xabc0, 0xc19d,	0xabff, 0xc19d,		0x21, 0
	.dw 0xac40, 0xc19d,	0xac7f, 0xc19d,		0x21, 0
	.dw 0xacc0, 0xc19d,	0xacff, 0xc19d,		0x21, 0
	.dw 0xad40, 0xc19d,	0xad7f, 0xc19d,		0x21, 0
	.dw 0xadc0, 0xc19d,	0xadff, 0xc19d,		0x21, 0
	.dw 0xae40, 0xc19d,	0xae7f, 0xc19d,		0x21, 0
	.dw 0xaec0, 0xc19d,	0xaeff, 0xc19d,		0x21, 0
	.dw 0xaf40, 0xc19d,	0xaf7f, 0xc19d,		0x21, 0
	.dw 0xafc0, 0xc19d,	0xafff, 0xc19d,		0x21, 0
	.dw 0xb040, 0xc19d,	0xb07f, 0xc19d,		0x21, 0
	.dw 0xb0c0, 0xc19d,	0xb0ff, 0xc19d,		0x21, 0
	.dw 0xb140, 0xc19d,	0xb17f, 0xc19d,		0x21, 0
	.dw 0xb1c0, 0xc19d,	0xb1ff, 0xc19d,		0x21, 0
	.dw 0xb240, 0xc19d,	0xb27f, 0xc19d,		0x21, 0
	.dw 0xb2c0, 0xc19d,	0xb2ff, 0xc19d,		0x21, 0
	.dw 0xb340, 0xc19d,	0xb37f, 0xc19d,		0x21, 0
	.dw 0xb3c0, 0xc19d,	0xb3ff, 0xc19d,		0x21, 0
	.dw 0xb440, 0xc19d,	0xb47f, 0xc19d,		0x21, 0
	.dw 0xb4c0, 0xc19d,	0xb4ff, 0xc19d,		0x21, 0
	.dw 0xb540, 0xc19d,	0xb57f, 0xc19d,		0x21, 0
	.dw 0xb5c0, 0xc19d,	0xb5ff, 0xc19d,		0x21, 0
	.dw 0xb640, 0xc19d,	0xb67f, 0xc19d,		0x21, 0
	.dw 0xb6c0, 0xc19d,	0xb6ff, 0xc19d,		0x21, 0
	.dw 0xb740, 0xc19d,	0xb77f, 0xc19d,		0x21, 0
	.dw 0xb7c0, 0xc19d,	0xb7ff, 0xc19d,		0x21, 0
	.dw 0xb840, 0xc19d,	0xb87f, 0xc19d,		0x21, 0
	.dw 0xb8c0, 0xc19d,	0xb8ff, 0xc19d,		0x21, 0
	.dw 0xb940, 0xc19d,	0xb97f, 0xc19d,		0x21, 0
	.dw 0xb9c0, 0xc19d,	0xbfff, 0xc19d,		0x21, 0
	.dw 0xc040, 0xc19d,	0xc07f, 0xc19d,		0x21, 0
	.dw 0xc0c0, 0xc19d,	0xc0ff, 0xc19d,		0x21, 0
	.dw 0xc140, 0xc19d,	0xc17f, 0xc19d,		0x21, 0
	.dw 0xc1c0, 0xc19d,	0xc1ff, 0xc19d,		0x21, 0
	.dw 0xc240, 0xc19d,	0xc27f, 0xc19d,		0x21, 0
	.dw 0xc2c0, 0xc19d,	0xc2ff, 0xc19d,		0x21, 0
	.dw 0xc340, 0xc19d,	0xc37f, 0xc19d,		0x21, 0
	.dw 0xc3c0, 0xc19d,	0xc3ff, 0xc19d,		0x21, 0
	.dw 0xc440, 0xc19d,	0xc47f, 0xc19d,		0x21, 0
	.dw 0xc4c0, 0xc19d,	0xc4ff, 0xc19d,		0x21, 0
	.dw 0xc540, 0xc19d,	0xc57f, 0xc19d,		0x21, 0
	.dw 0xc5c0, 0xc19d,	0xc5ff, 0xc19d,		0x21, 0
	.dw 0xc640, 0xc19d,	0xc67f, 0xc19d,		0x21, 0
	.dw 0xc6c0, 0xc19d,	0xc6ff, 0xc19d,		0x21, 0
	.dw 0xc740, 0xc19d,	0xc77f, 0xc19d,		0x21, 0
	.dw 0xc7c0, 0xc19d,	0xc7ff, 0xc19d,		0x21, 0
	.dw 0xc840, 0xc19d,	0xc87f, 0xc19d,		0x21, 0
	.dw 0xc8c0, 0xc19d,	0xc8ff, 0xc19d,		0x21, 0
	.dw 0xc940, 0xc19d,	0xc97f, 0xc19d,		0x21, 0
	.dw 0xc9c0, 0xc19d,	0xc9ff, 0xc19d,		0x21, 0
	.dw 0xca40, 0xc19d,	0xca7f, 0xc19d,		0x21, 0
	.dw 0xcac0, 0xc19d,	0xcaff, 0xc19d,		0x21, 0
	.dw 0xcb40, 0xc19d,	0xcb7f, 0xc19d,		0x21, 0
	.dw 0xcbc0, 0xc19d,	0xcbff, 0xc19d,		0x21, 0
	.dw 0xcc40, 0xc19d,	0xcc7f, 0xc19d,		0x21, 0
	.dw 0xccc0, 0xc19d,	0xccff, 0xc19d,		0x21, 0
	.dw 0xcd40, 0xc19d,	0xcd7f, 0xc19d,		0x21, 0
	.dw 0xcdc0, 0xc19d,	0xcdff, 0xc19d,		0x21, 0
	.dw 0xce40, 0xc19d,	0xce7f, 0xc19d,		0x21, 0
	.dw 0xcec0, 0xc19d,	0xceff, 0xc19d,		0x21, 0
	.dw 0xcf40, 0xc19d,	0xcf7f, 0xc19d,		0x21, 0
	.dw 0xcfc0, 0xc19d,	0xcfff, 0xc19d,		0x21, 0
	.dw 0xd040, 0xc19d,	0xd07f, 0xc19d,		0x21, 0
	.dw 0xd0c0, 0xc19d,	0xd0ff, 0xc19d,		0x21, 0
	.dw 0xd140, 0xc19d,	0xd17f, 0xc19d,		0x21, 0
	.dw 0xd1c0, 0xc19d,	0xd1ff, 0xc19d,		0x21, 0
	.dw 0xd240, 0xc19d,	0xd27f, 0xc19d,		0x21, 0
	.dw 0xd2c0, 0xc19d,	0xd2ff, 0xc19d,		0x21, 0
	.dw 0xd340, 0xc19d,	0xd37f, 0xc19d,		0x21, 0
	.dw 0xd3c0, 0xc19d,	0xd3ff, 0xc19d,		0x21, 0
	.dw 0xd440, 0xc19d,	0xd47f, 0xc19d,		0x21, 0
	.dw 0xd4c0, 0xc19d,	0xd4ff, 0xc19d,		0x21, 0
	.dw 0xd540, 0xc19d,	0xd57f, 0xc19d,		0x21, 0
	.dw 0xd5c0, 0xc19d,	0xd5ff, 0xc19d,		0x21, 0
	.dw 0xd640, 0xc19d,	0xd67f, 0xc19d,		0x21, 0
	.dw 0xd6c0, 0xc19d,	0xd6ff, 0xc19d,		0x21, 0
	.dw 0xd740, 0xc19d,	0xd77f, 0xc19d,		0x21, 0
	.dw 0xd7c0, 0xc19d,	0xd7ff, 0xc19d,		0x21, 0
	.dw 0xd840, 0xc19d,	0xd87f, 0xc19d,		0x21, 0
	.dw 0xd8c0, 0xc19d,	0xd8ff, 0xc19d,		0x21, 0
	.dw 0xd940, 0xc19d,	0xd97f, 0xc19d,		0x21, 0
	.dw 0xd9c0, 0xc19d,	0xdfff, 0xc19d,		0x21, 0
	.dw 0xe040, 0xc19d,	0xe07f, 0xc19d,		0x21, 0
	.dw 0xe0c0, 0xc19d,	0xe0ff, 0xc19d,		0x21, 0
	.dw 0xe140, 0xc19d,	0xe17f, 0xc19d,		0x21, 0
	.dw 0xe1c0, 0xc19d,	0xe1ff, 0xc19d,		0x21, 0
	.dw 0xe240, 0xc19d,	0xe27f, 0xc19d,		0x21, 0
	.dw 0xe2c0, 0xc19d,	0xe2ff, 0xc19d,		0x21, 0
	.dw 0xe340, 0xc19d,	0xe37f, 0xc19d,		0x21, 0
	.dw 0xe3c0, 0xc19d,	0xe3ff, 0xc19d,		0x21, 0
	.dw 0xe440, 0xc19d,	0xe47f, 0xc19d,		0x21, 0
	.dw 0xe4c0, 0xc19d,	0xe4ff, 0xc19d,		0x21, 0
	.dw 0xe540, 0xc19d,	0xe57f, 0xc19d,		0x21, 0
	.dw 0xe5c0, 0xc19d,	0xe5ff, 0xc19d,		0x21, 0
	.dw 0xe640, 0xc19d,	0xe67f, 0xc19d,		0x21, 0
	.dw 0xe6c0, 0xc19d,	0xe6ff, 0xc19d,		0x21, 0
	.dw 0xe740, 0xc19d,	0xe77f, 0xc19d,		0x21, 0
	.dw 0xe7c0, 0xc19d,	0xe7ff, 0xc19d,		0x21, 0
	.dw 0xe840, 0xc19d,	0xe87f, 0xc19d,		0x21, 0
	.dw 0xe8c0, 0xc19d,	0xe8ff, 0xc19d,		0x21, 0
	.dw 0xe940, 0xc19d,	0xe97f, 0xc19d,		0x21, 0
	.dw 0xe9c0, 0xc19d,	0xe9ff, 0xc19d,		0x21, 0
	.dw 0xea40, 0xc19d,	0xea7f, 0xc19d,		0x21, 0
	.dw 0xeac0, 0xc19d,	0xeaff, 0xc19d,		0x21, 0
	.dw 0xeb40, 0xc19d,	0xeb7f, 0xc19d,		0x21, 0
	.dw 0xebc0, 0xc19d,	0xebff, 0xc19d,		0x21, 0
	.dw 0xec40, 0xc19d,	0xec7f, 0xc19d,		0x21, 0
	.dw 0xecc0, 0xc19d,	0xecff, 0xc19d,		0x21, 0
	.dw 0xed40, 0xc19d,	0xed7f, 0xc19d,		0x21, 0
	.dw 0xedc0, 0xc19d,	0xedff, 0xc19d,		0x21, 0
	.dw 0xee40, 0xc19d,	0xee7f, 0xc19d,		0x21, 0
	.dw 0xeec0, 0xc19d,	0xeeff, 0xc19d,		0x21, 0
	.dw 0xef40, 0xc19d,	0xef7f, 0xc19d,		0x21, 0
	.dw 0xefc0, 0xc19d,	0xefff, 0xc19d,		0x21, 0
	.dw 0xf040, 0xc19d,	0xf07f, 0xc19d,		0x21, 0
	.dw 0xf0c0, 0xc19d,	0xf0ff, 0xc19d,		0x21, 0
	.dw 0xf140, 0xc19d,	0xf17f, 0xc19d,		0x21, 0
	.dw 0xf1c0, 0xc19d,	0xf1ff, 0xc19d,		0x21, 0
	.dw 0xf240, 0xc19d,	0xf27f, 0xc19d,		0x21, 0
	.dw 0xf2c0, 0xc19d,	0xf2ff, 0xc19d,		0x21, 0
	.dw 0xf340, 0xc19d,	0xf37f, 0xc19d,		0x21, 0
	.dw 0xf3c0, 0xc19d,	0xf3ff, 0xc19d,		0x21, 0
	.dw 0xf440, 0xc19d,	0xf47f, 0xc19d,		0x21, 0
	.dw 0xf4c0, 0xc19d,	0xf4ff, 0xc19d,		0x21, 0
	.dw 0xf540, 0xc19d,	0xf57f, 0xc19d,		0x21, 0
	.dw 0xf5c0, 0xc19d,	0xf5ff, 0xc19d,		0x21, 0
	.dw 0xf640, 0xc19d,	0xf67f, 0xc19d,		0x21, 0
	.dw 0xf6c0, 0xc19d,	0xf6ff, 0xc19d,		0x21, 0
	.dw 0xf740, 0xc19d,	0xf77f, 0xc19d,		0x21, 0
	.dw 0xf7c0, 0xc19d,	0xf7ff, 0xc19d,		0x21, 0
	.dw 0xf840, 0xc19d,	0xf87f, 0xc19d,		0x21, 0
	.dw 0xf8c0, 0xc19d,	0xf8ff, 0xc19d,		0x21, 0
	.dw 0xf940, 0xc19d,	0xf97f, 0xc19d,		0x21, 0
	.dw 0xf9c0, 0xc19d,	0xffff, 0xc19d,		0x21, 0
	.dw 0x0040, 0xc19e,	0x007f, 0xc19e,		0x21, 0
	.dw 0x00c0, 0xc19e,	0x00ff, 0xc19e,		0x21, 0
	.dw 0x0140, 0xc19e,	0x017f, 0xc19e,		0x21, 0
	.dw 0x01c0, 0xc19e,	0x01ff, 0xc19e,		0x21, 0
	.dw 0x0240, 0xc19e,	0x027f, 0xc19e,		0x21, 0
	.dw 0x02c0, 0xc19e,	0x02ff, 0xc19e,		0x21, 0
	.dw 0x0340, 0xc19e,	0x037f, 0xc19e,		0x21, 0
	.dw 0x03c0, 0xc19e,	0x03ff, 0xc19e,		0x21, 0
	.dw 0x0440, 0xc19e,	0x047f, 0xc19e,		0x21, 0
	.dw 0x04c0, 0xc19e,	0x04ff, 0xc19e,		0x21, 0
	.dw 0x0540, 0xc19e,	0x057f, 0xc19e,		0x21, 0
	.dw 0x05c0, 0xc19e,	0x05ff, 0xc19e,		0x21, 0
	.dw 0x0640, 0xc19e,	0x067f, 0xc19e,		0x21, 0
	.dw 0x06c0, 0xc19e,	0x06ff, 0xc19e,		0x21, 0
	.dw 0x0740, 0xc19e,	0x077f, 0xc19e,		0x21, 0
	.dw 0x07c0, 0xc19e,	0x07ff, 0xc19e,		0x21, 0
	.dw 0x0840, 0xc19e,	0x087f, 0xc19e,		0x21, 0
	.dw 0x08c0, 0xc19e,	0x08ff, 0xc19e,		0x21, 0
	.dw 0x0940, 0xc19e,	0x097f, 0xc19e,		0x21, 0
	.dw 0x09c0, 0xc19e,	0x09ff, 0xc19e,		0x21, 0
	.dw 0x0a40, 0xc19e,	0x0a7f, 0xc19e,		0x21, 0
	.dw 0x0ac0, 0xc19e,	0x0aff, 0xc19e,		0x21, 0
	.dw 0x0b40, 0xc19e,	0x0b7f, 0xc19e,		0x21, 0
	.dw 0x0bc0, 0xc19e,	0x0bff, 0xc19e,		0x21, 0
	.dw 0x0c40, 0xc19e,	0x0c7f, 0xc19e,		0x21, 0
	.dw 0x0cc0, 0xc19e,	0x0cff, 0xc19e,		0x21, 0
	.dw 0x0d40, 0xc19e,	0x0d7f, 0xc19e,		0x21, 0
	.dw 0x0dc0, 0xc19e,	0x0dff, 0xc19e,		0x21, 0
	.dw 0x0e40, 0xc19e,	0x0e7f, 0xc19e,		0x21, 0
	.dw 0x0ec0, 0xc19e,	0x0eff, 0xc19e,		0x21, 0
	.dw 0x0f40, 0xc19e,	0x0f7f, 0xc19e,		0x21, 0
	.dw 0x0fc0, 0xc19e,	0x0fff, 0xc19e,		0x21, 0
	.dw 0x1040, 0xc19e,	0x107f, 0xc19e,		0x21, 0
	.dw 0x10c0, 0xc19e,	0x10ff, 0xc19e,		0x21, 0
	.dw 0x1140, 0xc19e,	0x117f, 0xc19e,		0x21, 0
	.dw 0x11c0, 0xc19e,	0x11ff, 0xc19e,		0x21, 0
	.dw 0x1240, 0xc19e,	0x127f, 0xc19e,		0x21, 0
	.dw 0x12c0, 0xc19e,	0x12ff, 0xc19e,		0x21, 0
	.dw 0x1340, 0xc19e,	0x137f, 0xc19e,		0x21, 0
	.dw 0x13c0, 0xc19e,	0x13ff, 0xc19e,		0x21, 0
	.dw 0x1440, 0xc19e,	0x147f, 0xc19e,		0x21, 0
	.dw 0x14c0, 0xc19e,	0x14ff, 0xc19e,		0x21, 0
	.dw 0x1540, 0xc19e,	0x157f, 0xc19e,		0x21, 0
	.dw 0x15c0, 0xc19e,	0x15ff, 0xc19e,		0x21, 0
	.dw 0x1640, 0xc19e,	0x167f, 0xc19e,		0x21, 0
	.dw 0x16c0, 0xc19e,	0x16ff, 0xc19e,		0x21, 0
	.dw 0x1740, 0xc19e,	0x177f, 0xc19e,		0x21, 0
	.dw 0x17c0, 0xc19e,	0x17ff, 0xc19e,		0x21, 0
	.dw 0x1840, 0xc19e,	0x187f, 0xc19e,		0x21, 0
	.dw 0x18c0, 0xc19e,	0x18ff, 0xc19e,		0x21, 0
	.dw 0x1940, 0xc19e,	0x197f, 0xc19e,		0x21, 0
	.dw 0x19c0, 0xc19e,	0x1fff, 0xc19e,		0x21, 0
	.dw 0x2040, 0xc19e,	0x207f, 0xc19e,		0x21, 0
	.dw 0x20c0, 0xc19e,	0x20ff, 0xc19e,		0x21, 0
	.dw 0x2140, 0xc19e,	0x217f, 0xc19e,		0x21, 0
	.dw 0x21c0, 0xc19e,	0x21ff, 0xc19e,		0x21, 0
	.dw 0x2240, 0xc19e,	0x227f, 0xc19e,		0x21, 0
	.dw 0x22c0, 0xc19e,	0x22ff, 0xc19e,		0x21, 0
	.dw 0x2340, 0xc19e,	0x237f, 0xc19e,		0x21, 0
	.dw 0x23c0, 0xc19e,	0x23ff, 0xc19e,		0x21, 0
	.dw 0x2440, 0xc19e,	0x247f, 0xc19e,		0x21, 0
	.dw 0x24c0, 0xc19e,	0x24ff, 0xc19e,		0x21, 0
	.dw 0x2540, 0xc19e,	0x257f, 0xc19e,		0x21, 0
	.dw 0x25c0, 0xc19e,	0x25ff, 0xc19e,		0x21, 0
	.dw 0x2640, 0xc19e,	0x267f, 0xc19e,		0x21, 0
	.dw 0x26c0, 0xc19e,	0x26ff, 0xc19e,		0x21, 0
	.dw 0x2740, 0xc19e,	0x277f, 0xc19e,		0x21, 0
	.dw 0x27c0, 0xc19e,	0x27ff, 0xc19e,		0x21, 0
	.dw 0x2840, 0xc19e,	0x287f, 0xc19e,		0x21, 0
	.dw 0x28c0, 0xc19e,	0x28ff, 0xc19e,		0x21, 0
	.dw 0x2940, 0xc19e,	0x297f, 0xc19e,		0x21, 0
	.dw 0x29c0, 0xc19e,	0x29ff, 0xc19e,		0x21, 0
	.dw 0x2a40, 0xc19e,	0x2a7f, 0xc19e,		0x21, 0
	.dw 0x2ac0, 0xc19e,	0x2aff, 0xc19e,		0x21, 0
	.dw 0x2b40, 0xc19e,	0x2b7f, 0xc19e,		0x21, 0
	.dw 0x2bc0, 0xc19e,	0x2bff, 0xc19e,		0x21, 0
	.dw 0x2c40, 0xc19e,	0x2c7f, 0xc19e,		0x21, 0
	.dw 0x2cc0, 0xc19e,	0x2cff, 0xc19e,		0x21, 0
	.dw 0x2d40, 0xc19e,	0x2d7f, 0xc19e,		0x21, 0
	.dw 0x2dc0, 0xc19e,	0x2dff, 0xc19e,		0x21, 0
	.dw 0x2e40, 0xc19e,	0x2e7f, 0xc19e,		0x21, 0
	.dw 0x2ec0, 0xc19e,	0x2eff, 0xc19e,		0x21, 0
	.dw 0x2f40, 0xc19e,	0x2f7f, 0xc19e,		0x21, 0
	.dw 0x2fc0, 0xc19e,	0x2fff, 0xc19e,		0x21, 0
	.dw 0x3040, 0xc19e,	0x307f, 0xc19e,		0x21, 0
	.dw 0x30c0, 0xc19e,	0x30ff, 0xc19e,		0x21, 0
	.dw 0x3140, 0xc19e,	0x317f, 0xc19e,		0x21, 0
	.dw 0x31c0, 0xc19e,	0x31ff, 0xc19e,		0x21, 0
	.dw 0x3240, 0xc19e,	0x327f, 0xc19e,		0x21, 0
	.dw 0x32c0, 0xc19e,	0x32ff, 0xc19e,		0x21, 0
	.dw 0x3340, 0xc19e,	0x337f, 0xc19e,		0x21, 0
	.dw 0x33c0, 0xc19e,	0x33ff, 0xc19e,		0x21, 0
	.dw 0x3440, 0xc19e,	0x347f, 0xc19e,		0x21, 0
	.dw 0x34c0, 0xc19e,	0x34ff, 0xc19e,		0x21, 0
	.dw 0x3540, 0xc19e,	0x357f, 0xc19e,		0x21, 0
	.dw 0x35c0, 0xc19e,	0x35ff, 0xc19e,		0x21, 0
	.dw 0x3640, 0xc19e,	0x367f, 0xc19e,		0x21, 0
	.dw 0x36c0, 0xc19e,	0x36ff, 0xc19e,		0x21, 0
	.dw 0x3740, 0xc19e,	0x377f, 0xc19e,		0x21, 0
	.dw 0x37c0, 0xc19e,	0x37ff, 0xc19e,		0x21, 0
	.dw 0x3840, 0xc19e,	0x387f, 0xc19e,		0x21, 0
	.dw 0x38c0, 0xc19e,	0x38ff, 0xc19e,		0x21, 0
	.dw 0x3940, 0xc19e,	0x397f, 0xc19e,		0x21, 0
	.dw 0x39c0, 0xc19e,	0x3fff, 0xc19e,		0x21, 0
	.dw 0x4040, 0xc19e,	0x407f, 0xc19e,		0x21, 0
	.dw 0x40c0, 0xc19e,	0x40ff, 0xc19e,		0x21, 0
	.dw 0x4140, 0xc19e,	0x417f, 0xc19e,		0x21, 0
	.dw 0x41c0, 0xc19e,	0x41ff, 0xc19e,		0x21, 0
	.dw 0x4240, 0xc19e,	0x427f, 0xc19e,		0x21, 0
	.dw 0x42c0, 0xc19e,	0x42ff, 0xc19e,		0x21, 0
	.dw 0x4340, 0xc19e,	0x437f, 0xc19e,		0x21, 0
	.dw 0x43c0, 0xc19e,	0x43ff, 0xc19e,		0x21, 0
	.dw 0x4440, 0xc19e,	0x447f, 0xc19e,		0x21, 0
	.dw 0x44c0, 0xc19e,	0x44ff, 0xc19e,		0x21, 0
	.dw 0x4540, 0xc19e,	0x457f, 0xc19e,		0x21, 0
	.dw 0x45c0, 0xc19e,	0x45ff, 0xc19e,		0x21, 0
	.dw 0x4640, 0xc19e,	0x467f, 0xc19e,		0x21, 0
	.dw 0x46c0, 0xc19e,	0x46ff, 0xc19e,		0x21, 0
	.dw 0x4740, 0xc19e,	0x477f, 0xc19e,		0x21, 0
	.dw 0x47c0, 0xc19e,	0x47ff, 0xc19e,		0x21, 0
	.dw 0x4840, 0xc19e,	0x487f, 0xc19e,		0x21, 0
	.dw 0x48c0, 0xc19e,	0x48ff, 0xc19e,		0x21, 0
	.dw 0x4940, 0xc19e,	0x497f, 0xc19e,		0x21, 0
	.dw 0x49c0, 0xc19e,	0x49ff, 0xc19e,		0x21, 0
	.dw 0x4a40, 0xc19e,	0x4a7f, 0xc19e,		0x21, 0
	.dw 0x4ac0, 0xc19e,	0x4aff, 0xc19e,		0x21, 0
	.dw 0x4b40, 0xc19e,	0x4b7f, 0xc19e,		0x21, 0
	.dw 0x4bc0, 0xc19e,	0x4bff, 0xc19e,		0x21, 0
	.dw 0x4c40, 0xc19e,	0x4c7f, 0xc19e,		0x21, 0
	.dw 0x4cc0, 0xc19e,	0x4cff, 0xc19e,		0x21, 0
	.dw 0x4d40, 0xc19e,	0x4d7f, 0xc19e,		0x21, 0
	.dw 0x4dc0, 0xc19e,	0x4dff, 0xc19e,		0x21, 0
	.dw 0x4e40, 0xc19e,	0x4e7f, 0xc19e,		0x21, 0
	.dw 0x4ec0, 0xc19e,	0x4eff, 0xc19e,		0x21, 0
	.dw 0x4f40, 0xc19e,	0x4f7f, 0xc19e,		0x21, 0
	.dw 0x4fc0, 0xc19e,	0x4fff, 0xc19e,		0x21, 0
	.dw 0x5040, 0xc19e,	0x507f, 0xc19e,		0x21, 0
	.dw 0x50c0, 0xc19e,	0x50ff, 0xc19e,		0x21, 0
	.dw 0x5140, 0xc19e,	0x517f, 0xc19e,		0x21, 0
	.dw 0x51c0, 0xc19e,	0x51ff, 0xc19e,		0x21, 0
	.dw 0x5240, 0xc19e,	0x527f, 0xc19e,		0x21, 0
	.dw 0x52c0, 0xc19e,	0x52ff, 0xc19e,		0x21, 0
	.dw 0x5340, 0xc19e,	0x537f, 0xc19e,		0x21, 0
	.dw 0x53c0, 0xc19e,	0x53ff, 0xc19e,		0x21, 0
	.dw 0x5440, 0xc19e,	0x547f, 0xc19e,		0x21, 0
	.dw 0x54c0, 0xc19e,	0x54ff, 0xc19e,		0x21, 0
	.dw 0x5540, 0xc19e,	0x557f, 0xc19e,		0x21, 0
	.dw 0x55c0, 0xc19e,	0x55ff, 0xc19e,		0x21, 0
	.dw 0x5640, 0xc19e,	0x567f, 0xc19e,		0x21, 0
	.dw 0x56c0, 0xc19e,	0x56ff, 0xc19e,		0x21, 0
	.dw 0x5740, 0xc19e,	0x577f, 0xc19e,		0x21, 0
	.dw 0x57c0, 0xc19e,	0x57ff, 0xc19e,		0x21, 0
	.dw 0x5840, 0xc19e,	0x587f, 0xc19e,		0x21, 0
	.dw 0x58c0, 0xc19e,	0x58ff, 0xc19e,		0x21, 0
	.dw 0x5940, 0xc19e,	0x597f, 0xc19e,		0x21, 0
	.dw 0x59c0, 0xc19e,	0x5fff, 0xc19e,		0x21, 0
	.dw 0x6040, 0xc19e,	0x607f, 0xc19e,		0x21, 0
	.dw 0x60c0, 0xc19e,	0x60ff, 0xc19e,		0x21, 0
	.dw 0x6140, 0xc19e,	0x617f, 0xc19e,		0x21, 0
	.dw 0x61c0, 0xc19e,	0x61ff, 0xc19e,		0x21, 0
	.dw 0x6240, 0xc19e,	0x627f, 0xc19e,		0x21, 0
	.dw 0x62c0, 0xc19e,	0x62ff, 0xc19e,		0x21, 0
	.dw 0x6340, 0xc19e,	0x637f, 0xc19e,		0x21, 0
	.dw 0x63c0, 0xc19e,	0x63ff, 0xc19e,		0x21, 0
	.dw 0x6440, 0xc19e,	0x647f, 0xc19e,		0x21, 0
	.dw 0x64c0, 0xc19e,	0x64ff, 0xc19e,		0x21, 0
	.dw 0x6540, 0xc19e,	0x657f, 0xc19e,		0x21, 0
	.dw 0x65c0, 0xc19e,	0x65ff, 0xc19e,		0x21, 0
	.dw 0x6640, 0xc19e,	0x667f, 0xc19e,		0x21, 0
	.dw 0x66c0, 0xc19e,	0x66ff, 0xc19e,		0x21, 0
	.dw 0x6740, 0xc19e,	0x677f, 0xc19e,		0x21, 0
	.dw 0x67c0, 0xc19e,	0x67ff, 0xc19e,		0x21, 0
	.dw 0x6840, 0xc19e,	0x687f, 0xc19e,		0x21, 0
	.dw 0x68c0, 0xc19e,	0x68ff, 0xc19e,		0x21, 0
	.dw 0x6940, 0xc19e,	0x697f, 0xc19e,		0x21, 0
	.dw 0x69c0, 0xc19e,	0x69ff, 0xc19e,		0x21, 0
	.dw 0x6a40, 0xc19e,	0x6a7f, 0xc19e,		0x21, 0
	.dw 0x6ac0, 0xc19e,	0x6aff, 0xc19e,		0x21, 0
	.dw 0x6b40, 0xc19e,	0x6b7f, 0xc19e,		0x21, 0
	.dw 0x6bc0, 0xc19e,	0x6bff, 0xc19e,		0x21, 0
	.dw 0x6c40, 0xc19e,	0x6c7f, 0xc19e,		0x21, 0
	.dw 0x6cc0, 0xc19e,	0x6cff, 0xc19e,		0x21, 0
	.dw 0x6d40, 0xc19e,	0x6d7f, 0xc19e,		0x21, 0
	.dw 0x6dc0, 0xc19e,	0x6dff, 0xc19e,		0x21, 0
	.dw 0x6e40, 0xc19e,	0x6e7f, 0xc19e,		0x21, 0
	.dw 0x6ec0, 0xc19e,	0x6eff, 0xc19e,		0x21, 0
	.dw 0x6f40, 0xc19e,	0x6f7f, 0xc19e,		0x21, 0
	.dw 0x6fc0, 0xc19e,	0x6fff, 0xc19e,		0x21, 0
	.dw 0x7040, 0xc19e,	0x707f, 0xc19e,		0x21, 0
	.dw 0x70c0, 0xc19e,	0x70ff, 0xc19e,		0x21, 0
	.dw 0x7140, 0xc19e,	0x717f, 0xc19e,		0x21, 0
	.dw 0x71c0, 0xc19e,	0x71ff, 0xc19e,		0x21, 0
	.dw 0x7240, 0xc19e,	0x727f, 0xc19e,		0x21, 0
	.dw 0x72c0, 0xc19e,	0x72ff, 0xc19e,		0x21, 0
	.dw 0x7340, 0xc19e,	0x737f, 0xc19e,		0x21, 0
	.dw 0x73c0, 0xc19e,	0x73ff, 0xc19e,		0x21, 0
	.dw 0x7440, 0xc19e,	0x747f, 0xc19e,		0x21, 0
	.dw 0x74c0, 0xc19e,	0x74ff, 0xc19e,		0x21, 0
	.dw 0x7540, 0xc19e,	0x757f, 0xc19e,		0x21, 0
	.dw 0x75c0, 0xc19e,	0x75ff, 0xc19e,		0x21, 0
	.dw 0x7640, 0xc19e,	0x767f, 0xc19e,		0x21, 0
	.dw 0x76c0, 0xc19e,	0x76ff, 0xc19e,		0x21, 0
	.dw 0x7740, 0xc19e,	0x777f, 0xc19e,		0x21, 0
	.dw 0x77c0, 0xc19e,	0x77ff, 0xc19e,		0x21, 0
	.dw 0x7840, 0xc19e,	0x787f, 0xc19e,		0x21, 0
	.dw 0x78c0, 0xc19e,	0x78ff, 0xc19e,		0x21, 0
	.dw 0x7940, 0xc19e,	0x797f, 0xc19e,		0x21, 0
	.dw 0x79c0, 0xc19e,	0x7fff, 0xc19e,		0x21, 0
	.dw 0x8040, 0xc19e,	0x807f, 0xc19e,		0x21, 0
	.dw 0x80c0, 0xc19e,	0x80ff, 0xc19e,		0x21, 0
	.dw 0x8140, 0xc19e,	0x817f, 0xc19e,		0x21, 0
	.dw 0x81c0, 0xc19e,	0x81ff, 0xc19e,		0x21, 0
	.dw 0x8240, 0xc19e,	0x827f, 0xc19e,		0x21, 0
	.dw 0x82c0, 0xc19e,	0x82ff, 0xc19e,		0x21, 0
	.dw 0x8340, 0xc19e,	0x837f, 0xc19e,		0x21, 0
	.dw 0x83c0, 0xc19e,	0x83ff, 0xc19e,		0x21, 0
	.dw 0x8440, 0xc19e,	0x847f, 0xc19e,		0x21, 0
	.dw 0x84c0, 0xc19e,	0x84ff, 0xc19e,		0x21, 0
	.dw 0x8540, 0xc19e,	0x857f, 0xc19e,		0x21, 0
	.dw 0x85c0, 0xc19e,	0x85ff, 0xc19e,		0x21, 0
	.dw 0x8640, 0xc19e,	0x867f, 0xc19e,		0x21, 0
	.dw 0x86c0, 0xc19e,	0x86ff, 0xc19e,		0x21, 0
	.dw 0x8740, 0xc19e,	0x877f, 0xc19e,		0x21, 0
	.dw 0x87c0, 0xc19e,	0x87ff, 0xc19e,		0x21, 0
	.dw 0x8840, 0xc19e,	0x887f, 0xc19e,		0x21, 0
	.dw 0x88c0, 0xc19e,	0x88ff, 0xc19e,		0x21, 0
	.dw 0x8940, 0xc19e,	0x897f, 0xc19e,		0x21, 0
	.dw 0x89c0, 0xc19e,	0x89ff, 0xc19e,		0x21, 0
	.dw 0x8a40, 0xc19e,	0x8a7f, 0xc19e,		0x21, 0
	.dw 0x8ac0, 0xc19e,	0x8aff, 0xc19e,		0x21, 0
	.dw 0x8b40, 0xc19e,	0x8b7f, 0xc19e,		0x21, 0
	.dw 0x8bc0, 0xc19e,	0x8bff, 0xc19e,		0x21, 0
	.dw 0x8c40, 0xc19e,	0x8c7f, 0xc19e,		0x21, 0
	.dw 0x8cc0, 0xc19e,	0x8cff, 0xc19e,		0x21, 0
	.dw 0x8d40, 0xc19e,	0x8d7f, 0xc19e,		0x21, 0
	.dw 0x8dc0, 0xc19e,	0x8dff, 0xc19e,		0x21, 0
	.dw 0x8e40, 0xc19e,	0x8e7f, 0xc19e,		0x21, 0
	.dw 0x8ec0, 0xc19e,	0x8eff, 0xc19e,		0x21, 0
	.dw 0x8f40, 0xc19e,	0x8f7f, 0xc19e,		0x21, 0
	.dw 0x8fc0, 0xc19e,	0x8fff, 0xc19e,		0x21, 0
	.dw 0x9040, 0xc19e,	0x907f, 0xc19e,		0x21, 0
	.dw 0x90c0, 0xc19e,	0x90ff, 0xc19e,		0x21, 0
	.dw 0x9140, 0xc19e,	0x917f, 0xc19e,		0x21, 0
	.dw 0x91c0, 0xc19e,	0x91ff, 0xc19e,		0x21, 0
	.dw 0x9240, 0xc19e,	0x927f, 0xc19e,		0x21, 0
	.dw 0x92c0, 0xc19e,	0x92ff, 0xc19e,		0x21, 0
	.dw 0x9340, 0xc19e,	0x937f, 0xc19e,		0x21, 0
	.dw 0x93c0, 0xc19e,	0x93ff, 0xc19e,		0x21, 0
	.dw 0x9440, 0xc19e,	0x947f, 0xc19e,		0x21, 0
	.dw 0x94c0, 0xc19e,	0x94ff, 0xc19e,		0x21, 0
	.dw 0x9540, 0xc19e,	0x957f, 0xc19e,		0x21, 0
	.dw 0x95c0, 0xc19e,	0x95ff, 0xc19e,		0x21, 0
	.dw 0x9640, 0xc19e,	0x967f, 0xc19e,		0x21, 0
	.dw 0x96c0, 0xc19e,	0x96ff, 0xc19e,		0x21, 0
	.dw 0x9740, 0xc19e,	0x977f, 0xc19e,		0x21, 0
	.dw 0x97c0, 0xc19e,	0x97ff, 0xc19e,		0x21, 0
	.dw 0x9840, 0xc19e,	0x987f, 0xc19e,		0x21, 0
	.dw 0x98c0, 0xc19e,	0x98ff, 0xc19e,		0x21, 0
	.dw 0x9940, 0xc19e,	0x997f, 0xc19e,		0x21, 0
	.dw 0x99c0, 0xc19e,	0x9fff, 0xc19e,		0x21, 0
	.dw 0xa040, 0xc19e,	0xa07f, 0xc19e,		0x21, 0
	.dw 0xa0c0, 0xc19e,	0xa0ff, 0xc19e,		0x21, 0
	.dw 0xa140, 0xc19e,	0xa17f, 0xc19e,		0x21, 0
	.dw 0xa1c0, 0xc19e,	0xa1ff, 0xc19e,		0x21, 0
	.dw 0xa240, 0xc19e,	0xa27f, 0xc19e,		0x21, 0
	.dw 0xa2c0, 0xc19e,	0xa2ff, 0xc19e,		0x21, 0
	.dw 0xa340, 0xc19e,	0xa37f, 0xc19e,		0x21, 0
	.dw 0xa3c0, 0xc19e,	0xa3ff, 0xc19e,		0x21, 0
	.dw 0xa440, 0xc19e,	0xa47f, 0xc19e,		0x21, 0
	.dw 0xa4c0, 0xc19e,	0xa4ff, 0xc19e,		0x21, 0
	.dw 0xa540, 0xc19e,	0xa57f, 0xc19e,		0x21, 0
	.dw 0xa5c0, 0xc19e,	0xa5ff, 0xc19e,		0x21, 0
	.dw 0xa640, 0xc19e,	0xa67f, 0xc19e,		0x21, 0
	.dw 0xa6c0, 0xc19e,	0xa6ff, 0xc19e,		0x21, 0
	.dw 0xa740, 0xc19e,	0xa77f, 0xc19e,		0x21, 0
	.dw 0xa7c0, 0xc19e,	0xa7ff, 0xc19e,		0x21, 0
	.dw 0xa840, 0xc19e,	0xa87f, 0xc19e,		0x21, 0
	.dw 0xa8c0, 0xc19e,	0xa8ff, 0xc19e,		0x21, 0
	.dw 0xa940, 0xc19e,	0xa97f, 0xc19e,		0x21, 0
	.dw 0xa9c0, 0xc19e,	0xa9ff, 0xc19e,		0x21, 0
	.dw 0xaa40, 0xc19e,	0xaa7f, 0xc19e,		0x21, 0
	.dw 0xaac0, 0xc19e,	0xaaff, 0xc19e,		0x21, 0
	.dw 0xab40, 0xc19e,	0xab7f, 0xc19e,		0x21, 0
	.dw 0xabc0, 0xc19e,	0xabff, 0xc19e,		0x21, 0
	.dw 0xac40, 0xc19e,	0xac7f, 0xc19e,		0x21, 0
	.dw 0xacc0, 0xc19e,	0xacff, 0xc19e,		0x21, 0
	.dw 0xad40, 0xc19e,	0xad7f, 0xc19e,		0x21, 0
	.dw 0xadc0, 0xc19e,	0xadff, 0xc19e,		0x21, 0
	.dw 0xae40, 0xc19e,	0xae7f, 0xc19e,		0x21, 0
	.dw 0xaec0, 0xc19e,	0xaeff, 0xc19e,		0x21, 0
	.dw 0xaf40, 0xc19e,	0xaf7f, 0xc19e,		0x21, 0
	.dw 0xafc0, 0xc19e,	0xafff, 0xc19e,		0x21, 0
	.dw 0xb040, 0xc19e,	0xb07f, 0xc19e,		0x21, 0
	.dw 0xb0c0, 0xc19e,	0xb0ff, 0xc19e,		0x21, 0
	.dw 0xb140, 0xc19e,	0xb17f, 0xc19e,		0x21, 0
	.dw 0xb1c0, 0xc19e,	0xb1ff, 0xc19e,		0x21, 0
	.dw 0xb240, 0xc19e,	0xb27f, 0xc19e,		0x21, 0
	.dw 0xb2c0, 0xc19e,	0xb2ff, 0xc19e,		0x21, 0
	.dw 0xb340, 0xc19e,	0xb37f, 0xc19e,		0x21, 0
	.dw 0xb3c0, 0xc19e,	0xb3ff, 0xc19e,		0x21, 0
	.dw 0xb440, 0xc19e,	0xb47f, 0xc19e,		0x21, 0
	.dw 0xb4c0, 0xc19e,	0xb4ff, 0xc19e,		0x21, 0
	.dw 0xb540, 0xc19e,	0xb57f, 0xc19e,		0x21, 0
	.dw 0xb5c0, 0xc19e,	0xb5ff, 0xc19e,		0x21, 0
	.dw 0xb640, 0xc19e,	0xb67f, 0xc19e,		0x21, 0
	.dw 0xb6c0, 0xc19e,	0xb6ff, 0xc19e,		0x21, 0
	.dw 0xb740, 0xc19e,	0xb77f, 0xc19e,		0x21, 0
	.dw 0xb7c0, 0xc19e,	0xb7ff, 0xc19e,		0x21, 0
	.dw 0xb840, 0xc19e,	0xb87f, 0xc19e,		0x21, 0
	.dw 0xb8c0, 0xc19e,	0xb8ff, 0xc19e,		0x21, 0
	.dw 0xb940, 0xc19e,	0xb97f, 0xc19e,		0x21, 0
	.dw 0xb9c0, 0xc19e,	0xbfff, 0xc19e,		0x21, 0
	.dw 0xc040, 0xc19e,	0xc07f, 0xc19e,		0x21, 0
	.dw 0xc0c0, 0xc19e,	0xc0ff, 0xc19e,		0x21, 0
	.dw 0xc140, 0xc19e,	0xc17f, 0xc19e,		0x21, 0
	.dw 0xc1c0, 0xc19e,	0xc1ff, 0xc19e,		0x21, 0
	.dw 0xc240, 0xc19e,	0xc27f, 0xc19e,		0x21, 0
	.dw 0xc2c0, 0xc19e,	0xc2ff, 0xc19e,		0x21, 0
	.dw 0xc340, 0xc19e,	0xc37f, 0xc19e,		0x21, 0
	.dw 0xc3c0, 0xc19e,	0xc3ff, 0xc19e,		0x21, 0
	.dw 0xc440, 0xc19e,	0xc47f, 0xc19e,		0x21, 0
	.dw 0xc4c0, 0xc19e,	0xc4ff, 0xc19e,		0x21, 0
	.dw 0xc540, 0xc19e,	0xc57f, 0xc19e,		0x21, 0
	.dw 0xc5c0, 0xc19e,	0xc5ff, 0xc19e,		0x21, 0
	.dw 0xc640, 0xc19e,	0xc67f, 0xc19e,		0x21, 0
	.dw 0xc6c0, 0xc19e,	0xc6ff, 0xc19e,		0x21, 0
	.dw 0xc740, 0xc19e,	0xc77f, 0xc19e,		0x21, 0
	.dw 0xc7c0, 0xc19e,	0xc7ff, 0xc19e,		0x21, 0
	.dw 0xc840, 0xc19e,	0xc87f, 0xc19e,		0x21, 0
	.dw 0xc8c0, 0xc19e,	0xc8ff, 0xc19e,		0x21, 0
	.dw 0xc940, 0xc19e,	0xc97f, 0xc19e,		0x21, 0
	.dw 0xc9c0, 0xc19e,	0xc9ff, 0xc19e,		0x21, 0
	.dw 0xca40, 0xc19e,	0xca7f, 0xc19e,		0x21, 0
	.dw 0xcac0, 0xc19e,	0xcaff, 0xc19e,		0x21, 0
	.dw 0xcb40, 0xc19e,	0xcb7f, 0xc19e,		0x21, 0
	.dw 0xcbc0, 0xc19e,	0xcbff, 0xc19e,		0x21, 0
	.dw 0xcc40, 0xc19e,	0xcc7f, 0xc19e,		0x21, 0
	.dw 0xccc0, 0xc19e,	0xccff, 0xc19e,		0x21, 0
	.dw 0xcd40, 0xc19e,	0xcd7f, 0xc19e,		0x21, 0
	.dw 0xcdc0, 0xc19e,	0xcdff, 0xc19e,		0x21, 0
	.dw 0xce40, 0xc19e,	0xce7f, 0xc19e,		0x21, 0
	.dw 0xcec0, 0xc19e,	0xceff, 0xc19e,		0x21, 0
	.dw 0xcf40, 0xc19e,	0xcf7f, 0xc19e,		0x21, 0
	.dw 0xcfc0, 0xc19e,	0xcfff, 0xc19e,		0x21, 0
	.dw 0xd040, 0xc19e,	0xd07f, 0xc19e,		0x21, 0
	.dw 0xd0c0, 0xc19e,	0xd0ff, 0xc19e,		0x21, 0
	.dw 0xd140, 0xc19e,	0xd17f, 0xc19e,		0x21, 0
	.dw 0xd1c0, 0xc19e,	0xd1ff, 0xc19e,		0x21, 0
	.dw 0xd240, 0xc19e,	0xd27f, 0xc19e,		0x21, 0
	.dw 0xd2c0, 0xc19e,	0xd2ff, 0xc19e,		0x21, 0
	.dw 0xd340, 0xc19e,	0xd37f, 0xc19e,		0x21, 0
	.dw 0xd3c0, 0xc19e,	0xd3ff, 0xc19e,		0x21, 0
	.dw 0xd440, 0xc19e,	0xd47f, 0xc19e,		0x21, 0
	.dw 0xd4c0, 0xc19e,	0xd4ff, 0xc19e,		0x21, 0
	.dw 0xd540, 0xc19e,	0xd57f, 0xc19e,		0x21, 0
	.dw 0xd5c0, 0xc19e,	0xd5ff, 0xc19e,		0x21, 0
	.dw 0xd640, 0xc19e,	0xd67f, 0xc19e,		0x21, 0
	.dw 0xd6c0, 0xc19e,	0xd6ff, 0xc19e,		0x21, 0
	.dw 0xd740, 0xc19e,	0xd77f, 0xc19e,		0x21, 0
	.dw 0xd7c0, 0xc19e,	0xd7ff, 0xc19e,		0x21, 0
	.dw 0xd840, 0xc19e,	0xd87f, 0xc19e,		0x21, 0
	.dw 0xd8c0, 0xc19e,	0xd8ff, 0xc19e,		0x21, 0
	.dw 0xd940, 0xc19e,	0xd97f, 0xc19e,		0x21, 0
	.dw 0xd9c0, 0xc19e,	0xdfff, 0xc19e,		0x21, 0
	.dw 0xe040, 0xc19e,	0xe07f, 0xc19e,		0x21, 0
	.dw 0xe0c0, 0xc19e,	0xe0ff, 0xc19e,		0x21, 0
	.dw 0xe140, 0xc19e,	0xe17f, 0xc19e,		0x21, 0
	.dw 0xe1c0, 0xc19e,	0xe1ff, 0xc19e,		0x21, 0
	.dw 0xe240, 0xc19e,	0xe27f, 0xc19e,		0x21, 0
	.dw 0xe2c0, 0xc19e,	0xe2ff, 0xc19e,		0x21, 0
	.dw 0xe340, 0xc19e,	0xe37f, 0xc19e,		0x21, 0
	.dw 0xe3c0, 0xc19e,	0xe3ff, 0xc19e,		0x21, 0
	.dw 0xe440, 0xc19e,	0xe47f, 0xc19e,		0x21, 0
	.dw 0xe4c0, 0xc19e,	0xe4ff, 0xc19e,		0x21, 0
	.dw 0xe540, 0xc19e,	0xe57f, 0xc19e,		0x21, 0
	.dw 0xe5c0, 0xc19e,	0xe5ff, 0xc19e,		0x21, 0
	.dw 0xe640, 0xc19e,	0xe67f, 0xc19e,		0x21, 0
	.dw 0xe6c0, 0xc19e,	0xe6ff, 0xc19e,		0x21, 0
	.dw 0xe740, 0xc19e,	0xe77f, 0xc19e,		0x21, 0
	.dw 0xe7c0, 0xc19e,	0xe7ff, 0xc19e,		0x21, 0
	.dw 0xe840, 0xc19e,	0xe87f, 0xc19e,		0x21, 0
	.dw 0xe8c0, 0xc19e,	0xe8ff, 0xc19e,		0x21, 0
	.dw 0xe940, 0xc19e,	0xe97f, 0xc19e,		0x21, 0
	.dw 0xe9c0, 0xc19e,	0xe9ff, 0xc19e,		0x21, 0
	.dw 0xea40, 0xc19e,	0xea7f, 0xc19e,		0x21, 0
	.dw 0xeac0, 0xc19e,	0xeaff, 0xc19e,		0x21, 0
	.dw 0xeb40, 0xc19e,	0xeb7f, 0xc19e,		0x21, 0
	.dw 0xebc0, 0xc19e,	0xebff, 0xc19e,		0x21, 0
	.dw 0xec40, 0xc19e,	0xec7f, 0xc19e,		0x21, 0
	.dw 0xecc0, 0xc19e,	0xecff, 0xc19e,		0x21, 0
	.dw 0xed40, 0xc19e,	0xed7f, 0xc19e,		0x21, 0
	.dw 0xedc0, 0xc19e,	0xedff, 0xc19e,		0x21, 0
	.dw 0xee40, 0xc19e,	0xee7f, 0xc19e,		0x21, 0
	.dw 0xeec0, 0xc19e,	0xeeff, 0xc19e,		0x21, 0
	.dw 0xef40, 0xc19e,	0xef7f, 0xc19e,		0x21, 0
	.dw 0xefc0, 0xc19e,	0xefff, 0xc19e,		0x21, 0
	.dw 0xf040, 0xc19e,	0xf07f, 0xc19e,		0x21, 0
	.dw 0xf0c0, 0xc19e,	0xf0ff, 0xc19e,		0x21, 0
	.dw 0xf140, 0xc19e,	0xf17f, 0xc19e,		0x21, 0
	.dw 0xf1c0, 0xc19e,	0xf1ff, 0xc19e,		0x21, 0
	.dw 0xf240, 0xc19e,	0xf27f, 0xc19e,		0x21, 0
	.dw 0xf2c0, 0xc19e,	0xf2ff, 0xc19e,		0x21, 0
	.dw 0xf340, 0xc19e,	0xf37f, 0xc19e,		0x21, 0
	.dw 0xf3c0, 0xc19e,	0xf3ff, 0xc19e,		0x21, 0
	.dw 0xf440, 0xc19e,	0xf47f, 0xc19e,		0x21, 0
	.dw 0xf4c0, 0xc19e,	0xf4ff, 0xc19e,		0x21, 0
	.dw 0xf540, 0xc19e,	0xf57f, 0xc19e,		0x21, 0
	.dw 0xf5c0, 0xc19e,	0xf5ff, 0xc19e,		0x21, 0
	.dw 0xf640, 0xc19e,	0xf67f, 0xc19e,		0x21, 0
	.dw 0xf6c0, 0xc19e,	0xf6ff, 0xc19e,		0x21, 0
	.dw 0xf740, 0xc19e,	0xf77f, 0xc19e,		0x21, 0
	.dw 0xf7c0, 0xc19e,	0xf7ff, 0xc19e,		0x21, 0
	.dw 0xf840, 0xc19e,	0xf87f, 0xc19e,		0x21, 0
	.dw 0xf8c0, 0xc19e,	0xf8ff, 0xc19e,		0x21, 0
	.dw 0xf940, 0xc19e,	0xf97f, 0xc19e,		0x21, 0
	.dw 0xf9c0, 0xc19e,	0xffff, 0xc19e,		0x21, 0
	.dw 0x0040, 0xc19f,	0x007f, 0xc19f,		0x21, 0
	.dw 0x00c0, 0xc19f,	0x00ff, 0xc19f,		0x21, 0
	.dw 0x0140, 0xc19f,	0x017f, 0xc19f,		0x21, 0
	.dw 0x01c0, 0xc19f,	0x01ff, 0xc19f,		0x21, 0
	.dw 0x0240, 0xc19f,	0x027f, 0xc19f,		0x21, 0
	.dw 0x02c0, 0xc19f,	0x02ff, 0xc19f,		0x21, 0
	.dw 0x0340, 0xc19f,	0x037f, 0xc19f,		0x21, 0
	.dw 0x03c0, 0xc19f,	0x03ff, 0xc19f,		0x21, 0
	.dw 0x0440, 0xc19f,	0x047f, 0xc19f,		0x21, 0
	.dw 0x04c0, 0xc19f,	0x04ff, 0xc19f,		0x21, 0
	.dw 0x0540, 0xc19f,	0x057f, 0xc19f,		0x21, 0
	.dw 0x05c0, 0xc19f,	0x05ff, 0xc19f,		0x21, 0
	.dw 0x0640, 0xc19f,	0x067f, 0xc19f,		0x21, 0
	.dw 0x06c0, 0xc19f,	0x06ff, 0xc19f,		0x21, 0
	.dw 0x0740, 0xc19f,	0x077f, 0xc19f,		0x21, 0
	.dw 0x07c0, 0xc19f,	0x07ff, 0xc19f,		0x21, 0
	.dw 0x0840, 0xc19f,	0x087f, 0xc19f,		0x21, 0
	.dw 0x08c0, 0xc19f,	0x08ff, 0xc19f,		0x21, 0
	.dw 0x0940, 0xc19f,	0x097f, 0xc19f,		0x21, 0
	.dw 0x09c0, 0xc19f,	0x09ff, 0xc19f,		0x21, 0
	.dw 0x0a40, 0xc19f,	0x0a7f, 0xc19f,		0x21, 0
	.dw 0x0ac0, 0xc19f,	0x0aff, 0xc19f,		0x21, 0
	.dw 0x0b40, 0xc19f,	0x0b7f, 0xc19f,		0x21, 0
	.dw 0x0bc0, 0xc19f,	0x0bff, 0xc19f,		0x21, 0
	.dw 0x0c40, 0xc19f,	0x0c7f, 0xc19f,		0x21, 0
	.dw 0x0cc0, 0xc19f,	0x0cff, 0xc19f,		0x21, 0
	.dw 0x0d40, 0xc19f,	0x0d7f, 0xc19f,		0x21, 0
	.dw 0x0dc0, 0xc19f,	0x0dff, 0xc19f,		0x21, 0
	.dw 0x0e40, 0xc19f,	0x0e7f, 0xc19f,		0x21, 0
	.dw 0x0ec0, 0xc19f,	0x0eff, 0xc19f,		0x21, 0
	.dw 0x0f40, 0xc19f,	0x0f7f, 0xc19f,		0x21, 0
	.dw 0x0fc0, 0xc19f,	0x0fff, 0xc19f,		0x21, 0
	.dw 0x1040, 0xc19f,	0x107f, 0xc19f,		0x21, 0
	.dw 0x10c0, 0xc19f,	0x10ff, 0xc19f,		0x21, 0
	.dw 0x1140, 0xc19f,	0x117f, 0xc19f,		0x21, 0
	.dw 0x11c0, 0xc19f,	0x11ff, 0xc19f,		0x21, 0
	.dw 0x1240, 0xc19f,	0x127f, 0xc19f,		0x21, 0
	.dw 0x12c0, 0xc19f,	0x12ff, 0xc19f,		0x21, 0
	.dw 0x1340, 0xc19f,	0x137f, 0xc19f,		0x21, 0
	.dw 0x13c0, 0xc19f,	0x13ff, 0xc19f,		0x21, 0
	.dw 0x1440, 0xc19f,	0x147f, 0xc19f,		0x21, 0
	.dw 0x14c0, 0xc19f,	0x14ff, 0xc19f,		0x21, 0
	.dw 0x1540, 0xc19f,	0x157f, 0xc19f,		0x21, 0
	.dw 0x15c0, 0xc19f,	0x15ff, 0xc19f,		0x21, 0
	.dw 0x1640, 0xc19f,	0x167f, 0xc19f,		0x21, 0
	.dw 0x16c0, 0xc19f,	0x16ff, 0xc19f,		0x21, 0
	.dw 0x1740, 0xc19f,	0x177f, 0xc19f,		0x21, 0
	.dw 0x17c0, 0xc19f,	0x17ff, 0xc19f,		0x21, 0
	.dw 0x1840, 0xc19f,	0x187f, 0xc19f,		0x21, 0
	.dw 0x18c0, 0xc19f,	0x18ff, 0xc19f,		0x21, 0
	.dw 0x1940, 0xc19f,	0x197f, 0xc19f,		0x21, 0
	.dw 0x19c0, 0xc19f,	0x1fff, 0xc19f,		0x21, 0
	.dw 0x2040, 0xc19f,	0x207f, 0xc19f,		0x21, 0
	.dw 0x20c0, 0xc19f,	0x20ff, 0xc19f,		0x21, 0
	.dw 0x2140, 0xc19f,	0x217f, 0xc19f,		0x21, 0
	.dw 0x21c0, 0xc19f,	0x21ff, 0xc19f,		0x21, 0
	.dw 0x2240, 0xc19f,	0x227f, 0xc19f,		0x21, 0
	.dw 0x22c0, 0xc19f,	0x22ff, 0xc19f,		0x21, 0
	.dw 0x2340, 0xc19f,	0x237f, 0xc19f,		0x21, 0
	.dw 0x23c0, 0xc19f,	0x23ff, 0xc19f,		0x21, 0
	.dw 0x2440, 0xc19f,	0x247f, 0xc19f,		0x21, 0
	.dw 0x24c0, 0xc19f,	0x24ff, 0xc19f,		0x21, 0
	.dw 0x2540, 0xc19f,	0x257f, 0xc19f,		0x21, 0
	.dw 0x25c0, 0xc19f,	0x25ff, 0xc19f,		0x21, 0
	.dw 0x2640, 0xc19f,	0x267f, 0xc19f,		0x21, 0
	.dw 0x26c0, 0xc19f,	0x26ff, 0xc19f,		0x21, 0
	.dw 0x2740, 0xc19f,	0x277f, 0xc19f,		0x21, 0
	.dw 0x27c0, 0xc19f,	0x27ff, 0xc19f,		0x21, 0
	.dw 0x2840, 0xc19f,	0x287f, 0xc19f,		0x21, 0
	.dw 0x28c0, 0xc19f,	0x28ff, 0xc19f,		0x21, 0
	.dw 0x2940, 0xc19f,	0x297f, 0xc19f,		0x21, 0
	.dw 0x29c0, 0xc19f,	0x29ff, 0xc19f,		0x21, 0
	.dw 0x2a40, 0xc19f,	0x2a7f, 0xc19f,		0x21, 0
	.dw 0x2ac0, 0xc19f,	0x2aff, 0xc19f,		0x21, 0
	.dw 0x2b40, 0xc19f,	0x2b7f, 0xc19f,		0x21, 0
	.dw 0x2bc0, 0xc19f,	0x2bff, 0xc19f,		0x21, 0
	.dw 0x2c40, 0xc19f,	0x2c7f, 0xc19f,		0x21, 0
	.dw 0x2cc0, 0xc19f,	0x2cff, 0xc19f,		0x21, 0
	.dw 0x2d40, 0xc19f,	0x2d7f, 0xc19f,		0x21, 0
	.dw 0x2dc0, 0xc19f,	0x2dff, 0xc19f,		0x21, 0
	.dw 0x2e40, 0xc19f,	0x2e7f, 0xc19f,		0x21, 0
	.dw 0x2ec0, 0xc19f,	0x2eff, 0xc19f,		0x21, 0
	.dw 0x2f40, 0xc19f,	0x2f7f, 0xc19f,		0x21, 0
	.dw 0x2fc0, 0xc19f,	0x2fff, 0xc19f,		0x21, 0
	.dw 0x3040, 0xc19f,	0x307f, 0xc19f,		0x21, 0
	.dw 0x30c0, 0xc19f,	0x30ff, 0xc19f,		0x21, 0
	.dw 0x3140, 0xc19f,	0x317f, 0xc19f,		0x21, 0
	.dw 0x31c0, 0xc19f,	0x31ff, 0xc19f,		0x21, 0
	.dw 0x3240, 0xc19f,	0x327f, 0xc19f,		0x21, 0
	.dw 0x32c0, 0xc19f,	0x32ff, 0xc19f,		0x21, 0
	.dw 0x3340, 0xc19f,	0x337f, 0xc19f,		0x21, 0
	.dw 0x33c0, 0xc19f,	0x33ff, 0xc19f,		0x21, 0
	.dw 0x3440, 0xc19f,	0x347f, 0xc19f,		0x21, 0
	.dw 0x34c0, 0xc19f,	0x34ff, 0xc19f,		0x21, 0
	.dw 0x3540, 0xc19f,	0x357f, 0xc19f,		0x21, 0
	.dw 0x35c0, 0xc19f,	0x35ff, 0xc19f,		0x21, 0
	.dw 0x3640, 0xc19f,	0x367f, 0xc19f,		0x21, 0
	.dw 0x36c0, 0xc19f,	0x36ff, 0xc19f,		0x21, 0
	.dw 0x3740, 0xc19f,	0x377f, 0xc19f,		0x21, 0
	.dw 0x37c0, 0xc19f,	0x37ff, 0xc19f,		0x21, 0
	.dw 0x3840, 0xc19f,	0x387f, 0xc19f,		0x21, 0
	.dw 0x38c0, 0xc19f,	0x38ff, 0xc19f,		0x21, 0
	.dw 0x3940, 0xc19f,	0x397f, 0xc19f,		0x21, 0
	.dw 0x39c0, 0xc19f,	0x1fff, 0xc200,		0x21, 0
	.dw 0x2800, 0xc200,	0xffff, 0xc203,		0x21, 0
	.dw 0x0200, 0xc204,	0x1fff, 0xc204,		0x21, 0
	.dw 0x2800, 0xc204,	0x3fff, 0xc204,		0x21, 0
	.dw 0x4200, 0xc204,	0x5fff, 0xc204,		0x21, 0
	.dw 0x6800, 0xc204,	0x7fff, 0xc204,		0x21, 0
	.dw 0x8200, 0xc204,	0x9fff, 0xc204,		0x21, 0
	.dw 0xa800, 0xc204,	0xbfff, 0xc204,		0x21, 0
	.dw 0xc200, 0xc204,	0xdfff, 0xc204,		0x21, 0
	.dw 0xe800, 0xc204,	0x1fff, 0xc208,		0x21, 0
	.dw 0x2040, 0xc208,	0x207f, 0xc208,		0x21, 0
	.dw 0x20c0, 0xc208,	0x20ff, 0xc208,		0x21, 0
	.dw 0x2140, 0xc208,	0x217f, 0xc208,		0x21, 0
	.dw 0x21c0, 0xc208,	0x21ff, 0xc208,		0x21, 0
	.dw 0x2240, 0xc208,	0x227f, 0xc208,		0x21, 0
	.dw 0x22c0, 0xc208,	0x22ff, 0xc208,		0x21, 0
	.dw 0x2340, 0xc208,	0x237f, 0xc208,		0x21, 0
	.dw 0x23c0, 0xc208,	0x23ff, 0xc208,		0x21, 0
	.dw 0x2440, 0xc208,	0x247f, 0xc208,		0x21, 0
	.dw 0x24c0, 0xc208,	0x24ff, 0xc208,		0x21, 0
	.dw 0x2540, 0xc208,	0x257f, 0xc208,		0x21, 0
	.dw 0x25c0, 0xc208,	0x25ff, 0xc208,		0x21, 0
	.dw 0x2640, 0xc208,	0x267f, 0xc208,		0x21, 0
	.dw 0x26c0, 0xc208,	0x26ff, 0xc208,		0x21, 0
	.dw 0x2740, 0xc208,	0x277f, 0xc208,		0x21, 0
	.dw 0x27c0, 0xc208,	0xffff, 0xc20b,		0x21, 0
	.dw 0x0040, 0xc20c,	0x007f, 0xc20c,		0x21, 0
	.dw 0x00c0, 0xc20c,	0x00ff, 0xc20c,		0x21, 0
	.dw 0x0140, 0xc20c,	0x017f, 0xc20c,		0x21, 0
	.dw 0x01c0, 0xc20c,	0x1fff, 0xc20c,		0x21, 0
	.dw 0x2040, 0xc20c,	0x207f, 0xc20c,		0x21, 0
	.dw 0x20c0, 0xc20c,	0x20ff, 0xc20c,		0x21, 0
	.dw 0x2140, 0xc20c,	0x217f, 0xc20c,		0x21, 0
	.dw 0x21c0, 0xc20c,	0x21ff, 0xc20c,		0x21, 0
	.dw 0x2240, 0xc20c,	0x227f, 0xc20c,		0x21, 0
	.dw 0x22c0, 0xc20c,	0x22ff, 0xc20c,		0x21, 0
	.dw 0x2340, 0xc20c,	0x237f, 0xc20c,		0x21, 0
	.dw 0x23c0, 0xc20c,	0x23ff, 0xc20c,		0x21, 0
	.dw 0x2440, 0xc20c,	0x247f, 0xc20c,		0x21, 0
	.dw 0x24c0, 0xc20c,	0x24ff, 0xc20c,		0x21, 0
	.dw 0x2540, 0xc20c,	0x257f, 0xc20c,		0x21, 0
	.dw 0x25c0, 0xc20c,	0x25ff, 0xc20c,		0x21, 0
	.dw 0x2640, 0xc20c,	0x267f, 0xc20c,		0x21, 0
	.dw 0x26c0, 0xc20c,	0x26ff, 0xc20c,		0x21, 0
	.dw 0x2740, 0xc20c,	0x277f, 0xc20c,		0x21, 0
	.dw 0x27c0, 0xc20c,	0x3fff, 0xc20c,		0x21, 0
	.dw 0x4040, 0xc20c,	0x407f, 0xc20c,		0x21, 0
	.dw 0x40c0, 0xc20c,	0x40ff, 0xc20c,		0x21, 0
	.dw 0x4140, 0xc20c,	0x417f, 0xc20c,		0x21, 0
	.dw 0x41c0, 0xc20c,	0x5fff, 0xc20c,		0x21, 0
	.dw 0x6040, 0xc20c,	0x607f, 0xc20c,		0x21, 0
	.dw 0x60c0, 0xc20c,	0x60ff, 0xc20c,		0x21, 0
	.dw 0x6140, 0xc20c,	0x617f, 0xc20c,		0x21, 0
	.dw 0x61c0, 0xc20c,	0x61ff, 0xc20c,		0x21, 0
	.dw 0x6240, 0xc20c,	0x627f, 0xc20c,		0x21, 0
	.dw 0x62c0, 0xc20c,	0x62ff, 0xc20c,		0x21, 0
	.dw 0x6340, 0xc20c,	0x637f, 0xc20c,		0x21, 0
	.dw 0x63c0, 0xc20c,	0x63ff, 0xc20c,		0x21, 0
	.dw 0x6440, 0xc20c,	0x647f, 0xc20c,		0x21, 0
	.dw 0x64c0, 0xc20c,	0x64ff, 0xc20c,		0x21, 0
	.dw 0x6540, 0xc20c,	0x657f, 0xc20c,		0x21, 0
	.dw 0x65c0, 0xc20c,	0x65ff, 0xc20c,		0x21, 0
	.dw 0x6640, 0xc20c,	0x667f, 0xc20c,		0x21, 0
	.dw 0x66c0, 0xc20c,	0x66ff, 0xc20c,		0x21, 0
	.dw 0x6740, 0xc20c,	0x677f, 0xc20c,		0x21, 0
	.dw 0x67c0, 0xc20c,	0x7fff, 0xc20c,		0x21, 0
	.dw 0x8040, 0xc20c,	0x807f, 0xc20c,		0x21, 0
	.dw 0x80c0, 0xc20c,	0x80ff, 0xc20c,		0x21, 0
	.dw 0x8140, 0xc20c,	0x817f, 0xc20c,		0x21, 0
	.dw 0x81c0, 0xc20c,	0x9fff, 0xc20c,		0x21, 0
	.dw 0xa040, 0xc20c,	0xa07f, 0xc20c,		0x21, 0
	.dw 0xa0c0, 0xc20c,	0xa0ff, 0xc20c,		0x21, 0
	.dw 0xa140, 0xc20c,	0xa17f, 0xc20c,		0x21, 0
	.dw 0xa1c0, 0xc20c,	0xa1ff, 0xc20c,		0x21, 0
	.dw 0xa240, 0xc20c,	0xa27f, 0xc20c,		0x21, 0
	.dw 0xa2c0, 0xc20c,	0xa2ff, 0xc20c,		0x21, 0
	.dw 0xa340, 0xc20c,	0xa37f, 0xc20c,		0x21, 0
	.dw 0xa3c0, 0xc20c,	0xa3ff, 0xc20c,		0x21, 0
	.dw 0xa440, 0xc20c,	0xa47f, 0xc20c,		0x21, 0
	.dw 0xa4c0, 0xc20c,	0xa4ff, 0xc20c,		0x21, 0
	.dw 0xa540, 0xc20c,	0xa57f, 0xc20c,		0x21, 0
	.dw 0xa5c0, 0xc20c,	0xa5ff, 0xc20c,		0x21, 0
	.dw 0xa640, 0xc20c,	0xa67f, 0xc20c,		0x21, 0
	.dw 0xa6c0, 0xc20c,	0xa6ff, 0xc20c,		0x21, 0
	.dw 0xa740, 0xc20c,	0xa77f, 0xc20c,		0x21, 0
	.dw 0xa7c0, 0xc20c,	0xbfff, 0xc20c,		0x21, 0
	.dw 0xc040, 0xc20c,	0xc07f, 0xc20c,		0x21, 0
	.dw 0xc0c0, 0xc20c,	0xc0ff, 0xc20c,		0x21, 0
	.dw 0xc140, 0xc20c,	0xc17f, 0xc20c,		0x21, 0
	.dw 0xc1c0, 0xc20c,	0xdfff, 0xc20c,		0x21, 0
	.dw 0xe040, 0xc20c,	0xe07f, 0xc20c,		0x21, 0
	.dw 0xe0c0, 0xc20c,	0xe0ff, 0xc20c,		0x21, 0
	.dw 0xe140, 0xc20c,	0xe17f, 0xc20c,		0x21, 0
	.dw 0xe1c0, 0xc20c,	0xe1ff, 0xc20c,		0x21, 0
	.dw 0xe240, 0xc20c,	0xe27f, 0xc20c,		0x21, 0
	.dw 0xe2c0, 0xc20c,	0xe2ff, 0xc20c,		0x21, 0
	.dw 0xe340, 0xc20c,	0xe37f, 0xc20c,		0x21, 0
	.dw 0xe3c0, 0xc20c,	0xe3ff, 0xc20c,		0x21, 0
	.dw 0xe440, 0xc20c,	0xe47f, 0xc20c,		0x21, 0
	.dw 0xe4c0, 0xc20c,	0xe4ff, 0xc20c,		0x21, 0
	.dw 0xe540, 0xc20c,	0xe57f, 0xc20c,		0x21, 0
	.dw 0xe5c0, 0xc20c,	0xe5ff, 0xc20c,		0x21, 0
	.dw 0xe640, 0xc20c,	0xe67f, 0xc20c,		0x21, 0
	.dw 0xe6c0, 0xc20c,	0xe6ff, 0xc20c,		0x21, 0
	.dw 0xe740, 0xc20c,	0xe77f, 0xc20c,		0x21, 0
	.dw 0xe7c0, 0xc20c,	0xffff, 0xc213,		0x21, 0
	.dw 0x0200, 0xc214,	0x1fff, 0xc214,		0x21, 0
	.dw 0x2800, 0xc214,	0x3fff, 0xc214,		0x21, 0
	.dw 0x4200, 0xc214,	0x5fff, 0xc214,		0x21, 0
	.dw 0x6800, 0xc214,	0x7fff, 0xc214,		0x21, 0
	.dw 0x8200, 0xc214,	0x9fff, 0xc214,		0x21, 0
	.dw 0xa800, 0xc214,	0xbfff, 0xc214,		0x21, 0
	.dw 0xc200, 0xc214,	0xdfff, 0xc214,		0x21, 0
	.dw 0xe800, 0xc214,	0xffff, 0xc21b,		0x21, 0
	.dw 0x0040, 0xc21c,	0x007f, 0xc21c,		0x21, 0
	.dw 0x00c0, 0xc21c,	0x00ff, 0xc21c,		0x21, 0
	.dw 0x0140, 0xc21c,	0x017f, 0xc21c,		0x21, 0
	.dw 0x01c0, 0xc21c,	0x1fff, 0xc21c,		0x21, 0
	.dw 0x2040, 0xc21c,	0x207f, 0xc21c,		0x21, 0
	.dw 0x20c0, 0xc21c,	0x20ff, 0xc21c,		0x21, 0
	.dw 0x2140, 0xc21c,	0x217f, 0xc21c,		0x21, 0
	.dw 0x21c0, 0xc21c,	0x21ff, 0xc21c,		0x21, 0
	.dw 0x2240, 0xc21c,	0x227f, 0xc21c,		0x21, 0
	.dw 0x22c0, 0xc21c,	0x22ff, 0xc21c,		0x21, 0
	.dw 0x2340, 0xc21c,	0x237f, 0xc21c,		0x21, 0
	.dw 0x23c0, 0xc21c,	0x23ff, 0xc21c,		0x21, 0
	.dw 0x2440, 0xc21c,	0x247f, 0xc21c,		0x21, 0
	.dw 0x24c0, 0xc21c,	0x24ff, 0xc21c,		0x21, 0
	.dw 0x2540, 0xc21c,	0x257f, 0xc21c,		0x21, 0
	.dw 0x25c0, 0xc21c,	0x25ff, 0xc21c,		0x21, 0
	.dw 0x2640, 0xc21c,	0x267f, 0xc21c,		0x21, 0
	.dw 0x26c0, 0xc21c,	0x26ff, 0xc21c,		0x21, 0
	.dw 0x2740, 0xc21c,	0x277f, 0xc21c,		0x21, 0
	.dw 0x27c0, 0xc21c,	0x3fff, 0xc21c,		0x21, 0
	.dw 0x4040, 0xc21c,	0x407f, 0xc21c,		0x21, 0
	.dw 0x40c0, 0xc21c,	0x40ff, 0xc21c,		0x21, 0
	.dw 0x4140, 0xc21c,	0x417f, 0xc21c,		0x21, 0
	.dw 0x41c0, 0xc21c,	0x5fff, 0xc21c,		0x21, 0
	.dw 0x6040, 0xc21c,	0x607f, 0xc21c,		0x21, 0
	.dw 0x60c0, 0xc21c,	0x60ff, 0xc21c,		0x21, 0
	.dw 0x6140, 0xc21c,	0x617f, 0xc21c,		0x21, 0
	.dw 0x61c0, 0xc21c,	0x61ff, 0xc21c,		0x21, 0
	.dw 0x6240, 0xc21c,	0x627f, 0xc21c,		0x21, 0
	.dw 0x62c0, 0xc21c,	0x62ff, 0xc21c,		0x21, 0
	.dw 0x6340, 0xc21c,	0x637f, 0xc21c,		0x21, 0
	.dw 0x63c0, 0xc21c,	0x63ff, 0xc21c,		0x21, 0
	.dw 0x6440, 0xc21c,	0x647f, 0xc21c,		0x21, 0
	.dw 0x64c0, 0xc21c,	0x64ff, 0xc21c,		0x21, 0
	.dw 0x6540, 0xc21c,	0x657f, 0xc21c,		0x21, 0
	.dw 0x65c0, 0xc21c,	0x65ff, 0xc21c,		0x21, 0
	.dw 0x6640, 0xc21c,	0x667f, 0xc21c,		0x21, 0
	.dw 0x66c0, 0xc21c,	0x66ff, 0xc21c,		0x21, 0
	.dw 0x6740, 0xc21c,	0x677f, 0xc21c,		0x21, 0
	.dw 0x67c0, 0xc21c,	0x7fff, 0xc21c,		0x21, 0
	.dw 0x8040, 0xc21c,	0x807f, 0xc21c,		0x21, 0
	.dw 0x80c0, 0xc21c,	0x80ff, 0xc21c,		0x21, 0
	.dw 0x8140, 0xc21c,	0x817f, 0xc21c,		0x21, 0
	.dw 0x81c0, 0xc21c,	0x9fff, 0xc21c,		0x21, 0
	.dw 0xa040, 0xc21c,	0xa07f, 0xc21c,		0x21, 0
	.dw 0xa0c0, 0xc21c,	0xa0ff, 0xc21c,		0x21, 0
	.dw 0xa140, 0xc21c,	0xa17f, 0xc21c,		0x21, 0
	.dw 0xa1c0, 0xc21c,	0xa1ff, 0xc21c,		0x21, 0
	.dw 0xa240, 0xc21c,	0xa27f, 0xc21c,		0x21, 0
	.dw 0xa2c0, 0xc21c,	0xa2ff, 0xc21c,		0x21, 0
	.dw 0xa340, 0xc21c,	0xa37f, 0xc21c,		0x21, 0
	.dw 0xa3c0, 0xc21c,	0xa3ff, 0xc21c,		0x21, 0
	.dw 0xa440, 0xc21c,	0xa47f, 0xc21c,		0x21, 0
	.dw 0xa4c0, 0xc21c,	0xa4ff, 0xc21c,		0x21, 0
	.dw 0xa540, 0xc21c,	0xa57f, 0xc21c,		0x21, 0
	.dw 0xa5c0, 0xc21c,	0xa5ff, 0xc21c,		0x21, 0
	.dw 0xa640, 0xc21c,	0xa67f, 0xc21c,		0x21, 0
	.dw 0xa6c0, 0xc21c,	0xa6ff, 0xc21c,		0x21, 0
	.dw 0xa740, 0xc21c,	0xa77f, 0xc21c,		0x21, 0
	.dw 0xa7c0, 0xc21c,	0xbfff, 0xc21c,		0x21, 0
	.dw 0xc040, 0xc21c,	0xc07f, 0xc21c,		0x21, 0
	.dw 0xc0c0, 0xc21c,	0xc0ff, 0xc21c,		0x21, 0
	.dw 0xc140, 0xc21c,	0xc17f, 0xc21c,		0x21, 0
	.dw 0xc1c0, 0xc21c,	0xdfff, 0xc21c,		0x21, 0
	.dw 0xe040, 0xc21c,	0xe07f, 0xc21c,		0x21, 0
	.dw 0xe0c0, 0xc21c,	0xe0ff, 0xc21c,		0x21, 0
	.dw 0xe140, 0xc21c,	0xe17f, 0xc21c,		0x21, 0
	.dw 0xe1c0, 0xc21c,	0xe1ff, 0xc21c,		0x21, 0
	.dw 0xe240, 0xc21c,	0xe27f, 0xc21c,		0x21, 0
	.dw 0xe2c0, 0xc21c,	0xe2ff, 0xc21c,		0x21, 0
	.dw 0xe340, 0xc21c,	0xe37f, 0xc21c,		0x21, 0
	.dw 0xe3c0, 0xc21c,	0xe3ff, 0xc21c,		0x21, 0
	.dw 0xe440, 0xc21c,	0xe47f, 0xc21c,		0x21, 0
	.dw 0xe4c0, 0xc21c,	0xe4ff, 0xc21c,		0x21, 0
	.dw 0xe540, 0xc21c,	0xe57f, 0xc21c,		0x21, 0
	.dw 0xe5c0, 0xc21c,	0xe5ff, 0xc21c,		0x21, 0
	.dw 0xe640, 0xc21c,	0xe67f, 0xc21c,		0x21, 0
	.dw 0xe6c0, 0xc21c,	0xe6ff, 0xc21c,		0x21, 0
	.dw 0xe740, 0xc21c,	0xe77f, 0xc21c,		0x21, 0
	.dw 0xe7c0, 0xc21c,	0x1fff, 0xc220,		0x21, 0
	.dw 0x2800, 0xc220,	0xffff, 0xc223,		0x21, 0
	.dw 0x0200, 0xc224,	0x1fff, 0xc224,		0x21, 0
	.dw 0x2800, 0xc224,	0x3fff, 0xc224,		0x21, 0
	.dw 0x4200, 0xc224,	0x5fff, 0xc224,		0x21, 0
	.dw 0x6800, 0xc224,	0x7fff, 0xc224,		0x21, 0
	.dw 0x8200, 0xc224,	0x9fff, 0xc224,		0x21, 0
	.dw 0xa800, 0xc224,	0xbfff, 0xc224,		0x21, 0
	.dw 0xc200, 0xc224,	0xdfff, 0xc224,		0x21, 0
	.dw 0xe800, 0xc224,	0x1fff, 0xc228,		0x21, 0
	.dw 0x2040, 0xc228,	0x207f, 0xc228,		0x21, 0
	.dw 0x20c0, 0xc228,	0x20ff, 0xc228,		0x21, 0
	.dw 0x2140, 0xc228,	0x217f, 0xc228,		0x21, 0
	.dw 0x21c0, 0xc228,	0x21ff, 0xc228,		0x21, 0
	.dw 0x2240, 0xc228,	0x227f, 0xc228,		0x21, 0
	.dw 0x22c0, 0xc228,	0x22ff, 0xc228,		0x21, 0
	.dw 0x2340, 0xc228,	0x237f, 0xc228,		0x21, 0
	.dw 0x23c0, 0xc228,	0x23ff, 0xc228,		0x21, 0
	.dw 0x2440, 0xc228,	0x247f, 0xc228,		0x21, 0
	.dw 0x24c0, 0xc228,	0x24ff, 0xc228,		0x21, 0
	.dw 0x2540, 0xc228,	0x257f, 0xc228,		0x21, 0
	.dw 0x25c0, 0xc228,	0x25ff, 0xc228,		0x21, 0
	.dw 0x2640, 0xc228,	0x267f, 0xc228,		0x21, 0
	.dw 0x26c0, 0xc228,	0x26ff, 0xc228,		0x21, 0
	.dw 0x2740, 0xc228,	0x277f, 0xc228,		0x21, 0
	.dw 0x27c0, 0xc228,	0xffff, 0xc22b,		0x21, 0
	.dw 0x0040, 0xc22c,	0x007f, 0xc22c,		0x21, 0
	.dw 0x00c0, 0xc22c,	0x00ff, 0xc22c,		0x21, 0
	.dw 0x0140, 0xc22c,	0x017f, 0xc22c,		0x21, 0
	.dw 0x01c0, 0xc22c,	0x1fff, 0xc22c,		0x21, 0
	.dw 0x2040, 0xc22c,	0x207f, 0xc22c,		0x21, 0
	.dw 0x20c0, 0xc22c,	0x20ff, 0xc22c,		0x21, 0
	.dw 0x2140, 0xc22c,	0x217f, 0xc22c,		0x21, 0
	.dw 0x21c0, 0xc22c,	0x21ff, 0xc22c,		0x21, 0
	.dw 0x2240, 0xc22c,	0x227f, 0xc22c,		0x21, 0
	.dw 0x22c0, 0xc22c,	0x22ff, 0xc22c,		0x21, 0
	.dw 0x2340, 0xc22c,	0x237f, 0xc22c,		0x21, 0
	.dw 0x23c0, 0xc22c,	0x23ff, 0xc22c,		0x21, 0
	.dw 0x2440, 0xc22c,	0x247f, 0xc22c,		0x21, 0
	.dw 0x24c0, 0xc22c,	0x24ff, 0xc22c,		0x21, 0
	.dw 0x2540, 0xc22c,	0x257f, 0xc22c,		0x21, 0
	.dw 0x25c0, 0xc22c,	0x25ff, 0xc22c,		0x21, 0
	.dw 0x2640, 0xc22c,	0x267f, 0xc22c,		0x21, 0
	.dw 0x26c0, 0xc22c,	0x26ff, 0xc22c,		0x21, 0
	.dw 0x2740, 0xc22c,	0x277f, 0xc22c,		0x21, 0
	.dw 0x27c0, 0xc22c,	0x3fff, 0xc22c,		0x21, 0
	.dw 0x4040, 0xc22c,	0x407f, 0xc22c,		0x21, 0
	.dw 0x40c0, 0xc22c,	0x40ff, 0xc22c,		0x21, 0
	.dw 0x4140, 0xc22c,	0x417f, 0xc22c,		0x21, 0
	.dw 0x41c0, 0xc22c,	0x5fff, 0xc22c,		0x21, 0
	.dw 0x6040, 0xc22c,	0x607f, 0xc22c,		0x21, 0
	.dw 0x60c0, 0xc22c,	0x60ff, 0xc22c,		0x21, 0
	.dw 0x6140, 0xc22c,	0x617f, 0xc22c,		0x21, 0
	.dw 0x61c0, 0xc22c,	0x61ff, 0xc22c,		0x21, 0
	.dw 0x6240, 0xc22c,	0x627f, 0xc22c,		0x21, 0
	.dw 0x62c0, 0xc22c,	0x62ff, 0xc22c,		0x21, 0
	.dw 0x6340, 0xc22c,	0x637f, 0xc22c,		0x21, 0
	.dw 0x63c0, 0xc22c,	0x63ff, 0xc22c,		0x21, 0
	.dw 0x6440, 0xc22c,	0x647f, 0xc22c,		0x21, 0
	.dw 0x64c0, 0xc22c,	0x64ff, 0xc22c,		0x21, 0
	.dw 0x6540, 0xc22c,	0x657f, 0xc22c,		0x21, 0
	.dw 0x65c0, 0xc22c,	0x65ff, 0xc22c,		0x21, 0
	.dw 0x6640, 0xc22c,	0x667f, 0xc22c,		0x21, 0
	.dw 0x66c0, 0xc22c,	0x66ff, 0xc22c,		0x21, 0
	.dw 0x6740, 0xc22c,	0x677f, 0xc22c,		0x21, 0
	.dw 0x67c0, 0xc22c,	0x7fff, 0xc22c,		0x21, 0
	.dw 0x8040, 0xc22c,	0x807f, 0xc22c,		0x21, 0
	.dw 0x80c0, 0xc22c,	0x80ff, 0xc22c,		0x21, 0
	.dw 0x8140, 0xc22c,	0x817f, 0xc22c,		0x21, 0
	.dw 0x81c0, 0xc22c,	0x9fff, 0xc22c,		0x21, 0
	.dw 0xa040, 0xc22c,	0xa07f, 0xc22c,		0x21, 0
	.dw 0xa0c0, 0xc22c,	0xa0ff, 0xc22c,		0x21, 0
	.dw 0xa140, 0xc22c,	0xa17f, 0xc22c,		0x21, 0
	.dw 0xa1c0, 0xc22c,	0xa1ff, 0xc22c,		0x21, 0
	.dw 0xa240, 0xc22c,	0xa27f, 0xc22c,		0x21, 0
	.dw 0xa2c0, 0xc22c,	0xa2ff, 0xc22c,		0x21, 0
	.dw 0xa340, 0xc22c,	0xa37f, 0xc22c,		0x21, 0
	.dw 0xa3c0, 0xc22c,	0xa3ff, 0xc22c,		0x21, 0
	.dw 0xa440, 0xc22c,	0xa47f, 0xc22c,		0x21, 0
	.dw 0xa4c0, 0xc22c,	0xa4ff, 0xc22c,		0x21, 0
	.dw 0xa540, 0xc22c,	0xa57f, 0xc22c,		0x21, 0
	.dw 0xa5c0, 0xc22c,	0xa5ff, 0xc22c,		0x21, 0
	.dw 0xa640, 0xc22c,	0xa67f, 0xc22c,		0x21, 0
	.dw 0xa6c0, 0xc22c,	0xa6ff, 0xc22c,		0x21, 0
	.dw 0xa740, 0xc22c,	0xa77f, 0xc22c,		0x21, 0
	.dw 0xa7c0, 0xc22c,	0xbfff, 0xc22c,		0x21, 0
	.dw 0xc040, 0xc22c,	0xc07f, 0xc22c,		0x21, 0
	.dw 0xc0c0, 0xc22c,	0xc0ff, 0xc22c,		0x21, 0
	.dw 0xc140, 0xc22c,	0xc17f, 0xc22c,		0x21, 0
	.dw 0xc1c0, 0xc22c,	0xdfff, 0xc22c,		0x21, 0
	.dw 0xe040, 0xc22c,	0xe07f, 0xc22c,		0x21, 0
	.dw 0xe0c0, 0xc22c,	0xe0ff, 0xc22c,		0x21, 0
	.dw 0xe140, 0xc22c,	0xe17f, 0xc22c,		0x21, 0
	.dw 0xe1c0, 0xc22c,	0xe1ff, 0xc22c,		0x21, 0
	.dw 0xe240, 0xc22c,	0xe27f, 0xc22c,		0x21, 0
	.dw 0xe2c0, 0xc22c,	0xe2ff, 0xc22c,		0x21, 0
	.dw 0xe340, 0xc22c,	0xe37f, 0xc22c,		0x21, 0
	.dw 0xe3c0, 0xc22c,	0xe3ff, 0xc22c,		0x21, 0
	.dw 0xe440, 0xc22c,	0xe47f, 0xc22c,		0x21, 0
	.dw 0xe4c0, 0xc22c,	0xe4ff, 0xc22c,		0x21, 0
	.dw 0xe540, 0xc22c,	0xe57f, 0xc22c,		0x21, 0
	.dw 0xe5c0, 0xc22c,	0xe5ff, 0xc22c,		0x21, 0
	.dw 0xe640, 0xc22c,	0xe67f, 0xc22c,		0x21, 0
	.dw 0xe6c0, 0xc22c,	0xe6ff, 0xc22c,		0x21, 0
	.dw 0xe740, 0xc22c,	0xe77f, 0xc22c,		0x21, 0
	.dw 0xe7c0, 0xc22c,	0xffff, 0xc233,		0x21, 0
	.dw 0x0200, 0xc234,	0x1fff, 0xc234,		0x21, 0
	.dw 0x2800, 0xc234,	0x3fff, 0xc234,		0x21, 0
	.dw 0x4200, 0xc234,	0x5fff, 0xc234,		0x21, 0
	.dw 0x6800, 0xc234,	0x7fff, 0xc234,		0x21, 0
	.dw 0x8200, 0xc234,	0x9fff, 0xc234,		0x21, 0
	.dw 0xa800, 0xc234,	0xbfff, 0xc234,		0x21, 0
	.dw 0xc200, 0xc234,	0xdfff, 0xc234,		0x21, 0
	.dw 0xe800, 0xc234,	0xffff, 0xc23b,		0x21, 0
	.dw 0x0040, 0xc23c,	0x007f, 0xc23c,		0x21, 0
	.dw 0x00c0, 0xc23c,	0x00ff, 0xc23c,		0x21, 0
	.dw 0x0140, 0xc23c,	0x017f, 0xc23c,		0x21, 0
	.dw 0x01c0, 0xc23c,	0x1fff, 0xc23c,		0x21, 0
	.dw 0x2040, 0xc23c,	0x207f, 0xc23c,		0x21, 0
	.dw 0x20c0, 0xc23c,	0x20ff, 0xc23c,		0x21, 0
	.dw 0x2140, 0xc23c,	0x217f, 0xc23c,		0x21, 0
	.dw 0x21c0, 0xc23c,	0x21ff, 0xc23c,		0x21, 0
	.dw 0x2240, 0xc23c,	0x227f, 0xc23c,		0x21, 0
	.dw 0x22c0, 0xc23c,	0x22ff, 0xc23c,		0x21, 0
	.dw 0x2340, 0xc23c,	0x237f, 0xc23c,		0x21, 0
	.dw 0x23c0, 0xc23c,	0x23ff, 0xc23c,		0x21, 0
	.dw 0x2440, 0xc23c,	0x247f, 0xc23c,		0x21, 0
	.dw 0x24c0, 0xc23c,	0x24ff, 0xc23c,		0x21, 0
	.dw 0x2540, 0xc23c,	0x257f, 0xc23c,		0x21, 0
	.dw 0x25c0, 0xc23c,	0x25ff, 0xc23c,		0x21, 0
	.dw 0x2640, 0xc23c,	0x267f, 0xc23c,		0x21, 0
	.dw 0x26c0, 0xc23c,	0x26ff, 0xc23c,		0x21, 0
	.dw 0x2740, 0xc23c,	0x277f, 0xc23c,		0x21, 0
	.dw 0x27c0, 0xc23c,	0x3fff, 0xc23c,		0x21, 0
	.dw 0x4040, 0xc23c,	0x407f, 0xc23c,		0x21, 0
	.dw 0x40c0, 0xc23c,	0x40ff, 0xc23c,		0x21, 0
	.dw 0x4140, 0xc23c,	0x417f, 0xc23c,		0x21, 0
	.dw 0x41c0, 0xc23c,	0x5fff, 0xc23c,		0x21, 0
	.dw 0x6040, 0xc23c,	0x607f, 0xc23c,		0x21, 0
	.dw 0x60c0, 0xc23c,	0x60ff, 0xc23c,		0x21, 0
	.dw 0x6140, 0xc23c,	0x617f, 0xc23c,		0x21, 0
	.dw 0x61c0, 0xc23c,	0x61ff, 0xc23c,		0x21, 0
	.dw 0x6240, 0xc23c,	0x627f, 0xc23c,		0x21, 0
	.dw 0x62c0, 0xc23c,	0x62ff, 0xc23c,		0x21, 0
	.dw 0x6340, 0xc23c,	0x637f, 0xc23c,		0x21, 0
	.dw 0x63c0, 0xc23c,	0x63ff, 0xc23c,		0x21, 0
	.dw 0x6440, 0xc23c,	0x647f, 0xc23c,		0x21, 0
	.dw 0x64c0, 0xc23c,	0x64ff, 0xc23c,		0x21, 0
	.dw 0x6540, 0xc23c,	0x657f, 0xc23c,		0x21, 0
	.dw 0x65c0, 0xc23c,	0x65ff, 0xc23c,		0x21, 0
	.dw 0x6640, 0xc23c,	0x667f, 0xc23c,		0x21, 0
	.dw 0x66c0, 0xc23c,	0x66ff, 0xc23c,		0x21, 0
	.dw 0x6740, 0xc23c,	0x677f, 0xc23c,		0x21, 0
	.dw 0x67c0, 0xc23c,	0x7fff, 0xc23c,		0x21, 0
	.dw 0x8040, 0xc23c,	0x807f, 0xc23c,		0x21, 0
	.dw 0x80c0, 0xc23c,	0x80ff, 0xc23c,		0x21, 0
	.dw 0x8140, 0xc23c,	0x817f, 0xc23c,		0x21, 0
	.dw 0x81c0, 0xc23c,	0x9fff, 0xc23c,		0x21, 0
	.dw 0xa040, 0xc23c,	0xa07f, 0xc23c,		0x21, 0
	.dw 0xa0c0, 0xc23c,	0xa0ff, 0xc23c,		0x21, 0
	.dw 0xa140, 0xc23c,	0xa17f, 0xc23c,		0x21, 0
	.dw 0xa1c0, 0xc23c,	0xa1ff, 0xc23c,		0x21, 0
	.dw 0xa240, 0xc23c,	0xa27f, 0xc23c,		0x21, 0
	.dw 0xa2c0, 0xc23c,	0xa2ff, 0xc23c,		0x21, 0
	.dw 0xa340, 0xc23c,	0xa37f, 0xc23c,		0x21, 0
	.dw 0xa3c0, 0xc23c,	0xa3ff, 0xc23c,		0x21, 0
	.dw 0xa440, 0xc23c,	0xa47f, 0xc23c,		0x21, 0
	.dw 0xa4c0, 0xc23c,	0xa4ff, 0xc23c,		0x21, 0
	.dw 0xa540, 0xc23c,	0xa57f, 0xc23c,		0x21, 0
	.dw 0xa5c0, 0xc23c,	0xa5ff, 0xc23c,		0x21, 0
	.dw 0xa640, 0xc23c,	0xa67f, 0xc23c,		0x21, 0
	.dw 0xa6c0, 0xc23c,	0xa6ff, 0xc23c,		0x21, 0
	.dw 0xa740, 0xc23c,	0xa77f, 0xc23c,		0x21, 0
	.dw 0xa7c0, 0xc23c,	0xbfff, 0xc23c,		0x21, 0
	.dw 0xc040, 0xc23c,	0xc07f, 0xc23c,		0x21, 0
	.dw 0xc0c0, 0xc23c,	0xc0ff, 0xc23c,		0x21, 0
	.dw 0xc140, 0xc23c,	0xc17f, 0xc23c,		0x21, 0
	.dw 0xc1c0, 0xc23c,	0xdfff, 0xc23c,		0x21, 0
	.dw 0xe040, 0xc23c,	0xe07f, 0xc23c,		0x21, 0
	.dw 0xe0c0, 0xc23c,	0xe0ff, 0xc23c,		0x21, 0
	.dw 0xe140, 0xc23c,	0xe17f, 0xc23c,		0x21, 0
	.dw 0xe1c0, 0xc23c,	0xe1ff, 0xc23c,		0x21, 0
	.dw 0xe240, 0xc23c,	0xe27f, 0xc23c,		0x21, 0
	.dw 0xe2c0, 0xc23c,	0xe2ff, 0xc23c,		0x21, 0
	.dw 0xe340, 0xc23c,	0xe37f, 0xc23c,		0x21, 0
	.dw 0xe3c0, 0xc23c,	0xe3ff, 0xc23c,		0x21, 0
	.dw 0xe440, 0xc23c,	0xe47f, 0xc23c,		0x21, 0
	.dw 0xe4c0, 0xc23c,	0xe4ff, 0xc23c,		0x21, 0
	.dw 0xe540, 0xc23c,	0xe57f, 0xc23c,		0x21, 0
	.dw 0xe5c0, 0xc23c,	0xe5ff, 0xc23c,		0x21, 0
	.dw 0xe640, 0xc23c,	0xe67f, 0xc23c,		0x21, 0
	.dw 0xe6c0, 0xc23c,	0xe6ff, 0xc23c,		0x21, 0
	.dw 0xe740, 0xc23c,	0xe77f, 0xc23c,		0x21, 0
	.dw 0xe7c0, 0xc23c,	0x1fff, 0xc240,		0x21, 0
	.dw 0x2800, 0xc240,	0xffff, 0xc243,		0x21, 0
	.dw 0x0200, 0xc244,	0x1fff, 0xc244,		0x21, 0
	.dw 0x2800, 0xc244,	0x3fff, 0xc244,		0x21, 0
	.dw 0x4200, 0xc244,	0x5fff, 0xc244,		0x21, 0
	.dw 0x6800, 0xc244,	0x7fff, 0xc244,		0x21, 0
	.dw 0x8200, 0xc244,	0x9fff, 0xc244,		0x21, 0
	.dw 0xa800, 0xc244,	0xbfff, 0xc244,		0x21, 0
	.dw 0xc200, 0xc244,	0xdfff, 0xc244,		0x21, 0
	.dw 0xe800, 0xc244,	0xffff, 0xc253,		0x21, 0
	.dw 0x0200, 0xc254,	0x1fff, 0xc254,		0x21, 0
	.dw 0x2800, 0xc254,	0x3fff, 0xc254,		0x21, 0
	.dw 0x4200, 0xc254,	0x5fff, 0xc254,		0x21, 0
	.dw 0x6800, 0xc254,	0x7fff, 0xc254,		0x21, 0
	.dw 0x8200, 0xc254,	0x9fff, 0xc254,		0x21, 0
	.dw 0xa800, 0xc254,	0xbfff, 0xc254,		0x21, 0
	.dw 0xc200, 0xc254,	0xdfff, 0xc254,		0x21, 0
	.dw 0xe800, 0xc254,	0x1fff, 0xc280,		0x21, 0
	.dw 0x2800, 0xc280,	0xffff, 0xc283,		0x21, 0
	.dw 0x0200, 0xc284,	0x1fff, 0xc284,		0x21, 0
	.dw 0x2800, 0xc284,	0x3fff, 0xc284,		0x21, 0
	.dw 0x4200, 0xc284,	0x5fff, 0xc284,		0x21, 0
	.dw 0x6800, 0xc284,	0x7fff, 0xc284,		0x21, 0
	.dw 0x8200, 0xc284,	0x9fff, 0xc284,		0x21, 0
	.dw 0xa800, 0xc284,	0xbfff, 0xc284,		0x21, 0
	.dw 0xc200, 0xc284,	0xdfff, 0xc284,		0x21, 0
	.dw 0xe800, 0xc284,	0x1fff, 0xc288,		0x21, 0
	.dw 0x2040, 0xc288,	0x207f, 0xc288,		0x21, 0
	.dw 0x20c0, 0xc288,	0x20ff, 0xc288,		0x21, 0
	.dw 0x2140, 0xc288,	0x217f, 0xc288,		0x21, 0
	.dw 0x21c0, 0xc288,	0x21ff, 0xc288,		0x21, 0
	.dw 0x2240, 0xc288,	0x227f, 0xc288,		0x21, 0
	.dw 0x22c0, 0xc288,	0x22ff, 0xc288,		0x21, 0
	.dw 0x2340, 0xc288,	0x237f, 0xc288,		0x21, 0
	.dw 0x23c0, 0xc288,	0x23ff, 0xc288,		0x21, 0
	.dw 0x2440, 0xc288,	0x247f, 0xc288,		0x21, 0
	.dw 0x24c0, 0xc288,	0x24ff, 0xc288,		0x21, 0
	.dw 0x2540, 0xc288,	0x257f, 0xc288,		0x21, 0
	.dw 0x25c0, 0xc288,	0x25ff, 0xc288,		0x21, 0
	.dw 0x2640, 0xc288,	0x267f, 0xc288,		0x21, 0
	.dw 0x26c0, 0xc288,	0x26ff, 0xc288,		0x21, 0
	.dw 0x2740, 0xc288,	0x277f, 0xc288,		0x21, 0
	.dw 0x27c0, 0xc288,	0xffff, 0xc28b,		0x21, 0
	.dw 0x0040, 0xc28c,	0x007f, 0xc28c,		0x21, 0
	.dw 0x00c0, 0xc28c,	0x00ff, 0xc28c,		0x21, 0
	.dw 0x0140, 0xc28c,	0x017f, 0xc28c,		0x21, 0
	.dw 0x01c0, 0xc28c,	0x1fff, 0xc28c,		0x21, 0
	.dw 0x2040, 0xc28c,	0x207f, 0xc28c,		0x21, 0
	.dw 0x20c0, 0xc28c,	0x20ff, 0xc28c,		0x21, 0
	.dw 0x2140, 0xc28c,	0x217f, 0xc28c,		0x21, 0
	.dw 0x21c0, 0xc28c,	0x21ff, 0xc28c,		0x21, 0
	.dw 0x2240, 0xc28c,	0x227f, 0xc28c,		0x21, 0
	.dw 0x22c0, 0xc28c,	0x22ff, 0xc28c,		0x21, 0
	.dw 0x2340, 0xc28c,	0x237f, 0xc28c,		0x21, 0
	.dw 0x23c0, 0xc28c,	0x23ff, 0xc28c,		0x21, 0
	.dw 0x2440, 0xc28c,	0x247f, 0xc28c,		0x21, 0
	.dw 0x24c0, 0xc28c,	0x24ff, 0xc28c,		0x21, 0
	.dw 0x2540, 0xc28c,	0x257f, 0xc28c,		0x21, 0
	.dw 0x25c0, 0xc28c,	0x25ff, 0xc28c,		0x21, 0
	.dw 0x2640, 0xc28c,	0x267f, 0xc28c,		0x21, 0
	.dw 0x26c0, 0xc28c,	0x26ff, 0xc28c,		0x21, 0
	.dw 0x2740, 0xc28c,	0x277f, 0xc28c,		0x21, 0
	.dw 0x27c0, 0xc28c,	0x3fff, 0xc28c,		0x21, 0
	.dw 0x4040, 0xc28c,	0x407f, 0xc28c,		0x21, 0
	.dw 0x40c0, 0xc28c,	0x40ff, 0xc28c,		0x21, 0
	.dw 0x4140, 0xc28c,	0x417f, 0xc28c,		0x21, 0
	.dw 0x41c0, 0xc28c,	0x5fff, 0xc28c,		0x21, 0
	.dw 0x6040, 0xc28c,	0x607f, 0xc28c,		0x21, 0
	.dw 0x60c0, 0xc28c,	0x60ff, 0xc28c,		0x21, 0
	.dw 0x6140, 0xc28c,	0x617f, 0xc28c,		0x21, 0
	.dw 0x61c0, 0xc28c,	0x61ff, 0xc28c,		0x21, 0
	.dw 0x6240, 0xc28c,	0x627f, 0xc28c,		0x21, 0
	.dw 0x62c0, 0xc28c,	0x62ff, 0xc28c,		0x21, 0
	.dw 0x6340, 0xc28c,	0x637f, 0xc28c,		0x21, 0
	.dw 0x63c0, 0xc28c,	0x63ff, 0xc28c,		0x21, 0
	.dw 0x6440, 0xc28c,	0x647f, 0xc28c,		0x21, 0
	.dw 0x64c0, 0xc28c,	0x64ff, 0xc28c,		0x21, 0
	.dw 0x6540, 0xc28c,	0x657f, 0xc28c,		0x21, 0
	.dw 0x65c0, 0xc28c,	0x65ff, 0xc28c,		0x21, 0
	.dw 0x6640, 0xc28c,	0x667f, 0xc28c,		0x21, 0
	.dw 0x66c0, 0xc28c,	0x66ff, 0xc28c,		0x21, 0
	.dw 0x6740, 0xc28c,	0x677f, 0xc28c,		0x21, 0
	.dw 0x67c0, 0xc28c,	0x7fff, 0xc28c,		0x21, 0
	.dw 0x8040, 0xc28c,	0x807f, 0xc28c,		0x21, 0
	.dw 0x80c0, 0xc28c,	0x80ff, 0xc28c,		0x21, 0
	.dw 0x8140, 0xc28c,	0x817f, 0xc28c,		0x21, 0
	.dw 0x81c0, 0xc28c,	0x9fff, 0xc28c,		0x21, 0
	.dw 0xa040, 0xc28c,	0xa07f, 0xc28c,		0x21, 0
	.dw 0xa0c0, 0xc28c,	0xa0ff, 0xc28c,		0x21, 0
	.dw 0xa140, 0xc28c,	0xa17f, 0xc28c,		0x21, 0
	.dw 0xa1c0, 0xc28c,	0xa1ff, 0xc28c,		0x21, 0
	.dw 0xa240, 0xc28c,	0xa27f, 0xc28c,		0x21, 0
	.dw 0xa2c0, 0xc28c,	0xa2ff, 0xc28c,		0x21, 0
	.dw 0xa340, 0xc28c,	0xa37f, 0xc28c,		0x21, 0
	.dw 0xa3c0, 0xc28c,	0xa3ff, 0xc28c,		0x21, 0
	.dw 0xa440, 0xc28c,	0xa47f, 0xc28c,		0x21, 0
	.dw 0xa4c0, 0xc28c,	0xa4ff, 0xc28c,		0x21, 0
	.dw 0xa540, 0xc28c,	0xa57f, 0xc28c,		0x21, 0
	.dw 0xa5c0, 0xc28c,	0xa5ff, 0xc28c,		0x21, 0
	.dw 0xa640, 0xc28c,	0xa67f, 0xc28c,		0x21, 0
	.dw 0xa6c0, 0xc28c,	0xa6ff, 0xc28c,		0x21, 0
	.dw 0xa740, 0xc28c,	0xa77f, 0xc28c,		0x21, 0
	.dw 0xa7c0, 0xc28c,	0xbfff, 0xc28c,		0x21, 0
	.dw 0xc040, 0xc28c,	0xc07f, 0xc28c,		0x21, 0
	.dw 0xc0c0, 0xc28c,	0xc0ff, 0xc28c,		0x21, 0
	.dw 0xc140, 0xc28c,	0xc17f, 0xc28c,		0x21, 0
	.dw 0xc1c0, 0xc28c,	0xdfff, 0xc28c,		0x21, 0
	.dw 0xe040, 0xc28c,	0xe07f, 0xc28c,		0x21, 0
	.dw 0xe0c0, 0xc28c,	0xe0ff, 0xc28c,		0x21, 0
	.dw 0xe140, 0xc28c,	0xe17f, 0xc28c,		0x21, 0
	.dw 0xe1c0, 0xc28c,	0xe1ff, 0xc28c,		0x21, 0
	.dw 0xe240, 0xc28c,	0xe27f, 0xc28c,		0x21, 0
	.dw 0xe2c0, 0xc28c,	0xe2ff, 0xc28c,		0x21, 0
	.dw 0xe340, 0xc28c,	0xe37f, 0xc28c,		0x21, 0
	.dw 0xe3c0, 0xc28c,	0xe3ff, 0xc28c,		0x21, 0
	.dw 0xe440, 0xc28c,	0xe47f, 0xc28c,		0x21, 0
	.dw 0xe4c0, 0xc28c,	0xe4ff, 0xc28c,		0x21, 0
	.dw 0xe540, 0xc28c,	0xe57f, 0xc28c,		0x21, 0
	.dw 0xe5c0, 0xc28c,	0xe5ff, 0xc28c,		0x21, 0
	.dw 0xe640, 0xc28c,	0xe67f, 0xc28c,		0x21, 0
	.dw 0xe6c0, 0xc28c,	0xe6ff, 0xc28c,		0x21, 0
	.dw 0xe740, 0xc28c,	0xe77f, 0xc28c,		0x21, 0
	.dw 0xe7c0, 0xc28c,	0xffff, 0xc293,		0x21, 0
	.dw 0x0200, 0xc294,	0x1fff, 0xc294,		0x21, 0
	.dw 0x2800, 0xc294,	0x3fff, 0xc294,		0x21, 0
	.dw 0x4200, 0xc294,	0x5fff, 0xc294,		0x21, 0
	.dw 0x6800, 0xc294,	0x7fff, 0xc294,		0x21, 0
	.dw 0x8200, 0xc294,	0x9fff, 0xc294,		0x21, 0
	.dw 0xa800, 0xc294,	0xbfff, 0xc294,		0x21, 0
	.dw 0xc200, 0xc294,	0xdfff, 0xc294,		0x21, 0
	.dw 0xe800, 0xc294,	0xffff, 0xc29b,		0x21, 0
	.dw 0x0040, 0xc29c,	0x007f, 0xc29c,		0x21, 0
	.dw 0x00c0, 0xc29c,	0x00ff, 0xc29c,		0x21, 0
	.dw 0x0140, 0xc29c,	0x017f, 0xc29c,		0x21, 0
	.dw 0x01c0, 0xc29c,	0x1fff, 0xc29c,		0x21, 0
	.dw 0x2040, 0xc29c,	0x207f, 0xc29c,		0x21, 0
	.dw 0x20c0, 0xc29c,	0x20ff, 0xc29c,		0x21, 0
	.dw 0x2140, 0xc29c,	0x217f, 0xc29c,		0x21, 0
	.dw 0x21c0, 0xc29c,	0x21ff, 0xc29c,		0x21, 0
	.dw 0x2240, 0xc29c,	0x227f, 0xc29c,		0x21, 0
	.dw 0x22c0, 0xc29c,	0x22ff, 0xc29c,		0x21, 0
	.dw 0x2340, 0xc29c,	0x237f, 0xc29c,		0x21, 0
	.dw 0x23c0, 0xc29c,	0x23ff, 0xc29c,		0x21, 0
	.dw 0x2440, 0xc29c,	0x247f, 0xc29c,		0x21, 0
	.dw 0x24c0, 0xc29c,	0x24ff, 0xc29c,		0x21, 0
	.dw 0x2540, 0xc29c,	0x257f, 0xc29c,		0x21, 0
	.dw 0x25c0, 0xc29c,	0x25ff, 0xc29c,		0x21, 0
	.dw 0x2640, 0xc29c,	0x267f, 0xc29c,		0x21, 0
	.dw 0x26c0, 0xc29c,	0x26ff, 0xc29c,		0x21, 0
	.dw 0x2740, 0xc29c,	0x277f, 0xc29c,		0x21, 0
	.dw 0x27c0, 0xc29c,	0x3fff, 0xc29c,		0x21, 0
	.dw 0x4040, 0xc29c,	0x407f, 0xc29c,		0x21, 0
	.dw 0x40c0, 0xc29c,	0x40ff, 0xc29c,		0x21, 0
	.dw 0x4140, 0xc29c,	0x417f, 0xc29c,		0x21, 0
	.dw 0x41c0, 0xc29c,	0x5fff, 0xc29c,		0x21, 0
	.dw 0x6040, 0xc29c,	0x607f, 0xc29c,		0x21, 0
	.dw 0x60c0, 0xc29c,	0x60ff, 0xc29c,		0x21, 0
	.dw 0x6140, 0xc29c,	0x617f, 0xc29c,		0x21, 0
	.dw 0x61c0, 0xc29c,	0x61ff, 0xc29c,		0x21, 0
	.dw 0x6240, 0xc29c,	0x627f, 0xc29c,		0x21, 0
	.dw 0x62c0, 0xc29c,	0x62ff, 0xc29c,		0x21, 0
	.dw 0x6340, 0xc29c,	0x637f, 0xc29c,		0x21, 0
	.dw 0x63c0, 0xc29c,	0x63ff, 0xc29c,		0x21, 0
	.dw 0x6440, 0xc29c,	0x647f, 0xc29c,		0x21, 0
	.dw 0x64c0, 0xc29c,	0x64ff, 0xc29c,		0x21, 0
	.dw 0x6540, 0xc29c,	0x657f, 0xc29c,		0x21, 0
	.dw 0x65c0, 0xc29c,	0x65ff, 0xc29c,		0x21, 0
	.dw 0x6640, 0xc29c,	0x667f, 0xc29c,		0x21, 0
	.dw 0x66c0, 0xc29c,	0x66ff, 0xc29c,		0x21, 0
	.dw 0x6740, 0xc29c,	0x677f, 0xc29c,		0x21, 0
	.dw 0x67c0, 0xc29c,	0x7fff, 0xc29c,		0x21, 0
	.dw 0x8040, 0xc29c,	0x807f, 0xc29c,		0x21, 0
	.dw 0x80c0, 0xc29c,	0x80ff, 0xc29c,		0x21, 0
	.dw 0x8140, 0xc29c,	0x817f, 0xc29c,		0x21, 0
	.dw 0x81c0, 0xc29c,	0x9fff, 0xc29c,		0x21, 0
	.dw 0xa040, 0xc29c,	0xa07f, 0xc29c,		0x21, 0
	.dw 0xa0c0, 0xc29c,	0xa0ff, 0xc29c,		0x21, 0
	.dw 0xa140, 0xc29c,	0xa17f, 0xc29c,		0x21, 0
	.dw 0xa1c0, 0xc29c,	0xa1ff, 0xc29c,		0x21, 0
	.dw 0xa240, 0xc29c,	0xa27f, 0xc29c,		0x21, 0
	.dw 0xa2c0, 0xc29c,	0xa2ff, 0xc29c,		0x21, 0
	.dw 0xa340, 0xc29c,	0xa37f, 0xc29c,		0x21, 0
	.dw 0xa3c0, 0xc29c,	0xa3ff, 0xc29c,		0x21, 0
	.dw 0xa440, 0xc29c,	0xa47f, 0xc29c,		0x21, 0
	.dw 0xa4c0, 0xc29c,	0xa4ff, 0xc29c,		0x21, 0
	.dw 0xa540, 0xc29c,	0xa57f, 0xc29c,		0x21, 0
	.dw 0xa5c0, 0xc29c,	0xa5ff, 0xc29c,		0x21, 0
	.dw 0xa640, 0xc29c,	0xa67f, 0xc29c,		0x21, 0
	.dw 0xa6c0, 0xc29c,	0xa6ff, 0xc29c,		0x21, 0
	.dw 0xa740, 0xc29c,	0xa77f, 0xc29c,		0x21, 0
	.dw 0xa7c0, 0xc29c,	0xbfff, 0xc29c,		0x21, 0
	.dw 0xc040, 0xc29c,	0xc07f, 0xc29c,		0x21, 0
	.dw 0xc0c0, 0xc29c,	0xc0ff, 0xc29c,		0x21, 0
	.dw 0xc140, 0xc29c,	0xc17f, 0xc29c,		0x21, 0
	.dw 0xc1c0, 0xc29c,	0xdfff, 0xc29c,		0x21, 0
	.dw 0xe040, 0xc29c,	0xe07f, 0xc29c,		0x21, 0
	.dw 0xe0c0, 0xc29c,	0xe0ff, 0xc29c,		0x21, 0
	.dw 0xe140, 0xc29c,	0xe17f, 0xc29c,		0x21, 0
	.dw 0xe1c0, 0xc29c,	0xe1ff, 0xc29c,		0x21, 0
	.dw 0xe240, 0xc29c,	0xe27f, 0xc29c,		0x21, 0
	.dw 0xe2c0, 0xc29c,	0xe2ff, 0xc29c,		0x21, 0
	.dw 0xe340, 0xc29c,	0xe37f, 0xc29c,		0x21, 0
	.dw 0xe3c0, 0xc29c,	0xe3ff, 0xc29c,		0x21, 0
	.dw 0xe440, 0xc29c,	0xe47f, 0xc29c,		0x21, 0
	.dw 0xe4c0, 0xc29c,	0xe4ff, 0xc29c,		0x21, 0
	.dw 0xe540, 0xc29c,	0xe57f, 0xc29c,		0x21, 0
	.dw 0xe5c0, 0xc29c,	0xe5ff, 0xc29c,		0x21, 0
	.dw 0xe640, 0xc29c,	0xe67f, 0xc29c,		0x21, 0
	.dw 0xe6c0, 0xc29c,	0xe6ff, 0xc29c,		0x21, 0
	.dw 0xe740, 0xc29c,	0xe77f, 0xc29c,		0x21, 0
	.dw 0xe7c0, 0xc29c,	0x1fff, 0xc2c0,		0x21, 0
	.dw 0x2800, 0xc2c0,	0xffff, 0xc2c3,		0x21, 0
	.dw 0x0200, 0xc2c4,	0x1fff, 0xc2c4,		0x21, 0
	.dw 0x2800, 0xc2c4,	0x3fff, 0xc2c4,		0x21, 0
	.dw 0x4200, 0xc2c4,	0x5fff, 0xc2c4,		0x21, 0
	.dw 0x6800, 0xc2c4,	0x7fff, 0xc2c4,		0x21, 0
	.dw 0x8200, 0xc2c4,	0x9fff, 0xc2c4,		0x21, 0
	.dw 0xa800, 0xc2c4,	0xbfff, 0xc2c4,		0x21, 0
	.dw 0xc200, 0xc2c4,	0xdfff, 0xc2c4,		0x21, 0
	.dw 0xe800, 0xc2c4,	0xffff, 0xc2d3,		0x21, 0
	.dw 0x0200, 0xc2d4,	0x1fff, 0xc2d4,		0x21, 0
	.dw 0x2800, 0xc2d4,	0x3fff, 0xc2d4,		0x21, 0
	.dw 0x4200, 0xc2d4,	0x5fff, 0xc2d4,		0x21, 0
	.dw 0x6800, 0xc2d4,	0x7fff, 0xc2d4,		0x21, 0
	.dw 0x8200, 0xc2d4,	0x9fff, 0xc2d4,		0x21, 0
	.dw 0xa800, 0xc2d4,	0xbfff, 0xc2d4,		0x21, 0
	.dw 0xc200, 0xc2d4,	0xdfff, 0xc2d4,		0x21, 0
	.dw 0xe800, 0xc2d4,	0x1fff, 0xc300,		0x21, 0
	.dw 0x2800, 0xc300,	0xffff, 0xc303,		0x21, 0
	.dw 0x0200, 0xc304,	0x1fff, 0xc304,		0x21, 0
	.dw 0x2800, 0xc304,	0x3fff, 0xc304,		0x21, 0
	.dw 0x4200, 0xc304,	0x5fff, 0xc304,		0x21, 0
	.dw 0x6800, 0xc304,	0x7fff, 0xc304,		0x21, 0
	.dw 0x8200, 0xc304,	0x9fff, 0xc304,		0x21, 0
	.dw 0xa800, 0xc304,	0xbfff, 0xc304,		0x21, 0
	.dw 0xc200, 0xc304,	0xdfff, 0xc304,		0x21, 0
	.dw 0xe800, 0xc304,	0x1fff, 0xc308,		0x21, 0
	.dw 0x2040, 0xc308,	0x207f, 0xc308,		0x21, 0
	.dw 0x20c0, 0xc308,	0x20ff, 0xc308,		0x21, 0
	.dw 0x2140, 0xc308,	0x217f, 0xc308,		0x21, 0
	.dw 0x21c0, 0xc308,	0x21ff, 0xc308,		0x21, 0
	.dw 0x2240, 0xc308,	0x227f, 0xc308,		0x21, 0
	.dw 0x22c0, 0xc308,	0x22ff, 0xc308,		0x21, 0
	.dw 0x2340, 0xc308,	0x237f, 0xc308,		0x21, 0
	.dw 0x23c0, 0xc308,	0x23ff, 0xc308,		0x21, 0
	.dw 0x2440, 0xc308,	0x247f, 0xc308,		0x21, 0
	.dw 0x24c0, 0xc308,	0x24ff, 0xc308,		0x21, 0
	.dw 0x2540, 0xc308,	0x257f, 0xc308,		0x21, 0
	.dw 0x25c0, 0xc308,	0x25ff, 0xc308,		0x21, 0
	.dw 0x2640, 0xc308,	0x267f, 0xc308,		0x21, 0
	.dw 0x26c0, 0xc308,	0x26ff, 0xc308,		0x21, 0
	.dw 0x2740, 0xc308,	0x277f, 0xc308,		0x21, 0
	.dw 0x27c0, 0xc308,	0xffff, 0xc30b,		0x21, 0
	.dw 0x0040, 0xc30c,	0x007f, 0xc30c,		0x21, 0
	.dw 0x00c0, 0xc30c,	0x00ff, 0xc30c,		0x21, 0
	.dw 0x0140, 0xc30c,	0x017f, 0xc30c,		0x21, 0
	.dw 0x01c0, 0xc30c,	0x1fff, 0xc30c,		0x21, 0
	.dw 0x2040, 0xc30c,	0x207f, 0xc30c,		0x21, 0
	.dw 0x20c0, 0xc30c,	0x20ff, 0xc30c,		0x21, 0
	.dw 0x2140, 0xc30c,	0x217f, 0xc30c,		0x21, 0
	.dw 0x21c0, 0xc30c,	0x21ff, 0xc30c,		0x21, 0
	.dw 0x2240, 0xc30c,	0x227f, 0xc30c,		0x21, 0
	.dw 0x22c0, 0xc30c,	0x22ff, 0xc30c,		0x21, 0
	.dw 0x2340, 0xc30c,	0x237f, 0xc30c,		0x21, 0
	.dw 0x23c0, 0xc30c,	0x23ff, 0xc30c,		0x21, 0
	.dw 0x2440, 0xc30c,	0x247f, 0xc30c,		0x21, 0
	.dw 0x24c0, 0xc30c,	0x24ff, 0xc30c,		0x21, 0
	.dw 0x2540, 0xc30c,	0x257f, 0xc30c,		0x21, 0
	.dw 0x25c0, 0xc30c,	0x25ff, 0xc30c,		0x21, 0
	.dw 0x2640, 0xc30c,	0x267f, 0xc30c,		0x21, 0
	.dw 0x26c0, 0xc30c,	0x26ff, 0xc30c,		0x21, 0
	.dw 0x2740, 0xc30c,	0x277f, 0xc30c,		0x21, 0
	.dw 0x27c0, 0xc30c,	0x3fff, 0xc30c,		0x21, 0
	.dw 0x4040, 0xc30c,	0x407f, 0xc30c,		0x21, 0
	.dw 0x40c0, 0xc30c,	0x40ff, 0xc30c,		0x21, 0
	.dw 0x4140, 0xc30c,	0x417f, 0xc30c,		0x21, 0
	.dw 0x41c0, 0xc30c,	0x5fff, 0xc30c,		0x21, 0
	.dw 0x6040, 0xc30c,	0x607f, 0xc30c,		0x21, 0
	.dw 0x60c0, 0xc30c,	0x60ff, 0xc30c,		0x21, 0
	.dw 0x6140, 0xc30c,	0x617f, 0xc30c,		0x21, 0
	.dw 0x61c0, 0xc30c,	0x61ff, 0xc30c,		0x21, 0
	.dw 0x6240, 0xc30c,	0x627f, 0xc30c,		0x21, 0
	.dw 0x62c0, 0xc30c,	0x62ff, 0xc30c,		0x21, 0
	.dw 0x6340, 0xc30c,	0x637f, 0xc30c,		0x21, 0
	.dw 0x63c0, 0xc30c,	0x63ff, 0xc30c,		0x21, 0
	.dw 0x6440, 0xc30c,	0x647f, 0xc30c,		0x21, 0
	.dw 0x64c0, 0xc30c,	0x64ff, 0xc30c,		0x21, 0
	.dw 0x6540, 0xc30c,	0x657f, 0xc30c,		0x21, 0
	.dw 0x65c0, 0xc30c,	0x65ff, 0xc30c,		0x21, 0
	.dw 0x6640, 0xc30c,	0x667f, 0xc30c,		0x21, 0
	.dw 0x66c0, 0xc30c,	0x66ff, 0xc30c,		0x21, 0
	.dw 0x6740, 0xc30c,	0x677f, 0xc30c,		0x21, 0
	.dw 0x67c0, 0xc30c,	0x7fff, 0xc30c,		0x21, 0
	.dw 0x8040, 0xc30c,	0x807f, 0xc30c,		0x21, 0
	.dw 0x80c0, 0xc30c,	0x80ff, 0xc30c,		0x21, 0
	.dw 0x8140, 0xc30c,	0x817f, 0xc30c,		0x21, 0
	.dw 0x81c0, 0xc30c,	0x9fff, 0xc30c,		0x21, 0
	.dw 0xa040, 0xc30c,	0xa07f, 0xc30c,		0x21, 0
	.dw 0xa0c0, 0xc30c,	0xa0ff, 0xc30c,		0x21, 0
	.dw 0xa140, 0xc30c,	0xa17f, 0xc30c,		0x21, 0
	.dw 0xa1c0, 0xc30c,	0xa1ff, 0xc30c,		0x21, 0
	.dw 0xa240, 0xc30c,	0xa27f, 0xc30c,		0x21, 0
	.dw 0xa2c0, 0xc30c,	0xa2ff, 0xc30c,		0x21, 0
	.dw 0xa340, 0xc30c,	0xa37f, 0xc30c,		0x21, 0
	.dw 0xa3c0, 0xc30c,	0xa3ff, 0xc30c,		0x21, 0
	.dw 0xa440, 0xc30c,	0xa47f, 0xc30c,		0x21, 0
	.dw 0xa4c0, 0xc30c,	0xa4ff, 0xc30c,		0x21, 0
	.dw 0xa540, 0xc30c,	0xa57f, 0xc30c,		0x21, 0
	.dw 0xa5c0, 0xc30c,	0xa5ff, 0xc30c,		0x21, 0
	.dw 0xa640, 0xc30c,	0xa67f, 0xc30c,		0x21, 0
	.dw 0xa6c0, 0xc30c,	0xa6ff, 0xc30c,		0x21, 0
	.dw 0xa740, 0xc30c,	0xa77f, 0xc30c,		0x21, 0
	.dw 0xa7c0, 0xc30c,	0xbfff, 0xc30c,		0x21, 0
	.dw 0xc040, 0xc30c,	0xc07f, 0xc30c,		0x21, 0
	.dw 0xc0c0, 0xc30c,	0xc0ff, 0xc30c,		0x21, 0
	.dw 0xc140, 0xc30c,	0xc17f, 0xc30c,		0x21, 0
	.dw 0xc1c0, 0xc30c,	0xdfff, 0xc30c,		0x21, 0
	.dw 0xe040, 0xc30c,	0xe07f, 0xc30c,		0x21, 0
	.dw 0xe0c0, 0xc30c,	0xe0ff, 0xc30c,		0x21, 0
	.dw 0xe140, 0xc30c,	0xe17f, 0xc30c,		0x21, 0
	.dw 0xe1c0, 0xc30c,	0xe1ff, 0xc30c,		0x21, 0
	.dw 0xe240, 0xc30c,	0xe27f, 0xc30c,		0x21, 0
	.dw 0xe2c0, 0xc30c,	0xe2ff, 0xc30c,		0x21, 0
	.dw 0xe340, 0xc30c,	0xe37f, 0xc30c,		0x21, 0
	.dw 0xe3c0, 0xc30c,	0xe3ff, 0xc30c,		0x21, 0
	.dw 0xe440, 0xc30c,	0xe47f, 0xc30c,		0x21, 0
	.dw 0xe4c0, 0xc30c,	0xe4ff, 0xc30c,		0x21, 0
	.dw 0xe540, 0xc30c,	0xe57f, 0xc30c,		0x21, 0
	.dw 0xe5c0, 0xc30c,	0xe5ff, 0xc30c,		0x21, 0
	.dw 0xe640, 0xc30c,	0xe67f, 0xc30c,		0x21, 0
	.dw 0xe6c0, 0xc30c,	0xe6ff, 0xc30c,		0x21, 0
	.dw 0xe740, 0xc30c,	0xe77f, 0xc30c,		0x21, 0
	.dw 0xe7c0, 0xc30c,	0xffff, 0xc313,		0x21, 0
	.dw 0x0200, 0xc314,	0x1fff, 0xc314,		0x21, 0
	.dw 0x2800, 0xc314,	0x3fff, 0xc314,		0x21, 0
	.dw 0x4200, 0xc314,	0x5fff, 0xc314,		0x21, 0
	.dw 0x6800, 0xc314,	0x7fff, 0xc314,		0x21, 0
	.dw 0x8200, 0xc314,	0x9fff, 0xc314,		0x21, 0
	.dw 0xa800, 0xc314,	0xbfff, 0xc314,		0x21, 0
	.dw 0xc200, 0xc314,	0xdfff, 0xc314,		0x21, 0
	.dw 0xe800, 0xc314,	0xffff, 0xc31b,		0x21, 0
	.dw 0x0040, 0xc31c,	0x007f, 0xc31c,		0x21, 0
	.dw 0x00c0, 0xc31c,	0x00ff, 0xc31c,		0x21, 0
	.dw 0x0140, 0xc31c,	0x017f, 0xc31c,		0x21, 0
	.dw 0x01c0, 0xc31c,	0x1fff, 0xc31c,		0x21, 0
	.dw 0x2040, 0xc31c,	0x207f, 0xc31c,		0x21, 0
	.dw 0x20c0, 0xc31c,	0x20ff, 0xc31c,		0x21, 0
	.dw 0x2140, 0xc31c,	0x217f, 0xc31c,		0x21, 0
	.dw 0x21c0, 0xc31c,	0x21ff, 0xc31c,		0x21, 0
	.dw 0x2240, 0xc31c,	0x227f, 0xc31c,		0x21, 0
	.dw 0x22c0, 0xc31c,	0x22ff, 0xc31c,		0x21, 0
	.dw 0x2340, 0xc31c,	0x237f, 0xc31c,		0x21, 0
	.dw 0x23c0, 0xc31c,	0x23ff, 0xc31c,		0x21, 0
	.dw 0x2440, 0xc31c,	0x247f, 0xc31c,		0x21, 0
	.dw 0x24c0, 0xc31c,	0x24ff, 0xc31c,		0x21, 0
	.dw 0x2540, 0xc31c,	0x257f, 0xc31c,		0x21, 0
	.dw 0x25c0, 0xc31c,	0x25ff, 0xc31c,		0x21, 0
	.dw 0x2640, 0xc31c,	0x267f, 0xc31c,		0x21, 0
	.dw 0x26c0, 0xc31c,	0x26ff, 0xc31c,		0x21, 0
	.dw 0x2740, 0xc31c,	0x277f, 0xc31c,		0x21, 0
	.dw 0x27c0, 0xc31c,	0x3fff, 0xc31c,		0x21, 0
	.dw 0x4040, 0xc31c,	0x407f, 0xc31c,		0x21, 0
	.dw 0x40c0, 0xc31c,	0x40ff, 0xc31c,		0x21, 0
	.dw 0x4140, 0xc31c,	0x417f, 0xc31c,		0x21, 0
	.dw 0x41c0, 0xc31c,	0x5fff, 0xc31c,		0x21, 0
	.dw 0x6040, 0xc31c,	0x607f, 0xc31c,		0x21, 0
	.dw 0x60c0, 0xc31c,	0x60ff, 0xc31c,		0x21, 0
	.dw 0x6140, 0xc31c,	0x617f, 0xc31c,		0x21, 0
	.dw 0x61c0, 0xc31c,	0x61ff, 0xc31c,		0x21, 0
	.dw 0x6240, 0xc31c,	0x627f, 0xc31c,		0x21, 0
	.dw 0x62c0, 0xc31c,	0x62ff, 0xc31c,		0x21, 0
	.dw 0x6340, 0xc31c,	0x637f, 0xc31c,		0x21, 0
	.dw 0x63c0, 0xc31c,	0x63ff, 0xc31c,		0x21, 0
	.dw 0x6440, 0xc31c,	0x647f, 0xc31c,		0x21, 0
	.dw 0x64c0, 0xc31c,	0x64ff, 0xc31c,		0x21, 0
	.dw 0x6540, 0xc31c,	0x657f, 0xc31c,		0x21, 0
	.dw 0x65c0, 0xc31c,	0x65ff, 0xc31c,		0x21, 0
	.dw 0x6640, 0xc31c,	0x667f, 0xc31c,		0x21, 0
	.dw 0x66c0, 0xc31c,	0x66ff, 0xc31c,		0x21, 0
	.dw 0x6740, 0xc31c,	0x677f, 0xc31c,		0x21, 0
	.dw 0x67c0, 0xc31c,	0x7fff, 0xc31c,		0x21, 0
	.dw 0x8040, 0xc31c,	0x807f, 0xc31c,		0x21, 0
	.dw 0x80c0, 0xc31c,	0x80ff, 0xc31c,		0x21, 0
	.dw 0x8140, 0xc31c,	0x817f, 0xc31c,		0x21, 0
	.dw 0x81c0, 0xc31c,	0x9fff, 0xc31c,		0x21, 0
	.dw 0xa040, 0xc31c,	0xa07f, 0xc31c,		0x21, 0
	.dw 0xa0c0, 0xc31c,	0xa0ff, 0xc31c,		0x21, 0
	.dw 0xa140, 0xc31c,	0xa17f, 0xc31c,		0x21, 0
	.dw 0xa1c0, 0xc31c,	0xa1ff, 0xc31c,		0x21, 0
	.dw 0xa240, 0xc31c,	0xa27f, 0xc31c,		0x21, 0
	.dw 0xa2c0, 0xc31c,	0xa2ff, 0xc31c,		0x21, 0
	.dw 0xa340, 0xc31c,	0xa37f, 0xc31c,		0x21, 0
	.dw 0xa3c0, 0xc31c,	0xa3ff, 0xc31c,		0x21, 0
	.dw 0xa440, 0xc31c,	0xa47f, 0xc31c,		0x21, 0
	.dw 0xa4c0, 0xc31c,	0xa4ff, 0xc31c,		0x21, 0
	.dw 0xa540, 0xc31c,	0xa57f, 0xc31c,		0x21, 0
	.dw 0xa5c0, 0xc31c,	0xa5ff, 0xc31c,		0x21, 0
	.dw 0xa640, 0xc31c,	0xa67f, 0xc31c,		0x21, 0
	.dw 0xa6c0, 0xc31c,	0xa6ff, 0xc31c,		0x21, 0
	.dw 0xa740, 0xc31c,	0xa77f, 0xc31c,		0x21, 0
	.dw 0xa7c0, 0xc31c,	0xbfff, 0xc31c,		0x21, 0
	.dw 0xc040, 0xc31c,	0xc07f, 0xc31c,		0x21, 0
	.dw 0xc0c0, 0xc31c,	0xc0ff, 0xc31c,		0x21, 0
	.dw 0xc140, 0xc31c,	0xc17f, 0xc31c,		0x21, 0
	.dw 0xc1c0, 0xc31c,	0xdfff, 0xc31c,		0x21, 0
	.dw 0xe040, 0xc31c,	0xe07f, 0xc31c,		0x21, 0
	.dw 0xe0c0, 0xc31c,	0xe0ff, 0xc31c,		0x21, 0
	.dw 0xe140, 0xc31c,	0xe17f, 0xc31c,		0x21, 0
	.dw 0xe1c0, 0xc31c,	0xe1ff, 0xc31c,		0x21, 0
	.dw 0xe240, 0xc31c,	0xe27f, 0xc31c,		0x21, 0
	.dw 0xe2c0, 0xc31c,	0xe2ff, 0xc31c,		0x21, 0
	.dw 0xe340, 0xc31c,	0xe37f, 0xc31c,		0x21, 0
	.dw 0xe3c0, 0xc31c,	0xe3ff, 0xc31c,		0x21, 0
	.dw 0xe440, 0xc31c,	0xe47f, 0xc31c,		0x21, 0
	.dw 0xe4c0, 0xc31c,	0xe4ff, 0xc31c,		0x21, 0
	.dw 0xe540, 0xc31c,	0xe57f, 0xc31c,		0x21, 0
	.dw 0xe5c0, 0xc31c,	0xe5ff, 0xc31c,		0x21, 0
	.dw 0xe640, 0xc31c,	0xe67f, 0xc31c,		0x21, 0
	.dw 0xe6c0, 0xc31c,	0xe6ff, 0xc31c,		0x21, 0
	.dw 0xe740, 0xc31c,	0xe77f, 0xc31c,		0x21, 0
	.dw 0xe7c0, 0xc31c,	0x1fff, 0xc320,		0x21, 0
	.dw 0x2800, 0xc320,	0xffff, 0xc323,		0x21, 0
	.dw 0x0200, 0xc324,	0x1fff, 0xc324,		0x21, 0
	.dw 0x2800, 0xc324,	0x3fff, 0xc324,		0x21, 0
	.dw 0x4200, 0xc324,	0x5fff, 0xc324,		0x21, 0
	.dw 0x6800, 0xc324,	0x7fff, 0xc324,		0x21, 0
	.dw 0x8200, 0xc324,	0x9fff, 0xc324,		0x21, 0
	.dw 0xa800, 0xc324,	0xbfff, 0xc324,		0x21, 0
	.dw 0xc200, 0xc324,	0xdfff, 0xc324,		0x21, 0
	.dw 0xe800, 0xc324,	0x1fff, 0xc328,		0x21, 0
	.dw 0x2040, 0xc328,	0x207f, 0xc328,		0x21, 0
	.dw 0x20c0, 0xc328,	0x20ff, 0xc328,		0x21, 0
	.dw 0x2140, 0xc328,	0x217f, 0xc328,		0x21, 0
	.dw 0x21c0, 0xc328,	0x21ff, 0xc328,		0x21, 0
	.dw 0x2240, 0xc328,	0x227f, 0xc328,		0x21, 0
	.dw 0x22c0, 0xc328,	0x22ff, 0xc328,		0x21, 0
	.dw 0x2340, 0xc328,	0x237f, 0xc328,		0x21, 0
	.dw 0x23c0, 0xc328,	0x23ff, 0xc328,		0x21, 0
	.dw 0x2440, 0xc328,	0x247f, 0xc328,		0x21, 0
	.dw 0x24c0, 0xc328,	0x24ff, 0xc328,		0x21, 0
	.dw 0x2540, 0xc328,	0x257f, 0xc328,		0x21, 0
	.dw 0x25c0, 0xc328,	0x25ff, 0xc328,		0x21, 0
	.dw 0x2640, 0xc328,	0x267f, 0xc328,		0x21, 0
	.dw 0x26c0, 0xc328,	0x26ff, 0xc328,		0x21, 0
	.dw 0x2740, 0xc328,	0x277f, 0xc328,		0x21, 0
	.dw 0x27c0, 0xc328,	0xffff, 0xc32b,		0x21, 0
	.dw 0x0040, 0xc32c,	0x007f, 0xc32c,		0x21, 0
	.dw 0x00c0, 0xc32c,	0x00ff, 0xc32c,		0x21, 0
	.dw 0x0140, 0xc32c,	0x017f, 0xc32c,		0x21, 0
	.dw 0x01c0, 0xc32c,	0x1fff, 0xc32c,		0x21, 0
	.dw 0x2040, 0xc32c,	0x207f, 0xc32c,		0x21, 0
	.dw 0x20c0, 0xc32c,	0x20ff, 0xc32c,		0x21, 0
	.dw 0x2140, 0xc32c,	0x217f, 0xc32c,		0x21, 0
	.dw 0x21c0, 0xc32c,	0x21ff, 0xc32c,		0x21, 0
	.dw 0x2240, 0xc32c,	0x227f, 0xc32c,		0x21, 0
	.dw 0x22c0, 0xc32c,	0x22ff, 0xc32c,		0x21, 0
	.dw 0x2340, 0xc32c,	0x237f, 0xc32c,		0x21, 0
	.dw 0x23c0, 0xc32c,	0x23ff, 0xc32c,		0x21, 0
	.dw 0x2440, 0xc32c,	0x247f, 0xc32c,		0x21, 0
	.dw 0x24c0, 0xc32c,	0x24ff, 0xc32c,		0x21, 0
	.dw 0x2540, 0xc32c,	0x257f, 0xc32c,		0x21, 0
	.dw 0x25c0, 0xc32c,	0x25ff, 0xc32c,		0x21, 0
	.dw 0x2640, 0xc32c,	0x267f, 0xc32c,		0x21, 0
	.dw 0x26c0, 0xc32c,	0x26ff, 0xc32c,		0x21, 0
	.dw 0x2740, 0xc32c,	0x277f, 0xc32c,		0x21, 0
	.dw 0x27c0, 0xc32c,	0x3fff, 0xc32c,		0x21, 0
	.dw 0x4040, 0xc32c,	0x407f, 0xc32c,		0x21, 0
	.dw 0x40c0, 0xc32c,	0x40ff, 0xc32c,		0x21, 0
	.dw 0x4140, 0xc32c,	0x417f, 0xc32c,		0x21, 0
	.dw 0x41c0, 0xc32c,	0x5fff, 0xc32c,		0x21, 0
	.dw 0x6040, 0xc32c,	0x607f, 0xc32c,		0x21, 0
	.dw 0x60c0, 0xc32c,	0x60ff, 0xc32c,		0x21, 0
	.dw 0x6140, 0xc32c,	0x617f, 0xc32c,		0x21, 0
	.dw 0x61c0, 0xc32c,	0x61ff, 0xc32c,		0x21, 0
	.dw 0x6240, 0xc32c,	0x627f, 0xc32c,		0x21, 0
	.dw 0x62c0, 0xc32c,	0x62ff, 0xc32c,		0x21, 0
	.dw 0x6340, 0xc32c,	0x637f, 0xc32c,		0x21, 0
	.dw 0x63c0, 0xc32c,	0x63ff, 0xc32c,		0x21, 0
	.dw 0x6440, 0xc32c,	0x647f, 0xc32c,		0x21, 0
	.dw 0x64c0, 0xc32c,	0x64ff, 0xc32c,		0x21, 0
	.dw 0x6540, 0xc32c,	0x657f, 0xc32c,		0x21, 0
	.dw 0x65c0, 0xc32c,	0x65ff, 0xc32c,		0x21, 0
	.dw 0x6640, 0xc32c,	0x667f, 0xc32c,		0x21, 0
	.dw 0x66c0, 0xc32c,	0x66ff, 0xc32c,		0x21, 0
	.dw 0x6740, 0xc32c,	0x677f, 0xc32c,		0x21, 0
	.dw 0x67c0, 0xc32c,	0x7fff, 0xc32c,		0x21, 0
	.dw 0x8040, 0xc32c,	0x807f, 0xc32c,		0x21, 0
	.dw 0x80c0, 0xc32c,	0x80ff, 0xc32c,		0x21, 0
	.dw 0x8140, 0xc32c,	0x817f, 0xc32c,		0x21, 0
	.dw 0x81c0, 0xc32c,	0x9fff, 0xc32c,		0x21, 0
	.dw 0xa040, 0xc32c,	0xa07f, 0xc32c,		0x21, 0
	.dw 0xa0c0, 0xc32c,	0xa0ff, 0xc32c,		0x21, 0
	.dw 0xa140, 0xc32c,	0xa17f, 0xc32c,		0x21, 0
	.dw 0xa1c0, 0xc32c,	0xa1ff, 0xc32c,		0x21, 0
	.dw 0xa240, 0xc32c,	0xa27f, 0xc32c,		0x21, 0
	.dw 0xa2c0, 0xc32c,	0xa2ff, 0xc32c,		0x21, 0
	.dw 0xa340, 0xc32c,	0xa37f, 0xc32c,		0x21, 0
	.dw 0xa3c0, 0xc32c,	0xa3ff, 0xc32c,		0x21, 0
	.dw 0xa440, 0xc32c,	0xa47f, 0xc32c,		0x21, 0
	.dw 0xa4c0, 0xc32c,	0xa4ff, 0xc32c,		0x21, 0
	.dw 0xa540, 0xc32c,	0xa57f, 0xc32c,		0x21, 0
	.dw 0xa5c0, 0xc32c,	0xa5ff, 0xc32c,		0x21, 0
	.dw 0xa640, 0xc32c,	0xa67f, 0xc32c,		0x21, 0
	.dw 0xa6c0, 0xc32c,	0xa6ff, 0xc32c,		0x21, 0
	.dw 0xa740, 0xc32c,	0xa77f, 0xc32c,		0x21, 0
	.dw 0xa7c0, 0xc32c,	0xbfff, 0xc32c,		0x21, 0
	.dw 0xc040, 0xc32c,	0xc07f, 0xc32c,		0x21, 0
	.dw 0xc0c0, 0xc32c,	0xc0ff, 0xc32c,		0x21, 0
	.dw 0xc140, 0xc32c,	0xc17f, 0xc32c,		0x21, 0
	.dw 0xc1c0, 0xc32c,	0xdfff, 0xc32c,		0x21, 0
	.dw 0xe040, 0xc32c,	0xe07f, 0xc32c,		0x21, 0
	.dw 0xe0c0, 0xc32c,	0xe0ff, 0xc32c,		0x21, 0
	.dw 0xe140, 0xc32c,	0xe17f, 0xc32c,		0x21, 0
	.dw 0xe1c0, 0xc32c,	0xe1ff, 0xc32c,		0x21, 0
	.dw 0xe240, 0xc32c,	0xe27f, 0xc32c,		0x21, 0
	.dw 0xe2c0, 0xc32c,	0xe2ff, 0xc32c,		0x21, 0
	.dw 0xe340, 0xc32c,	0xe37f, 0xc32c,		0x21, 0
	.dw 0xe3c0, 0xc32c,	0xe3ff, 0xc32c,		0x21, 0
	.dw 0xe440, 0xc32c,	0xe47f, 0xc32c,		0x21, 0
	.dw 0xe4c0, 0xc32c,	0xe4ff, 0xc32c,		0x21, 0
	.dw 0xe540, 0xc32c,	0xe57f, 0xc32c,		0x21, 0
	.dw 0xe5c0, 0xc32c,	0xe5ff, 0xc32c,		0x21, 0
	.dw 0xe640, 0xc32c,	0xe67f, 0xc32c,		0x21, 0
	.dw 0xe6c0, 0xc32c,	0xe6ff, 0xc32c,		0x21, 0
	.dw 0xe740, 0xc32c,	0xe77f, 0xc32c,		0x21, 0
	.dw 0xe7c0, 0xc32c,	0xffff, 0xc333,		0x21, 0
	.dw 0x0200, 0xc334,	0x1fff, 0xc334,		0x21, 0
	.dw 0x2800, 0xc334,	0x3fff, 0xc334,		0x21, 0
	.dw 0x4200, 0xc334,	0x5fff, 0xc334,		0x21, 0
	.dw 0x6800, 0xc334,	0x7fff, 0xc334,		0x21, 0
	.dw 0x8200, 0xc334,	0x9fff, 0xc334,		0x21, 0
	.dw 0xa800, 0xc334,	0xbfff, 0xc334,		0x21, 0
	.dw 0xc200, 0xc334,	0xdfff, 0xc334,		0x21, 0
	.dw 0xe800, 0xc334,	0xffff, 0xc33b,		0x21, 0
	.dw 0x0040, 0xc33c,	0x007f, 0xc33c,		0x21, 0
	.dw 0x00c0, 0xc33c,	0x00ff, 0xc33c,		0x21, 0
	.dw 0x0140, 0xc33c,	0x017f, 0xc33c,		0x21, 0
	.dw 0x01c0, 0xc33c,	0x1fff, 0xc33c,		0x21, 0
	.dw 0x2040, 0xc33c,	0x207f, 0xc33c,		0x21, 0
	.dw 0x20c0, 0xc33c,	0x20ff, 0xc33c,		0x21, 0
	.dw 0x2140, 0xc33c,	0x217f, 0xc33c,		0x21, 0
	.dw 0x21c0, 0xc33c,	0x21ff, 0xc33c,		0x21, 0
	.dw 0x2240, 0xc33c,	0x227f, 0xc33c,		0x21, 0
	.dw 0x22c0, 0xc33c,	0x22ff, 0xc33c,		0x21, 0
	.dw 0x2340, 0xc33c,	0x237f, 0xc33c,		0x21, 0
	.dw 0x23c0, 0xc33c,	0x23ff, 0xc33c,		0x21, 0
	.dw 0x2440, 0xc33c,	0x247f, 0xc33c,		0x21, 0
	.dw 0x24c0, 0xc33c,	0x24ff, 0xc33c,		0x21, 0
	.dw 0x2540, 0xc33c,	0x257f, 0xc33c,		0x21, 0
	.dw 0x25c0, 0xc33c,	0x25ff, 0xc33c,		0x21, 0
	.dw 0x2640, 0xc33c,	0x267f, 0xc33c,		0x21, 0
	.dw 0x26c0, 0xc33c,	0x26ff, 0xc33c,		0x21, 0
	.dw 0x2740, 0xc33c,	0x277f, 0xc33c,		0x21, 0
	.dw 0x27c0, 0xc33c,	0x3fff, 0xc33c,		0x21, 0
	.dw 0x4040, 0xc33c,	0x407f, 0xc33c,		0x21, 0
	.dw 0x40c0, 0xc33c,	0x40ff, 0xc33c,		0x21, 0
	.dw 0x4140, 0xc33c,	0x417f, 0xc33c,		0x21, 0
	.dw 0x41c0, 0xc33c,	0x5fff, 0xc33c,		0x21, 0
	.dw 0x6040, 0xc33c,	0x607f, 0xc33c,		0x21, 0
	.dw 0x60c0, 0xc33c,	0x60ff, 0xc33c,		0x21, 0
	.dw 0x6140, 0xc33c,	0x617f, 0xc33c,		0x21, 0
	.dw 0x61c0, 0xc33c,	0x61ff, 0xc33c,		0x21, 0
	.dw 0x6240, 0xc33c,	0x627f, 0xc33c,		0x21, 0
	.dw 0x62c0, 0xc33c,	0x62ff, 0xc33c,		0x21, 0
	.dw 0x6340, 0xc33c,	0x637f, 0xc33c,		0x21, 0
	.dw 0x63c0, 0xc33c,	0x63ff, 0xc33c,		0x21, 0
	.dw 0x6440, 0xc33c,	0x647f, 0xc33c,		0x21, 0
	.dw 0x64c0, 0xc33c,	0x64ff, 0xc33c,		0x21, 0
	.dw 0x6540, 0xc33c,	0x657f, 0xc33c,		0x21, 0
	.dw 0x65c0, 0xc33c,	0x65ff, 0xc33c,		0x21, 0
	.dw 0x6640, 0xc33c,	0x667f, 0xc33c,		0x21, 0
	.dw 0x66c0, 0xc33c,	0x66ff, 0xc33c,		0x21, 0
	.dw 0x6740, 0xc33c,	0x677f, 0xc33c,		0x21, 0
	.dw 0x67c0, 0xc33c,	0x7fff, 0xc33c,		0x21, 0
	.dw 0x8040, 0xc33c,	0x807f, 0xc33c,		0x21, 0
	.dw 0x80c0, 0xc33c,	0x80ff, 0xc33c,		0x21, 0
	.dw 0x8140, 0xc33c,	0x817f, 0xc33c,		0x21, 0
	.dw 0x81c0, 0xc33c,	0x9fff, 0xc33c,		0x21, 0
	.dw 0xa040, 0xc33c,	0xa07f, 0xc33c,		0x21, 0
	.dw 0xa0c0, 0xc33c,	0xa0ff, 0xc33c,		0x21, 0
	.dw 0xa140, 0xc33c,	0xa17f, 0xc33c,		0x21, 0
	.dw 0xa1c0, 0xc33c,	0xa1ff, 0xc33c,		0x21, 0
	.dw 0xa240, 0xc33c,	0xa27f, 0xc33c,		0x21, 0
	.dw 0xa2c0, 0xc33c,	0xa2ff, 0xc33c,		0x21, 0
	.dw 0xa340, 0xc33c,	0xa37f, 0xc33c,		0x21, 0
	.dw 0xa3c0, 0xc33c,	0xa3ff, 0xc33c,		0x21, 0
	.dw 0xa440, 0xc33c,	0xa47f, 0xc33c,		0x21, 0
	.dw 0xa4c0, 0xc33c,	0xa4ff, 0xc33c,		0x21, 0
	.dw 0xa540, 0xc33c,	0xa57f, 0xc33c,		0x21, 0
	.dw 0xa5c0, 0xc33c,	0xa5ff, 0xc33c,		0x21, 0
	.dw 0xa640, 0xc33c,	0xa67f, 0xc33c,		0x21, 0
	.dw 0xa6c0, 0xc33c,	0xa6ff, 0xc33c,		0x21, 0
	.dw 0xa740, 0xc33c,	0xa77f, 0xc33c,		0x21, 0
	.dw 0xa7c0, 0xc33c,	0xbfff, 0xc33c,		0x21, 0
	.dw 0xc040, 0xc33c,	0xc07f, 0xc33c,		0x21, 0
	.dw 0xc0c0, 0xc33c,	0xc0ff, 0xc33c,		0x21, 0
	.dw 0xc140, 0xc33c,	0xc17f, 0xc33c,		0x21, 0
	.dw 0xc1c0, 0xc33c,	0xdfff, 0xc33c,		0x21, 0
	.dw 0xe040, 0xc33c,	0xe07f, 0xc33c,		0x21, 0
	.dw 0xe0c0, 0xc33c,	0xe0ff, 0xc33c,		0x21, 0
	.dw 0xe140, 0xc33c,	0xe17f, 0xc33c,		0x21, 0
	.dw 0xe1c0, 0xc33c,	0xe1ff, 0xc33c,		0x21, 0
	.dw 0xe240, 0xc33c,	0xe27f, 0xc33c,		0x21, 0
	.dw 0xe2c0, 0xc33c,	0xe2ff, 0xc33c,		0x21, 0
	.dw 0xe340, 0xc33c,	0xe37f, 0xc33c,		0x21, 0
	.dw 0xe3c0, 0xc33c,	0xe3ff, 0xc33c,		0x21, 0
	.dw 0xe440, 0xc33c,	0xe47f, 0xc33c,		0x21, 0
	.dw 0xe4c0, 0xc33c,	0xe4ff, 0xc33c,		0x21, 0
	.dw 0xe540, 0xc33c,	0xe57f, 0xc33c,		0x21, 0
	.dw 0xe5c0, 0xc33c,	0xe5ff, 0xc33c,		0x21, 0
	.dw 0xe640, 0xc33c,	0xe67f, 0xc33c,		0x21, 0
	.dw 0xe6c0, 0xc33c,	0xe6ff, 0xc33c,		0x21, 0
	.dw 0xe740, 0xc33c,	0xe77f, 0xc33c,		0x21, 0
	.dw 0xe7c0, 0xc33c,	0x1fff, 0xc360,		0x21, 0
	.dw 0x2800, 0xc360,	0xffff, 0xc363,		0x21, 0
	.dw 0x0200, 0xc364,	0x1fff, 0xc364,		0x21, 0
	.dw 0x2800, 0xc364,	0x3fff, 0xc364,		0x21, 0
	.dw 0x4200, 0xc364,	0x5fff, 0xc364,		0x21, 0
	.dw 0x6800, 0xc364,	0x7fff, 0xc364,		0x21, 0
	.dw 0x8200, 0xc364,	0x9fff, 0xc364,		0x21, 0
	.dw 0xa800, 0xc364,	0xbfff, 0xc364,		0x21, 0
	.dw 0xc200, 0xc364,	0xdfff, 0xc364,		0x21, 0
	.dw 0xe800, 0xc364,	0xffff, 0xc373,		0x21, 0
	.dw 0x0200, 0xc374,	0x1fff, 0xc374,		0x21, 0
	.dw 0x2800, 0xc374,	0x3fff, 0xc374,		0x21, 0
	.dw 0x4200, 0xc374,	0x5fff, 0xc374,		0x21, 0
	.dw 0x6800, 0xc374,	0x7fff, 0xc374,		0x21, 0
	.dw 0x8200, 0xc374,	0x9fff, 0xc374,		0x21, 0
	.dw 0xa800, 0xc374,	0xbfff, 0xc374,		0x21, 0
	.dw 0xc200, 0xc374,	0xdfff, 0xc374,		0x21, 0
	.dw 0xe800, 0xc374,	0x1fff, 0xc380,		0x21, 0
	.dw 0x2800, 0xc380,	0xffff, 0xc383,		0x21, 0
	.dw 0x0200, 0xc384,	0x1fff, 0xc384,		0x21, 0
	.dw 0x2800, 0xc384,	0x3fff, 0xc384,		0x21, 0
	.dw 0x4200, 0xc384,	0x5fff, 0xc384,		0x21, 0
	.dw 0x6800, 0xc384,	0x7fff, 0xc384,		0x21, 0
	.dw 0x8200, 0xc384,	0x9fff, 0xc384,		0x21, 0
	.dw 0xa800, 0xc384,	0xbfff, 0xc384,		0x21, 0
	.dw 0xc200, 0xc384,	0xdfff, 0xc384,		0x21, 0
	.dw 0xe800, 0xc384,	0x1fff, 0xc388,		0x21, 0
	.dw 0x2040, 0xc388,	0x207f, 0xc388,		0x21, 0
	.dw 0x20c0, 0xc388,	0x20ff, 0xc388,		0x21, 0
	.dw 0x2140, 0xc388,	0x217f, 0xc388,		0x21, 0
	.dw 0x21c0, 0xc388,	0x21ff, 0xc388,		0x21, 0
	.dw 0x2240, 0xc388,	0x227f, 0xc388,		0x21, 0
	.dw 0x22c0, 0xc388,	0x22ff, 0xc388,		0x21, 0
	.dw 0x2340, 0xc388,	0x237f, 0xc388,		0x21, 0
	.dw 0x23c0, 0xc388,	0x23ff, 0xc388,		0x21, 0
	.dw 0x2440, 0xc388,	0x247f, 0xc388,		0x21, 0
	.dw 0x24c0, 0xc388,	0x24ff, 0xc388,		0x21, 0
	.dw 0x2540, 0xc388,	0x257f, 0xc388,		0x21, 0
	.dw 0x25c0, 0xc388,	0x25ff, 0xc388,		0x21, 0
	.dw 0x2640, 0xc388,	0x267f, 0xc388,		0x21, 0
	.dw 0x26c0, 0xc388,	0x26ff, 0xc388,		0x21, 0
	.dw 0x2740, 0xc388,	0x277f, 0xc388,		0x21, 0
	.dw 0x27c0, 0xc388,	0xffff, 0xc38b,		0x21, 0
	.dw 0x0040, 0xc38c,	0x007f, 0xc38c,		0x21, 0
	.dw 0x00c0, 0xc38c,	0x00ff, 0xc38c,		0x21, 0
	.dw 0x0140, 0xc38c,	0x017f, 0xc38c,		0x21, 0
	.dw 0x01c0, 0xc38c,	0x1fff, 0xc38c,		0x21, 0
	.dw 0x2040, 0xc38c,	0x207f, 0xc38c,		0x21, 0
	.dw 0x20c0, 0xc38c,	0x20ff, 0xc38c,		0x21, 0
	.dw 0x2140, 0xc38c,	0x217f, 0xc38c,		0x21, 0
	.dw 0x21c0, 0xc38c,	0x21ff, 0xc38c,		0x21, 0
	.dw 0x2240, 0xc38c,	0x227f, 0xc38c,		0x21, 0
	.dw 0x22c0, 0xc38c,	0x22ff, 0xc38c,		0x21, 0
	.dw 0x2340, 0xc38c,	0x237f, 0xc38c,		0x21, 0
	.dw 0x23c0, 0xc38c,	0x23ff, 0xc38c,		0x21, 0
	.dw 0x2440, 0xc38c,	0x247f, 0xc38c,		0x21, 0
	.dw 0x24c0, 0xc38c,	0x24ff, 0xc38c,		0x21, 0
	.dw 0x2540, 0xc38c,	0x257f, 0xc38c,		0x21, 0
	.dw 0x25c0, 0xc38c,	0x25ff, 0xc38c,		0x21, 0
	.dw 0x2640, 0xc38c,	0x267f, 0xc38c,		0x21, 0
	.dw 0x26c0, 0xc38c,	0x26ff, 0xc38c,		0x21, 0
	.dw 0x2740, 0xc38c,	0x277f, 0xc38c,		0x21, 0
	.dw 0x27c0, 0xc38c,	0x3fff, 0xc38c,		0x21, 0
	.dw 0x4040, 0xc38c,	0x407f, 0xc38c,		0x21, 0
	.dw 0x40c0, 0xc38c,	0x40ff, 0xc38c,		0x21, 0
	.dw 0x4140, 0xc38c,	0x417f, 0xc38c,		0x21, 0
	.dw 0x41c0, 0xc38c,	0x5fff, 0xc38c,		0x21, 0
	.dw 0x6040, 0xc38c,	0x607f, 0xc38c,		0x21, 0
	.dw 0x60c0, 0xc38c,	0x60ff, 0xc38c,		0x21, 0
	.dw 0x6140, 0xc38c,	0x617f, 0xc38c,		0x21, 0
	.dw 0x61c0, 0xc38c,	0x61ff, 0xc38c,		0x21, 0
	.dw 0x6240, 0xc38c,	0x627f, 0xc38c,		0x21, 0
	.dw 0x62c0, 0xc38c,	0x62ff, 0xc38c,		0x21, 0
	.dw 0x6340, 0xc38c,	0x637f, 0xc38c,		0x21, 0
	.dw 0x63c0, 0xc38c,	0x63ff, 0xc38c,		0x21, 0
	.dw 0x6440, 0xc38c,	0x647f, 0xc38c,		0x21, 0
	.dw 0x64c0, 0xc38c,	0x64ff, 0xc38c,		0x21, 0
	.dw 0x6540, 0xc38c,	0x657f, 0xc38c,		0x21, 0
	.dw 0x65c0, 0xc38c,	0x65ff, 0xc38c,		0x21, 0
	.dw 0x6640, 0xc38c,	0x667f, 0xc38c,		0x21, 0
	.dw 0x66c0, 0xc38c,	0x66ff, 0xc38c,		0x21, 0
	.dw 0x6740, 0xc38c,	0x677f, 0xc38c,		0x21, 0
	.dw 0x67c0, 0xc38c,	0x7fff, 0xc38c,		0x21, 0
	.dw 0x8040, 0xc38c,	0x807f, 0xc38c,		0x21, 0
	.dw 0x80c0, 0xc38c,	0x80ff, 0xc38c,		0x21, 0
	.dw 0x8140, 0xc38c,	0x817f, 0xc38c,		0x21, 0
	.dw 0x81c0, 0xc38c,	0x9fff, 0xc38c,		0x21, 0
	.dw 0xa040, 0xc38c,	0xa07f, 0xc38c,		0x21, 0
	.dw 0xa0c0, 0xc38c,	0xa0ff, 0xc38c,		0x21, 0
	.dw 0xa140, 0xc38c,	0xa17f, 0xc38c,		0x21, 0
	.dw 0xa1c0, 0xc38c,	0xa1ff, 0xc38c,		0x21, 0
	.dw 0xa240, 0xc38c,	0xa27f, 0xc38c,		0x21, 0
	.dw 0xa2c0, 0xc38c,	0xa2ff, 0xc38c,		0x21, 0
	.dw 0xa340, 0xc38c,	0xa37f, 0xc38c,		0x21, 0
	.dw 0xa3c0, 0xc38c,	0xa3ff, 0xc38c,		0x21, 0
	.dw 0xa440, 0xc38c,	0xa47f, 0xc38c,		0x21, 0
	.dw 0xa4c0, 0xc38c,	0xa4ff, 0xc38c,		0x21, 0
	.dw 0xa540, 0xc38c,	0xa57f, 0xc38c,		0x21, 0
	.dw 0xa5c0, 0xc38c,	0xa5ff, 0xc38c,		0x21, 0
	.dw 0xa640, 0xc38c,	0xa67f, 0xc38c,		0x21, 0
	.dw 0xa6c0, 0xc38c,	0xa6ff, 0xc38c,		0x21, 0
	.dw 0xa740, 0xc38c,	0xa77f, 0xc38c,		0x21, 0
	.dw 0xa7c0, 0xc38c,	0xbfff, 0xc38c,		0x21, 0
	.dw 0xc040, 0xc38c,	0xc07f, 0xc38c,		0x21, 0
	.dw 0xc0c0, 0xc38c,	0xc0ff, 0xc38c,		0x21, 0
	.dw 0xc140, 0xc38c,	0xc17f, 0xc38c,		0x21, 0
	.dw 0xc1c0, 0xc38c,	0xdfff, 0xc38c,		0x21, 0
	.dw 0xe040, 0xc38c,	0xe07f, 0xc38c,		0x21, 0
	.dw 0xe0c0, 0xc38c,	0xe0ff, 0xc38c,		0x21, 0
	.dw 0xe140, 0xc38c,	0xe17f, 0xc38c,		0x21, 0
	.dw 0xe1c0, 0xc38c,	0xe1ff, 0xc38c,		0x21, 0
	.dw 0xe240, 0xc38c,	0xe27f, 0xc38c,		0x21, 0
	.dw 0xe2c0, 0xc38c,	0xe2ff, 0xc38c,		0x21, 0
	.dw 0xe340, 0xc38c,	0xe37f, 0xc38c,		0x21, 0
	.dw 0xe3c0, 0xc38c,	0xe3ff, 0xc38c,		0x21, 0
	.dw 0xe440, 0xc38c,	0xe47f, 0xc38c,		0x21, 0
	.dw 0xe4c0, 0xc38c,	0xe4ff, 0xc38c,		0x21, 0
	.dw 0xe540, 0xc38c,	0xe57f, 0xc38c,		0x21, 0
	.dw 0xe5c0, 0xc38c,	0xe5ff, 0xc38c,		0x21, 0
	.dw 0xe640, 0xc38c,	0xe67f, 0xc38c,		0x21, 0
	.dw 0xe6c0, 0xc38c,	0xe6ff, 0xc38c,		0x21, 0
	.dw 0xe740, 0xc38c,	0xe77f, 0xc38c,		0x21, 0
	.dw 0xe7c0, 0xc38c,	0xffff, 0xc393,		0x21, 0
	.dw 0x0200, 0xc394,	0x1fff, 0xc394,		0x21, 0
	.dw 0x2800, 0xc394,	0x3fff, 0xc394,		0x21, 0
	.dw 0x4200, 0xc394,	0x5fff, 0xc394,		0x21, 0
	.dw 0x6800, 0xc394,	0x7fff, 0xc394,		0x21, 0
	.dw 0x8200, 0xc394,	0x9fff, 0xc394,		0x21, 0
	.dw 0xa800, 0xc394,	0xbfff, 0xc394,		0x21, 0
	.dw 0xc200, 0xc394,	0xdfff, 0xc394,		0x21, 0
	.dw 0xe800, 0xc394,	0xffff, 0xc39b,		0x21, 0
	.dw 0x0040, 0xc39c,	0x007f, 0xc39c,		0x21, 0
	.dw 0x00c0, 0xc39c,	0x00ff, 0xc39c,		0x21, 0
	.dw 0x0140, 0xc39c,	0x017f, 0xc39c,		0x21, 0
	.dw 0x01c0, 0xc39c,	0x1fff, 0xc39c,		0x21, 0
	.dw 0x2040, 0xc39c,	0x207f, 0xc39c,		0x21, 0
	.dw 0x20c0, 0xc39c,	0x20ff, 0xc39c,		0x21, 0
	.dw 0x2140, 0xc39c,	0x217f, 0xc39c,		0x21, 0
	.dw 0x21c0, 0xc39c,	0x21ff, 0xc39c,		0x21, 0
	.dw 0x2240, 0xc39c,	0x227f, 0xc39c,		0x21, 0
	.dw 0x22c0, 0xc39c,	0x22ff, 0xc39c,		0x21, 0
	.dw 0x2340, 0xc39c,	0x237f, 0xc39c,		0x21, 0
	.dw 0x23c0, 0xc39c,	0x23ff, 0xc39c,		0x21, 0
	.dw 0x2440, 0xc39c,	0x247f, 0xc39c,		0x21, 0
	.dw 0x24c0, 0xc39c,	0x24ff, 0xc39c,		0x21, 0
	.dw 0x2540, 0xc39c,	0x257f, 0xc39c,		0x21, 0
	.dw 0x25c0, 0xc39c,	0x25ff, 0xc39c,		0x21, 0
	.dw 0x2640, 0xc39c,	0x267f, 0xc39c,		0x21, 0
	.dw 0x26c0, 0xc39c,	0x26ff, 0xc39c,		0x21, 0
	.dw 0x2740, 0xc39c,	0x277f, 0xc39c,		0x21, 0
	.dw 0x27c0, 0xc39c,	0x3fff, 0xc39c,		0x21, 0
	.dw 0x4040, 0xc39c,	0x407f, 0xc39c,		0x21, 0
	.dw 0x40c0, 0xc39c,	0x40ff, 0xc39c,		0x21, 0
	.dw 0x4140, 0xc39c,	0x417f, 0xc39c,		0x21, 0
	.dw 0x41c0, 0xc39c,	0x5fff, 0xc39c,		0x21, 0
	.dw 0x6040, 0xc39c,	0x607f, 0xc39c,		0x21, 0
	.dw 0x60c0, 0xc39c,	0x60ff, 0xc39c,		0x21, 0
	.dw 0x6140, 0xc39c,	0x617f, 0xc39c,		0x21, 0
	.dw 0x61c0, 0xc39c,	0x61ff, 0xc39c,		0x21, 0
	.dw 0x6240, 0xc39c,	0x627f, 0xc39c,		0x21, 0
	.dw 0x62c0, 0xc39c,	0x62ff, 0xc39c,		0x21, 0
	.dw 0x6340, 0xc39c,	0x637f, 0xc39c,		0x21, 0
	.dw 0x63c0, 0xc39c,	0x63ff, 0xc39c,		0x21, 0
	.dw 0x6440, 0xc39c,	0x647f, 0xc39c,		0x21, 0
	.dw 0x64c0, 0xc39c,	0x64ff, 0xc39c,		0x21, 0
	.dw 0x6540, 0xc39c,	0x657f, 0xc39c,		0x21, 0
	.dw 0x65c0, 0xc39c,	0x65ff, 0xc39c,		0x21, 0
	.dw 0x6640, 0xc39c,	0x667f, 0xc39c,		0x21, 0
	.dw 0x66c0, 0xc39c,	0x66ff, 0xc39c,		0x21, 0
	.dw 0x6740, 0xc39c,	0x677f, 0xc39c,		0x21, 0
	.dw 0x67c0, 0xc39c,	0x7fff, 0xc39c,		0x21, 0
	.dw 0x8040, 0xc39c,	0x807f, 0xc39c,		0x21, 0
	.dw 0x80c0, 0xc39c,	0x80ff, 0xc39c,		0x21, 0
	.dw 0x8140, 0xc39c,	0x817f, 0xc39c,		0x21, 0
	.dw 0x81c0, 0xc39c,	0x9fff, 0xc39c,		0x21, 0
	.dw 0xa040, 0xc39c,	0xa07f, 0xc39c,		0x21, 0
	.dw 0xa0c0, 0xc39c,	0xa0ff, 0xc39c,		0x21, 0
	.dw 0xa140, 0xc39c,	0xa17f, 0xc39c,		0x21, 0
	.dw 0xa1c0, 0xc39c,	0xa1ff, 0xc39c,		0x21, 0
	.dw 0xa240, 0xc39c,	0xa27f, 0xc39c,		0x21, 0
	.dw 0xa2c0, 0xc39c,	0xa2ff, 0xc39c,		0x21, 0
	.dw 0xa340, 0xc39c,	0xa37f, 0xc39c,		0x21, 0
	.dw 0xa3c0, 0xc39c,	0xa3ff, 0xc39c,		0x21, 0
	.dw 0xa440, 0xc39c,	0xa47f, 0xc39c,		0x21, 0
	.dw 0xa4c0, 0xc39c,	0xa4ff, 0xc39c,		0x21, 0
	.dw 0xa540, 0xc39c,	0xa57f, 0xc39c,		0x21, 0
	.dw 0xa5c0, 0xc39c,	0xa5ff, 0xc39c,		0x21, 0
	.dw 0xa640, 0xc39c,	0xa67f, 0xc39c,		0x21, 0
	.dw 0xa6c0, 0xc39c,	0xa6ff, 0xc39c,		0x21, 0
	.dw 0xa740, 0xc39c,	0xa77f, 0xc39c,		0x21, 0
	.dw 0xa7c0, 0xc39c,	0xbfff, 0xc39c,		0x21, 0
	.dw 0xc040, 0xc39c,	0xc07f, 0xc39c,		0x21, 0
	.dw 0xc0c0, 0xc39c,	0xc0ff, 0xc39c,		0x21, 0
	.dw 0xc140, 0xc39c,	0xc17f, 0xc39c,		0x21, 0
	.dw 0xc1c0, 0xc39c,	0xdfff, 0xc39c,		0x21, 0
	.dw 0xe040, 0xc39c,	0xe07f, 0xc39c,		0x21, 0
	.dw 0xe0c0, 0xc39c,	0xe0ff, 0xc39c,		0x21, 0
	.dw 0xe140, 0xc39c,	0xe17f, 0xc39c,		0x21, 0
	.dw 0xe1c0, 0xc39c,	0xe1ff, 0xc39c,		0x21, 0
	.dw 0xe240, 0xc39c,	0xe27f, 0xc39c,		0x21, 0
	.dw 0xe2c0, 0xc39c,	0xe2ff, 0xc39c,		0x21, 0
	.dw 0xe340, 0xc39c,	0xe37f, 0xc39c,		0x21, 0
	.dw 0xe3c0, 0xc39c,	0xe3ff, 0xc39c,		0x21, 0
	.dw 0xe440, 0xc39c,	0xe47f, 0xc39c,		0x21, 0
	.dw 0xe4c0, 0xc39c,	0xe4ff, 0xc39c,		0x21, 0
	.dw 0xe540, 0xc39c,	0xe57f, 0xc39c,		0x21, 0
	.dw 0xe5c0, 0xc39c,	0xe5ff, 0xc39c,		0x21, 0
	.dw 0xe640, 0xc39c,	0xe67f, 0xc39c,		0x21, 0
	.dw 0xe6c0, 0xc39c,	0xe6ff, 0xc39c,		0x21, 0
	.dw 0xe740, 0xc39c,	0xe77f, 0xc39c,		0x21, 0
	.dw 0xe7c0, 0xc39c,	0xffff, 0xc3ff,		0x21, 0
	.dw 0x0000, 0xc401,	0x003f, 0xc401,		0x22, 0
	.dw 0x0240, 0xc401,	0x027f, 0xc401,		0x22, 0
	.dw 0x0480, 0xc401,	0x04bf, 0xc401,		0x22, 0
	.dw 0x06c0, 0xc401,	0x06ff, 0xc401,		0x22, 0
	.dw 0x0900, 0xc401,	0x093f, 0xc401,		0x22, 0
	.dw 0x0b40, 0xc401,	0x0b7f, 0xc401,		0x22, 0
	.dw 0x0d80, 0xc401,	0x0dbf, 0xc401,		0x22, 0
	.dw 0x0fc0, 0xc401,	0x103f, 0xc401,		0x22, 0
	.dw 0x1240, 0xc401,	0x127f, 0xc401,		0x22, 0
	.dw 0x1480, 0xc401,	0x14bf, 0xc401,		0x22, 0
	.dw 0x16c0, 0xc401,	0x16ff, 0xc401,		0x22, 0
	.dw 0x1900, 0xc401,	0x193f, 0xc401,		0x22, 0
	.dw 0x1b40, 0xc401,	0x1b7f, 0xc401,		0x22, 0
	.dw 0x1d80, 0xc401,	0x1dbf, 0xc401,		0x22, 0
	.dw 0x1fc0, 0xc401,	0x203f, 0xc401,		0x22, 0
	.dw 0x2240, 0xc401,	0x227f, 0xc401,		0x22, 0
	.dw 0x2480, 0xc401,	0x24bf, 0xc401,		0x22, 0
	.dw 0x26c0, 0xc401,	0x26ff, 0xc401,		0x22, 0
	.dw 0x2900, 0xc401,	0x293f, 0xc401,		0x22, 0
	.dw 0x2b40, 0xc401,	0x2b7f, 0xc401,		0x22, 0
	.dw 0x2d80, 0xc401,	0x2dbf, 0xc401,		0x22, 0
	.dw 0x2fc0, 0xc401,	0x303f, 0xc401,		0x22, 0
	.dw 0x3240, 0xc401,	0x327f, 0xc401,		0x22, 0
	.dw 0x3480, 0xc401,	0x34bf, 0xc401,		0x22, 0
	.dw 0x36c0, 0xc401,	0x36ff, 0xc401,		0x22, 0
	.dw 0x3900, 0xc401,	0x393f, 0xc401,		0x22, 0
	.dw 0x3b40, 0xc401,	0x3b7f, 0xc401,		0x22, 0
	.dw 0x3d80, 0xc401,	0x3dbf, 0xc401,		0x22, 0
	.dw 0x3fc0, 0xc401,	0x3fff, 0xc401,		0x22, 0
	.dw 0x4000, 0xc401,	0x7fff, 0xc401,		0x21, 0
	.dw 0x8000, 0xc401,	0x803f, 0xc401,		0x22, 0
	.dw 0x8240, 0xc401,	0x827f, 0xc401,		0x22, 0
	.dw 0x8480, 0xc401,	0x84bf, 0xc401,		0x22, 0
	.dw 0x86c0, 0xc401,	0x86ff, 0xc401,		0x22, 0
	.dw 0x8900, 0xc401,	0x893f, 0xc401,		0x22, 0
	.dw 0x8b40, 0xc401,	0x8b7f, 0xc401,		0x22, 0
	.dw 0x8d80, 0xc401,	0x8dbf, 0xc401,		0x22, 0
	.dw 0x8fc0, 0xc401,	0x903f, 0xc401,		0x22, 0
	.dw 0x9240, 0xc401,	0x927f, 0xc401,		0x22, 0
	.dw 0x9480, 0xc401,	0x94bf, 0xc401,		0x22, 0
	.dw 0x96c0, 0xc401,	0x96ff, 0xc401,		0x22, 0
	.dw 0x9900, 0xc401,	0x993f, 0xc401,		0x22, 0
	.dw 0x9b40, 0xc401,	0x9b7f, 0xc401,		0x22, 0
	.dw 0x9d80, 0xc401,	0x9dbf, 0xc401,		0x22, 0
	.dw 0x9fc0, 0xc401,	0xa03f, 0xc401,		0x22, 0
	.dw 0xa240, 0xc401,	0xa27f, 0xc401,		0x22, 0
	.dw 0xa480, 0xc401,	0xa4bf, 0xc401,		0x22, 0
	.dw 0xa6c0, 0xc401,	0xa6ff, 0xc401,		0x22, 0
	.dw 0xa900, 0xc401,	0xa93f, 0xc401,		0x22, 0
	.dw 0xab40, 0xc401,	0xab7f, 0xc401,		0x22, 0
	.dw 0xad80, 0xc401,	0xadbf, 0xc401,		0x22, 0
	.dw 0xafc0, 0xc401,	0xb03f, 0xc401,		0x22, 0
	.dw 0xb240, 0xc401,	0xb27f, 0xc401,		0x22, 0
	.dw 0xb480, 0xc401,	0xb4bf, 0xc401,		0x22, 0
	.dw 0xb6c0, 0xc401,	0xb6ff, 0xc401,		0x22, 0
	.dw 0xb900, 0xc401,	0xb93f, 0xc401,		0x22, 0
	.dw 0xbb40, 0xc401,	0xbb7f, 0xc401,		0x22, 0
	.dw 0xbd80, 0xc401,	0xbdbf, 0xc401,		0x22, 0
	.dw 0xbfc0, 0xc401,	0xc03f, 0xc401,		0x22, 0
	.dw 0xc240, 0xc401,	0xc27f, 0xc401,		0x22, 0
	.dw 0xc480, 0xc401,	0xc4bf, 0xc401,		0x22, 0
	.dw 0xc6c0, 0xc401,	0xc6ff, 0xc401,		0x22, 0
	.dw 0xc900, 0xc401,	0xc93f, 0xc401,		0x22, 0
	.dw 0xcb40, 0xc401,	0xcb7f, 0xc401,		0x22, 0
	.dw 0xcd80, 0xc401,	0xcdbf, 0xc401,		0x22, 0
	.dw 0xcfc0, 0xc401,	0xd03f, 0xc401,		0x22, 0
	.dw 0xd240, 0xc401,	0xd27f, 0xc401,		0x22, 0
	.dw 0xd480, 0xc401,	0xd4bf, 0xc401,		0x22, 0
	.dw 0xd6c0, 0xc401,	0xd6ff, 0xc401,		0x22, 0
	.dw 0xd900, 0xc401,	0xd93f, 0xc401,		0x22, 0
	.dw 0xdb40, 0xc401,	0xdb7f, 0xc401,		0x22, 0
	.dw 0xdd80, 0xc401,	0xddbf, 0xc401,		0x22, 0
	.dw 0xdfc0, 0xc401,	0xe03f, 0xc401,		0x22, 0
	.dw 0xe240, 0xc401,	0xe27f, 0xc401,		0x22, 0
	.dw 0xe480, 0xc401,	0xe4bf, 0xc401,		0x22, 0
	.dw 0xe6c0, 0xc401,	0xe6ff, 0xc401,		0x22, 0
	.dw 0xe900, 0xc401,	0xe93f, 0xc401,		0x22, 0
	.dw 0xeb40, 0xc401,	0xeb7f, 0xc401,		0x22, 0
	.dw 0xed80, 0xc401,	0xedbf, 0xc401,		0x22, 0
	.dw 0xefc0, 0xc401,	0xf03f, 0xc401,		0x22, 0
	.dw 0xf240, 0xc401,	0xf27f, 0xc401,		0x22, 0
	.dw 0xf480, 0xc401,	0xf4bf, 0xc401,		0x22, 0
	.dw 0xf6c0, 0xc401,	0xf6ff, 0xc401,		0x22, 0
	.dw 0xf900, 0xc401,	0xf93f, 0xc401,		0x22, 0
	.dw 0xfb40, 0xc401,	0xfb7f, 0xc401,		0x22, 0
	.dw 0xfd80, 0xc401,	0xfdbf, 0xc401,		0x22, 0
	.dw 0xffc0, 0xc401,	0xffff, 0xc401,		0x22, 0
	.dw 0x1000, 0xc402,	0x1fff, 0xc402,		0x21, 0
	.dw 0x3000, 0xc402,	0x3fff, 0xc402,		0x21, 0
	.dw 0x5000, 0xc402,	0x5fff, 0xc402,		0x21, 0
	.dw 0x7000, 0xc402,	0x7fff, 0xc402,		0x21, 0
	.dw 0x9000, 0xc402,	0x9fff, 0xc402,		0x21, 0
	.dw 0xb000, 0xc402,	0xbfff, 0xc402,		0x21, 0
	.dw 0xd000, 0xc402,	0xdfff, 0xc402,		0x21, 0
	.dw 0xf000, 0xc402,	0xffff, 0xc402,		0x21, 0
	.dw 0x1000, 0xc403,	0x1fff, 0xc403,		0x21, 0
	.dw 0x3000, 0xc403,	0x3fff, 0xc403,		0x21, 0
	.dw 0x5000, 0xc403,	0x5fff, 0xc403,		0x21, 0
	.dw 0x7000, 0xc403,	0x7fff, 0xc403,		0x21, 0
	.dw 0x9000, 0xc403,	0x9fff, 0xc403,		0x21, 0
	.dw 0xb000, 0xc403,	0xbfff, 0xc403,		0x21, 0
	.dw 0xd000, 0xc403,	0xdfff, 0xc403,		0x21, 0
	.dw 0xf000, 0xc403,	0xffff, 0xc403,		0x21, 0
	.dw 0x1000, 0xc404,	0x1fff, 0xc404,		0x21, 0
	.dw 0x3000, 0xc404,	0x3fff, 0xc404,		0x21, 0
	.dw 0x5000, 0xc404,	0x5fff, 0xc404,		0x21, 0
	.dw 0x7000, 0xc404,	0x7fff, 0xc404,		0x21, 0
	.dw 0x8000, 0xc404,	0x803f, 0xc404,		0x22, 0
	.dw 0x8240, 0xc404,	0x827f, 0xc404,		0x22, 0
	.dw 0x8480, 0xc404,	0x84bf, 0xc404,		0x22, 0
	.dw 0x86c0, 0xc404,	0x86ff, 0xc404,		0x22, 0
	.dw 0x8900, 0xc404,	0x893f, 0xc404,		0x22, 0
	.dw 0x8b40, 0xc404,	0x8b7f, 0xc404,		0x22, 0
	.dw 0x8d80, 0xc404,	0x8dbf, 0xc404,		0x22, 0
	.dw 0x8fc0, 0xc404,	0x8fff, 0xc404,		0x22, 0
	.dw 0x9000, 0xc404,	0x9fff, 0xc404,		0x21, 0
	.dw 0xa000, 0xc404,	0xa03f, 0xc404,		0x22, 0
	.dw 0xa240, 0xc404,	0xa27f, 0xc404,		0x22, 0
	.dw 0xa480, 0xc404,	0xa4bf, 0xc404,		0x22, 0
	.dw 0xa6c0, 0xc404,	0xa6ff, 0xc404,		0x22, 0
	.dw 0xa900, 0xc404,	0xa93f, 0xc404,		0x22, 0
	.dw 0xab40, 0xc404,	0xab7f, 0xc404,		0x22, 0
	.dw 0xad80, 0xc404,	0xadbf, 0xc404,		0x22, 0
	.dw 0xafc0, 0xc404,	0xafff, 0xc404,		0x22, 0
	.dw 0xb000, 0xc404,	0xffff, 0xc404,		0x21, 0
	.dw 0x1000, 0xc405,	0x3fff, 0xc405,		0x21, 0
	.dw 0x5000, 0xc405,	0x8fff, 0xc405,		0x21, 0
	.dw 0xa000, 0xc405,	0xcfff, 0xc405,		0x21, 0
	.dw 0xe000, 0xc405,	0xffff, 0xc405,		0x21, 0
	.dw 0x1000, 0xc406,	0x3fff, 0xc406,		0x21, 0
	.dw 0x5000, 0xc406,	0x7fff, 0xc406,		0x21, 0
	.dw 0x9000, 0xc406,	0xffff, 0xc406,		0x21, 0
	.dw 0x1000, 0xc407,	0x3fff, 0xc407,		0x21, 0
	.dw 0x5000, 0xc407,	0x7fff, 0xc407,		0x21, 0
	.dw 0x9000, 0xc407,	0xbfff, 0xc407,		0x21, 0
	.dw 0xd000, 0xc407,	0xdfff, 0xc407,		0x21, 0
	.dw 0xf000, 0xc407,	0xffff, 0xc407,		0x21, 0
	.dw 0x1000, 0xc408,	0x1fff, 0xc408,		0x21, 0
	.dw 0x3000, 0xc408,	0x3fff, 0xc408,		0x21, 0
	.dw 0x5000, 0xc408,	0x5fff, 0xc408,		0x21, 0
	.dw 0x7000, 0xc408,	0x7fff, 0xc408,		0x21, 0
	.dw 0x9000, 0xc408,	0x9fff, 0xc408,		0x21, 0
	.dw 0xb000, 0xc408,	0xbfff, 0xc408,		0x21, 0
	.dw 0xd000, 0xc408,	0xdfff, 0xc408,		0x21, 0
	.dw 0xf000, 0xc408,	0xffff, 0xc408,		0x21, 0
	.dw 0x1000, 0xc409,	0x1fff, 0xc409,		0x21, 0
	.dw 0x3000, 0xc409,	0x3fff, 0xc409,		0x21, 0
	.dw 0x5000, 0xc409,	0x7fff, 0xc409,		0x21, 0
	.dw 0x9000, 0xc409,	0x9fff, 0xc409,		0x21, 0
	.dw 0xb000, 0xc409,	0xbfff, 0xc409,		0x21, 0
	.dw 0xd000, 0xc409,	0xffff, 0xc409,		0x21, 0
	.dw 0x1000, 0xc40a,	0x3fff, 0xc40a,		0x21, 0
	.dw 0x5000, 0xc40a,	0xffff, 0xc40a,		0x21, 0
	.dw 0x1000, 0xc40b,	0x3fff, 0xc40b,		0x21, 0
	.dw 0x5000, 0xc40b,	0x7fff, 0xc40b,		0x21, 0
	.dw 0x9000, 0xc40b,	0x9fff, 0xc40b,		0x21, 0
	.dw 0xb000, 0xc40b,	0xbfff, 0xc40b,		0x21, 0
	.dw 0xd000, 0xc40b,	0xdfff, 0xc40b,		0x21, 0
	.dw 0xf000, 0xc40b,	0xffff, 0xc40b,		0x21, 0
	.dw 0x1000, 0xc40c,	0x3fff, 0xc40c,		0x21, 0
	.dw 0x4000, 0xc40c,	0x403f, 0xc40c,		0x22, 0
	.dw 0x4240, 0xc40c,	0x427f, 0xc40c,		0x22, 0
	.dw 0x4480, 0xc40c,	0x44bf, 0xc40c,		0x22, 0
	.dw 0x46c0, 0xc40c,	0x46ff, 0xc40c,		0x22, 0
	.dw 0x4900, 0xc40c,	0x493f, 0xc40c,		0x22, 0
	.dw 0x4b40, 0xc40c,	0x4b7f, 0xc40c,		0x22, 0
	.dw 0x4d80, 0xc40c,	0x4dbf, 0xc40c,		0x22, 0
	.dw 0x4fc0, 0xc40c,	0x4fff, 0xc40c,		0x22, 0
	.dw 0x5000, 0xc40c,	0xbfff, 0xc40c,		0x21, 0
	.dw 0xd000, 0xc40c,	0xffff, 0xc40c,		0x21, 0
	.dw 0x0000, 0xc40d,	0x003f, 0xc40d,		0x22, 0
	.dw 0x0240, 0xc40d,	0x027f, 0xc40d,		0x22, 0
	.dw 0x0480, 0xc40d,	0x04bf, 0xc40d,		0x22, 0
	.dw 0x06c0, 0xc40d,	0x06ff, 0xc40d,		0x22, 0
	.dw 0x0900, 0xc40d,	0x093f, 0xc40d,		0x22, 0
	.dw 0x0b40, 0xc40d,	0x0b7f, 0xc40d,		0x22, 0
	.dw 0x0d80, 0xc40d,	0x0dbf, 0xc40d,		0x22, 0
	.dw 0x0fc0, 0xc40d,	0x0fff, 0xc40d,		0x22, 0
	.dw 0x1000, 0xc40d,	0x3fff, 0xc40d,		0x21, 0
	.dw 0x4000, 0xc40d,	0x403f, 0xc40d,		0x22, 0
	.dw 0x4240, 0xc40d,	0x427f, 0xc40d,		0x22, 0
	.dw 0x4480, 0xc40d,	0x44bf, 0xc40d,		0x22, 0
	.dw 0x46c0, 0xc40d,	0x46ff, 0xc40d,		0x22, 0
	.dw 0x4900, 0xc40d,	0x493f, 0xc40d,		0x22, 0
	.dw 0x4b40, 0xc40d,	0x4b7f, 0xc40d,		0x22, 0
	.dw 0x4d80, 0xc40d,	0x4dbf, 0xc40d,		0x22, 0
	.dw 0x4fc0, 0xc40d,	0x4fff, 0xc40d,		0x22, 0
	.dw 0x5000, 0xc40d,	0x7fff, 0xc40d,		0x21, 0
	.dw 0x8000, 0xc40d,	0x803f, 0xc40d,		0x22, 0
	.dw 0x8240, 0xc40d,	0x827f, 0xc40d,		0x22, 0
	.dw 0x8480, 0xc40d,	0x84bf, 0xc40d,		0x22, 0
	.dw 0x86c0, 0xc40d,	0x86ff, 0xc40d,		0x22, 0
	.dw 0x8900, 0xc40d,	0x893f, 0xc40d,		0x22, 0
	.dw 0x8b40, 0xc40d,	0x8b7f, 0xc40d,		0x22, 0
	.dw 0x8d80, 0xc40d,	0x8dbf, 0xc40d,		0x22, 0
	.dw 0x8fc0, 0xc40d,	0x8fff, 0xc40d,		0x22, 0
	.dw 0x9000, 0xc40d,	0xbfff, 0xc40d,		0x21, 0
	.dw 0xc000, 0xc40d,	0xc03f, 0xc40d,		0x22, 0
	.dw 0xc240, 0xc40d,	0xc27f, 0xc40d,		0x22, 0
	.dw 0xc480, 0xc40d,	0xc4bf, 0xc40d,		0x22, 0
	.dw 0xc6c0, 0xc40d,	0xc6ff, 0xc40d,		0x22, 0
	.dw 0xc900, 0xc40d,	0xc93f, 0xc40d,		0x22, 0
	.dw 0xcb40, 0xc40d,	0xcb7f, 0xc40d,		0x22, 0
	.dw 0xcd80, 0xc40d,	0xcdbf, 0xc40d,		0x22, 0
	.dw 0xcfc0, 0xc40d,	0xcfff, 0xc40d,		0x22, 0
	.dw 0xd000, 0xc40d,	0xffff, 0xc40d,		0x21, 0
	.dw 0x1000, 0xc40e,	0x3fff, 0xc40e,		0x21, 0
	.dw 0x5000, 0xc40e,	0xbfff, 0xc40e,		0x21, 0
	.dw 0xd000, 0xc40e,	0xbfff, 0xc40f,		0x21, 0
	.dw 0xd000, 0xc40f,	0xffff, 0xc40f,		0x21, 0
	.dw 0x1000, 0xc410,	0x3fff, 0xc410,		0x21, 0
	.dw 0x5000, 0xc410,	0xbfff, 0xc410,		0x21, 0
	.dw 0xd000, 0xc410,	0xffff, 0xc410,		0x21, 0
	.dw 0x0000, 0xc411,	0x003f, 0xc411,		0x22, 0
	.dw 0x0240, 0xc411,	0x027f, 0xc411,		0x22, 0
	.dw 0x0480, 0xc411,	0x04bf, 0xc411,		0x22, 0
	.dw 0x06c0, 0xc411,	0x06ff, 0xc411,		0x22, 0
	.dw 0x0900, 0xc411,	0x093f, 0xc411,		0x22, 0
	.dw 0x0b40, 0xc411,	0x0b7f, 0xc411,		0x22, 0
	.dw 0x0d80, 0xc411,	0x0dbf, 0xc411,		0x22, 0
	.dw 0x0fc0, 0xc411,	0x0fff, 0xc411,		0x22, 0
	.dw 0x1000, 0xc411,	0x1fff, 0xc411,		0x21, 0
	.dw 0x2000, 0xc411,	0x203f, 0xc411,		0x22, 0
	.dw 0x2240, 0xc411,	0x227f, 0xc411,		0x22, 0
	.dw 0x2480, 0xc411,	0x24bf, 0xc411,		0x22, 0
	.dw 0x26c0, 0xc411,	0x26ff, 0xc411,		0x22, 0
	.dw 0x2900, 0xc411,	0x293f, 0xc411,		0x22, 0
	.dw 0x2b40, 0xc411,	0x2b7f, 0xc411,		0x22, 0
	.dw 0x2d80, 0xc411,	0x2dbf, 0xc411,		0x22, 0
	.dw 0x2fc0, 0xc411,	0x2fff, 0xc411,		0x22, 0
	.dw 0x3000, 0xc411,	0x3fff, 0xc411,		0x21, 0
	.dw 0x4000, 0xc411,	0x403f, 0xc411,		0x22, 0
	.dw 0x4240, 0xc411,	0x427f, 0xc411,		0x22, 0
	.dw 0x4480, 0xc411,	0x44bf, 0xc411,		0x22, 0
	.dw 0x46c0, 0xc411,	0x46ff, 0xc411,		0x22, 0
	.dw 0x4900, 0xc411,	0x493f, 0xc411,		0x22, 0
	.dw 0x4b40, 0xc411,	0x4b7f, 0xc411,		0x22, 0
	.dw 0x4d80, 0xc411,	0x4dbf, 0xc411,		0x22, 0
	.dw 0x4fc0, 0xc411,	0x4fff, 0xc411,		0x22, 0
	.dw 0x5000, 0xc411,	0x5fff, 0xc411,		0x21, 0
	.dw 0x6000, 0xc411,	0x603f, 0xc411,		0x22, 0
	.dw 0x6240, 0xc411,	0x627f, 0xc411,		0x22, 0
	.dw 0x6480, 0xc411,	0x64bf, 0xc411,		0x22, 0
	.dw 0x66c0, 0xc411,	0x66ff, 0xc411,		0x22, 0
	.dw 0x6900, 0xc411,	0x693f, 0xc411,		0x22, 0
	.dw 0x6b40, 0xc411,	0x6b7f, 0xc411,		0x22, 0
	.dw 0x6d80, 0xc411,	0x6dbf, 0xc411,		0x22, 0
	.dw 0x6fc0, 0xc411,	0x6fff, 0xc411,		0x22, 0
	.dw 0x7000, 0xc411,	0xffff, 0xc411,		0x21, 0
	.dw 0x0001, 0xc412,	0x0001, 0xc412,		0x21, 0
	.dw 0x0003, 0xc412,	0x000f, 0xc412,		0x21, 0
	.dw 0x0011, 0xc412,	0x0011, 0xc412,		0x21, 0
	.dw 0x0013, 0xc412,	0x003f, 0xc412,		0x21, 0
	.dw 0x0041, 0xc412,	0x0041, 0xc412,		0x21, 0
	.dw 0x0043, 0xc412,	0x004f, 0xc412,		0x21, 0
	.dw 0x0051, 0xc412,	0x0051, 0xc412,		0x21, 0
	.dw 0x0053, 0xc412,	0x007f, 0xc412,		0x21, 0
	.dw 0x0081, 0xc412,	0x0081, 0xc412,		0x21, 0
	.dw 0x0083, 0xc412,	0x008f, 0xc412,		0x21, 0
	.dw 0x0091, 0xc412,	0x0091, 0xc412,		0x21, 0
	.dw 0x0093, 0xc412,	0x00bf, 0xc412,		0x21, 0
	.dw 0x00c1, 0xc412,	0x00c1, 0xc412,		0x21, 0
	.dw 0x00c3, 0xc412,	0x00cf, 0xc412,		0x21, 0
	.dw 0x00d1, 0xc412,	0x00d1, 0xc412,		0x21, 0
	.dw 0x00d3, 0xc412,	0x00ff, 0xc412,		0x21, 0
	.dw 0x0101, 0xc412,	0x0101, 0xc412,		0x21, 0
	.dw 0x0103, 0xc412,	0x010f, 0xc412,		0x21, 0
	.dw 0x0111, 0xc412,	0x0111, 0xc412,		0x21, 0
	.dw 0x0113, 0xc412,	0x013f, 0xc412,		0x21, 0
	.dw 0x0141, 0xc412,	0x0141, 0xc412,		0x21, 0
	.dw 0x0143, 0xc412,	0x014f, 0xc412,		0x21, 0
	.dw 0x0151, 0xc412,	0x0151, 0xc412,		0x21, 0
	.dw 0x0153, 0xc412,	0x017f, 0xc412,		0x21, 0
	.dw 0x0181, 0xc412,	0x0181, 0xc412,		0x21, 0
	.dw 0x0183, 0xc412,	0x018f, 0xc412,		0x21, 0
	.dw 0x0191, 0xc412,	0x0191, 0xc412,		0x21, 0
	.dw 0x0193, 0xc412,	0x01bf, 0xc412,		0x21, 0
	.dw 0x01c1, 0xc412,	0x01c1, 0xc412,		0x21, 0
	.dw 0x01c3, 0xc412,	0x01cf, 0xc412,		0x21, 0
	.dw 0x01d1, 0xc412,	0x01d1, 0xc412,		0x21, 0
	.dw 0x01d3, 0xc412,	0x01ff, 0xc412,		0x21, 0
	.dw 0x0201, 0xc412,	0x0201, 0xc412,		0x21, 0
	.dw 0x0203, 0xc412,	0x020f, 0xc412,		0x21, 0
	.dw 0x0211, 0xc412,	0x0211, 0xc412,		0x21, 0
	.dw 0x0213, 0xc412,	0x023f, 0xc412,		0x21, 0
	.dw 0x0241, 0xc412,	0x0241, 0xc412,		0x21, 0
	.dw 0x0243, 0xc412,	0x024f, 0xc412,		0x21, 0
	.dw 0x0251, 0xc412,	0x0251, 0xc412,		0x21, 0
	.dw 0x0253, 0xc412,	0x027f, 0xc412,		0x21, 0
	.dw 0x0281, 0xc412,	0x0281, 0xc412,		0x21, 0
	.dw 0x0283, 0xc412,	0x028f, 0xc412,		0x21, 0
	.dw 0x0291, 0xc412,	0x0291, 0xc412,		0x21, 0
	.dw 0x0293, 0xc412,	0x02bf, 0xc412,		0x21, 0
	.dw 0x02c1, 0xc412,	0x02c1, 0xc412,		0x21, 0
	.dw 0x02c3, 0xc412,	0x02cf, 0xc412,		0x21, 0
	.dw 0x02d1, 0xc412,	0x02d1, 0xc412,		0x21, 0
	.dw 0x02d3, 0xc412,	0x02ff, 0xc412,		0x21, 0
	.dw 0x0301, 0xc412,	0x0301, 0xc412,		0x21, 0
	.dw 0x0303, 0xc412,	0x030f, 0xc412,		0x21, 0
	.dw 0x0311, 0xc412,	0x0311, 0xc412,		0x21, 0
	.dw 0x0313, 0xc412,	0x033f, 0xc412,		0x21, 0
	.dw 0x0341, 0xc412,	0x0341, 0xc412,		0x21, 0
	.dw 0x0343, 0xc412,	0x034f, 0xc412,		0x21, 0
	.dw 0x0351, 0xc412,	0x0351, 0xc412,		0x21, 0
	.dw 0x0353, 0xc412,	0x037f, 0xc412,		0x21, 0
	.dw 0x0381, 0xc412,	0x0381, 0xc412,		0x21, 0
	.dw 0x0383, 0xc412,	0x038f, 0xc412,		0x21, 0
	.dw 0x0391, 0xc412,	0x0391, 0xc412,		0x21, 0
	.dw 0x0393, 0xc412,	0x03bf, 0xc412,		0x21, 0
	.dw 0x03c1, 0xc412,	0x03c1, 0xc412,		0x21, 0
	.dw 0x03c3, 0xc412,	0x03cf, 0xc412,		0x21, 0
	.dw 0x03d1, 0xc412,	0x03d1, 0xc412,		0x21, 0
	.dw 0x03d3, 0xc412,	0x03ff, 0xc412,		0x21, 0
	.dw 0x0401, 0xc412,	0x0401, 0xc412,		0x21, 0
	.dw 0x0403, 0xc412,	0x040f, 0xc412,		0x21, 0
	.dw 0x0411, 0xc412,	0x0411, 0xc412,		0x21, 0
	.dw 0x0413, 0xc412,	0x043f, 0xc412,		0x21, 0
	.dw 0x0441, 0xc412,	0x0441, 0xc412,		0x21, 0
	.dw 0x0443, 0xc412,	0x044f, 0xc412,		0x21, 0
	.dw 0x0451, 0xc412,	0x0451, 0xc412,		0x21, 0
	.dw 0x0453, 0xc412,	0x047f, 0xc412,		0x21, 0
	.dw 0x0481, 0xc412,	0x0481, 0xc412,		0x21, 0
	.dw 0x0483, 0xc412,	0x048f, 0xc412,		0x21, 0
	.dw 0x0491, 0xc412,	0x0491, 0xc412,		0x21, 0
	.dw 0x0493, 0xc412,	0x04bf, 0xc412,		0x21, 0
	.dw 0x04c1, 0xc412,	0x04c1, 0xc412,		0x21, 0
	.dw 0x04c3, 0xc412,	0x04cf, 0xc412,		0x21, 0
	.dw 0x04d1, 0xc412,	0x04d1, 0xc412,		0x21, 0
	.dw 0x04d3, 0xc412,	0x04ff, 0xc412,		0x21, 0
	.dw 0x0501, 0xc412,	0x0501, 0xc412,		0x21, 0
	.dw 0x0503, 0xc412,	0x050f, 0xc412,		0x21, 0
	.dw 0x0511, 0xc412,	0x0511, 0xc412,		0x21, 0
	.dw 0x0513, 0xc412,	0x053f, 0xc412,		0x21, 0
	.dw 0x0541, 0xc412,	0x0541, 0xc412,		0x21, 0
	.dw 0x0543, 0xc412,	0x054f, 0xc412,		0x21, 0
	.dw 0x0551, 0xc412,	0x0551, 0xc412,		0x21, 0
	.dw 0x0553, 0xc412,	0x057f, 0xc412,		0x21, 0
	.dw 0x0581, 0xc412,	0x0581, 0xc412,		0x21, 0
	.dw 0x0583, 0xc412,	0x058f, 0xc412,		0x21, 0
	.dw 0x0591, 0xc412,	0x0591, 0xc412,		0x21, 0
	.dw 0x0593, 0xc412,	0x05bf, 0xc412,		0x21, 0
	.dw 0x05c1, 0xc412,	0x05c1, 0xc412,		0x21, 0
	.dw 0x05c3, 0xc412,	0x05cf, 0xc412,		0x21, 0
	.dw 0x05d1, 0xc412,	0x05d1, 0xc412,		0x21, 0
	.dw 0x05d3, 0xc412,	0x05ff, 0xc412,		0x21, 0
	.dw 0x0601, 0xc412,	0x0601, 0xc412,		0x21, 0
	.dw 0x0603, 0xc412,	0x060f, 0xc412,		0x21, 0
	.dw 0x0611, 0xc412,	0x0611, 0xc412,		0x21, 0
	.dw 0x0613, 0xc412,	0x063f, 0xc412,		0x21, 0
	.dw 0x0641, 0xc412,	0x0641, 0xc412,		0x21, 0
	.dw 0x0643, 0xc412,	0x064f, 0xc412,		0x21, 0
	.dw 0x0651, 0xc412,	0x0651, 0xc412,		0x21, 0
	.dw 0x0653, 0xc412,	0x067f, 0xc412,		0x21, 0
	.dw 0x0681, 0xc412,	0x0681, 0xc412,		0x21, 0
	.dw 0x0683, 0xc412,	0x068f, 0xc412,		0x21, 0
	.dw 0x0691, 0xc412,	0x0691, 0xc412,		0x21, 0
	.dw 0x0693, 0xc412,	0x06bf, 0xc412,		0x21, 0
	.dw 0x06c1, 0xc412,	0x06c1, 0xc412,		0x21, 0
	.dw 0x06c3, 0xc412,	0x06cf, 0xc412,		0x21, 0
	.dw 0x06d1, 0xc412,	0x06d1, 0xc412,		0x21, 0
	.dw 0x06d3, 0xc412,	0x06ff, 0xc412,		0x21, 0
	.dw 0x0701, 0xc412,	0x0701, 0xc412,		0x21, 0
	.dw 0x0703, 0xc412,	0x070f, 0xc412,		0x21, 0
	.dw 0x0711, 0xc412,	0x0711, 0xc412,		0x21, 0
	.dw 0x0713, 0xc412,	0x073f, 0xc412,		0x21, 0
	.dw 0x0741, 0xc412,	0x0741, 0xc412,		0x21, 0
	.dw 0x0743, 0xc412,	0x074f, 0xc412,		0x21, 0
	.dw 0x0751, 0xc412,	0x0751, 0xc412,		0x21, 0
	.dw 0x0753, 0xc412,	0x077f, 0xc412,		0x21, 0
	.dw 0x0781, 0xc412,	0x0781, 0xc412,		0x21, 0
	.dw 0x0783, 0xc412,	0x078f, 0xc412,		0x21, 0
	.dw 0x0791, 0xc412,	0x0791, 0xc412,		0x21, 0
	.dw 0x0793, 0xc412,	0x07bf, 0xc412,		0x21, 0
	.dw 0x07c1, 0xc412,	0x07c1, 0xc412,		0x21, 0
	.dw 0x07c3, 0xc412,	0x07cf, 0xc412,		0x21, 0
	.dw 0x07d1, 0xc412,	0x07d1, 0xc412,		0x21, 0
	.dw 0x07d3, 0xc412,	0x07ff, 0xc412,		0x21, 0
	.dw 0x0801, 0xc412,	0x0801, 0xc412,		0x21, 0
	.dw 0x0803, 0xc412,	0x080f, 0xc412,		0x21, 0
	.dw 0x0811, 0xc412,	0x0811, 0xc412,		0x21, 0
	.dw 0x0813, 0xc412,	0x083f, 0xc412,		0x21, 0
	.dw 0x0841, 0xc412,	0x0841, 0xc412,		0x21, 0
	.dw 0x0843, 0xc412,	0x084f, 0xc412,		0x21, 0
	.dw 0x0851, 0xc412,	0x0851, 0xc412,		0x21, 0
	.dw 0x0853, 0xc412,	0x087f, 0xc412,		0x21, 0
	.dw 0x0881, 0xc412,	0x0881, 0xc412,		0x21, 0
	.dw 0x0883, 0xc412,	0x088f, 0xc412,		0x21, 0
	.dw 0x0891, 0xc412,	0x0891, 0xc412,		0x21, 0
	.dw 0x0893, 0xc412,	0x08bf, 0xc412,		0x21, 0
	.dw 0x08c1, 0xc412,	0x08c1, 0xc412,		0x21, 0
	.dw 0x08c3, 0xc412,	0x08cf, 0xc412,		0x21, 0
	.dw 0x08d1, 0xc412,	0x08d1, 0xc412,		0x21, 0
	.dw 0x08d3, 0xc412,	0x08ff, 0xc412,		0x21, 0
	.dw 0x0901, 0xc412,	0x0901, 0xc412,		0x21, 0
	.dw 0x0903, 0xc412,	0x090f, 0xc412,		0x21, 0
	.dw 0x0911, 0xc412,	0x0911, 0xc412,		0x21, 0
	.dw 0x0913, 0xc412,	0x093f, 0xc412,		0x21, 0
	.dw 0x0941, 0xc412,	0x0941, 0xc412,		0x21, 0
	.dw 0x0943, 0xc412,	0x094f, 0xc412,		0x21, 0
	.dw 0x0951, 0xc412,	0x0951, 0xc412,		0x21, 0
	.dw 0x0953, 0xc412,	0x097f, 0xc412,		0x21, 0
	.dw 0x0981, 0xc412,	0x0981, 0xc412,		0x21, 0
	.dw 0x0983, 0xc412,	0x098f, 0xc412,		0x21, 0
	.dw 0x0991, 0xc412,	0x0991, 0xc412,		0x21, 0
	.dw 0x0993, 0xc412,	0x09bf, 0xc412,		0x21, 0
	.dw 0x09c1, 0xc412,	0x09c1, 0xc412,		0x21, 0
	.dw 0x09c3, 0xc412,	0x09cf, 0xc412,		0x21, 0
	.dw 0x09d1, 0xc412,	0x09d1, 0xc412,		0x21, 0
	.dw 0x09d3, 0xc412,	0x09ff, 0xc412,		0x21, 0
	.dw 0x0a01, 0xc412,	0x0a01, 0xc412,		0x21, 0
	.dw 0x0a03, 0xc412,	0x0a0f, 0xc412,		0x21, 0
	.dw 0x0a11, 0xc412,	0x0a11, 0xc412,		0x21, 0
	.dw 0x0a13, 0xc412,	0x0a3f, 0xc412,		0x21, 0
	.dw 0x0a41, 0xc412,	0x0a41, 0xc412,		0x21, 0
	.dw 0x0a43, 0xc412,	0x0a4f, 0xc412,		0x21, 0
	.dw 0x0a51, 0xc412,	0x0a51, 0xc412,		0x21, 0
	.dw 0x0a53, 0xc412,	0x0a7f, 0xc412,		0x21, 0
	.dw 0x0a81, 0xc412,	0x0a81, 0xc412,		0x21, 0
	.dw 0x0a83, 0xc412,	0x0a8f, 0xc412,		0x21, 0
	.dw 0x0a91, 0xc412,	0x0a91, 0xc412,		0x21, 0
	.dw 0x0a93, 0xc412,	0x0abf, 0xc412,		0x21, 0
	.dw 0x0ac1, 0xc412,	0x0ac1, 0xc412,		0x21, 0
	.dw 0x0ac3, 0xc412,	0x0acf, 0xc412,		0x21, 0
	.dw 0x0ad1, 0xc412,	0x0ad1, 0xc412,		0x21, 0
	.dw 0x0ad3, 0xc412,	0x0aff, 0xc412,		0x21, 0
	.dw 0x0b01, 0xc412,	0x0b01, 0xc412,		0x21, 0
	.dw 0x0b03, 0xc412,	0x0b0f, 0xc412,		0x21, 0
	.dw 0x0b11, 0xc412,	0x0b11, 0xc412,		0x21, 0
	.dw 0x0b13, 0xc412,	0x0b3f, 0xc412,		0x21, 0
	.dw 0x0b41, 0xc412,	0x0b41, 0xc412,		0x21, 0
	.dw 0x0b43, 0xc412,	0x0b4f, 0xc412,		0x21, 0
	.dw 0x0b51, 0xc412,	0x0b51, 0xc412,		0x21, 0
	.dw 0x0b53, 0xc412,	0x0b7f, 0xc412,		0x21, 0
	.dw 0x0b81, 0xc412,	0x0b81, 0xc412,		0x21, 0
	.dw 0x0b83, 0xc412,	0x0b8f, 0xc412,		0x21, 0
	.dw 0x0b91, 0xc412,	0x0b91, 0xc412,		0x21, 0
	.dw 0x0b93, 0xc412,	0x0bbf, 0xc412,		0x21, 0
	.dw 0x0bc1, 0xc412,	0x0bc1, 0xc412,		0x21, 0
	.dw 0x0bc3, 0xc412,	0x0bcf, 0xc412,		0x21, 0
	.dw 0x0bd1, 0xc412,	0x0bd1, 0xc412,		0x21, 0
	.dw 0x0bd3, 0xc412,	0x0bff, 0xc412,		0x21, 0
	.dw 0x0c01, 0xc412,	0x0c01, 0xc412,		0x21, 0
	.dw 0x0c03, 0xc412,	0x0c0f, 0xc412,		0x21, 0
	.dw 0x0c11, 0xc412,	0x0c11, 0xc412,		0x21, 0
	.dw 0x0c13, 0xc412,	0x0c3f, 0xc412,		0x21, 0
	.dw 0x0c41, 0xc412,	0x0c41, 0xc412,		0x21, 0
	.dw 0x0c43, 0xc412,	0x0c4f, 0xc412,		0x21, 0
	.dw 0x0c51, 0xc412,	0x0c51, 0xc412,		0x21, 0
	.dw 0x0c53, 0xc412,	0x0c7f, 0xc412,		0x21, 0
	.dw 0x0c81, 0xc412,	0x0c81, 0xc412,		0x21, 0
	.dw 0x0c83, 0xc412,	0x0c8f, 0xc412,		0x21, 0
	.dw 0x0c91, 0xc412,	0x0c91, 0xc412,		0x21, 0
	.dw 0x0c93, 0xc412,	0x0cbf, 0xc412,		0x21, 0
	.dw 0x0cc1, 0xc412,	0x0cc1, 0xc412,		0x21, 0
	.dw 0x0cc3, 0xc412,	0x0ccf, 0xc412,		0x21, 0
	.dw 0x0cd1, 0xc412,	0x0cd1, 0xc412,		0x21, 0
	.dw 0x0cd3, 0xc412,	0x0cff, 0xc412,		0x21, 0
	.dw 0x0d01, 0xc412,	0x0d01, 0xc412,		0x21, 0
	.dw 0x0d03, 0xc412,	0x0d0f, 0xc412,		0x21, 0
	.dw 0x0d11, 0xc412,	0x0d11, 0xc412,		0x21, 0
	.dw 0x0d13, 0xc412,	0x0d3f, 0xc412,		0x21, 0
	.dw 0x0d41, 0xc412,	0x0d41, 0xc412,		0x21, 0
	.dw 0x0d43, 0xc412,	0x0d4f, 0xc412,		0x21, 0
	.dw 0x0d51, 0xc412,	0x0d51, 0xc412,		0x21, 0
	.dw 0x0d53, 0xc412,	0x0d7f, 0xc412,		0x21, 0
	.dw 0x0d81, 0xc412,	0x0d81, 0xc412,		0x21, 0
	.dw 0x0d83, 0xc412,	0x0d8f, 0xc412,		0x21, 0
	.dw 0x0d91, 0xc412,	0x0d91, 0xc412,		0x21, 0
	.dw 0x0d93, 0xc412,	0x0dbf, 0xc412,		0x21, 0
	.dw 0x0dc1, 0xc412,	0x0dc1, 0xc412,		0x21, 0
	.dw 0x0dc3, 0xc412,	0x0dcf, 0xc412,		0x21, 0
	.dw 0x0dd1, 0xc412,	0x0dd1, 0xc412,		0x21, 0
	.dw 0x0dd3, 0xc412,	0x0dff, 0xc412,		0x21, 0
	.dw 0x0e01, 0xc412,	0x0e01, 0xc412,		0x21, 0
	.dw 0x0e03, 0xc412,	0x0e0f, 0xc412,		0x21, 0
	.dw 0x0e11, 0xc412,	0x0e11, 0xc412,		0x21, 0
	.dw 0x0e13, 0xc412,	0x0e3f, 0xc412,		0x21, 0
	.dw 0x0e41, 0xc412,	0x0e41, 0xc412,		0x21, 0
	.dw 0x0e43, 0xc412,	0x0e4f, 0xc412,		0x21, 0
	.dw 0x0e51, 0xc412,	0x0e51, 0xc412,		0x21, 0
	.dw 0x0e53, 0xc412,	0x0e7f, 0xc412,		0x21, 0
	.dw 0x0e81, 0xc412,	0x0e81, 0xc412,		0x21, 0
	.dw 0x0e83, 0xc412,	0x0e8f, 0xc412,		0x21, 0
	.dw 0x0e91, 0xc412,	0x0e91, 0xc412,		0x21, 0
	.dw 0x0e93, 0xc412,	0x0ebf, 0xc412,		0x21, 0
	.dw 0x0ec1, 0xc412,	0x0ec1, 0xc412,		0x21, 0
	.dw 0x0ec3, 0xc412,	0x0ecf, 0xc412,		0x21, 0
	.dw 0x0ed1, 0xc412,	0x0ed1, 0xc412,		0x21, 0
	.dw 0x0ed3, 0xc412,	0x0eff, 0xc412,		0x21, 0
	.dw 0x0f01, 0xc412,	0x0f01, 0xc412,		0x21, 0
	.dw 0x0f03, 0xc412,	0x0f0f, 0xc412,		0x21, 0
	.dw 0x0f11, 0xc412,	0x0f11, 0xc412,		0x21, 0
	.dw 0x0f13, 0xc412,	0x0f3f, 0xc412,		0x21, 0
	.dw 0x0f41, 0xc412,	0x0f41, 0xc412,		0x21, 0
	.dw 0x0f43, 0xc412,	0x0f4f, 0xc412,		0x21, 0
	.dw 0x0f51, 0xc412,	0x0f51, 0xc412,		0x21, 0
	.dw 0x0f53, 0xc412,	0x0f7f, 0xc412,		0x21, 0
	.dw 0x0f81, 0xc412,	0x0f81, 0xc412,		0x21, 0
	.dw 0x0f83, 0xc412,	0x0f8f, 0xc412,		0x21, 0
	.dw 0x0f91, 0xc412,	0x0f91, 0xc412,		0x21, 0
	.dw 0x0f93, 0xc412,	0x0fbf, 0xc412,		0x21, 0
	.dw 0x0fc1, 0xc412,	0x0fc1, 0xc412,		0x21, 0
	.dw 0x0fc3, 0xc412,	0x0fcf, 0xc412,		0x21, 0
	.dw 0x0fd1, 0xc412,	0x0fd1, 0xc412,		0x21, 0
	.dw 0x0fd3, 0xc412,	0x1fff, 0xc412,		0x21, 0
	.dw 0x2001, 0xc412,	0x2001, 0xc412,		0x21, 0
	.dw 0x2003, 0xc412,	0x200f, 0xc412,		0x21, 0
	.dw 0x2011, 0xc412,	0x2011, 0xc412,		0x21, 0
	.dw 0x2013, 0xc412,	0x203f, 0xc412,		0x21, 0
	.dw 0x2041, 0xc412,	0x2041, 0xc412,		0x21, 0
	.dw 0x2043, 0xc412,	0x204f, 0xc412,		0x21, 0
	.dw 0x2051, 0xc412,	0x2051, 0xc412,		0x21, 0
	.dw 0x2053, 0xc412,	0x207f, 0xc412,		0x21, 0
	.dw 0x2081, 0xc412,	0x2081, 0xc412,		0x21, 0
	.dw 0x2083, 0xc412,	0x208f, 0xc412,		0x21, 0
	.dw 0x2091, 0xc412,	0x2091, 0xc412,		0x21, 0
	.dw 0x2093, 0xc412,	0x20bf, 0xc412,		0x21, 0
	.dw 0x20c1, 0xc412,	0x20c1, 0xc412,		0x21, 0
	.dw 0x20c3, 0xc412,	0x20cf, 0xc412,		0x21, 0
	.dw 0x20d1, 0xc412,	0x20d1, 0xc412,		0x21, 0
	.dw 0x20d3, 0xc412,	0x20ff, 0xc412,		0x21, 0
	.dw 0x2101, 0xc412,	0x2101, 0xc412,		0x21, 0
	.dw 0x2103, 0xc412,	0x210f, 0xc412,		0x21, 0
	.dw 0x2111, 0xc412,	0x2111, 0xc412,		0x21, 0
	.dw 0x2113, 0xc412,	0x213f, 0xc412,		0x21, 0
	.dw 0x2141, 0xc412,	0x2141, 0xc412,		0x21, 0
	.dw 0x2143, 0xc412,	0x214f, 0xc412,		0x21, 0
	.dw 0x2151, 0xc412,	0x2151, 0xc412,		0x21, 0
	.dw 0x2153, 0xc412,	0x217f, 0xc412,		0x21, 0
	.dw 0x2181, 0xc412,	0x2181, 0xc412,		0x21, 0
	.dw 0x2183, 0xc412,	0x218f, 0xc412,		0x21, 0
	.dw 0x2191, 0xc412,	0x2191, 0xc412,		0x21, 0
	.dw 0x2193, 0xc412,	0x21bf, 0xc412,		0x21, 0
	.dw 0x21c1, 0xc412,	0x21c1, 0xc412,		0x21, 0
	.dw 0x21c3, 0xc412,	0x21cf, 0xc412,		0x21, 0
	.dw 0x21d1, 0xc412,	0x21d1, 0xc412,		0x21, 0
	.dw 0x21d3, 0xc412,	0x21ff, 0xc412,		0x21, 0
	.dw 0x2201, 0xc412,	0x2201, 0xc412,		0x21, 0
	.dw 0x2203, 0xc412,	0x220f, 0xc412,		0x21, 0
	.dw 0x2211, 0xc412,	0x2211, 0xc412,		0x21, 0
	.dw 0x2213, 0xc412,	0x223f, 0xc412,		0x21, 0
	.dw 0x2241, 0xc412,	0x2241, 0xc412,		0x21, 0
	.dw 0x2243, 0xc412,	0x224f, 0xc412,		0x21, 0
	.dw 0x2251, 0xc412,	0x2251, 0xc412,		0x21, 0
	.dw 0x2253, 0xc412,	0x227f, 0xc412,		0x21, 0
	.dw 0x2281, 0xc412,	0x2281, 0xc412,		0x21, 0
	.dw 0x2283, 0xc412,	0x228f, 0xc412,		0x21, 0
	.dw 0x2291, 0xc412,	0x2291, 0xc412,		0x21, 0
	.dw 0x2293, 0xc412,	0x22bf, 0xc412,		0x21, 0
	.dw 0x22c1, 0xc412,	0x22c1, 0xc412,		0x21, 0
	.dw 0x22c3, 0xc412,	0x22cf, 0xc412,		0x21, 0
	.dw 0x22d1, 0xc412,	0x22d1, 0xc412,		0x21, 0
	.dw 0x22d3, 0xc412,	0x22ff, 0xc412,		0x21, 0
	.dw 0x2301, 0xc412,	0x2301, 0xc412,		0x21, 0
	.dw 0x2303, 0xc412,	0x230f, 0xc412,		0x21, 0
	.dw 0x2311, 0xc412,	0x2311, 0xc412,		0x21, 0
	.dw 0x2313, 0xc412,	0x233f, 0xc412,		0x21, 0
	.dw 0x2341, 0xc412,	0x2341, 0xc412,		0x21, 0
	.dw 0x2343, 0xc412,	0x234f, 0xc412,		0x21, 0
	.dw 0x2351, 0xc412,	0x2351, 0xc412,		0x21, 0
	.dw 0x2353, 0xc412,	0x237f, 0xc412,		0x21, 0
	.dw 0x2381, 0xc412,	0x2381, 0xc412,		0x21, 0
	.dw 0x2383, 0xc412,	0x238f, 0xc412,		0x21, 0
	.dw 0x2391, 0xc412,	0x2391, 0xc412,		0x21, 0
	.dw 0x2393, 0xc412,	0x23bf, 0xc412,		0x21, 0
	.dw 0x23c1, 0xc412,	0x23c1, 0xc412,		0x21, 0
	.dw 0x23c3, 0xc412,	0x23cf, 0xc412,		0x21, 0
	.dw 0x23d1, 0xc412,	0x23d1, 0xc412,		0x21, 0
	.dw 0x23d3, 0xc412,	0x23ff, 0xc412,		0x21, 0
	.dw 0x2401, 0xc412,	0x2401, 0xc412,		0x21, 0
	.dw 0x2403, 0xc412,	0x240f, 0xc412,		0x21, 0
	.dw 0x2411, 0xc412,	0x2411, 0xc412,		0x21, 0
	.dw 0x2413, 0xc412,	0x243f, 0xc412,		0x21, 0
	.dw 0x2441, 0xc412,	0x2441, 0xc412,		0x21, 0
	.dw 0x2443, 0xc412,	0x244f, 0xc412,		0x21, 0
	.dw 0x2451, 0xc412,	0x2451, 0xc412,		0x21, 0
	.dw 0x2453, 0xc412,	0x247f, 0xc412,		0x21, 0
	.dw 0x2481, 0xc412,	0x2481, 0xc412,		0x21, 0
	.dw 0x2483, 0xc412,	0x248f, 0xc412,		0x21, 0
	.dw 0x2491, 0xc412,	0x2491, 0xc412,		0x21, 0
	.dw 0x2493, 0xc412,	0x24bf, 0xc412,		0x21, 0
	.dw 0x24c1, 0xc412,	0x24c1, 0xc412,		0x21, 0
	.dw 0x24c3, 0xc412,	0x24cf, 0xc412,		0x21, 0
	.dw 0x24d1, 0xc412,	0x24d1, 0xc412,		0x21, 0
	.dw 0x24d3, 0xc412,	0x24ff, 0xc412,		0x21, 0
	.dw 0x2501, 0xc412,	0x2501, 0xc412,		0x21, 0
	.dw 0x2503, 0xc412,	0x250f, 0xc412,		0x21, 0
	.dw 0x2511, 0xc412,	0x2511, 0xc412,		0x21, 0
	.dw 0x2513, 0xc412,	0x253f, 0xc412,		0x21, 0
	.dw 0x2541, 0xc412,	0x2541, 0xc412,		0x21, 0
	.dw 0x2543, 0xc412,	0x254f, 0xc412,		0x21, 0
	.dw 0x2551, 0xc412,	0x2551, 0xc412,		0x21, 0
	.dw 0x2553, 0xc412,	0x257f, 0xc412,		0x21, 0
	.dw 0x2581, 0xc412,	0x2581, 0xc412,		0x21, 0
	.dw 0x2583, 0xc412,	0x258f, 0xc412,		0x21, 0
	.dw 0x2591, 0xc412,	0x2591, 0xc412,		0x21, 0
	.dw 0x2593, 0xc412,	0x25bf, 0xc412,		0x21, 0
	.dw 0x25c1, 0xc412,	0x25c1, 0xc412,		0x21, 0
	.dw 0x25c3, 0xc412,	0x25cf, 0xc412,		0x21, 0
	.dw 0x25d1, 0xc412,	0x25d1, 0xc412,		0x21, 0
	.dw 0x25d3, 0xc412,	0x25ff, 0xc412,		0x21, 0
	.dw 0x2601, 0xc412,	0x2601, 0xc412,		0x21, 0
	.dw 0x2603, 0xc412,	0x260f, 0xc412,		0x21, 0
	.dw 0x2611, 0xc412,	0x2611, 0xc412,		0x21, 0
	.dw 0x2613, 0xc412,	0x263f, 0xc412,		0x21, 0
	.dw 0x2641, 0xc412,	0x2641, 0xc412,		0x21, 0
	.dw 0x2643, 0xc412,	0x264f, 0xc412,		0x21, 0
	.dw 0x2651, 0xc412,	0x2651, 0xc412,		0x21, 0
	.dw 0x2653, 0xc412,	0x267f, 0xc412,		0x21, 0
	.dw 0x2681, 0xc412,	0x2681, 0xc412,		0x21, 0
	.dw 0x2683, 0xc412,	0x268f, 0xc412,		0x21, 0
	.dw 0x2691, 0xc412,	0x2691, 0xc412,		0x21, 0
	.dw 0x2693, 0xc412,	0x26bf, 0xc412,		0x21, 0
	.dw 0x26c1, 0xc412,	0x26c1, 0xc412,		0x21, 0
	.dw 0x26c3, 0xc412,	0x26cf, 0xc412,		0x21, 0
	.dw 0x26d1, 0xc412,	0x26d1, 0xc412,		0x21, 0
	.dw 0x26d3, 0xc412,	0x26ff, 0xc412,		0x21, 0
	.dw 0x2701, 0xc412,	0x2701, 0xc412,		0x21, 0
	.dw 0x2703, 0xc412,	0x270f, 0xc412,		0x21, 0
	.dw 0x2711, 0xc412,	0x2711, 0xc412,		0x21, 0
	.dw 0x2713, 0xc412,	0x273f, 0xc412,		0x21, 0
	.dw 0x2741, 0xc412,	0x2741, 0xc412,		0x21, 0
	.dw 0x2743, 0xc412,	0x274f, 0xc412,		0x21, 0
	.dw 0x2751, 0xc412,	0x2751, 0xc412,		0x21, 0
	.dw 0x2753, 0xc412,	0x277f, 0xc412,		0x21, 0
	.dw 0x2781, 0xc412,	0x2781, 0xc412,		0x21, 0
	.dw 0x2783, 0xc412,	0x278f, 0xc412,		0x21, 0
	.dw 0x2791, 0xc412,	0x2791, 0xc412,		0x21, 0
	.dw 0x2793, 0xc412,	0x27bf, 0xc412,		0x21, 0
	.dw 0x27c1, 0xc412,	0x27c1, 0xc412,		0x21, 0
	.dw 0x27c3, 0xc412,	0x27cf, 0xc412,		0x21, 0
	.dw 0x27d1, 0xc412,	0x27d1, 0xc412,		0x21, 0
	.dw 0x27d3, 0xc412,	0x27ff, 0xc412,		0x21, 0
	.dw 0x2801, 0xc412,	0x2801, 0xc412,		0x21, 0
	.dw 0x2803, 0xc412,	0x280f, 0xc412,		0x21, 0
	.dw 0x2811, 0xc412,	0x2811, 0xc412,		0x21, 0
	.dw 0x2813, 0xc412,	0x283f, 0xc412,		0x21, 0
	.dw 0x2841, 0xc412,	0x2841, 0xc412,		0x21, 0
	.dw 0x2843, 0xc412,	0x284f, 0xc412,		0x21, 0
	.dw 0x2851, 0xc412,	0x2851, 0xc412,		0x21, 0
	.dw 0x2853, 0xc412,	0x287f, 0xc412,		0x21, 0
	.dw 0x2881, 0xc412,	0x2881, 0xc412,		0x21, 0
	.dw 0x2883, 0xc412,	0x288f, 0xc412,		0x21, 0
	.dw 0x2891, 0xc412,	0x2891, 0xc412,		0x21, 0
	.dw 0x2893, 0xc412,	0x28bf, 0xc412,		0x21, 0
	.dw 0x28c1, 0xc412,	0x28c1, 0xc412,		0x21, 0
	.dw 0x28c3, 0xc412,	0x28cf, 0xc412,		0x21, 0
	.dw 0x28d1, 0xc412,	0x28d1, 0xc412,		0x21, 0
	.dw 0x28d3, 0xc412,	0x28ff, 0xc412,		0x21, 0
	.dw 0x2901, 0xc412,	0x2901, 0xc412,		0x21, 0
	.dw 0x2903, 0xc412,	0x290f, 0xc412,		0x21, 0
	.dw 0x2911, 0xc412,	0x2911, 0xc412,		0x21, 0
	.dw 0x2913, 0xc412,	0x293f, 0xc412,		0x21, 0
	.dw 0x2941, 0xc412,	0x2941, 0xc412,		0x21, 0
	.dw 0x2943, 0xc412,	0x294f, 0xc412,		0x21, 0
	.dw 0x2951, 0xc412,	0x2951, 0xc412,		0x21, 0
	.dw 0x2953, 0xc412,	0x297f, 0xc412,		0x21, 0
	.dw 0x2981, 0xc412,	0x2981, 0xc412,		0x21, 0
	.dw 0x2983, 0xc412,	0x298f, 0xc412,		0x21, 0
	.dw 0x2991, 0xc412,	0x2991, 0xc412,		0x21, 0
	.dw 0x2993, 0xc412,	0x29bf, 0xc412,		0x21, 0
	.dw 0x29c1, 0xc412,	0x29c1, 0xc412,		0x21, 0
	.dw 0x29c3, 0xc412,	0x29cf, 0xc412,		0x21, 0
	.dw 0x29d1, 0xc412,	0x29d1, 0xc412,		0x21, 0
	.dw 0x29d3, 0xc412,	0x29ff, 0xc412,		0x21, 0
	.dw 0x2a01, 0xc412,	0x2a01, 0xc412,		0x21, 0
	.dw 0x2a03, 0xc412,	0x2a0f, 0xc412,		0x21, 0
	.dw 0x2a11, 0xc412,	0x2a11, 0xc412,		0x21, 0
	.dw 0x2a13, 0xc412,	0x2a3f, 0xc412,		0x21, 0
	.dw 0x2a41, 0xc412,	0x2a41, 0xc412,		0x21, 0
	.dw 0x2a43, 0xc412,	0x2a4f, 0xc412,		0x21, 0
	.dw 0x2a51, 0xc412,	0x2a51, 0xc412,		0x21, 0
	.dw 0x2a53, 0xc412,	0x2a7f, 0xc412,		0x21, 0
	.dw 0x2a81, 0xc412,	0x2a81, 0xc412,		0x21, 0
	.dw 0x2a83, 0xc412,	0x2a8f, 0xc412,		0x21, 0
	.dw 0x2a91, 0xc412,	0x2a91, 0xc412,		0x21, 0
	.dw 0x2a93, 0xc412,	0x2abf, 0xc412,		0x21, 0
	.dw 0x2ac1, 0xc412,	0x2ac1, 0xc412,		0x21, 0
	.dw 0x2ac3, 0xc412,	0x2acf, 0xc412,		0x21, 0
	.dw 0x2ad1, 0xc412,	0x2ad1, 0xc412,		0x21, 0
	.dw 0x2ad3, 0xc412,	0x2aff, 0xc412,		0x21, 0
	.dw 0x2b01, 0xc412,	0x2b01, 0xc412,		0x21, 0
	.dw 0x2b03, 0xc412,	0x2b0f, 0xc412,		0x21, 0
	.dw 0x2b11, 0xc412,	0x2b11, 0xc412,		0x21, 0
	.dw 0x2b13, 0xc412,	0x2b3f, 0xc412,		0x21, 0
	.dw 0x2b41, 0xc412,	0x2b41, 0xc412,		0x21, 0
	.dw 0x2b43, 0xc412,	0x2b4f, 0xc412,		0x21, 0
	.dw 0x2b51, 0xc412,	0x2b51, 0xc412,		0x21, 0
	.dw 0x2b53, 0xc412,	0x2b7f, 0xc412,		0x21, 0
	.dw 0x2b81, 0xc412,	0x2b81, 0xc412,		0x21, 0
	.dw 0x2b83, 0xc412,	0x2b8f, 0xc412,		0x21, 0
	.dw 0x2b91, 0xc412,	0x2b91, 0xc412,		0x21, 0
	.dw 0x2b93, 0xc412,	0x2bbf, 0xc412,		0x21, 0
	.dw 0x2bc1, 0xc412,	0x2bc1, 0xc412,		0x21, 0
	.dw 0x2bc3, 0xc412,	0x2bcf, 0xc412,		0x21, 0
	.dw 0x2bd1, 0xc412,	0x2bd1, 0xc412,		0x21, 0
	.dw 0x2bd3, 0xc412,	0x2bff, 0xc412,		0x21, 0
	.dw 0x2c01, 0xc412,	0x2c01, 0xc412,		0x21, 0
	.dw 0x2c03, 0xc412,	0x2c0f, 0xc412,		0x21, 0
	.dw 0x2c11, 0xc412,	0x2c11, 0xc412,		0x21, 0
	.dw 0x2c13, 0xc412,	0x2c3f, 0xc412,		0x21, 0
	.dw 0x2c41, 0xc412,	0x2c41, 0xc412,		0x21, 0
	.dw 0x2c43, 0xc412,	0x2c4f, 0xc412,		0x21, 0
	.dw 0x2c51, 0xc412,	0x2c51, 0xc412,		0x21, 0
	.dw 0x2c53, 0xc412,	0x2c7f, 0xc412,		0x21, 0
	.dw 0x2c81, 0xc412,	0x2c81, 0xc412,		0x21, 0
	.dw 0x2c83, 0xc412,	0x2c8f, 0xc412,		0x21, 0
	.dw 0x2c91, 0xc412,	0x2c91, 0xc412,		0x21, 0
	.dw 0x2c93, 0xc412,	0x2cbf, 0xc412,		0x21, 0
	.dw 0x2cc1, 0xc412,	0x2cc1, 0xc412,		0x21, 0
	.dw 0x2cc3, 0xc412,	0x2ccf, 0xc412,		0x21, 0
	.dw 0x2cd1, 0xc412,	0x2cd1, 0xc412,		0x21, 0
	.dw 0x2cd3, 0xc412,	0x2cff, 0xc412,		0x21, 0
	.dw 0x2d01, 0xc412,	0x2d01, 0xc412,		0x21, 0
	.dw 0x2d03, 0xc412,	0x2d0f, 0xc412,		0x21, 0
	.dw 0x2d11, 0xc412,	0x2d11, 0xc412,		0x21, 0
	.dw 0x2d13, 0xc412,	0x2d3f, 0xc412,		0x21, 0
	.dw 0x2d41, 0xc412,	0x2d41, 0xc412,		0x21, 0
	.dw 0x2d43, 0xc412,	0x2d4f, 0xc412,		0x21, 0
	.dw 0x2d51, 0xc412,	0x2d51, 0xc412,		0x21, 0
	.dw 0x2d53, 0xc412,	0x2d7f, 0xc412,		0x21, 0
	.dw 0x2d81, 0xc412,	0x2d81, 0xc412,		0x21, 0
	.dw 0x2d83, 0xc412,	0x2d8f, 0xc412,		0x21, 0
	.dw 0x2d91, 0xc412,	0x2d91, 0xc412,		0x21, 0
	.dw 0x2d93, 0xc412,	0x2dbf, 0xc412,		0x21, 0
	.dw 0x2dc1, 0xc412,	0x2dc1, 0xc412,		0x21, 0
	.dw 0x2dc3, 0xc412,	0x2dcf, 0xc412,		0x21, 0
	.dw 0x2dd1, 0xc412,	0x2dd1, 0xc412,		0x21, 0
	.dw 0x2dd3, 0xc412,	0x2dff, 0xc412,		0x21, 0
	.dw 0x2e01, 0xc412,	0x2e01, 0xc412,		0x21, 0
	.dw 0x2e03, 0xc412,	0x2e0f, 0xc412,		0x21, 0
	.dw 0x2e11, 0xc412,	0x2e11, 0xc412,		0x21, 0
	.dw 0x2e13, 0xc412,	0x2e3f, 0xc412,		0x21, 0
	.dw 0x2e41, 0xc412,	0x2e41, 0xc412,		0x21, 0
	.dw 0x2e43, 0xc412,	0x2e4f, 0xc412,		0x21, 0
	.dw 0x2e51, 0xc412,	0x2e51, 0xc412,		0x21, 0
	.dw 0x2e53, 0xc412,	0x2e7f, 0xc412,		0x21, 0
	.dw 0x2e81, 0xc412,	0x2e81, 0xc412,		0x21, 0
	.dw 0x2e83, 0xc412,	0x2e8f, 0xc412,		0x21, 0
	.dw 0x2e91, 0xc412,	0x2e91, 0xc412,		0x21, 0
	.dw 0x2e93, 0xc412,	0x2ebf, 0xc412,		0x21, 0
	.dw 0x2ec1, 0xc412,	0x2ec1, 0xc412,		0x21, 0
	.dw 0x2ec3, 0xc412,	0x2ecf, 0xc412,		0x21, 0
	.dw 0x2ed1, 0xc412,	0x2ed1, 0xc412,		0x21, 0
	.dw 0x2ed3, 0xc412,	0x2eff, 0xc412,		0x21, 0
	.dw 0x2f01, 0xc412,	0x2f01, 0xc412,		0x21, 0
	.dw 0x2f03, 0xc412,	0x2f0f, 0xc412,		0x21, 0
	.dw 0x2f11, 0xc412,	0x2f11, 0xc412,		0x21, 0
	.dw 0x2f13, 0xc412,	0x2f3f, 0xc412,		0x21, 0
	.dw 0x2f41, 0xc412,	0x2f41, 0xc412,		0x21, 0
	.dw 0x2f43, 0xc412,	0x2f4f, 0xc412,		0x21, 0
	.dw 0x2f51, 0xc412,	0x2f51, 0xc412,		0x21, 0
	.dw 0x2f53, 0xc412,	0x2f7f, 0xc412,		0x21, 0
	.dw 0x2f81, 0xc412,	0x2f81, 0xc412,		0x21, 0
	.dw 0x2f83, 0xc412,	0x2f8f, 0xc412,		0x21, 0
	.dw 0x2f91, 0xc412,	0x2f91, 0xc412,		0x21, 0
	.dw 0x2f93, 0xc412,	0x2fbf, 0xc412,		0x21, 0
	.dw 0x2fc1, 0xc412,	0x2fc1, 0xc412,		0x21, 0
	.dw 0x2fc3, 0xc412,	0x2fcf, 0xc412,		0x21, 0
	.dw 0x2fd1, 0xc412,	0x2fd1, 0xc412,		0x21, 0
	.dw 0x2fd3, 0xc412,	0xbfff, 0xc412,		0x21, 0
	.dw 0xd000, 0xc412,	0xffff, 0xc413,		0x21, 0
	.dw 0x0001, 0xc414,	0x0001, 0xc414,		0x21, 0
	.dw 0x0003, 0xc414,	0x000f, 0xc414,		0x21, 0
	.dw 0x0011, 0xc414,	0x0011, 0xc414,		0x21, 0
	.dw 0x0013, 0xc414,	0x003f, 0xc414,		0x21, 0
	.dw 0x0041, 0xc414,	0x0041, 0xc414,		0x21, 0
	.dw 0x0043, 0xc414,	0x004f, 0xc414,		0x21, 0
	.dw 0x0051, 0xc414,	0x0051, 0xc414,		0x21, 0
	.dw 0x0053, 0xc414,	0x007f, 0xc414,		0x21, 0
	.dw 0x0081, 0xc414,	0x0081, 0xc414,		0x21, 0
	.dw 0x0083, 0xc414,	0x008f, 0xc414,		0x21, 0
	.dw 0x0091, 0xc414,	0x0091, 0xc414,		0x21, 0
	.dw 0x0093, 0xc414,	0x00bf, 0xc414,		0x21, 0
	.dw 0x00c1, 0xc414,	0x00c1, 0xc414,		0x21, 0
	.dw 0x00c3, 0xc414,	0x00cf, 0xc414,		0x21, 0
	.dw 0x00d1, 0xc414,	0x00d1, 0xc414,		0x21, 0
	.dw 0x00d3, 0xc414,	0x00ff, 0xc414,		0x21, 0
	.dw 0x0101, 0xc414,	0x0101, 0xc414,		0x21, 0
	.dw 0x0103, 0xc414,	0x010f, 0xc414,		0x21, 0
	.dw 0x0111, 0xc414,	0x0111, 0xc414,		0x21, 0
	.dw 0x0113, 0xc414,	0x013f, 0xc414,		0x21, 0
	.dw 0x0141, 0xc414,	0x0141, 0xc414,		0x21, 0
	.dw 0x0143, 0xc414,	0x014f, 0xc414,		0x21, 0
	.dw 0x0151, 0xc414,	0x0151, 0xc414,		0x21, 0
	.dw 0x0153, 0xc414,	0x017f, 0xc414,		0x21, 0
	.dw 0x0181, 0xc414,	0x0181, 0xc414,		0x21, 0
	.dw 0x0183, 0xc414,	0x018f, 0xc414,		0x21, 0
	.dw 0x0191, 0xc414,	0x0191, 0xc414,		0x21, 0
	.dw 0x0193, 0xc414,	0x01bf, 0xc414,		0x21, 0
	.dw 0x01c1, 0xc414,	0x01c1, 0xc414,		0x21, 0
	.dw 0x01c3, 0xc414,	0x01cf, 0xc414,		0x21, 0
	.dw 0x01d1, 0xc414,	0x01d1, 0xc414,		0x21, 0
	.dw 0x01d3, 0xc414,	0x01ff, 0xc414,		0x21, 0
	.dw 0x0201, 0xc414,	0x0201, 0xc414,		0x21, 0
	.dw 0x0203, 0xc414,	0x020f, 0xc414,		0x21, 0
	.dw 0x0211, 0xc414,	0x0211, 0xc414,		0x21, 0
	.dw 0x0213, 0xc414,	0x023f, 0xc414,		0x21, 0
	.dw 0x0241, 0xc414,	0x0241, 0xc414,		0x21, 0
	.dw 0x0243, 0xc414,	0x024f, 0xc414,		0x21, 0
	.dw 0x0251, 0xc414,	0x0251, 0xc414,		0x21, 0
	.dw 0x0253, 0xc414,	0x027f, 0xc414,		0x21, 0
	.dw 0x0281, 0xc414,	0x0281, 0xc414,		0x21, 0
	.dw 0x0283, 0xc414,	0x028f, 0xc414,		0x21, 0
	.dw 0x0291, 0xc414,	0x0291, 0xc414,		0x21, 0
	.dw 0x0293, 0xc414,	0x02bf, 0xc414,		0x21, 0
	.dw 0x02c1, 0xc414,	0x02c1, 0xc414,		0x21, 0
	.dw 0x02c3, 0xc414,	0x02cf, 0xc414,		0x21, 0
	.dw 0x02d1, 0xc414,	0x02d1, 0xc414,		0x21, 0
	.dw 0x02d3, 0xc414,	0x02ff, 0xc414,		0x21, 0
	.dw 0x0301, 0xc414,	0x0301, 0xc414,		0x21, 0
	.dw 0x0303, 0xc414,	0x030f, 0xc414,		0x21, 0
	.dw 0x0311, 0xc414,	0x0311, 0xc414,		0x21, 0
	.dw 0x0313, 0xc414,	0x033f, 0xc414,		0x21, 0
	.dw 0x0341, 0xc414,	0x0341, 0xc414,		0x21, 0
	.dw 0x0343, 0xc414,	0x034f, 0xc414,		0x21, 0
	.dw 0x0351, 0xc414,	0x0351, 0xc414,		0x21, 0
	.dw 0x0353, 0xc414,	0x037f, 0xc414,		0x21, 0
	.dw 0x0381, 0xc414,	0x0381, 0xc414,		0x21, 0
	.dw 0x0383, 0xc414,	0x038f, 0xc414,		0x21, 0
	.dw 0x0391, 0xc414,	0x0391, 0xc414,		0x21, 0
	.dw 0x0393, 0xc414,	0x03bf, 0xc414,		0x21, 0
	.dw 0x03c1, 0xc414,	0x03c1, 0xc414,		0x21, 0
	.dw 0x03c3, 0xc414,	0x03cf, 0xc414,		0x21, 0
	.dw 0x03d1, 0xc414,	0x03d1, 0xc414,		0x21, 0
	.dw 0x03d3, 0xc414,	0x03ff, 0xc414,		0x21, 0
	.dw 0x0401, 0xc414,	0x0401, 0xc414,		0x21, 0
	.dw 0x0403, 0xc414,	0x040f, 0xc414,		0x21, 0
	.dw 0x0411, 0xc414,	0x0411, 0xc414,		0x21, 0
	.dw 0x0413, 0xc414,	0x043f, 0xc414,		0x21, 0
	.dw 0x0441, 0xc414,	0x0441, 0xc414,		0x21, 0
	.dw 0x0443, 0xc414,	0x044f, 0xc414,		0x21, 0
	.dw 0x0451, 0xc414,	0x0451, 0xc414,		0x21, 0
	.dw 0x0453, 0xc414,	0x047f, 0xc414,		0x21, 0
	.dw 0x0481, 0xc414,	0x0481, 0xc414,		0x21, 0
	.dw 0x0483, 0xc414,	0x048f, 0xc414,		0x21, 0
	.dw 0x0491, 0xc414,	0x0491, 0xc414,		0x21, 0
	.dw 0x0493, 0xc414,	0x04bf, 0xc414,		0x21, 0
	.dw 0x04c1, 0xc414,	0x04c1, 0xc414,		0x21, 0
	.dw 0x04c3, 0xc414,	0x04cf, 0xc414,		0x21, 0
	.dw 0x04d1, 0xc414,	0x04d1, 0xc414,		0x21, 0
	.dw 0x04d3, 0xc414,	0x04ff, 0xc414,		0x21, 0
	.dw 0x0501, 0xc414,	0x0501, 0xc414,		0x21, 0
	.dw 0x0503, 0xc414,	0x050f, 0xc414,		0x21, 0
	.dw 0x0511, 0xc414,	0x0511, 0xc414,		0x21, 0
	.dw 0x0513, 0xc414,	0x053f, 0xc414,		0x21, 0
	.dw 0x0541, 0xc414,	0x0541, 0xc414,		0x21, 0
	.dw 0x0543, 0xc414,	0x054f, 0xc414,		0x21, 0
	.dw 0x0551, 0xc414,	0x0551, 0xc414,		0x21, 0
	.dw 0x0553, 0xc414,	0x057f, 0xc414,		0x21, 0
	.dw 0x0581, 0xc414,	0x0581, 0xc414,		0x21, 0
	.dw 0x0583, 0xc414,	0x058f, 0xc414,		0x21, 0
	.dw 0x0591, 0xc414,	0x0591, 0xc414,		0x21, 0
	.dw 0x0593, 0xc414,	0x05bf, 0xc414,		0x21, 0
	.dw 0x05c1, 0xc414,	0x05c1, 0xc414,		0x21, 0
	.dw 0x05c3, 0xc414,	0x05cf, 0xc414,		0x21, 0
	.dw 0x05d1, 0xc414,	0x05d1, 0xc414,		0x21, 0
	.dw 0x05d3, 0xc414,	0x05ff, 0xc414,		0x21, 0
	.dw 0x0601, 0xc414,	0x0601, 0xc414,		0x21, 0
	.dw 0x0603, 0xc414,	0x060f, 0xc414,		0x21, 0
	.dw 0x0611, 0xc414,	0x0611, 0xc414,		0x21, 0
	.dw 0x0613, 0xc414,	0x063f, 0xc414,		0x21, 0
	.dw 0x0641, 0xc414,	0x0641, 0xc414,		0x21, 0
	.dw 0x0643, 0xc414,	0x064f, 0xc414,		0x21, 0
	.dw 0x0651, 0xc414,	0x0651, 0xc414,		0x21, 0
	.dw 0x0653, 0xc414,	0x067f, 0xc414,		0x21, 0
	.dw 0x0681, 0xc414,	0x0681, 0xc414,		0x21, 0
	.dw 0x0683, 0xc414,	0x068f, 0xc414,		0x21, 0
	.dw 0x0691, 0xc414,	0x0691, 0xc414,		0x21, 0
	.dw 0x0693, 0xc414,	0x06bf, 0xc414,		0x21, 0
	.dw 0x06c1, 0xc414,	0x06c1, 0xc414,		0x21, 0
	.dw 0x06c3, 0xc414,	0x06cf, 0xc414,		0x21, 0
	.dw 0x06d1, 0xc414,	0x06d1, 0xc414,		0x21, 0
	.dw 0x06d3, 0xc414,	0x06ff, 0xc414,		0x21, 0
	.dw 0x0701, 0xc414,	0x0701, 0xc414,		0x21, 0
	.dw 0x0703, 0xc414,	0x070f, 0xc414,		0x21, 0
	.dw 0x0711, 0xc414,	0x0711, 0xc414,		0x21, 0
	.dw 0x0713, 0xc414,	0x073f, 0xc414,		0x21, 0
	.dw 0x0741, 0xc414,	0x0741, 0xc414,		0x21, 0
	.dw 0x0743, 0xc414,	0x074f, 0xc414,		0x21, 0
	.dw 0x0751, 0xc414,	0x0751, 0xc414,		0x21, 0
	.dw 0x0753, 0xc414,	0x077f, 0xc414,		0x21, 0
	.dw 0x0781, 0xc414,	0x0781, 0xc414,		0x21, 0
	.dw 0x0783, 0xc414,	0x078f, 0xc414,		0x21, 0
	.dw 0x0791, 0xc414,	0x0791, 0xc414,		0x21, 0
	.dw 0x0793, 0xc414,	0x07bf, 0xc414,		0x21, 0
	.dw 0x07c1, 0xc414,	0x07c1, 0xc414,		0x21, 0
	.dw 0x07c3, 0xc414,	0x07cf, 0xc414,		0x21, 0
	.dw 0x07d1, 0xc414,	0x07d1, 0xc414,		0x21, 0
	.dw 0x07d3, 0xc414,	0x07ff, 0xc414,		0x21, 0
	.dw 0x0801, 0xc414,	0x0801, 0xc414,		0x21, 0
	.dw 0x0803, 0xc414,	0x080f, 0xc414,		0x21, 0
	.dw 0x0811, 0xc414,	0x0811, 0xc414,		0x21, 0
	.dw 0x0813, 0xc414,	0x083f, 0xc414,		0x21, 0
	.dw 0x0841, 0xc414,	0x0841, 0xc414,		0x21, 0
	.dw 0x0843, 0xc414,	0x084f, 0xc414,		0x21, 0
	.dw 0x0851, 0xc414,	0x0851, 0xc414,		0x21, 0
	.dw 0x0853, 0xc414,	0x087f, 0xc414,		0x21, 0
	.dw 0x0881, 0xc414,	0x0881, 0xc414,		0x21, 0
	.dw 0x0883, 0xc414,	0x088f, 0xc414,		0x21, 0
	.dw 0x0891, 0xc414,	0x0891, 0xc414,		0x21, 0
	.dw 0x0893, 0xc414,	0x08bf, 0xc414,		0x21, 0
	.dw 0x08c1, 0xc414,	0x08c1, 0xc414,		0x21, 0
	.dw 0x08c3, 0xc414,	0x08cf, 0xc414,		0x21, 0
	.dw 0x08d1, 0xc414,	0x08d1, 0xc414,		0x21, 0
	.dw 0x08d3, 0xc414,	0x08ff, 0xc414,		0x21, 0
	.dw 0x0901, 0xc414,	0x0901, 0xc414,		0x21, 0
	.dw 0x0903, 0xc414,	0x090f, 0xc414,		0x21, 0
	.dw 0x0911, 0xc414,	0x0911, 0xc414,		0x21, 0
	.dw 0x0913, 0xc414,	0x093f, 0xc414,		0x21, 0
	.dw 0x0941, 0xc414,	0x0941, 0xc414,		0x21, 0
	.dw 0x0943, 0xc414,	0x094f, 0xc414,		0x21, 0
	.dw 0x0951, 0xc414,	0x0951, 0xc414,		0x21, 0
	.dw 0x0953, 0xc414,	0x097f, 0xc414,		0x21, 0
	.dw 0x0981, 0xc414,	0x0981, 0xc414,		0x21, 0
	.dw 0x0983, 0xc414,	0x098f, 0xc414,		0x21, 0
	.dw 0x0991, 0xc414,	0x0991, 0xc414,		0x21, 0
	.dw 0x0993, 0xc414,	0x09bf, 0xc414,		0x21, 0
	.dw 0x09c1, 0xc414,	0x09c1, 0xc414,		0x21, 0
	.dw 0x09c3, 0xc414,	0x09cf, 0xc414,		0x21, 0
	.dw 0x09d1, 0xc414,	0x09d1, 0xc414,		0x21, 0
	.dw 0x09d3, 0xc414,	0x09ff, 0xc414,		0x21, 0
	.dw 0x0a01, 0xc414,	0x0a01, 0xc414,		0x21, 0
	.dw 0x0a03, 0xc414,	0x0a0f, 0xc414,		0x21, 0
	.dw 0x0a11, 0xc414,	0x0a11, 0xc414,		0x21, 0
	.dw 0x0a13, 0xc414,	0x0a3f, 0xc414,		0x21, 0
	.dw 0x0a41, 0xc414,	0x0a41, 0xc414,		0x21, 0
	.dw 0x0a43, 0xc414,	0x0a4f, 0xc414,		0x21, 0
	.dw 0x0a51, 0xc414,	0x0a51, 0xc414,		0x21, 0
	.dw 0x0a53, 0xc414,	0x0a7f, 0xc414,		0x21, 0
	.dw 0x0a81, 0xc414,	0x0a81, 0xc414,		0x21, 0
	.dw 0x0a83, 0xc414,	0x0a8f, 0xc414,		0x21, 0
	.dw 0x0a91, 0xc414,	0x0a91, 0xc414,		0x21, 0
	.dw 0x0a93, 0xc414,	0x0abf, 0xc414,		0x21, 0
	.dw 0x0ac1, 0xc414,	0x0ac1, 0xc414,		0x21, 0
	.dw 0x0ac3, 0xc414,	0x0acf, 0xc414,		0x21, 0
	.dw 0x0ad1, 0xc414,	0x0ad1, 0xc414,		0x21, 0
	.dw 0x0ad3, 0xc414,	0x0aff, 0xc414,		0x21, 0
	.dw 0x0b01, 0xc414,	0x0b01, 0xc414,		0x21, 0
	.dw 0x0b03, 0xc414,	0x0b0f, 0xc414,		0x21, 0
	.dw 0x0b11, 0xc414,	0x0b11, 0xc414,		0x21, 0
	.dw 0x0b13, 0xc414,	0x0b3f, 0xc414,		0x21, 0
	.dw 0x0b41, 0xc414,	0x0b41, 0xc414,		0x21, 0
	.dw 0x0b43, 0xc414,	0x0b4f, 0xc414,		0x21, 0
	.dw 0x0b51, 0xc414,	0x0b51, 0xc414,		0x21, 0
	.dw 0x0b53, 0xc414,	0x0b7f, 0xc414,		0x21, 0
	.dw 0x0b81, 0xc414,	0x0b81, 0xc414,		0x21, 0
	.dw 0x0b83, 0xc414,	0x0b8f, 0xc414,		0x21, 0
	.dw 0x0b91, 0xc414,	0x0b91, 0xc414,		0x21, 0
	.dw 0x0b93, 0xc414,	0x0bbf, 0xc414,		0x21, 0
	.dw 0x0bc1, 0xc414,	0x0bc1, 0xc414,		0x21, 0
	.dw 0x0bc3, 0xc414,	0x0bcf, 0xc414,		0x21, 0
	.dw 0x0bd1, 0xc414,	0x0bd1, 0xc414,		0x21, 0
	.dw 0x0bd3, 0xc414,	0x0bff, 0xc414,		0x21, 0
	.dw 0x0c01, 0xc414,	0x0c01, 0xc414,		0x21, 0
	.dw 0x0c03, 0xc414,	0x0c0f, 0xc414,		0x21, 0
	.dw 0x0c11, 0xc414,	0x0c11, 0xc414,		0x21, 0
	.dw 0x0c13, 0xc414,	0x0c3f, 0xc414,		0x21, 0
	.dw 0x0c41, 0xc414,	0x0c41, 0xc414,		0x21, 0
	.dw 0x0c43, 0xc414,	0x0c4f, 0xc414,		0x21, 0
	.dw 0x0c51, 0xc414,	0x0c51, 0xc414,		0x21, 0
	.dw 0x0c53, 0xc414,	0x0c7f, 0xc414,		0x21, 0
	.dw 0x0c81, 0xc414,	0x0c81, 0xc414,		0x21, 0
	.dw 0x0c83, 0xc414,	0x0c8f, 0xc414,		0x21, 0
	.dw 0x0c91, 0xc414,	0x0c91, 0xc414,		0x21, 0
	.dw 0x0c93, 0xc414,	0x0cbf, 0xc414,		0x21, 0
	.dw 0x0cc1, 0xc414,	0x0cc1, 0xc414,		0x21, 0
	.dw 0x0cc3, 0xc414,	0x0ccf, 0xc414,		0x21, 0
	.dw 0x0cd1, 0xc414,	0x0cd1, 0xc414,		0x21, 0
	.dw 0x0cd3, 0xc414,	0x0cff, 0xc414,		0x21, 0
	.dw 0x0d01, 0xc414,	0x0d01, 0xc414,		0x21, 0
	.dw 0x0d03, 0xc414,	0x0d0f, 0xc414,		0x21, 0
	.dw 0x0d11, 0xc414,	0x0d11, 0xc414,		0x21, 0
	.dw 0x0d13, 0xc414,	0x0d3f, 0xc414,		0x21, 0
	.dw 0x0d41, 0xc414,	0x0d41, 0xc414,		0x21, 0
	.dw 0x0d43, 0xc414,	0x0d4f, 0xc414,		0x21, 0
	.dw 0x0d51, 0xc414,	0x0d51, 0xc414,		0x21, 0
	.dw 0x0d53, 0xc414,	0x0d7f, 0xc414,		0x21, 0
	.dw 0x0d81, 0xc414,	0x0d81, 0xc414,		0x21, 0
	.dw 0x0d83, 0xc414,	0x0d8f, 0xc414,		0x21, 0
	.dw 0x0d91, 0xc414,	0x0d91, 0xc414,		0x21, 0
	.dw 0x0d93, 0xc414,	0x0dbf, 0xc414,		0x21, 0
	.dw 0x0dc1, 0xc414,	0x0dc1, 0xc414,		0x21, 0
	.dw 0x0dc3, 0xc414,	0x0dcf, 0xc414,		0x21, 0
	.dw 0x0dd1, 0xc414,	0x0dd1, 0xc414,		0x21, 0
	.dw 0x0dd3, 0xc414,	0x0dff, 0xc414,		0x21, 0
	.dw 0x0e01, 0xc414,	0x0e01, 0xc414,		0x21, 0
	.dw 0x0e03, 0xc414,	0x0e0f, 0xc414,		0x21, 0
	.dw 0x0e11, 0xc414,	0x0e11, 0xc414,		0x21, 0
	.dw 0x0e13, 0xc414,	0x0e3f, 0xc414,		0x21, 0
	.dw 0x0e41, 0xc414,	0x0e41, 0xc414,		0x21, 0
	.dw 0x0e43, 0xc414,	0x0e4f, 0xc414,		0x21, 0
	.dw 0x0e51, 0xc414,	0x0e51, 0xc414,		0x21, 0
	.dw 0x0e53, 0xc414,	0x0e7f, 0xc414,		0x21, 0
	.dw 0x0e81, 0xc414,	0x0e81, 0xc414,		0x21, 0
	.dw 0x0e83, 0xc414,	0x0e8f, 0xc414,		0x21, 0
	.dw 0x0e91, 0xc414,	0x0e91, 0xc414,		0x21, 0
	.dw 0x0e93, 0xc414,	0x0ebf, 0xc414,		0x21, 0
	.dw 0x0ec1, 0xc414,	0x0ec1, 0xc414,		0x21, 0
	.dw 0x0ec3, 0xc414,	0x0ecf, 0xc414,		0x21, 0
	.dw 0x0ed1, 0xc414,	0x0ed1, 0xc414,		0x21, 0
	.dw 0x0ed3, 0xc414,	0x0eff, 0xc414,		0x21, 0
	.dw 0x0f01, 0xc414,	0x0f01, 0xc414,		0x21, 0
	.dw 0x0f03, 0xc414,	0x0f0f, 0xc414,		0x21, 0
	.dw 0x0f11, 0xc414,	0x0f11, 0xc414,		0x21, 0
	.dw 0x0f13, 0xc414,	0x0f3f, 0xc414,		0x21, 0
	.dw 0x0f41, 0xc414,	0x0f41, 0xc414,		0x21, 0
	.dw 0x0f43, 0xc414,	0x0f4f, 0xc414,		0x21, 0
	.dw 0x0f51, 0xc414,	0x0f51, 0xc414,		0x21, 0
	.dw 0x0f53, 0xc414,	0x0f7f, 0xc414,		0x21, 0
	.dw 0x0f81, 0xc414,	0x0f81, 0xc414,		0x21, 0
	.dw 0x0f83, 0xc414,	0x0f8f, 0xc414,		0x21, 0
	.dw 0x0f91, 0xc414,	0x0f91, 0xc414,		0x21, 0
	.dw 0x0f93, 0xc414,	0x0fbf, 0xc414,		0x21, 0
	.dw 0x0fc1, 0xc414,	0x0fc1, 0xc414,		0x21, 0
	.dw 0x0fc3, 0xc414,	0x0fcf, 0xc414,		0x21, 0
	.dw 0x0fd1, 0xc414,	0x0fd1, 0xc414,		0x21, 0
	.dw 0x0fd3, 0xc414,	0x1fff, 0xc414,		0x21, 0
	.dw 0x2001, 0xc414,	0x2001, 0xc414,		0x21, 0
	.dw 0x2003, 0xc414,	0x200f, 0xc414,		0x21, 0
	.dw 0x2011, 0xc414,	0x2011, 0xc414,		0x21, 0
	.dw 0x2013, 0xc414,	0x203f, 0xc414,		0x21, 0
	.dw 0x2041, 0xc414,	0x2041, 0xc414,		0x21, 0
	.dw 0x2043, 0xc414,	0x204f, 0xc414,		0x21, 0
	.dw 0x2051, 0xc414,	0x2051, 0xc414,		0x21, 0
	.dw 0x2053, 0xc414,	0x207f, 0xc414,		0x21, 0
	.dw 0x2081, 0xc414,	0x2081, 0xc414,		0x21, 0
	.dw 0x2083, 0xc414,	0x208f, 0xc414,		0x21, 0
	.dw 0x2091, 0xc414,	0x2091, 0xc414,		0x21, 0
	.dw 0x2093, 0xc414,	0x20bf, 0xc414,		0x21, 0
	.dw 0x20c1, 0xc414,	0x20c1, 0xc414,		0x21, 0
	.dw 0x20c3, 0xc414,	0x20cf, 0xc414,		0x21, 0
	.dw 0x20d1, 0xc414,	0x20d1, 0xc414,		0x21, 0
	.dw 0x20d3, 0xc414,	0x20ff, 0xc414,		0x21, 0
	.dw 0x2101, 0xc414,	0x2101, 0xc414,		0x21, 0
	.dw 0x2103, 0xc414,	0x210f, 0xc414,		0x21, 0
	.dw 0x2111, 0xc414,	0x2111, 0xc414,		0x21, 0
	.dw 0x2113, 0xc414,	0x213f, 0xc414,		0x21, 0
	.dw 0x2141, 0xc414,	0x2141, 0xc414,		0x21, 0
	.dw 0x2143, 0xc414,	0x214f, 0xc414,		0x21, 0
	.dw 0x2151, 0xc414,	0x2151, 0xc414,		0x21, 0
	.dw 0x2153, 0xc414,	0x217f, 0xc414,		0x21, 0
	.dw 0x2181, 0xc414,	0x2181, 0xc414,		0x21, 0
	.dw 0x2183, 0xc414,	0x218f, 0xc414,		0x21, 0
	.dw 0x2191, 0xc414,	0x2191, 0xc414,		0x21, 0
	.dw 0x2193, 0xc414,	0x21bf, 0xc414,		0x21, 0
	.dw 0x21c1, 0xc414,	0x21c1, 0xc414,		0x21, 0
	.dw 0x21c3, 0xc414,	0x21cf, 0xc414,		0x21, 0
	.dw 0x21d1, 0xc414,	0x21d1, 0xc414,		0x21, 0
	.dw 0x21d3, 0xc414,	0x21ff, 0xc414,		0x21, 0
	.dw 0x2201, 0xc414,	0x2201, 0xc414,		0x21, 0
	.dw 0x2203, 0xc414,	0x220f, 0xc414,		0x21, 0
	.dw 0x2211, 0xc414,	0x2211, 0xc414,		0x21, 0
	.dw 0x2213, 0xc414,	0x223f, 0xc414,		0x21, 0
	.dw 0x2241, 0xc414,	0x2241, 0xc414,		0x21, 0
	.dw 0x2243, 0xc414,	0x224f, 0xc414,		0x21, 0
	.dw 0x2251, 0xc414,	0x2251, 0xc414,		0x21, 0
	.dw 0x2253, 0xc414,	0x227f, 0xc414,		0x21, 0
	.dw 0x2281, 0xc414,	0x2281, 0xc414,		0x21, 0
	.dw 0x2283, 0xc414,	0x228f, 0xc414,		0x21, 0
	.dw 0x2291, 0xc414,	0x2291, 0xc414,		0x21, 0
	.dw 0x2293, 0xc414,	0x22bf, 0xc414,		0x21, 0
	.dw 0x22c1, 0xc414,	0x22c1, 0xc414,		0x21, 0
	.dw 0x22c3, 0xc414,	0x22cf, 0xc414,		0x21, 0
	.dw 0x22d1, 0xc414,	0x22d1, 0xc414,		0x21, 0
	.dw 0x22d3, 0xc414,	0x22ff, 0xc414,		0x21, 0
	.dw 0x2301, 0xc414,	0x2301, 0xc414,		0x21, 0
	.dw 0x2303, 0xc414,	0x230f, 0xc414,		0x21, 0
	.dw 0x2311, 0xc414,	0x2311, 0xc414,		0x21, 0
	.dw 0x2313, 0xc414,	0x233f, 0xc414,		0x21, 0
	.dw 0x2341, 0xc414,	0x2341, 0xc414,		0x21, 0
	.dw 0x2343, 0xc414,	0x234f, 0xc414,		0x21, 0
	.dw 0x2351, 0xc414,	0x2351, 0xc414,		0x21, 0
	.dw 0x2353, 0xc414,	0x237f, 0xc414,		0x21, 0
	.dw 0x2381, 0xc414,	0x2381, 0xc414,		0x21, 0
	.dw 0x2383, 0xc414,	0x238f, 0xc414,		0x21, 0
	.dw 0x2391, 0xc414,	0x2391, 0xc414,		0x21, 0
	.dw 0x2393, 0xc414,	0x23bf, 0xc414,		0x21, 0
	.dw 0x23c1, 0xc414,	0x23c1, 0xc414,		0x21, 0
	.dw 0x23c3, 0xc414,	0x23cf, 0xc414,		0x21, 0
	.dw 0x23d1, 0xc414,	0x23d1, 0xc414,		0x21, 0
	.dw 0x23d3, 0xc414,	0x23ff, 0xc414,		0x21, 0
	.dw 0x2401, 0xc414,	0x2401, 0xc414,		0x21, 0
	.dw 0x2403, 0xc414,	0x240f, 0xc414,		0x21, 0
	.dw 0x2411, 0xc414,	0x2411, 0xc414,		0x21, 0
	.dw 0x2413, 0xc414,	0x243f, 0xc414,		0x21, 0
	.dw 0x2441, 0xc414,	0x2441, 0xc414,		0x21, 0
	.dw 0x2443, 0xc414,	0x244f, 0xc414,		0x21, 0
	.dw 0x2451, 0xc414,	0x2451, 0xc414,		0x21, 0
	.dw 0x2453, 0xc414,	0x247f, 0xc414,		0x21, 0
	.dw 0x2481, 0xc414,	0x2481, 0xc414,		0x21, 0
	.dw 0x2483, 0xc414,	0x248f, 0xc414,		0x21, 0
	.dw 0x2491, 0xc414,	0x2491, 0xc414,		0x21, 0
	.dw 0x2493, 0xc414,	0x24bf, 0xc414,		0x21, 0
	.dw 0x24c1, 0xc414,	0x24c1, 0xc414,		0x21, 0
	.dw 0x24c3, 0xc414,	0x24cf, 0xc414,		0x21, 0
	.dw 0x24d1, 0xc414,	0x24d1, 0xc414,		0x21, 0
	.dw 0x24d3, 0xc414,	0x24ff, 0xc414,		0x21, 0
	.dw 0x2501, 0xc414,	0x2501, 0xc414,		0x21, 0
	.dw 0x2503, 0xc414,	0x250f, 0xc414,		0x21, 0
	.dw 0x2511, 0xc414,	0x2511, 0xc414,		0x21, 0
	.dw 0x2513, 0xc414,	0x253f, 0xc414,		0x21, 0
	.dw 0x2541, 0xc414,	0x2541, 0xc414,		0x21, 0
	.dw 0x2543, 0xc414,	0x254f, 0xc414,		0x21, 0
	.dw 0x2551, 0xc414,	0x2551, 0xc414,		0x21, 0
	.dw 0x2553, 0xc414,	0x257f, 0xc414,		0x21, 0
	.dw 0x2581, 0xc414,	0x2581, 0xc414,		0x21, 0
	.dw 0x2583, 0xc414,	0x258f, 0xc414,		0x21, 0
	.dw 0x2591, 0xc414,	0x2591, 0xc414,		0x21, 0
	.dw 0x2593, 0xc414,	0x25bf, 0xc414,		0x21, 0
	.dw 0x25c1, 0xc414,	0x25c1, 0xc414,		0x21, 0
	.dw 0x25c3, 0xc414,	0x25cf, 0xc414,		0x21, 0
	.dw 0x25d1, 0xc414,	0x25d1, 0xc414,		0x21, 0
	.dw 0x25d3, 0xc414,	0x25ff, 0xc414,		0x21, 0
	.dw 0x2601, 0xc414,	0x2601, 0xc414,		0x21, 0
	.dw 0x2603, 0xc414,	0x260f, 0xc414,		0x21, 0
	.dw 0x2611, 0xc414,	0x2611, 0xc414,		0x21, 0
	.dw 0x2613, 0xc414,	0x263f, 0xc414,		0x21, 0
	.dw 0x2641, 0xc414,	0x2641, 0xc414,		0x21, 0
	.dw 0x2643, 0xc414,	0x264f, 0xc414,		0x21, 0
	.dw 0x2651, 0xc414,	0x2651, 0xc414,		0x21, 0
	.dw 0x2653, 0xc414,	0x267f, 0xc414,		0x21, 0
	.dw 0x2681, 0xc414,	0x2681, 0xc414,		0x21, 0
	.dw 0x2683, 0xc414,	0x268f, 0xc414,		0x21, 0
	.dw 0x2691, 0xc414,	0x2691, 0xc414,		0x21, 0
	.dw 0x2693, 0xc414,	0x26bf, 0xc414,		0x21, 0
	.dw 0x26c1, 0xc414,	0x26c1, 0xc414,		0x21, 0
	.dw 0x26c3, 0xc414,	0x26cf, 0xc414,		0x21, 0
	.dw 0x26d1, 0xc414,	0x26d1, 0xc414,		0x21, 0
	.dw 0x26d3, 0xc414,	0x26ff, 0xc414,		0x21, 0
	.dw 0x2701, 0xc414,	0x2701, 0xc414,		0x21, 0
	.dw 0x2703, 0xc414,	0x270f, 0xc414,		0x21, 0
	.dw 0x2711, 0xc414,	0x2711, 0xc414,		0x21, 0
	.dw 0x2713, 0xc414,	0x273f, 0xc414,		0x21, 0
	.dw 0x2741, 0xc414,	0x2741, 0xc414,		0x21, 0
	.dw 0x2743, 0xc414,	0x274f, 0xc414,		0x21, 0
	.dw 0x2751, 0xc414,	0x2751, 0xc414,		0x21, 0
	.dw 0x2753, 0xc414,	0x277f, 0xc414,		0x21, 0
	.dw 0x2781, 0xc414,	0x2781, 0xc414,		0x21, 0
	.dw 0x2783, 0xc414,	0x278f, 0xc414,		0x21, 0
	.dw 0x2791, 0xc414,	0x2791, 0xc414,		0x21, 0
	.dw 0x2793, 0xc414,	0x27bf, 0xc414,		0x21, 0
	.dw 0x27c1, 0xc414,	0x27c1, 0xc414,		0x21, 0
	.dw 0x27c3, 0xc414,	0x27cf, 0xc414,		0x21, 0
	.dw 0x27d1, 0xc414,	0x27d1, 0xc414,		0x21, 0
	.dw 0x27d3, 0xc414,	0x27ff, 0xc414,		0x21, 0
	.dw 0x2801, 0xc414,	0x2801, 0xc414,		0x21, 0
	.dw 0x2803, 0xc414,	0x280f, 0xc414,		0x21, 0
	.dw 0x2811, 0xc414,	0x2811, 0xc414,		0x21, 0
	.dw 0x2813, 0xc414,	0x283f, 0xc414,		0x21, 0
	.dw 0x2841, 0xc414,	0x2841, 0xc414,		0x21, 0
	.dw 0x2843, 0xc414,	0x284f, 0xc414,		0x21, 0
	.dw 0x2851, 0xc414,	0x2851, 0xc414,		0x21, 0
	.dw 0x2853, 0xc414,	0x287f, 0xc414,		0x21, 0
	.dw 0x2881, 0xc414,	0x2881, 0xc414,		0x21, 0
	.dw 0x2883, 0xc414,	0x288f, 0xc414,		0x21, 0
	.dw 0x2891, 0xc414,	0x2891, 0xc414,		0x21, 0
	.dw 0x2893, 0xc414,	0x28bf, 0xc414,		0x21, 0
	.dw 0x28c1, 0xc414,	0x28c1, 0xc414,		0x21, 0
	.dw 0x28c3, 0xc414,	0x28cf, 0xc414,		0x21, 0
	.dw 0x28d1, 0xc414,	0x28d1, 0xc414,		0x21, 0
	.dw 0x28d3, 0xc414,	0x28ff, 0xc414,		0x21, 0
	.dw 0x2901, 0xc414,	0x2901, 0xc414,		0x21, 0
	.dw 0x2903, 0xc414,	0x290f, 0xc414,		0x21, 0
	.dw 0x2911, 0xc414,	0x2911, 0xc414,		0x21, 0
	.dw 0x2913, 0xc414,	0x293f, 0xc414,		0x21, 0
	.dw 0x2941, 0xc414,	0x2941, 0xc414,		0x21, 0
	.dw 0x2943, 0xc414,	0x294f, 0xc414,		0x21, 0
	.dw 0x2951, 0xc414,	0x2951, 0xc414,		0x21, 0
	.dw 0x2953, 0xc414,	0x297f, 0xc414,		0x21, 0
	.dw 0x2981, 0xc414,	0x2981, 0xc414,		0x21, 0
	.dw 0x2983, 0xc414,	0x298f, 0xc414,		0x21, 0
	.dw 0x2991, 0xc414,	0x2991, 0xc414,		0x21, 0
	.dw 0x2993, 0xc414,	0x29bf, 0xc414,		0x21, 0
	.dw 0x29c1, 0xc414,	0x29c1, 0xc414,		0x21, 0
	.dw 0x29c3, 0xc414,	0x29cf, 0xc414,		0x21, 0
	.dw 0x29d1, 0xc414,	0x29d1, 0xc414,		0x21, 0
	.dw 0x29d3, 0xc414,	0x29ff, 0xc414,		0x21, 0
	.dw 0x2a01, 0xc414,	0x2a01, 0xc414,		0x21, 0
	.dw 0x2a03, 0xc414,	0x2a0f, 0xc414,		0x21, 0
	.dw 0x2a11, 0xc414,	0x2a11, 0xc414,		0x21, 0
	.dw 0x2a13, 0xc414,	0x2a3f, 0xc414,		0x21, 0
	.dw 0x2a41, 0xc414,	0x2a41, 0xc414,		0x21, 0
	.dw 0x2a43, 0xc414,	0x2a4f, 0xc414,		0x21, 0
	.dw 0x2a51, 0xc414,	0x2a51, 0xc414,		0x21, 0
	.dw 0x2a53, 0xc414,	0x2a7f, 0xc414,		0x21, 0
	.dw 0x2a81, 0xc414,	0x2a81, 0xc414,		0x21, 0
	.dw 0x2a83, 0xc414,	0x2a8f, 0xc414,		0x21, 0
	.dw 0x2a91, 0xc414,	0x2a91, 0xc414,		0x21, 0
	.dw 0x2a93, 0xc414,	0x2abf, 0xc414,		0x21, 0
	.dw 0x2ac1, 0xc414,	0x2ac1, 0xc414,		0x21, 0
	.dw 0x2ac3, 0xc414,	0x2acf, 0xc414,		0x21, 0
	.dw 0x2ad1, 0xc414,	0x2ad1, 0xc414,		0x21, 0
	.dw 0x2ad3, 0xc414,	0x2aff, 0xc414,		0x21, 0
	.dw 0x2b01, 0xc414,	0x2b01, 0xc414,		0x21, 0
	.dw 0x2b03, 0xc414,	0x2b0f, 0xc414,		0x21, 0
	.dw 0x2b11, 0xc414,	0x2b11, 0xc414,		0x21, 0
	.dw 0x2b13, 0xc414,	0x2b3f, 0xc414,		0x21, 0
	.dw 0x2b41, 0xc414,	0x2b41, 0xc414,		0x21, 0
	.dw 0x2b43, 0xc414,	0x2b4f, 0xc414,		0x21, 0
	.dw 0x2b51, 0xc414,	0x2b51, 0xc414,		0x21, 0
	.dw 0x2b53, 0xc414,	0x2b7f, 0xc414,		0x21, 0
	.dw 0x2b81, 0xc414,	0x2b81, 0xc414,		0x21, 0
	.dw 0x2b83, 0xc414,	0x2b8f, 0xc414,		0x21, 0
	.dw 0x2b91, 0xc414,	0x2b91, 0xc414,		0x21, 0
	.dw 0x2b93, 0xc414,	0x2bbf, 0xc414,		0x21, 0
	.dw 0x2bc1, 0xc414,	0x2bc1, 0xc414,		0x21, 0
	.dw 0x2bc3, 0xc414,	0x2bcf, 0xc414,		0x21, 0
	.dw 0x2bd1, 0xc414,	0x2bd1, 0xc414,		0x21, 0
	.dw 0x2bd3, 0xc414,	0x2bff, 0xc414,		0x21, 0
	.dw 0x2c01, 0xc414,	0x2c01, 0xc414,		0x21, 0
	.dw 0x2c03, 0xc414,	0x2c0f, 0xc414,		0x21, 0
	.dw 0x2c11, 0xc414,	0x2c11, 0xc414,		0x21, 0
	.dw 0x2c13, 0xc414,	0x2c3f, 0xc414,		0x21, 0
	.dw 0x2c41, 0xc414,	0x2c41, 0xc414,		0x21, 0
	.dw 0x2c43, 0xc414,	0x2c4f, 0xc414,		0x21, 0
	.dw 0x2c51, 0xc414,	0x2c51, 0xc414,		0x21, 0
	.dw 0x2c53, 0xc414,	0x2c7f, 0xc414,		0x21, 0
	.dw 0x2c81, 0xc414,	0x2c81, 0xc414,		0x21, 0
	.dw 0x2c83, 0xc414,	0x2c8f, 0xc414,		0x21, 0
	.dw 0x2c91, 0xc414,	0x2c91, 0xc414,		0x21, 0
	.dw 0x2c93, 0xc414,	0x2cbf, 0xc414,		0x21, 0
	.dw 0x2cc1, 0xc414,	0x2cc1, 0xc414,		0x21, 0
	.dw 0x2cc3, 0xc414,	0x2ccf, 0xc414,		0x21, 0
	.dw 0x2cd1, 0xc414,	0x2cd1, 0xc414,		0x21, 0
	.dw 0x2cd3, 0xc414,	0x2cff, 0xc414,		0x21, 0
	.dw 0x2d01, 0xc414,	0x2d01, 0xc414,		0x21, 0
	.dw 0x2d03, 0xc414,	0x2d0f, 0xc414,		0x21, 0
	.dw 0x2d11, 0xc414,	0x2d11, 0xc414,		0x21, 0
	.dw 0x2d13, 0xc414,	0x2d3f, 0xc414,		0x21, 0
	.dw 0x2d41, 0xc414,	0x2d41, 0xc414,		0x21, 0
	.dw 0x2d43, 0xc414,	0x2d4f, 0xc414,		0x21, 0
	.dw 0x2d51, 0xc414,	0x2d51, 0xc414,		0x21, 0
	.dw 0x2d53, 0xc414,	0x2d7f, 0xc414,		0x21, 0
	.dw 0x2d81, 0xc414,	0x2d81, 0xc414,		0x21, 0
	.dw 0x2d83, 0xc414,	0x2d8f, 0xc414,		0x21, 0
	.dw 0x2d91, 0xc414,	0x2d91, 0xc414,		0x21, 0
	.dw 0x2d93, 0xc414,	0x2dbf, 0xc414,		0x21, 0
	.dw 0x2dc1, 0xc414,	0x2dc1, 0xc414,		0x21, 0
	.dw 0x2dc3, 0xc414,	0x2dcf, 0xc414,		0x21, 0
	.dw 0x2dd1, 0xc414,	0x2dd1, 0xc414,		0x21, 0
	.dw 0x2dd3, 0xc414,	0x2dff, 0xc414,		0x21, 0
	.dw 0x2e01, 0xc414,	0x2e01, 0xc414,		0x21, 0
	.dw 0x2e03, 0xc414,	0x2e0f, 0xc414,		0x21, 0
	.dw 0x2e11, 0xc414,	0x2e11, 0xc414,		0x21, 0
	.dw 0x2e13, 0xc414,	0x2e3f, 0xc414,		0x21, 0
	.dw 0x2e41, 0xc414,	0x2e41, 0xc414,		0x21, 0
	.dw 0x2e43, 0xc414,	0x2e4f, 0xc414,		0x21, 0
	.dw 0x2e51, 0xc414,	0x2e51, 0xc414,		0x21, 0
	.dw 0x2e53, 0xc414,	0x2e7f, 0xc414,		0x21, 0
	.dw 0x2e81, 0xc414,	0x2e81, 0xc414,		0x21, 0
	.dw 0x2e83, 0xc414,	0x2e8f, 0xc414,		0x21, 0
	.dw 0x2e91, 0xc414,	0x2e91, 0xc414,		0x21, 0
	.dw 0x2e93, 0xc414,	0x2ebf, 0xc414,		0x21, 0
	.dw 0x2ec1, 0xc414,	0x2ec1, 0xc414,		0x21, 0
	.dw 0x2ec3, 0xc414,	0x2ecf, 0xc414,		0x21, 0
	.dw 0x2ed1, 0xc414,	0x2ed1, 0xc414,		0x21, 0
	.dw 0x2ed3, 0xc414,	0x2eff, 0xc414,		0x21, 0
	.dw 0x2f01, 0xc414,	0x2f01, 0xc414,		0x21, 0
	.dw 0x2f03, 0xc414,	0x2f0f, 0xc414,		0x21, 0
	.dw 0x2f11, 0xc414,	0x2f11, 0xc414,		0x21, 0
	.dw 0x2f13, 0xc414,	0x2f3f, 0xc414,		0x21, 0
	.dw 0x2f41, 0xc414,	0x2f41, 0xc414,		0x21, 0
	.dw 0x2f43, 0xc414,	0x2f4f, 0xc414,		0x21, 0
	.dw 0x2f51, 0xc414,	0x2f51, 0xc414,		0x21, 0
	.dw 0x2f53, 0xc414,	0x2f7f, 0xc414,		0x21, 0
	.dw 0x2f81, 0xc414,	0x2f81, 0xc414,		0x21, 0
	.dw 0x2f83, 0xc414,	0x2f8f, 0xc414,		0x21, 0
	.dw 0x2f91, 0xc414,	0x2f91, 0xc414,		0x21, 0
	.dw 0x2f93, 0xc414,	0x2fbf, 0xc414,		0x21, 0
	.dw 0x2fc1, 0xc414,	0x2fc1, 0xc414,		0x21, 0
	.dw 0x2fc3, 0xc414,	0x2fcf, 0xc414,		0x21, 0
	.dw 0x2fd1, 0xc414,	0x2fd1, 0xc414,		0x21, 0
	.dw 0x2fd3, 0xc414,	0x3fff, 0xc414,		0x21, 0
	.dw 0x4001, 0xc414,	0x4001, 0xc414,		0x21, 0
	.dw 0x4003, 0xc414,	0x400f, 0xc414,		0x21, 0
	.dw 0x4011, 0xc414,	0x4011, 0xc414,		0x21, 0
	.dw 0x4013, 0xc414,	0x403f, 0xc414,		0x21, 0
	.dw 0x4041, 0xc414,	0x4041, 0xc414,		0x21, 0
	.dw 0x4043, 0xc414,	0x404f, 0xc414,		0x21, 0
	.dw 0x4051, 0xc414,	0x4051, 0xc414,		0x21, 0
	.dw 0x4053, 0xc414,	0x407f, 0xc414,		0x21, 0
	.dw 0x4081, 0xc414,	0x4081, 0xc414,		0x21, 0
	.dw 0x4083, 0xc414,	0x408f, 0xc414,		0x21, 0
	.dw 0x4091, 0xc414,	0x4091, 0xc414,		0x21, 0
	.dw 0x4093, 0xc414,	0x40bf, 0xc414,		0x21, 0
	.dw 0x40c1, 0xc414,	0x40c1, 0xc414,		0x21, 0
	.dw 0x40c3, 0xc414,	0x40cf, 0xc414,		0x21, 0
	.dw 0x40d1, 0xc414,	0x40d1, 0xc414,		0x21, 0
	.dw 0x40d3, 0xc414,	0x40ff, 0xc414,		0x21, 0
	.dw 0x4101, 0xc414,	0x4101, 0xc414,		0x21, 0
	.dw 0x4103, 0xc414,	0x410f, 0xc414,		0x21, 0
	.dw 0x4111, 0xc414,	0x4111, 0xc414,		0x21, 0
	.dw 0x4113, 0xc414,	0x413f, 0xc414,		0x21, 0
	.dw 0x4141, 0xc414,	0x4141, 0xc414,		0x21, 0
	.dw 0x4143, 0xc414,	0x414f, 0xc414,		0x21, 0
	.dw 0x4151, 0xc414,	0x4151, 0xc414,		0x21, 0
	.dw 0x4153, 0xc414,	0x417f, 0xc414,		0x21, 0
	.dw 0x4181, 0xc414,	0x4181, 0xc414,		0x21, 0
	.dw 0x4183, 0xc414,	0x418f, 0xc414,		0x21, 0
	.dw 0x4191, 0xc414,	0x4191, 0xc414,		0x21, 0
	.dw 0x4193, 0xc414,	0x41bf, 0xc414,		0x21, 0
	.dw 0x41c1, 0xc414,	0x41c1, 0xc414,		0x21, 0
	.dw 0x41c3, 0xc414,	0x41cf, 0xc414,		0x21, 0
	.dw 0x41d1, 0xc414,	0x41d1, 0xc414,		0x21, 0
	.dw 0x41d3, 0xc414,	0x41ff, 0xc414,		0x21, 0
	.dw 0x4201, 0xc414,	0x4201, 0xc414,		0x21, 0
	.dw 0x4203, 0xc414,	0x420f, 0xc414,		0x21, 0
	.dw 0x4211, 0xc414,	0x4211, 0xc414,		0x21, 0
	.dw 0x4213, 0xc414,	0x423f, 0xc414,		0x21, 0
	.dw 0x4241, 0xc414,	0x4241, 0xc414,		0x21, 0
	.dw 0x4243, 0xc414,	0x424f, 0xc414,		0x21, 0
	.dw 0x4251, 0xc414,	0x4251, 0xc414,		0x21, 0
	.dw 0x4253, 0xc414,	0x427f, 0xc414,		0x21, 0
	.dw 0x4281, 0xc414,	0x4281, 0xc414,		0x21, 0
	.dw 0x4283, 0xc414,	0x428f, 0xc414,		0x21, 0
	.dw 0x4291, 0xc414,	0x4291, 0xc414,		0x21, 0
	.dw 0x4293, 0xc414,	0x42bf, 0xc414,		0x21, 0
	.dw 0x42c1, 0xc414,	0x42c1, 0xc414,		0x21, 0
	.dw 0x42c3, 0xc414,	0x42cf, 0xc414,		0x21, 0
	.dw 0x42d1, 0xc414,	0x42d1, 0xc414,		0x21, 0
	.dw 0x42d3, 0xc414,	0x42ff, 0xc414,		0x21, 0
	.dw 0x4301, 0xc414,	0x4301, 0xc414,		0x21, 0
	.dw 0x4303, 0xc414,	0x430f, 0xc414,		0x21, 0
	.dw 0x4311, 0xc414,	0x4311, 0xc414,		0x21, 0
	.dw 0x4313, 0xc414,	0x433f, 0xc414,		0x21, 0
	.dw 0x4341, 0xc414,	0x4341, 0xc414,		0x21, 0
	.dw 0x4343, 0xc414,	0x434f, 0xc414,		0x21, 0
	.dw 0x4351, 0xc414,	0x4351, 0xc414,		0x21, 0
	.dw 0x4353, 0xc414,	0x437f, 0xc414,		0x21, 0
	.dw 0x4381, 0xc414,	0x4381, 0xc414,		0x21, 0
	.dw 0x4383, 0xc414,	0x438f, 0xc414,		0x21, 0
	.dw 0x4391, 0xc414,	0x4391, 0xc414,		0x21, 0
	.dw 0x4393, 0xc414,	0x43bf, 0xc414,		0x21, 0
	.dw 0x43c1, 0xc414,	0x43c1, 0xc414,		0x21, 0
	.dw 0x43c3, 0xc414,	0x43cf, 0xc414,		0x21, 0
	.dw 0x43d1, 0xc414,	0x43d1, 0xc414,		0x21, 0
	.dw 0x43d3, 0xc414,	0x43ff, 0xc414,		0x21, 0
	.dw 0x4401, 0xc414,	0x4401, 0xc414,		0x21, 0
	.dw 0x4403, 0xc414,	0x440f, 0xc414,		0x21, 0
	.dw 0x4411, 0xc414,	0x4411, 0xc414,		0x21, 0
	.dw 0x4413, 0xc414,	0x443f, 0xc414,		0x21, 0
	.dw 0x4441, 0xc414,	0x4441, 0xc414,		0x21, 0
	.dw 0x4443, 0xc414,	0x444f, 0xc414,		0x21, 0
	.dw 0x4451, 0xc414,	0x4451, 0xc414,		0x21, 0
	.dw 0x4453, 0xc414,	0x447f, 0xc414,		0x21, 0
	.dw 0x4481, 0xc414,	0x4481, 0xc414,		0x21, 0
	.dw 0x4483, 0xc414,	0x448f, 0xc414,		0x21, 0
	.dw 0x4491, 0xc414,	0x4491, 0xc414,		0x21, 0
	.dw 0x4493, 0xc414,	0x44bf, 0xc414,		0x21, 0
	.dw 0x44c1, 0xc414,	0x44c1, 0xc414,		0x21, 0
	.dw 0x44c3, 0xc414,	0x44cf, 0xc414,		0x21, 0
	.dw 0x44d1, 0xc414,	0x44d1, 0xc414,		0x21, 0
	.dw 0x44d3, 0xc414,	0x44ff, 0xc414,		0x21, 0
	.dw 0x4501, 0xc414,	0x4501, 0xc414,		0x21, 0
	.dw 0x4503, 0xc414,	0x450f, 0xc414,		0x21, 0
	.dw 0x4511, 0xc414,	0x4511, 0xc414,		0x21, 0
	.dw 0x4513, 0xc414,	0x453f, 0xc414,		0x21, 0
	.dw 0x4541, 0xc414,	0x4541, 0xc414,		0x21, 0
	.dw 0x4543, 0xc414,	0x454f, 0xc414,		0x21, 0
	.dw 0x4551, 0xc414,	0x4551, 0xc414,		0x21, 0
	.dw 0x4553, 0xc414,	0x457f, 0xc414,		0x21, 0
	.dw 0x4581, 0xc414,	0x4581, 0xc414,		0x21, 0
	.dw 0x4583, 0xc414,	0x458f, 0xc414,		0x21, 0
	.dw 0x4591, 0xc414,	0x4591, 0xc414,		0x21, 0
	.dw 0x4593, 0xc414,	0x45bf, 0xc414,		0x21, 0
	.dw 0x45c1, 0xc414,	0x45c1, 0xc414,		0x21, 0
	.dw 0x45c3, 0xc414,	0x45cf, 0xc414,		0x21, 0
	.dw 0x45d1, 0xc414,	0x45d1, 0xc414,		0x21, 0
	.dw 0x45d3, 0xc414,	0x45ff, 0xc414,		0x21, 0
	.dw 0x4601, 0xc414,	0x4601, 0xc414,		0x21, 0
	.dw 0x4603, 0xc414,	0x460f, 0xc414,		0x21, 0
	.dw 0x4611, 0xc414,	0x4611, 0xc414,		0x21, 0
	.dw 0x4613, 0xc414,	0x463f, 0xc414,		0x21, 0
	.dw 0x4641, 0xc414,	0x4641, 0xc414,		0x21, 0
	.dw 0x4643, 0xc414,	0x464f, 0xc414,		0x21, 0
	.dw 0x4651, 0xc414,	0x4651, 0xc414,		0x21, 0
	.dw 0x4653, 0xc414,	0x467f, 0xc414,		0x21, 0
	.dw 0x4681, 0xc414,	0x4681, 0xc414,		0x21, 0
	.dw 0x4683, 0xc414,	0x468f, 0xc414,		0x21, 0
	.dw 0x4691, 0xc414,	0x4691, 0xc414,		0x21, 0
	.dw 0x4693, 0xc414,	0x46bf, 0xc414,		0x21, 0
	.dw 0x46c1, 0xc414,	0x46c1, 0xc414,		0x21, 0
	.dw 0x46c3, 0xc414,	0x46cf, 0xc414,		0x21, 0
	.dw 0x46d1, 0xc414,	0x46d1, 0xc414,		0x21, 0
	.dw 0x46d3, 0xc414,	0x46ff, 0xc414,		0x21, 0
	.dw 0x4701, 0xc414,	0x4701, 0xc414,		0x21, 0
	.dw 0x4703, 0xc414,	0x470f, 0xc414,		0x21, 0
	.dw 0x4711, 0xc414,	0x4711, 0xc414,		0x21, 0
	.dw 0x4713, 0xc414,	0x473f, 0xc414,		0x21, 0
	.dw 0x4741, 0xc414,	0x4741, 0xc414,		0x21, 0
	.dw 0x4743, 0xc414,	0x474f, 0xc414,		0x21, 0
	.dw 0x4751, 0xc414,	0x4751, 0xc414,		0x21, 0
	.dw 0x4753, 0xc414,	0x477f, 0xc414,		0x21, 0
	.dw 0x4781, 0xc414,	0x4781, 0xc414,		0x21, 0
	.dw 0x4783, 0xc414,	0x478f, 0xc414,		0x21, 0
	.dw 0x4791, 0xc414,	0x4791, 0xc414,		0x21, 0
	.dw 0x4793, 0xc414,	0x47bf, 0xc414,		0x21, 0
	.dw 0x47c1, 0xc414,	0x47c1, 0xc414,		0x21, 0
	.dw 0x47c3, 0xc414,	0x47cf, 0xc414,		0x21, 0
	.dw 0x47d1, 0xc414,	0x47d1, 0xc414,		0x21, 0
	.dw 0x47d3, 0xc414,	0x47ff, 0xc414,		0x21, 0
	.dw 0x4801, 0xc414,	0x4801, 0xc414,		0x21, 0
	.dw 0x4803, 0xc414,	0x480f, 0xc414,		0x21, 0
	.dw 0x4811, 0xc414,	0x4811, 0xc414,		0x21, 0
	.dw 0x4813, 0xc414,	0x483f, 0xc414,		0x21, 0
	.dw 0x4841, 0xc414,	0x4841, 0xc414,		0x21, 0
	.dw 0x4843, 0xc414,	0x484f, 0xc414,		0x21, 0
	.dw 0x4851, 0xc414,	0x4851, 0xc414,		0x21, 0
	.dw 0x4853, 0xc414,	0x487f, 0xc414,		0x21, 0
	.dw 0x4881, 0xc414,	0x4881, 0xc414,		0x21, 0
	.dw 0x4883, 0xc414,	0x488f, 0xc414,		0x21, 0
	.dw 0x4891, 0xc414,	0x4891, 0xc414,		0x21, 0
	.dw 0x4893, 0xc414,	0x48bf, 0xc414,		0x21, 0
	.dw 0x48c1, 0xc414,	0x48c1, 0xc414,		0x21, 0
	.dw 0x48c3, 0xc414,	0x48cf, 0xc414,		0x21, 0
	.dw 0x48d1, 0xc414,	0x48d1, 0xc414,		0x21, 0
	.dw 0x48d3, 0xc414,	0x48ff, 0xc414,		0x21, 0
	.dw 0x4901, 0xc414,	0x4901, 0xc414,		0x21, 0
	.dw 0x4903, 0xc414,	0x490f, 0xc414,		0x21, 0
	.dw 0x4911, 0xc414,	0x4911, 0xc414,		0x21, 0
	.dw 0x4913, 0xc414,	0x493f, 0xc414,		0x21, 0
	.dw 0x4941, 0xc414,	0x4941, 0xc414,		0x21, 0
	.dw 0x4943, 0xc414,	0x494f, 0xc414,		0x21, 0
	.dw 0x4951, 0xc414,	0x4951, 0xc414,		0x21, 0
	.dw 0x4953, 0xc414,	0x497f, 0xc414,		0x21, 0
	.dw 0x4981, 0xc414,	0x4981, 0xc414,		0x21, 0
	.dw 0x4983, 0xc414,	0x498f, 0xc414,		0x21, 0
	.dw 0x4991, 0xc414,	0x4991, 0xc414,		0x21, 0
	.dw 0x4993, 0xc414,	0x49bf, 0xc414,		0x21, 0
	.dw 0x49c1, 0xc414,	0x49c1, 0xc414,		0x21, 0
	.dw 0x49c3, 0xc414,	0x49cf, 0xc414,		0x21, 0
	.dw 0x49d1, 0xc414,	0x49d1, 0xc414,		0x21, 0
	.dw 0x49d3, 0xc414,	0x49ff, 0xc414,		0x21, 0
	.dw 0x4a01, 0xc414,	0x4a01, 0xc414,		0x21, 0
	.dw 0x4a03, 0xc414,	0x4a0f, 0xc414,		0x21, 0
	.dw 0x4a11, 0xc414,	0x4a11, 0xc414,		0x21, 0
	.dw 0x4a13, 0xc414,	0x4a3f, 0xc414,		0x21, 0
	.dw 0x4a41, 0xc414,	0x4a41, 0xc414,		0x21, 0
	.dw 0x4a43, 0xc414,	0x4a4f, 0xc414,		0x21, 0
	.dw 0x4a51, 0xc414,	0x4a51, 0xc414,		0x21, 0
	.dw 0x4a53, 0xc414,	0x4a7f, 0xc414,		0x21, 0
	.dw 0x4a81, 0xc414,	0x4a81, 0xc414,		0x21, 0
	.dw 0x4a83, 0xc414,	0x4a8f, 0xc414,		0x21, 0
	.dw 0x4a91, 0xc414,	0x4a91, 0xc414,		0x21, 0
	.dw 0x4a93, 0xc414,	0x4abf, 0xc414,		0x21, 0
	.dw 0x4ac1, 0xc414,	0x4ac1, 0xc414,		0x21, 0
	.dw 0x4ac3, 0xc414,	0x4acf, 0xc414,		0x21, 0
	.dw 0x4ad1, 0xc414,	0x4ad1, 0xc414,		0x21, 0
	.dw 0x4ad3, 0xc414,	0x4aff, 0xc414,		0x21, 0
	.dw 0x4b01, 0xc414,	0x4b01, 0xc414,		0x21, 0
	.dw 0x4b03, 0xc414,	0x4b0f, 0xc414,		0x21, 0
	.dw 0x4b11, 0xc414,	0x4b11, 0xc414,		0x21, 0
	.dw 0x4b13, 0xc414,	0x4b3f, 0xc414,		0x21, 0
	.dw 0x4b41, 0xc414,	0x4b41, 0xc414,		0x21, 0
	.dw 0x4b43, 0xc414,	0x4b4f, 0xc414,		0x21, 0
	.dw 0x4b51, 0xc414,	0x4b51, 0xc414,		0x21, 0
	.dw 0x4b53, 0xc414,	0x4b7f, 0xc414,		0x21, 0
	.dw 0x4b81, 0xc414,	0x4b81, 0xc414,		0x21, 0
	.dw 0x4b83, 0xc414,	0x4b8f, 0xc414,		0x21, 0
	.dw 0x4b91, 0xc414,	0x4b91, 0xc414,		0x21, 0
	.dw 0x4b93, 0xc414,	0x4bbf, 0xc414,		0x21, 0
	.dw 0x4bc1, 0xc414,	0x4bc1, 0xc414,		0x21, 0
	.dw 0x4bc3, 0xc414,	0x4bcf, 0xc414,		0x21, 0
	.dw 0x4bd1, 0xc414,	0x4bd1, 0xc414,		0x21, 0
	.dw 0x4bd3, 0xc414,	0x4bff, 0xc414,		0x21, 0
	.dw 0x4c01, 0xc414,	0x4c01, 0xc414,		0x21, 0
	.dw 0x4c03, 0xc414,	0x4c0f, 0xc414,		0x21, 0
	.dw 0x4c11, 0xc414,	0x4c11, 0xc414,		0x21, 0
	.dw 0x4c13, 0xc414,	0x4c3f, 0xc414,		0x21, 0
	.dw 0x4c41, 0xc414,	0x4c41, 0xc414,		0x21, 0
	.dw 0x4c43, 0xc414,	0x4c4f, 0xc414,		0x21, 0
	.dw 0x4c51, 0xc414,	0x4c51, 0xc414,		0x21, 0
	.dw 0x4c53, 0xc414,	0x4c7f, 0xc414,		0x21, 0
	.dw 0x4c81, 0xc414,	0x4c81, 0xc414,		0x21, 0
	.dw 0x4c83, 0xc414,	0x4c8f, 0xc414,		0x21, 0
	.dw 0x4c91, 0xc414,	0x4c91, 0xc414,		0x21, 0
	.dw 0x4c93, 0xc414,	0x4cbf, 0xc414,		0x21, 0
	.dw 0x4cc1, 0xc414,	0x4cc1, 0xc414,		0x21, 0
	.dw 0x4cc3, 0xc414,	0x4ccf, 0xc414,		0x21, 0
	.dw 0x4cd1, 0xc414,	0x4cd1, 0xc414,		0x21, 0
	.dw 0x4cd3, 0xc414,	0x4cff, 0xc414,		0x21, 0
	.dw 0x4d01, 0xc414,	0x4d01, 0xc414,		0x21, 0
	.dw 0x4d03, 0xc414,	0x4d0f, 0xc414,		0x21, 0
	.dw 0x4d11, 0xc414,	0x4d11, 0xc414,		0x21, 0
	.dw 0x4d13, 0xc414,	0x4d3f, 0xc414,		0x21, 0
	.dw 0x4d41, 0xc414,	0x4d41, 0xc414,		0x21, 0
	.dw 0x4d43, 0xc414,	0x4d4f, 0xc414,		0x21, 0
	.dw 0x4d51, 0xc414,	0x4d51, 0xc414,		0x21, 0
	.dw 0x4d53, 0xc414,	0x4d7f, 0xc414,		0x21, 0
	.dw 0x4d81, 0xc414,	0x4d81, 0xc414,		0x21, 0
	.dw 0x4d83, 0xc414,	0x4d8f, 0xc414,		0x21, 0
	.dw 0x4d91, 0xc414,	0x4d91, 0xc414,		0x21, 0
	.dw 0x4d93, 0xc414,	0x4dbf, 0xc414,		0x21, 0
	.dw 0x4dc1, 0xc414,	0x4dc1, 0xc414,		0x21, 0
	.dw 0x4dc3, 0xc414,	0x4dcf, 0xc414,		0x21, 0
	.dw 0x4dd1, 0xc414,	0x4dd1, 0xc414,		0x21, 0
	.dw 0x4dd3, 0xc414,	0x4dff, 0xc414,		0x21, 0
	.dw 0x4e01, 0xc414,	0x4e01, 0xc414,		0x21, 0
	.dw 0x4e03, 0xc414,	0x4e0f, 0xc414,		0x21, 0
	.dw 0x4e11, 0xc414,	0x4e11, 0xc414,		0x21, 0
	.dw 0x4e13, 0xc414,	0x4e3f, 0xc414,		0x21, 0
	.dw 0x4e41, 0xc414,	0x4e41, 0xc414,		0x21, 0
	.dw 0x4e43, 0xc414,	0x4e4f, 0xc414,		0x21, 0
	.dw 0x4e51, 0xc414,	0x4e51, 0xc414,		0x21, 0
	.dw 0x4e53, 0xc414,	0x4e7f, 0xc414,		0x21, 0
	.dw 0x4e81, 0xc414,	0x4e81, 0xc414,		0x21, 0
	.dw 0x4e83, 0xc414,	0x4e8f, 0xc414,		0x21, 0
	.dw 0x4e91, 0xc414,	0x4e91, 0xc414,		0x21, 0
	.dw 0x4e93, 0xc414,	0x4ebf, 0xc414,		0x21, 0
	.dw 0x4ec1, 0xc414,	0x4ec1, 0xc414,		0x21, 0
	.dw 0x4ec3, 0xc414,	0x4ecf, 0xc414,		0x21, 0
	.dw 0x4ed1, 0xc414,	0x4ed1, 0xc414,		0x21, 0
	.dw 0x4ed3, 0xc414,	0x4eff, 0xc414,		0x21, 0
	.dw 0x4f01, 0xc414,	0x4f01, 0xc414,		0x21, 0
	.dw 0x4f03, 0xc414,	0x4f0f, 0xc414,		0x21, 0
	.dw 0x4f11, 0xc414,	0x4f11, 0xc414,		0x21, 0
	.dw 0x4f13, 0xc414,	0x4f3f, 0xc414,		0x21, 0
	.dw 0x4f41, 0xc414,	0x4f41, 0xc414,		0x21, 0
	.dw 0x4f43, 0xc414,	0x4f4f, 0xc414,		0x21, 0
	.dw 0x4f51, 0xc414,	0x4f51, 0xc414,		0x21, 0
	.dw 0x4f53, 0xc414,	0x4f7f, 0xc414,		0x21, 0
	.dw 0x4f81, 0xc414,	0x4f81, 0xc414,		0x21, 0
	.dw 0x4f83, 0xc414,	0x4f8f, 0xc414,		0x21, 0
	.dw 0x4f91, 0xc414,	0x4f91, 0xc414,		0x21, 0
	.dw 0x4f93, 0xc414,	0x4fbf, 0xc414,		0x21, 0
	.dw 0x4fc1, 0xc414,	0x4fc1, 0xc414,		0x21, 0
	.dw 0x4fc3, 0xc414,	0x4fcf, 0xc414,		0x21, 0
	.dw 0x4fd1, 0xc414,	0x4fd1, 0xc414,		0x21, 0
	.dw 0x4fd3, 0xc414,	0x5fff, 0xc414,		0x21, 0
	.dw 0x6001, 0xc414,	0x6001, 0xc414,		0x21, 0
	.dw 0x6003, 0xc414,	0x600f, 0xc414,		0x21, 0
	.dw 0x6011, 0xc414,	0x6011, 0xc414,		0x21, 0
	.dw 0x6013, 0xc414,	0x603f, 0xc414,		0x21, 0
	.dw 0x6041, 0xc414,	0x6041, 0xc414,		0x21, 0
	.dw 0x6043, 0xc414,	0x604f, 0xc414,		0x21, 0
	.dw 0x6051, 0xc414,	0x6051, 0xc414,		0x21, 0
	.dw 0x6053, 0xc414,	0x607f, 0xc414,		0x21, 0
	.dw 0x6081, 0xc414,	0x6081, 0xc414,		0x21, 0
	.dw 0x6083, 0xc414,	0x608f, 0xc414,		0x21, 0
	.dw 0x6091, 0xc414,	0x6091, 0xc414,		0x21, 0
	.dw 0x6093, 0xc414,	0x60bf, 0xc414,		0x21, 0
	.dw 0x60c1, 0xc414,	0x60c1, 0xc414,		0x21, 0
	.dw 0x60c3, 0xc414,	0x60cf, 0xc414,		0x21, 0
	.dw 0x60d1, 0xc414,	0x60d1, 0xc414,		0x21, 0
	.dw 0x60d3, 0xc414,	0x60ff, 0xc414,		0x21, 0
	.dw 0x6101, 0xc414,	0x6101, 0xc414,		0x21, 0
	.dw 0x6103, 0xc414,	0x610f, 0xc414,		0x21, 0
	.dw 0x6111, 0xc414,	0x6111, 0xc414,		0x21, 0
	.dw 0x6113, 0xc414,	0x613f, 0xc414,		0x21, 0
	.dw 0x6141, 0xc414,	0x6141, 0xc414,		0x21, 0
	.dw 0x6143, 0xc414,	0x614f, 0xc414,		0x21, 0
	.dw 0x6151, 0xc414,	0x6151, 0xc414,		0x21, 0
	.dw 0x6153, 0xc414,	0x617f, 0xc414,		0x21, 0
	.dw 0x6181, 0xc414,	0x6181, 0xc414,		0x21, 0
	.dw 0x6183, 0xc414,	0x618f, 0xc414,		0x21, 0
	.dw 0x6191, 0xc414,	0x6191, 0xc414,		0x21, 0
	.dw 0x6193, 0xc414,	0x61bf, 0xc414,		0x21, 0
	.dw 0x61c1, 0xc414,	0x61c1, 0xc414,		0x21, 0
	.dw 0x61c3, 0xc414,	0x61cf, 0xc414,		0x21, 0
	.dw 0x61d1, 0xc414,	0x61d1, 0xc414,		0x21, 0
	.dw 0x61d3, 0xc414,	0x61ff, 0xc414,		0x21, 0
	.dw 0x6201, 0xc414,	0x6201, 0xc414,		0x21, 0
	.dw 0x6203, 0xc414,	0x620f, 0xc414,		0x21, 0
	.dw 0x6211, 0xc414,	0x6211, 0xc414,		0x21, 0
	.dw 0x6213, 0xc414,	0x623f, 0xc414,		0x21, 0
	.dw 0x6241, 0xc414,	0x6241, 0xc414,		0x21, 0
	.dw 0x6243, 0xc414,	0x624f, 0xc414,		0x21, 0
	.dw 0x6251, 0xc414,	0x6251, 0xc414,		0x21, 0
	.dw 0x6253, 0xc414,	0x627f, 0xc414,		0x21, 0
	.dw 0x6281, 0xc414,	0x6281, 0xc414,		0x21, 0
	.dw 0x6283, 0xc414,	0x628f, 0xc414,		0x21, 0
	.dw 0x6291, 0xc414,	0x6291, 0xc414,		0x21, 0
	.dw 0x6293, 0xc414,	0x62bf, 0xc414,		0x21, 0
	.dw 0x62c1, 0xc414,	0x62c1, 0xc414,		0x21, 0
	.dw 0x62c3, 0xc414,	0x62cf, 0xc414,		0x21, 0
	.dw 0x62d1, 0xc414,	0x62d1, 0xc414,		0x21, 0
	.dw 0x62d3, 0xc414,	0x62ff, 0xc414,		0x21, 0
	.dw 0x6301, 0xc414,	0x6301, 0xc414,		0x21, 0
	.dw 0x6303, 0xc414,	0x630f, 0xc414,		0x21, 0
	.dw 0x6311, 0xc414,	0x6311, 0xc414,		0x21, 0
	.dw 0x6313, 0xc414,	0x633f, 0xc414,		0x21, 0
	.dw 0x6341, 0xc414,	0x6341, 0xc414,		0x21, 0
	.dw 0x6343, 0xc414,	0x634f, 0xc414,		0x21, 0
	.dw 0x6351, 0xc414,	0x6351, 0xc414,		0x21, 0
	.dw 0x6353, 0xc414,	0x637f, 0xc414,		0x21, 0
	.dw 0x6381, 0xc414,	0x6381, 0xc414,		0x21, 0
	.dw 0x6383, 0xc414,	0x638f, 0xc414,		0x21, 0
	.dw 0x6391, 0xc414,	0x6391, 0xc414,		0x21, 0
	.dw 0x6393, 0xc414,	0x63bf, 0xc414,		0x21, 0
	.dw 0x63c1, 0xc414,	0x63c1, 0xc414,		0x21, 0
	.dw 0x63c3, 0xc414,	0x63cf, 0xc414,		0x21, 0
	.dw 0x63d1, 0xc414,	0x63d1, 0xc414,		0x21, 0
	.dw 0x63d3, 0xc414,	0x63ff, 0xc414,		0x21, 0
	.dw 0x6401, 0xc414,	0x6401, 0xc414,		0x21, 0
	.dw 0x6403, 0xc414,	0x640f, 0xc414,		0x21, 0
	.dw 0x6411, 0xc414,	0x6411, 0xc414,		0x21, 0
	.dw 0x6413, 0xc414,	0x643f, 0xc414,		0x21, 0
	.dw 0x6441, 0xc414,	0x6441, 0xc414,		0x21, 0
	.dw 0x6443, 0xc414,	0x644f, 0xc414,		0x21, 0
	.dw 0x6451, 0xc414,	0x6451, 0xc414,		0x21, 0
	.dw 0x6453, 0xc414,	0x647f, 0xc414,		0x21, 0
	.dw 0x6481, 0xc414,	0x6481, 0xc414,		0x21, 0
	.dw 0x6483, 0xc414,	0x648f, 0xc414,		0x21, 0
	.dw 0x6491, 0xc414,	0x6491, 0xc414,		0x21, 0
	.dw 0x6493, 0xc414,	0x64bf, 0xc414,		0x21, 0
	.dw 0x64c1, 0xc414,	0x64c1, 0xc414,		0x21, 0
	.dw 0x64c3, 0xc414,	0x64cf, 0xc414,		0x21, 0
	.dw 0x64d1, 0xc414,	0x64d1, 0xc414,		0x21, 0
	.dw 0x64d3, 0xc414,	0x64ff, 0xc414,		0x21, 0
	.dw 0x6501, 0xc414,	0x6501, 0xc414,		0x21, 0
	.dw 0x6503, 0xc414,	0x650f, 0xc414,		0x21, 0
	.dw 0x6511, 0xc414,	0x6511, 0xc414,		0x21, 0
	.dw 0x6513, 0xc414,	0x653f, 0xc414,		0x21, 0
	.dw 0x6541, 0xc414,	0x6541, 0xc414,		0x21, 0
	.dw 0x6543, 0xc414,	0x654f, 0xc414,		0x21, 0
	.dw 0x6551, 0xc414,	0x6551, 0xc414,		0x21, 0
	.dw 0x6553, 0xc414,	0x657f, 0xc414,		0x21, 0
	.dw 0x6581, 0xc414,	0x6581, 0xc414,		0x21, 0
	.dw 0x6583, 0xc414,	0x658f, 0xc414,		0x21, 0
	.dw 0x6591, 0xc414,	0x6591, 0xc414,		0x21, 0
	.dw 0x6593, 0xc414,	0x65bf, 0xc414,		0x21, 0
	.dw 0x65c1, 0xc414,	0x65c1, 0xc414,		0x21, 0
	.dw 0x65c3, 0xc414,	0x65cf, 0xc414,		0x21, 0
	.dw 0x65d1, 0xc414,	0x65d1, 0xc414,		0x21, 0
	.dw 0x65d3, 0xc414,	0x65ff, 0xc414,		0x21, 0
	.dw 0x6601, 0xc414,	0x6601, 0xc414,		0x21, 0
	.dw 0x6603, 0xc414,	0x660f, 0xc414,		0x21, 0
	.dw 0x6611, 0xc414,	0x6611, 0xc414,		0x21, 0
	.dw 0x6613, 0xc414,	0x663f, 0xc414,		0x21, 0
	.dw 0x6641, 0xc414,	0x6641, 0xc414,		0x21, 0
	.dw 0x6643, 0xc414,	0x664f, 0xc414,		0x21, 0
	.dw 0x6651, 0xc414,	0x6651, 0xc414,		0x21, 0
	.dw 0x6653, 0xc414,	0x667f, 0xc414,		0x21, 0
	.dw 0x6681, 0xc414,	0x6681, 0xc414,		0x21, 0
	.dw 0x6683, 0xc414,	0x668f, 0xc414,		0x21, 0
	.dw 0x6691, 0xc414,	0x6691, 0xc414,		0x21, 0
	.dw 0x6693, 0xc414,	0x66bf, 0xc414,		0x21, 0
	.dw 0x66c1, 0xc414,	0x66c1, 0xc414,		0x21, 0
	.dw 0x66c3, 0xc414,	0x66cf, 0xc414,		0x21, 0
	.dw 0x66d1, 0xc414,	0x66d1, 0xc414,		0x21, 0
	.dw 0x66d3, 0xc414,	0x66ff, 0xc414,		0x21, 0
	.dw 0x6701, 0xc414,	0x6701, 0xc414,		0x21, 0
	.dw 0x6703, 0xc414,	0x670f, 0xc414,		0x21, 0
	.dw 0x6711, 0xc414,	0x6711, 0xc414,		0x21, 0
	.dw 0x6713, 0xc414,	0x673f, 0xc414,		0x21, 0
	.dw 0x6741, 0xc414,	0x6741, 0xc414,		0x21, 0
	.dw 0x6743, 0xc414,	0x674f, 0xc414,		0x21, 0
	.dw 0x6751, 0xc414,	0x6751, 0xc414,		0x21, 0
	.dw 0x6753, 0xc414,	0x677f, 0xc414,		0x21, 0
	.dw 0x6781, 0xc414,	0x6781, 0xc414,		0x21, 0
	.dw 0x6783, 0xc414,	0x678f, 0xc414,		0x21, 0
	.dw 0x6791, 0xc414,	0x6791, 0xc414,		0x21, 0
	.dw 0x6793, 0xc414,	0x67bf, 0xc414,		0x21, 0
	.dw 0x67c1, 0xc414,	0x67c1, 0xc414,		0x21, 0
	.dw 0x67c3, 0xc414,	0x67cf, 0xc414,		0x21, 0
	.dw 0x67d1, 0xc414,	0x67d1, 0xc414,		0x21, 0
	.dw 0x67d3, 0xc414,	0x67ff, 0xc414,		0x21, 0
	.dw 0x6801, 0xc414,	0x6801, 0xc414,		0x21, 0
	.dw 0x6803, 0xc414,	0x680f, 0xc414,		0x21, 0
	.dw 0x6811, 0xc414,	0x6811, 0xc414,		0x21, 0
	.dw 0x6813, 0xc414,	0x683f, 0xc414,		0x21, 0
	.dw 0x6841, 0xc414,	0x6841, 0xc414,		0x21, 0
	.dw 0x6843, 0xc414,	0x684f, 0xc414,		0x21, 0
	.dw 0x6851, 0xc414,	0x6851, 0xc414,		0x21, 0
	.dw 0x6853, 0xc414,	0x687f, 0xc414,		0x21, 0
	.dw 0x6881, 0xc414,	0x6881, 0xc414,		0x21, 0
	.dw 0x6883, 0xc414,	0x688f, 0xc414,		0x21, 0
	.dw 0x6891, 0xc414,	0x6891, 0xc414,		0x21, 0
	.dw 0x6893, 0xc414,	0x68bf, 0xc414,		0x21, 0
	.dw 0x68c1, 0xc414,	0x68c1, 0xc414,		0x21, 0
	.dw 0x68c3, 0xc414,	0x68cf, 0xc414,		0x21, 0
	.dw 0x68d1, 0xc414,	0x68d1, 0xc414,		0x21, 0
	.dw 0x68d3, 0xc414,	0x68ff, 0xc414,		0x21, 0
	.dw 0x6901, 0xc414,	0x6901, 0xc414,		0x21, 0
	.dw 0x6903, 0xc414,	0x690f, 0xc414,		0x21, 0
	.dw 0x6911, 0xc414,	0x6911, 0xc414,		0x21, 0
	.dw 0x6913, 0xc414,	0x693f, 0xc414,		0x21, 0
	.dw 0x6941, 0xc414,	0x6941, 0xc414,		0x21, 0
	.dw 0x6943, 0xc414,	0x694f, 0xc414,		0x21, 0
	.dw 0x6951, 0xc414,	0x6951, 0xc414,		0x21, 0
	.dw 0x6953, 0xc414,	0x697f, 0xc414,		0x21, 0
	.dw 0x6981, 0xc414,	0x6981, 0xc414,		0x21, 0
	.dw 0x6983, 0xc414,	0x698f, 0xc414,		0x21, 0
	.dw 0x6991, 0xc414,	0x6991, 0xc414,		0x21, 0
	.dw 0x6993, 0xc414,	0x69bf, 0xc414,		0x21, 0
	.dw 0x69c1, 0xc414,	0x69c1, 0xc414,		0x21, 0
	.dw 0x69c3, 0xc414,	0x69cf, 0xc414,		0x21, 0
	.dw 0x69d1, 0xc414,	0x69d1, 0xc414,		0x21, 0
	.dw 0x69d3, 0xc414,	0x69ff, 0xc414,		0x21, 0
	.dw 0x6a01, 0xc414,	0x6a01, 0xc414,		0x21, 0
	.dw 0x6a03, 0xc414,	0x6a0f, 0xc414,		0x21, 0
	.dw 0x6a11, 0xc414,	0x6a11, 0xc414,		0x21, 0
	.dw 0x6a13, 0xc414,	0x6a3f, 0xc414,		0x21, 0
	.dw 0x6a41, 0xc414,	0x6a41, 0xc414,		0x21, 0
	.dw 0x6a43, 0xc414,	0x6a4f, 0xc414,		0x21, 0
	.dw 0x6a51, 0xc414,	0x6a51, 0xc414,		0x21, 0
	.dw 0x6a53, 0xc414,	0x6a7f, 0xc414,		0x21, 0
	.dw 0x6a81, 0xc414,	0x6a81, 0xc414,		0x21, 0
	.dw 0x6a83, 0xc414,	0x6a8f, 0xc414,		0x21, 0
	.dw 0x6a91, 0xc414,	0x6a91, 0xc414,		0x21, 0
	.dw 0x6a93, 0xc414,	0x6abf, 0xc414,		0x21, 0
	.dw 0x6ac1, 0xc414,	0x6ac1, 0xc414,		0x21, 0
	.dw 0x6ac3, 0xc414,	0x6acf, 0xc414,		0x21, 0
	.dw 0x6ad1, 0xc414,	0x6ad1, 0xc414,		0x21, 0
	.dw 0x6ad3, 0xc414,	0x6aff, 0xc414,		0x21, 0
	.dw 0x6b01, 0xc414,	0x6b01, 0xc414,		0x21, 0
	.dw 0x6b03, 0xc414,	0x6b0f, 0xc414,		0x21, 0
	.dw 0x6b11, 0xc414,	0x6b11, 0xc414,		0x21, 0
	.dw 0x6b13, 0xc414,	0x6b3f, 0xc414,		0x21, 0
	.dw 0x6b41, 0xc414,	0x6b41, 0xc414,		0x21, 0
	.dw 0x6b43, 0xc414,	0x6b4f, 0xc414,		0x21, 0
	.dw 0x6b51, 0xc414,	0x6b51, 0xc414,		0x21, 0
	.dw 0x6b53, 0xc414,	0x6b7f, 0xc414,		0x21, 0
	.dw 0x6b81, 0xc414,	0x6b81, 0xc414,		0x21, 0
	.dw 0x6b83, 0xc414,	0x6b8f, 0xc414,		0x21, 0
	.dw 0x6b91, 0xc414,	0x6b91, 0xc414,		0x21, 0
	.dw 0x6b93, 0xc414,	0x6bbf, 0xc414,		0x21, 0
	.dw 0x6bc1, 0xc414,	0x6bc1, 0xc414,		0x21, 0
	.dw 0x6bc3, 0xc414,	0x6bcf, 0xc414,		0x21, 0
	.dw 0x6bd1, 0xc414,	0x6bd1, 0xc414,		0x21, 0
	.dw 0x6bd3, 0xc414,	0x6bff, 0xc414,		0x21, 0
	.dw 0x6c01, 0xc414,	0x6c01, 0xc414,		0x21, 0
	.dw 0x6c03, 0xc414,	0x6c0f, 0xc414,		0x21, 0
	.dw 0x6c11, 0xc414,	0x6c11, 0xc414,		0x21, 0
	.dw 0x6c13, 0xc414,	0x6c3f, 0xc414,		0x21, 0
	.dw 0x6c41, 0xc414,	0x6c41, 0xc414,		0x21, 0
	.dw 0x6c43, 0xc414,	0x6c4f, 0xc414,		0x21, 0
	.dw 0x6c51, 0xc414,	0x6c51, 0xc414,		0x21, 0
	.dw 0x6c53, 0xc414,	0x6c7f, 0xc414,		0x21, 0
	.dw 0x6c81, 0xc414,	0x6c81, 0xc414,		0x21, 0
	.dw 0x6c83, 0xc414,	0x6c8f, 0xc414,		0x21, 0
	.dw 0x6c91, 0xc414,	0x6c91, 0xc414,		0x21, 0
	.dw 0x6c93, 0xc414,	0x6cbf, 0xc414,		0x21, 0
	.dw 0x6cc1, 0xc414,	0x6cc1, 0xc414,		0x21, 0
	.dw 0x6cc3, 0xc414,	0x6ccf, 0xc414,		0x21, 0
	.dw 0x6cd1, 0xc414,	0x6cd1, 0xc414,		0x21, 0
	.dw 0x6cd3, 0xc414,	0x6cff, 0xc414,		0x21, 0
	.dw 0x6d01, 0xc414,	0x6d01, 0xc414,		0x21, 0
	.dw 0x6d03, 0xc414,	0x6d0f, 0xc414,		0x21, 0
	.dw 0x6d11, 0xc414,	0x6d11, 0xc414,		0x21, 0
	.dw 0x6d13, 0xc414,	0x6d3f, 0xc414,		0x21, 0
	.dw 0x6d41, 0xc414,	0x6d41, 0xc414,		0x21, 0
	.dw 0x6d43, 0xc414,	0x6d4f, 0xc414,		0x21, 0
	.dw 0x6d51, 0xc414,	0x6d51, 0xc414,		0x21, 0
	.dw 0x6d53, 0xc414,	0x6d7f, 0xc414,		0x21, 0
	.dw 0x6d81, 0xc414,	0x6d81, 0xc414,		0x21, 0
	.dw 0x6d83, 0xc414,	0x6d8f, 0xc414,		0x21, 0
	.dw 0x6d91, 0xc414,	0x6d91, 0xc414,		0x21, 0
	.dw 0x6d93, 0xc414,	0x6dbf, 0xc414,		0x21, 0
	.dw 0x6dc1, 0xc414,	0x6dc1, 0xc414,		0x21, 0
	.dw 0x6dc3, 0xc414,	0x6dcf, 0xc414,		0x21, 0
	.dw 0x6dd1, 0xc414,	0x6dd1, 0xc414,		0x21, 0
	.dw 0x6dd3, 0xc414,	0x6dff, 0xc414,		0x21, 0
	.dw 0x6e01, 0xc414,	0x6e01, 0xc414,		0x21, 0
	.dw 0x6e03, 0xc414,	0x6e0f, 0xc414,		0x21, 0
	.dw 0x6e11, 0xc414,	0x6e11, 0xc414,		0x21, 0
	.dw 0x6e13, 0xc414,	0x6e3f, 0xc414,		0x21, 0
	.dw 0x6e41, 0xc414,	0x6e41, 0xc414,		0x21, 0
	.dw 0x6e43, 0xc414,	0x6e4f, 0xc414,		0x21, 0
	.dw 0x6e51, 0xc414,	0x6e51, 0xc414,		0x21, 0
	.dw 0x6e53, 0xc414,	0x6e7f, 0xc414,		0x21, 0
	.dw 0x6e81, 0xc414,	0x6e81, 0xc414,		0x21, 0
	.dw 0x6e83, 0xc414,	0x6e8f, 0xc414,		0x21, 0
	.dw 0x6e91, 0xc414,	0x6e91, 0xc414,		0x21, 0
	.dw 0x6e93, 0xc414,	0x6ebf, 0xc414,		0x21, 0
	.dw 0x6ec1, 0xc414,	0x6ec1, 0xc414,		0x21, 0
	.dw 0x6ec3, 0xc414,	0x6ecf, 0xc414,		0x21, 0
	.dw 0x6ed1, 0xc414,	0x6ed1, 0xc414,		0x21, 0
	.dw 0x6ed3, 0xc414,	0x6eff, 0xc414,		0x21, 0
	.dw 0x6f01, 0xc414,	0x6f01, 0xc414,		0x21, 0
	.dw 0x6f03, 0xc414,	0x6f0f, 0xc414,		0x21, 0
	.dw 0x6f11, 0xc414,	0x6f11, 0xc414,		0x21, 0
	.dw 0x6f13, 0xc414,	0x6f3f, 0xc414,		0x21, 0
	.dw 0x6f41, 0xc414,	0x6f41, 0xc414,		0x21, 0
	.dw 0x6f43, 0xc414,	0x6f4f, 0xc414,		0x21, 0
	.dw 0x6f51, 0xc414,	0x6f51, 0xc414,		0x21, 0
	.dw 0x6f53, 0xc414,	0x6f7f, 0xc414,		0x21, 0
	.dw 0x6f81, 0xc414,	0x6f81, 0xc414,		0x21, 0
	.dw 0x6f83, 0xc414,	0x6f8f, 0xc414,		0x21, 0
	.dw 0x6f91, 0xc414,	0x6f91, 0xc414,		0x21, 0
	.dw 0x6f93, 0xc414,	0x6fbf, 0xc414,		0x21, 0
	.dw 0x6fc1, 0xc414,	0x6fc1, 0xc414,		0x21, 0
	.dw 0x6fc3, 0xc414,	0x6fcf, 0xc414,		0x21, 0
	.dw 0x6fd1, 0xc414,	0x6fd1, 0xc414,		0x21, 0
	.dw 0x6fd3, 0xc414,	0xffff, 0xc414,		0x21, 0
	.dw 0x0000, 0xc415,	0x0000, 0xc415,		0x22, 0
	.dw 0x0001, 0xc415,	0x0001, 0xc415,		0x21, 0
	.dw 0x0002, 0xc415,	0x0002, 0xc415,		0x22, 0
	.dw 0x0003, 0xc415,	0x000f, 0xc415,		0x21, 0
	.dw 0x0010, 0xc415,	0x0010, 0xc415,		0x22, 0
	.dw 0x0011, 0xc415,	0x0011, 0xc415,		0x21, 0
	.dw 0x0012, 0xc415,	0x0012, 0xc415,		0x22, 0
	.dw 0x0013, 0xc415,	0x003f, 0xc415,		0x21, 0
	.dw 0x0041, 0xc415,	0x0041, 0xc415,		0x21, 0
	.dw 0x0043, 0xc415,	0x004f, 0xc415,		0x21, 0
	.dw 0x0051, 0xc415,	0x0051, 0xc415,		0x21, 0
	.dw 0x0053, 0xc415,	0x007f, 0xc415,		0x21, 0
	.dw 0x0081, 0xc415,	0x0081, 0xc415,		0x21, 0
	.dw 0x0083, 0xc415,	0x008f, 0xc415,		0x21, 0
	.dw 0x0091, 0xc415,	0x0091, 0xc415,		0x21, 0
	.dw 0x0093, 0xc415,	0x00bf, 0xc415,		0x21, 0
	.dw 0x00c1, 0xc415,	0x00c1, 0xc415,		0x21, 0
	.dw 0x00c3, 0xc415,	0x00cf, 0xc415,		0x21, 0
	.dw 0x00d1, 0xc415,	0x00d1, 0xc415,		0x21, 0
	.dw 0x00d3, 0xc415,	0x00ff, 0xc415,		0x21, 0
	.dw 0x0101, 0xc415,	0x0101, 0xc415,		0x21, 0
	.dw 0x0103, 0xc415,	0x010f, 0xc415,		0x21, 0
	.dw 0x0111, 0xc415,	0x0111, 0xc415,		0x21, 0
	.dw 0x0113, 0xc415,	0x013f, 0xc415,		0x21, 0
	.dw 0x0141, 0xc415,	0x0141, 0xc415,		0x21, 0
	.dw 0x0143, 0xc415,	0x014f, 0xc415,		0x21, 0
	.dw 0x0151, 0xc415,	0x0151, 0xc415,		0x21, 0
	.dw 0x0153, 0xc415,	0x017f, 0xc415,		0x21, 0
	.dw 0x0181, 0xc415,	0x0181, 0xc415,		0x21, 0
	.dw 0x0183, 0xc415,	0x018f, 0xc415,		0x21, 0
	.dw 0x0191, 0xc415,	0x0191, 0xc415,		0x21, 0
	.dw 0x0193, 0xc415,	0x01bf, 0xc415,		0x21, 0
	.dw 0x01c1, 0xc415,	0x01c1, 0xc415,		0x21, 0
	.dw 0x01c3, 0xc415,	0x01cf, 0xc415,		0x21, 0
	.dw 0x01d1, 0xc415,	0x01d1, 0xc415,		0x21, 0
	.dw 0x01d3, 0xc415,	0x01ff, 0xc415,		0x21, 0
	.dw 0x0201, 0xc415,	0x0201, 0xc415,		0x21, 0
	.dw 0x0203, 0xc415,	0x020f, 0xc415,		0x21, 0
	.dw 0x0211, 0xc415,	0x0211, 0xc415,		0x21, 0
	.dw 0x0213, 0xc415,	0x023f, 0xc415,		0x21, 0
	.dw 0x0240, 0xc415,	0x0240, 0xc415,		0x22, 0
	.dw 0x0241, 0xc415,	0x0241, 0xc415,		0x21, 0
	.dw 0x0242, 0xc415,	0x0242, 0xc415,		0x22, 0
	.dw 0x0243, 0xc415,	0x024f, 0xc415,		0x21, 0
	.dw 0x0250, 0xc415,	0x0250, 0xc415,		0x22, 0
	.dw 0x0251, 0xc415,	0x0251, 0xc415,		0x21, 0
	.dw 0x0252, 0xc415,	0x0252, 0xc415,		0x22, 0
	.dw 0x0253, 0xc415,	0x027f, 0xc415,		0x21, 0
	.dw 0x0281, 0xc415,	0x0281, 0xc415,		0x21, 0
	.dw 0x0283, 0xc415,	0x028f, 0xc415,		0x21, 0
	.dw 0x0291, 0xc415,	0x0291, 0xc415,		0x21, 0
	.dw 0x0293, 0xc415,	0x02bf, 0xc415,		0x21, 0
	.dw 0x02c1, 0xc415,	0x02c1, 0xc415,		0x21, 0
	.dw 0x02c3, 0xc415,	0x02cf, 0xc415,		0x21, 0
	.dw 0x02d1, 0xc415,	0x02d1, 0xc415,		0x21, 0
	.dw 0x02d3, 0xc415,	0x02ff, 0xc415,		0x21, 0
	.dw 0x0301, 0xc415,	0x0301, 0xc415,		0x21, 0
	.dw 0x0303, 0xc415,	0x030f, 0xc415,		0x21, 0
	.dw 0x0311, 0xc415,	0x0311, 0xc415,		0x21, 0
	.dw 0x0313, 0xc415,	0x033f, 0xc415,		0x21, 0
	.dw 0x0341, 0xc415,	0x0341, 0xc415,		0x21, 0
	.dw 0x0343, 0xc415,	0x034f, 0xc415,		0x21, 0
	.dw 0x0351, 0xc415,	0x0351, 0xc415,		0x21, 0
	.dw 0x0353, 0xc415,	0x037f, 0xc415,		0x21, 0
	.dw 0x0381, 0xc415,	0x0381, 0xc415,		0x21, 0
	.dw 0x0383, 0xc415,	0x038f, 0xc415,		0x21, 0
	.dw 0x0391, 0xc415,	0x0391, 0xc415,		0x21, 0
	.dw 0x0393, 0xc415,	0x03bf, 0xc415,		0x21, 0
	.dw 0x03c1, 0xc415,	0x03c1, 0xc415,		0x21, 0
	.dw 0x03c3, 0xc415,	0x03cf, 0xc415,		0x21, 0
	.dw 0x03d1, 0xc415,	0x03d1, 0xc415,		0x21, 0
	.dw 0x03d3, 0xc415,	0x03ff, 0xc415,		0x21, 0
	.dw 0x0401, 0xc415,	0x0401, 0xc415,		0x21, 0
	.dw 0x0403, 0xc415,	0x040f, 0xc415,		0x21, 0
	.dw 0x0411, 0xc415,	0x0411, 0xc415,		0x21, 0
	.dw 0x0413, 0xc415,	0x043f, 0xc415,		0x21, 0
	.dw 0x0441, 0xc415,	0x0441, 0xc415,		0x21, 0
	.dw 0x0443, 0xc415,	0x044f, 0xc415,		0x21, 0
	.dw 0x0451, 0xc415,	0x0451, 0xc415,		0x21, 0
	.dw 0x0453, 0xc415,	0x047f, 0xc415,		0x21, 0
	.dw 0x0480, 0xc415,	0x0480, 0xc415,		0x22, 0
	.dw 0x0481, 0xc415,	0x0481, 0xc415,		0x21, 0
	.dw 0x0482, 0xc415,	0x0482, 0xc415,		0x22, 0
	.dw 0x0483, 0xc415,	0x048f, 0xc415,		0x21, 0
	.dw 0x0490, 0xc415,	0x0490, 0xc415,		0x22, 0
	.dw 0x0491, 0xc415,	0x0491, 0xc415,		0x21, 0
	.dw 0x0492, 0xc415,	0x0492, 0xc415,		0x22, 0
	.dw 0x0493, 0xc415,	0x04bf, 0xc415,		0x21, 0
	.dw 0x04c1, 0xc415,	0x04c1, 0xc415,		0x21, 0
	.dw 0x04c3, 0xc415,	0x04cf, 0xc415,		0x21, 0
	.dw 0x04d1, 0xc415,	0x04d1, 0xc415,		0x21, 0
	.dw 0x04d3, 0xc415,	0x04ff, 0xc415,		0x21, 0
	.dw 0x0501, 0xc415,	0x0501, 0xc415,		0x21, 0
	.dw 0x0503, 0xc415,	0x050f, 0xc415,		0x21, 0
	.dw 0x0511, 0xc415,	0x0511, 0xc415,		0x21, 0
	.dw 0x0513, 0xc415,	0x053f, 0xc415,		0x21, 0
	.dw 0x0541, 0xc415,	0x0541, 0xc415,		0x21, 0
	.dw 0x0543, 0xc415,	0x054f, 0xc415,		0x21, 0
	.dw 0x0551, 0xc415,	0x0551, 0xc415,		0x21, 0
	.dw 0x0553, 0xc415,	0x057f, 0xc415,		0x21, 0
	.dw 0x0581, 0xc415,	0x0581, 0xc415,		0x21, 0
	.dw 0x0583, 0xc415,	0x058f, 0xc415,		0x21, 0
	.dw 0x0591, 0xc415,	0x0591, 0xc415,		0x21, 0
	.dw 0x0593, 0xc415,	0x05bf, 0xc415,		0x21, 0
	.dw 0x05c1, 0xc415,	0x05c1, 0xc415,		0x21, 0
	.dw 0x05c3, 0xc415,	0x05cf, 0xc415,		0x21, 0
	.dw 0x05d1, 0xc415,	0x05d1, 0xc415,		0x21, 0
	.dw 0x05d3, 0xc415,	0x05ff, 0xc415,		0x21, 0
	.dw 0x0601, 0xc415,	0x0601, 0xc415,		0x21, 0
	.dw 0x0603, 0xc415,	0x060f, 0xc415,		0x21, 0
	.dw 0x0611, 0xc415,	0x0611, 0xc415,		0x21, 0
	.dw 0x0613, 0xc415,	0x063f, 0xc415,		0x21, 0
	.dw 0x0641, 0xc415,	0x0641, 0xc415,		0x21, 0
	.dw 0x0643, 0xc415,	0x064f, 0xc415,		0x21, 0
	.dw 0x0651, 0xc415,	0x0651, 0xc415,		0x21, 0
	.dw 0x0653, 0xc415,	0x067f, 0xc415,		0x21, 0
	.dw 0x0681, 0xc415,	0x0681, 0xc415,		0x21, 0
	.dw 0x0683, 0xc415,	0x068f, 0xc415,		0x21, 0
	.dw 0x0691, 0xc415,	0x0691, 0xc415,		0x21, 0
	.dw 0x0693, 0xc415,	0x06bf, 0xc415,		0x21, 0
	.dw 0x06c0, 0xc415,	0x06c0, 0xc415,		0x22, 0
	.dw 0x06c1, 0xc415,	0x06c1, 0xc415,		0x21, 0
	.dw 0x06c2, 0xc415,	0x06c2, 0xc415,		0x22, 0
	.dw 0x06c3, 0xc415,	0x06cf, 0xc415,		0x21, 0
	.dw 0x06d0, 0xc415,	0x06d0, 0xc415,		0x22, 0
	.dw 0x06d1, 0xc415,	0x06d1, 0xc415,		0x21, 0
	.dw 0x06d2, 0xc415,	0x06d2, 0xc415,		0x22, 0
	.dw 0x06d3, 0xc415,	0x06ff, 0xc415,		0x21, 0
	.dw 0x0701, 0xc415,	0x0701, 0xc415,		0x21, 0
	.dw 0x0703, 0xc415,	0x070f, 0xc415,		0x21, 0
	.dw 0x0711, 0xc415,	0x0711, 0xc415,		0x21, 0
	.dw 0x0713, 0xc415,	0x073f, 0xc415,		0x21, 0
	.dw 0x0741, 0xc415,	0x0741, 0xc415,		0x21, 0
	.dw 0x0743, 0xc415,	0x074f, 0xc415,		0x21, 0
	.dw 0x0751, 0xc415,	0x0751, 0xc415,		0x21, 0
	.dw 0x0753, 0xc415,	0x077f, 0xc415,		0x21, 0
	.dw 0x0781, 0xc415,	0x0781, 0xc415,		0x21, 0
	.dw 0x0783, 0xc415,	0x078f, 0xc415,		0x21, 0
	.dw 0x0791, 0xc415,	0x0791, 0xc415,		0x21, 0
	.dw 0x0793, 0xc415,	0x07bf, 0xc415,		0x21, 0
	.dw 0x07c1, 0xc415,	0x07c1, 0xc415,		0x21, 0
	.dw 0x07c3, 0xc415,	0x07cf, 0xc415,		0x21, 0
	.dw 0x07d1, 0xc415,	0x07d1, 0xc415,		0x21, 0
	.dw 0x07d3, 0xc415,	0x07ff, 0xc415,		0x21, 0
	.dw 0x0801, 0xc415,	0x0801, 0xc415,		0x21, 0
	.dw 0x0803, 0xc415,	0x080f, 0xc415,		0x21, 0
	.dw 0x0811, 0xc415,	0x0811, 0xc415,		0x21, 0
	.dw 0x0813, 0xc415,	0x083f, 0xc415,		0x21, 0
	.dw 0x0841, 0xc415,	0x0841, 0xc415,		0x21, 0
	.dw 0x0843, 0xc415,	0x084f, 0xc415,		0x21, 0
	.dw 0x0851, 0xc415,	0x0851, 0xc415,		0x21, 0
	.dw 0x0853, 0xc415,	0x087f, 0xc415,		0x21, 0
	.dw 0x0881, 0xc415,	0x0881, 0xc415,		0x21, 0
	.dw 0x0883, 0xc415,	0x088f, 0xc415,		0x21, 0
	.dw 0x0891, 0xc415,	0x0891, 0xc415,		0x21, 0
	.dw 0x0893, 0xc415,	0x08bf, 0xc415,		0x21, 0
	.dw 0x08c1, 0xc415,	0x08c1, 0xc415,		0x21, 0
	.dw 0x08c3, 0xc415,	0x08cf, 0xc415,		0x21, 0
	.dw 0x08d1, 0xc415,	0x08d1, 0xc415,		0x21, 0
	.dw 0x08d3, 0xc415,	0x08ff, 0xc415,		0x21, 0
	.dw 0x0900, 0xc415,	0x0900, 0xc415,		0x22, 0
	.dw 0x0901, 0xc415,	0x0901, 0xc415,		0x21, 0
	.dw 0x0902, 0xc415,	0x0902, 0xc415,		0x22, 0
	.dw 0x0903, 0xc415,	0x090f, 0xc415,		0x21, 0
	.dw 0x0910, 0xc415,	0x0910, 0xc415,		0x22, 0
	.dw 0x0911, 0xc415,	0x0911, 0xc415,		0x21, 0
	.dw 0x0912, 0xc415,	0x0912, 0xc415,		0x22, 0
	.dw 0x0913, 0xc415,	0x093f, 0xc415,		0x21, 0
	.dw 0x0941, 0xc415,	0x0941, 0xc415,		0x21, 0
	.dw 0x0943, 0xc415,	0x094f, 0xc415,		0x21, 0
	.dw 0x0951, 0xc415,	0x0951, 0xc415,		0x21, 0
	.dw 0x0953, 0xc415,	0x097f, 0xc415,		0x21, 0
	.dw 0x0981, 0xc415,	0x0981, 0xc415,		0x21, 0
	.dw 0x0983, 0xc415,	0x098f, 0xc415,		0x21, 0
	.dw 0x0991, 0xc415,	0x0991, 0xc415,		0x21, 0
	.dw 0x0993, 0xc415,	0x09bf, 0xc415,		0x21, 0
	.dw 0x09c1, 0xc415,	0x09c1, 0xc415,		0x21, 0
	.dw 0x09c3, 0xc415,	0x09cf, 0xc415,		0x21, 0
	.dw 0x09d1, 0xc415,	0x09d1, 0xc415,		0x21, 0
	.dw 0x09d3, 0xc415,	0x09ff, 0xc415,		0x21, 0
	.dw 0x0a01, 0xc415,	0x0a01, 0xc415,		0x21, 0
	.dw 0x0a03, 0xc415,	0x0a0f, 0xc415,		0x21, 0
	.dw 0x0a11, 0xc415,	0x0a11, 0xc415,		0x21, 0
	.dw 0x0a13, 0xc415,	0x0a3f, 0xc415,		0x21, 0
	.dw 0x0a41, 0xc415,	0x0a41, 0xc415,		0x21, 0
	.dw 0x0a43, 0xc415,	0x0a4f, 0xc415,		0x21, 0
	.dw 0x0a51, 0xc415,	0x0a51, 0xc415,		0x21, 0
	.dw 0x0a53, 0xc415,	0x0a7f, 0xc415,		0x21, 0
	.dw 0x0a81, 0xc415,	0x0a81, 0xc415,		0x21, 0
	.dw 0x0a83, 0xc415,	0x0a8f, 0xc415,		0x21, 0
	.dw 0x0a91, 0xc415,	0x0a91, 0xc415,		0x21, 0
	.dw 0x0a93, 0xc415,	0x0abf, 0xc415,		0x21, 0
	.dw 0x0ac1, 0xc415,	0x0ac1, 0xc415,		0x21, 0
	.dw 0x0ac3, 0xc415,	0x0acf, 0xc415,		0x21, 0
	.dw 0x0ad1, 0xc415,	0x0ad1, 0xc415,		0x21, 0
	.dw 0x0ad3, 0xc415,	0x0aff, 0xc415,		0x21, 0
	.dw 0x0b01, 0xc415,	0x0b01, 0xc415,		0x21, 0
	.dw 0x0b03, 0xc415,	0x0b0f, 0xc415,		0x21, 0
	.dw 0x0b11, 0xc415,	0x0b11, 0xc415,		0x21, 0
	.dw 0x0b13, 0xc415,	0x0b3f, 0xc415,		0x21, 0
	.dw 0x0b40, 0xc415,	0x0b40, 0xc415,		0x22, 0
	.dw 0x0b41, 0xc415,	0x0b41, 0xc415,		0x21, 0
	.dw 0x0b42, 0xc415,	0x0b42, 0xc415,		0x22, 0
	.dw 0x0b43, 0xc415,	0x0b4f, 0xc415,		0x21, 0
	.dw 0x0b50, 0xc415,	0x0b50, 0xc415,		0x22, 0
	.dw 0x0b51, 0xc415,	0x0b51, 0xc415,		0x21, 0
	.dw 0x0b52, 0xc415,	0x0b52, 0xc415,		0x22, 0
	.dw 0x0b53, 0xc415,	0x0b7f, 0xc415,		0x21, 0
	.dw 0x0b81, 0xc415,	0x0b81, 0xc415,		0x21, 0
	.dw 0x0b83, 0xc415,	0x0b8f, 0xc415,		0x21, 0
	.dw 0x0b91, 0xc415,	0x0b91, 0xc415,		0x21, 0
	.dw 0x0b93, 0xc415,	0x0bbf, 0xc415,		0x21, 0
	.dw 0x0bc1, 0xc415,	0x0bc1, 0xc415,		0x21, 0
	.dw 0x0bc3, 0xc415,	0x0bcf, 0xc415,		0x21, 0
	.dw 0x0bd1, 0xc415,	0x0bd1, 0xc415,		0x21, 0
	.dw 0x0bd3, 0xc415,	0x0bff, 0xc415,		0x21, 0
	.dw 0x0c01, 0xc415,	0x0c01, 0xc415,		0x21, 0
	.dw 0x0c03, 0xc415,	0x0c0f, 0xc415,		0x21, 0
	.dw 0x0c11, 0xc415,	0x0c11, 0xc415,		0x21, 0
	.dw 0x0c13, 0xc415,	0x0c3f, 0xc415,		0x21, 0
	.dw 0x0c41, 0xc415,	0x0c41, 0xc415,		0x21, 0
	.dw 0x0c43, 0xc415,	0x0c4f, 0xc415,		0x21, 0
	.dw 0x0c51, 0xc415,	0x0c51, 0xc415,		0x21, 0
	.dw 0x0c53, 0xc415,	0x0c7f, 0xc415,		0x21, 0
	.dw 0x0c81, 0xc415,	0x0c81, 0xc415,		0x21, 0
	.dw 0x0c83, 0xc415,	0x0c8f, 0xc415,		0x21, 0
	.dw 0x0c91, 0xc415,	0x0c91, 0xc415,		0x21, 0
	.dw 0x0c93, 0xc415,	0x0cbf, 0xc415,		0x21, 0
	.dw 0x0cc1, 0xc415,	0x0cc1, 0xc415,		0x21, 0
	.dw 0x0cc3, 0xc415,	0x0ccf, 0xc415,		0x21, 0
	.dw 0x0cd1, 0xc415,	0x0cd1, 0xc415,		0x21, 0
	.dw 0x0cd3, 0xc415,	0x0cff, 0xc415,		0x21, 0
	.dw 0x0d01, 0xc415,	0x0d01, 0xc415,		0x21, 0
	.dw 0x0d03, 0xc415,	0x0d0f, 0xc415,		0x21, 0
	.dw 0x0d11, 0xc415,	0x0d11, 0xc415,		0x21, 0
	.dw 0x0d13, 0xc415,	0x0d3f, 0xc415,		0x21, 0
	.dw 0x0d41, 0xc415,	0x0d41, 0xc415,		0x21, 0
	.dw 0x0d43, 0xc415,	0x0d4f, 0xc415,		0x21, 0
	.dw 0x0d51, 0xc415,	0x0d51, 0xc415,		0x21, 0
	.dw 0x0d53, 0xc415,	0x0d7f, 0xc415,		0x21, 0
	.dw 0x0d80, 0xc415,	0x0d80, 0xc415,		0x22, 0
	.dw 0x0d81, 0xc415,	0x0d81, 0xc415,		0x21, 0
	.dw 0x0d82, 0xc415,	0x0d82, 0xc415,		0x22, 0
	.dw 0x0d83, 0xc415,	0x0d8f, 0xc415,		0x21, 0
	.dw 0x0d90, 0xc415,	0x0d90, 0xc415,		0x22, 0
	.dw 0x0d91, 0xc415,	0x0d91, 0xc415,		0x21, 0
	.dw 0x0d92, 0xc415,	0x0d92, 0xc415,		0x22, 0
	.dw 0x0d93, 0xc415,	0x0dbf, 0xc415,		0x21, 0
	.dw 0x0dc1, 0xc415,	0x0dc1, 0xc415,		0x21, 0
	.dw 0x0dc3, 0xc415,	0x0dcf, 0xc415,		0x21, 0
	.dw 0x0dd1, 0xc415,	0x0dd1, 0xc415,		0x21, 0
	.dw 0x0dd3, 0xc415,	0x0dff, 0xc415,		0x21, 0
	.dw 0x0e01, 0xc415,	0x0e01, 0xc415,		0x21, 0
	.dw 0x0e03, 0xc415,	0x0e0f, 0xc415,		0x21, 0
	.dw 0x0e11, 0xc415,	0x0e11, 0xc415,		0x21, 0
	.dw 0x0e13, 0xc415,	0x0e3f, 0xc415,		0x21, 0
	.dw 0x0e41, 0xc415,	0x0e41, 0xc415,		0x21, 0
	.dw 0x0e43, 0xc415,	0x0e4f, 0xc415,		0x21, 0
	.dw 0x0e51, 0xc415,	0x0e51, 0xc415,		0x21, 0
	.dw 0x0e53, 0xc415,	0x0e7f, 0xc415,		0x21, 0
	.dw 0x0e81, 0xc415,	0x0e81, 0xc415,		0x21, 0
	.dw 0x0e83, 0xc415,	0x0e8f, 0xc415,		0x21, 0
	.dw 0x0e91, 0xc415,	0x0e91, 0xc415,		0x21, 0
	.dw 0x0e93, 0xc415,	0x0ebf, 0xc415,		0x21, 0
	.dw 0x0ec1, 0xc415,	0x0ec1, 0xc415,		0x21, 0
	.dw 0x0ec3, 0xc415,	0x0ecf, 0xc415,		0x21, 0
	.dw 0x0ed1, 0xc415,	0x0ed1, 0xc415,		0x21, 0
	.dw 0x0ed3, 0xc415,	0x0eff, 0xc415,		0x21, 0
	.dw 0x0f01, 0xc415,	0x0f01, 0xc415,		0x21, 0
	.dw 0x0f03, 0xc415,	0x0f0f, 0xc415,		0x21, 0
	.dw 0x0f11, 0xc415,	0x0f11, 0xc415,		0x21, 0
	.dw 0x0f13, 0xc415,	0x0f3f, 0xc415,		0x21, 0
	.dw 0x0f41, 0xc415,	0x0f41, 0xc415,		0x21, 0
	.dw 0x0f43, 0xc415,	0x0f4f, 0xc415,		0x21, 0
	.dw 0x0f51, 0xc415,	0x0f51, 0xc415,		0x21, 0
	.dw 0x0f53, 0xc415,	0x0f7f, 0xc415,		0x21, 0
	.dw 0x0f81, 0xc415,	0x0f81, 0xc415,		0x21, 0
	.dw 0x0f83, 0xc415,	0x0f8f, 0xc415,		0x21, 0
	.dw 0x0f91, 0xc415,	0x0f91, 0xc415,		0x21, 0
	.dw 0x0f93, 0xc415,	0x0fbf, 0xc415,		0x21, 0
	.dw 0x0fc0, 0xc415,	0x0fc0, 0xc415,		0x22, 0
	.dw 0x0fc1, 0xc415,	0x0fc1, 0xc415,		0x21, 0
	.dw 0x0fc2, 0xc415,	0x0fc2, 0xc415,		0x22, 0
	.dw 0x0fc3, 0xc415,	0x0fcf, 0xc415,		0x21, 0
	.dw 0x0fd0, 0xc415,	0x0fd0, 0xc415,		0x22, 0
	.dw 0x0fd1, 0xc415,	0x0fd1, 0xc415,		0x21, 0
	.dw 0x0fd2, 0xc415,	0x0fd2, 0xc415,		0x22, 0
	.dw 0x0fd3, 0xc415,	0x1fff, 0xc415,		0x21, 0
	.dw 0x2000, 0xc415,	0x2000, 0xc415,		0x22, 0
	.dw 0x2001, 0xc415,	0x2001, 0xc415,		0x21, 0
	.dw 0x2002, 0xc415,	0x2002, 0xc415,		0x22, 0
	.dw 0x2003, 0xc415,	0x200f, 0xc415,		0x21, 0
	.dw 0x2010, 0xc415,	0x2010, 0xc415,		0x22, 0
	.dw 0x2011, 0xc415,	0x2011, 0xc415,		0x21, 0
	.dw 0x2012, 0xc415,	0x2012, 0xc415,		0x22, 0
	.dw 0x2013, 0xc415,	0x203f, 0xc415,		0x21, 0
	.dw 0x2041, 0xc415,	0x2041, 0xc415,		0x21, 0
	.dw 0x2043, 0xc415,	0x204f, 0xc415,		0x21, 0
	.dw 0x2051, 0xc415,	0x2051, 0xc415,		0x21, 0
	.dw 0x2053, 0xc415,	0x207f, 0xc415,		0x21, 0
	.dw 0x2081, 0xc415,	0x2081, 0xc415,		0x21, 0
	.dw 0x2083, 0xc415,	0x208f, 0xc415,		0x21, 0
	.dw 0x2091, 0xc415,	0x2091, 0xc415,		0x21, 0
	.dw 0x2093, 0xc415,	0x20bf, 0xc415,		0x21, 0
	.dw 0x20c1, 0xc415,	0x20c1, 0xc415,		0x21, 0
	.dw 0x20c3, 0xc415,	0x20cf, 0xc415,		0x21, 0
	.dw 0x20d1, 0xc415,	0x20d1, 0xc415,		0x21, 0
	.dw 0x20d3, 0xc415,	0x20ff, 0xc415,		0x21, 0
	.dw 0x2101, 0xc415,	0x2101, 0xc415,		0x21, 0
	.dw 0x2103, 0xc415,	0x210f, 0xc415,		0x21, 0
	.dw 0x2111, 0xc415,	0x2111, 0xc415,		0x21, 0
	.dw 0x2113, 0xc415,	0x213f, 0xc415,		0x21, 0
	.dw 0x2141, 0xc415,	0x2141, 0xc415,		0x21, 0
	.dw 0x2143, 0xc415,	0x214f, 0xc415,		0x21, 0
	.dw 0x2151, 0xc415,	0x2151, 0xc415,		0x21, 0
	.dw 0x2153, 0xc415,	0x217f, 0xc415,		0x21, 0
	.dw 0x2181, 0xc415,	0x2181, 0xc415,		0x21, 0
	.dw 0x2183, 0xc415,	0x218f, 0xc415,		0x21, 0
	.dw 0x2191, 0xc415,	0x2191, 0xc415,		0x21, 0
	.dw 0x2193, 0xc415,	0x21bf, 0xc415,		0x21, 0
	.dw 0x21c1, 0xc415,	0x21c1, 0xc415,		0x21, 0
	.dw 0x21c3, 0xc415,	0x21cf, 0xc415,		0x21, 0
	.dw 0x21d1, 0xc415,	0x21d1, 0xc415,		0x21, 0
	.dw 0x21d3, 0xc415,	0x21ff, 0xc415,		0x21, 0
	.dw 0x2201, 0xc415,	0x2201, 0xc415,		0x21, 0
	.dw 0x2203, 0xc415,	0x220f, 0xc415,		0x21, 0
	.dw 0x2211, 0xc415,	0x2211, 0xc415,		0x21, 0
	.dw 0x2213, 0xc415,	0x223f, 0xc415,		0x21, 0
	.dw 0x2240, 0xc415,	0x2240, 0xc415,		0x22, 0
	.dw 0x2241, 0xc415,	0x2241, 0xc415,		0x21, 0
	.dw 0x2242, 0xc415,	0x2242, 0xc415,		0x22, 0
	.dw 0x2243, 0xc415,	0x224f, 0xc415,		0x21, 0
	.dw 0x2250, 0xc415,	0x2250, 0xc415,		0x22, 0
	.dw 0x2251, 0xc415,	0x2251, 0xc415,		0x21, 0
	.dw 0x2252, 0xc415,	0x2252, 0xc415,		0x22, 0
	.dw 0x2253, 0xc415,	0x227f, 0xc415,		0x21, 0
	.dw 0x2281, 0xc415,	0x2281, 0xc415,		0x21, 0
	.dw 0x2283, 0xc415,	0x228f, 0xc415,		0x21, 0
	.dw 0x2291, 0xc415,	0x2291, 0xc415,		0x21, 0
	.dw 0x2293, 0xc415,	0x22bf, 0xc415,		0x21, 0
	.dw 0x22c1, 0xc415,	0x22c1, 0xc415,		0x21, 0
	.dw 0x22c3, 0xc415,	0x22cf, 0xc415,		0x21, 0
	.dw 0x22d1, 0xc415,	0x22d1, 0xc415,		0x21, 0
	.dw 0x22d3, 0xc415,	0x22ff, 0xc415,		0x21, 0
	.dw 0x2301, 0xc415,	0x2301, 0xc415,		0x21, 0
	.dw 0x2303, 0xc415,	0x230f, 0xc415,		0x21, 0
	.dw 0x2311, 0xc415,	0x2311, 0xc415,		0x21, 0
	.dw 0x2313, 0xc415,	0x233f, 0xc415,		0x21, 0
	.dw 0x2341, 0xc415,	0x2341, 0xc415,		0x21, 0
	.dw 0x2343, 0xc415,	0x234f, 0xc415,		0x21, 0
	.dw 0x2351, 0xc415,	0x2351, 0xc415,		0x21, 0
	.dw 0x2353, 0xc415,	0x237f, 0xc415,		0x21, 0
	.dw 0x2381, 0xc415,	0x2381, 0xc415,		0x21, 0
	.dw 0x2383, 0xc415,	0x238f, 0xc415,		0x21, 0
	.dw 0x2391, 0xc415,	0x2391, 0xc415,		0x21, 0
	.dw 0x2393, 0xc415,	0x23bf, 0xc415,		0x21, 0
	.dw 0x23c1, 0xc415,	0x23c1, 0xc415,		0x21, 0
	.dw 0x23c3, 0xc415,	0x23cf, 0xc415,		0x21, 0
	.dw 0x23d1, 0xc415,	0x23d1, 0xc415,		0x21, 0
	.dw 0x23d3, 0xc415,	0x23ff, 0xc415,		0x21, 0
	.dw 0x2401, 0xc415,	0x2401, 0xc415,		0x21, 0
	.dw 0x2403, 0xc415,	0x240f, 0xc415,		0x21, 0
	.dw 0x2411, 0xc415,	0x2411, 0xc415,		0x21, 0
	.dw 0x2413, 0xc415,	0x243f, 0xc415,		0x21, 0
	.dw 0x2441, 0xc415,	0x2441, 0xc415,		0x21, 0
	.dw 0x2443, 0xc415,	0x244f, 0xc415,		0x21, 0
	.dw 0x2451, 0xc415,	0x2451, 0xc415,		0x21, 0
	.dw 0x2453, 0xc415,	0x247f, 0xc415,		0x21, 0
	.dw 0x2480, 0xc415,	0x2480, 0xc415,		0x22, 0
	.dw 0x2481, 0xc415,	0x2481, 0xc415,		0x21, 0
	.dw 0x2482, 0xc415,	0x2482, 0xc415,		0x22, 0
	.dw 0x2483, 0xc415,	0x248f, 0xc415,		0x21, 0
	.dw 0x2490, 0xc415,	0x2490, 0xc415,		0x22, 0
	.dw 0x2491, 0xc415,	0x2491, 0xc415,		0x21, 0
	.dw 0x2492, 0xc415,	0x2492, 0xc415,		0x22, 0
	.dw 0x2493, 0xc415,	0x24bf, 0xc415,		0x21, 0
	.dw 0x24c1, 0xc415,	0x24c1, 0xc415,		0x21, 0
	.dw 0x24c3, 0xc415,	0x24cf, 0xc415,		0x21, 0
	.dw 0x24d1, 0xc415,	0x24d1, 0xc415,		0x21, 0
	.dw 0x24d3, 0xc415,	0x24ff, 0xc415,		0x21, 0
	.dw 0x2501, 0xc415,	0x2501, 0xc415,		0x21, 0
	.dw 0x2503, 0xc415,	0x250f, 0xc415,		0x21, 0
	.dw 0x2511, 0xc415,	0x2511, 0xc415,		0x21, 0
	.dw 0x2513, 0xc415,	0x253f, 0xc415,		0x21, 0
	.dw 0x2541, 0xc415,	0x2541, 0xc415,		0x21, 0
	.dw 0x2543, 0xc415,	0x254f, 0xc415,		0x21, 0
	.dw 0x2551, 0xc415,	0x2551, 0xc415,		0x21, 0
	.dw 0x2553, 0xc415,	0x257f, 0xc415,		0x21, 0
	.dw 0x2581, 0xc415,	0x2581, 0xc415,		0x21, 0
	.dw 0x2583, 0xc415,	0x258f, 0xc415,		0x21, 0
	.dw 0x2591, 0xc415,	0x2591, 0xc415,		0x21, 0
	.dw 0x2593, 0xc415,	0x25bf, 0xc415,		0x21, 0
	.dw 0x25c1, 0xc415,	0x25c1, 0xc415,		0x21, 0
	.dw 0x25c3, 0xc415,	0x25cf, 0xc415,		0x21, 0
	.dw 0x25d1, 0xc415,	0x25d1, 0xc415,		0x21, 0
	.dw 0x25d3, 0xc415,	0x25ff, 0xc415,		0x21, 0
	.dw 0x2601, 0xc415,	0x2601, 0xc415,		0x21, 0
	.dw 0x2603, 0xc415,	0x260f, 0xc415,		0x21, 0
	.dw 0x2611, 0xc415,	0x2611, 0xc415,		0x21, 0
	.dw 0x2613, 0xc415,	0x263f, 0xc415,		0x21, 0
	.dw 0x2641, 0xc415,	0x2641, 0xc415,		0x21, 0
	.dw 0x2643, 0xc415,	0x264f, 0xc415,		0x21, 0
	.dw 0x2651, 0xc415,	0x2651, 0xc415,		0x21, 0
	.dw 0x2653, 0xc415,	0x267f, 0xc415,		0x21, 0
	.dw 0x2681, 0xc415,	0x2681, 0xc415,		0x21, 0
	.dw 0x2683, 0xc415,	0x268f, 0xc415,		0x21, 0
	.dw 0x2691, 0xc415,	0x2691, 0xc415,		0x21, 0
	.dw 0x2693, 0xc415,	0x26bf, 0xc415,		0x21, 0
	.dw 0x26c0, 0xc415,	0x26c0, 0xc415,		0x22, 0
	.dw 0x26c1, 0xc415,	0x26c1, 0xc415,		0x21, 0
	.dw 0x26c2, 0xc415,	0x26c2, 0xc415,		0x22, 0
	.dw 0x26c3, 0xc415,	0x26cf, 0xc415,		0x21, 0
	.dw 0x26d0, 0xc415,	0x26d0, 0xc415,		0x22, 0
	.dw 0x26d1, 0xc415,	0x26d1, 0xc415,		0x21, 0
	.dw 0x26d2, 0xc415,	0x26d2, 0xc415,		0x22, 0
	.dw 0x26d3, 0xc415,	0x26ff, 0xc415,		0x21, 0
	.dw 0x2701, 0xc415,	0x2701, 0xc415,		0x21, 0
	.dw 0x2703, 0xc415,	0x270f, 0xc415,		0x21, 0
	.dw 0x2711, 0xc415,	0x2711, 0xc415,		0x21, 0
	.dw 0x2713, 0xc415,	0x273f, 0xc415,		0x21, 0
	.dw 0x2741, 0xc415,	0x2741, 0xc415,		0x21, 0
	.dw 0x2743, 0xc415,	0x274f, 0xc415,		0x21, 0
	.dw 0x2751, 0xc415,	0x2751, 0xc415,		0x21, 0
	.dw 0x2753, 0xc415,	0x277f, 0xc415,		0x21, 0
	.dw 0x2781, 0xc415,	0x2781, 0xc415,		0x21, 0
	.dw 0x2783, 0xc415,	0x278f, 0xc415,		0x21, 0
	.dw 0x2791, 0xc415,	0x2791, 0xc415,		0x21, 0
	.dw 0x2793, 0xc415,	0x27bf, 0xc415,		0x21, 0
	.dw 0x27c1, 0xc415,	0x27c1, 0xc415,		0x21, 0
	.dw 0x27c3, 0xc415,	0x27cf, 0xc415,		0x21, 0
	.dw 0x27d1, 0xc415,	0x27d1, 0xc415,		0x21, 0
	.dw 0x27d3, 0xc415,	0x27ff, 0xc415,		0x21, 0
	.dw 0x2801, 0xc415,	0x2801, 0xc415,		0x21, 0
	.dw 0x2803, 0xc415,	0x280f, 0xc415,		0x21, 0
	.dw 0x2811, 0xc415,	0x2811, 0xc415,		0x21, 0
	.dw 0x2813, 0xc415,	0x283f, 0xc415,		0x21, 0
	.dw 0x2841, 0xc415,	0x2841, 0xc415,		0x21, 0
	.dw 0x2843, 0xc415,	0x284f, 0xc415,		0x21, 0
	.dw 0x2851, 0xc415,	0x2851, 0xc415,		0x21, 0
	.dw 0x2853, 0xc415,	0x287f, 0xc415,		0x21, 0
	.dw 0x2881, 0xc415,	0x2881, 0xc415,		0x21, 0
	.dw 0x2883, 0xc415,	0x288f, 0xc415,		0x21, 0
	.dw 0x2891, 0xc415,	0x2891, 0xc415,		0x21, 0
	.dw 0x2893, 0xc415,	0x28bf, 0xc415,		0x21, 0
	.dw 0x28c1, 0xc415,	0x28c1, 0xc415,		0x21, 0
	.dw 0x28c3, 0xc415,	0x28cf, 0xc415,		0x21, 0
	.dw 0x28d1, 0xc415,	0x28d1, 0xc415,		0x21, 0
	.dw 0x28d3, 0xc415,	0x28ff, 0xc415,		0x21, 0
	.dw 0x2900, 0xc415,	0x2900, 0xc415,		0x22, 0
	.dw 0x2901, 0xc415,	0x2901, 0xc415,		0x21, 0
	.dw 0x2902, 0xc415,	0x2902, 0xc415,		0x22, 0
	.dw 0x2903, 0xc415,	0x290f, 0xc415,		0x21, 0
	.dw 0x2910, 0xc415,	0x2910, 0xc415,		0x22, 0
	.dw 0x2911, 0xc415,	0x2911, 0xc415,		0x21, 0
	.dw 0x2912, 0xc415,	0x2912, 0xc415,		0x22, 0
	.dw 0x2913, 0xc415,	0x293f, 0xc415,		0x21, 0
	.dw 0x2941, 0xc415,	0x2941, 0xc415,		0x21, 0
	.dw 0x2943, 0xc415,	0x294f, 0xc415,		0x21, 0
	.dw 0x2951, 0xc415,	0x2951, 0xc415,		0x21, 0
	.dw 0x2953, 0xc415,	0x297f, 0xc415,		0x21, 0
	.dw 0x2981, 0xc415,	0x2981, 0xc415,		0x21, 0
	.dw 0x2983, 0xc415,	0x298f, 0xc415,		0x21, 0
	.dw 0x2991, 0xc415,	0x2991, 0xc415,		0x21, 0
	.dw 0x2993, 0xc415,	0x29bf, 0xc415,		0x21, 0
	.dw 0x29c1, 0xc415,	0x29c1, 0xc415,		0x21, 0
	.dw 0x29c3, 0xc415,	0x29cf, 0xc415,		0x21, 0
	.dw 0x29d1, 0xc415,	0x29d1, 0xc415,		0x21, 0
	.dw 0x29d3, 0xc415,	0x29ff, 0xc415,		0x21, 0
	.dw 0x2a01, 0xc415,	0x2a01, 0xc415,		0x21, 0
	.dw 0x2a03, 0xc415,	0x2a0f, 0xc415,		0x21, 0
	.dw 0x2a11, 0xc415,	0x2a11, 0xc415,		0x21, 0
	.dw 0x2a13, 0xc415,	0x2a3f, 0xc415,		0x21, 0
	.dw 0x2a41, 0xc415,	0x2a41, 0xc415,		0x21, 0
	.dw 0x2a43, 0xc415,	0x2a4f, 0xc415,		0x21, 0
	.dw 0x2a51, 0xc415,	0x2a51, 0xc415,		0x21, 0
	.dw 0x2a53, 0xc415,	0x2a7f, 0xc415,		0x21, 0
	.dw 0x2a81, 0xc415,	0x2a81, 0xc415,		0x21, 0
	.dw 0x2a83, 0xc415,	0x2a8f, 0xc415,		0x21, 0
	.dw 0x2a91, 0xc415,	0x2a91, 0xc415,		0x21, 0
	.dw 0x2a93, 0xc415,	0x2abf, 0xc415,		0x21, 0
	.dw 0x2ac1, 0xc415,	0x2ac1, 0xc415,		0x21, 0
	.dw 0x2ac3, 0xc415,	0x2acf, 0xc415,		0x21, 0
	.dw 0x2ad1, 0xc415,	0x2ad1, 0xc415,		0x21, 0
	.dw 0x2ad3, 0xc415,	0x2aff, 0xc415,		0x21, 0
	.dw 0x2b01, 0xc415,	0x2b01, 0xc415,		0x21, 0
	.dw 0x2b03, 0xc415,	0x2b0f, 0xc415,		0x21, 0
	.dw 0x2b11, 0xc415,	0x2b11, 0xc415,		0x21, 0
	.dw 0x2b13, 0xc415,	0x2b3f, 0xc415,		0x21, 0
	.dw 0x2b40, 0xc415,	0x2b40, 0xc415,		0x22, 0
	.dw 0x2b41, 0xc415,	0x2b41, 0xc415,		0x21, 0
	.dw 0x2b42, 0xc415,	0x2b42, 0xc415,		0x22, 0
	.dw 0x2b43, 0xc415,	0x2b4f, 0xc415,		0x21, 0
	.dw 0x2b50, 0xc415,	0x2b50, 0xc415,		0x22, 0
	.dw 0x2b51, 0xc415,	0x2b51, 0xc415,		0x21, 0
	.dw 0x2b52, 0xc415,	0x2b52, 0xc415,		0x22, 0
	.dw 0x2b53, 0xc415,	0x2b7f, 0xc415,		0x21, 0
	.dw 0x2b81, 0xc415,	0x2b81, 0xc415,		0x21, 0
	.dw 0x2b83, 0xc415,	0x2b8f, 0xc415,		0x21, 0
	.dw 0x2b91, 0xc415,	0x2b91, 0xc415,		0x21, 0
	.dw 0x2b93, 0xc415,	0x2bbf, 0xc415,		0x21, 0
	.dw 0x2bc1, 0xc415,	0x2bc1, 0xc415,		0x21, 0
	.dw 0x2bc3, 0xc415,	0x2bcf, 0xc415,		0x21, 0
	.dw 0x2bd1, 0xc415,	0x2bd1, 0xc415,		0x21, 0
	.dw 0x2bd3, 0xc415,	0x2bff, 0xc415,		0x21, 0
	.dw 0x2c01, 0xc415,	0x2c01, 0xc415,		0x21, 0
	.dw 0x2c03, 0xc415,	0x2c0f, 0xc415,		0x21, 0
	.dw 0x2c11, 0xc415,	0x2c11, 0xc415,		0x21, 0
	.dw 0x2c13, 0xc415,	0x2c3f, 0xc415,		0x21, 0
	.dw 0x2c41, 0xc415,	0x2c41, 0xc415,		0x21, 0
	.dw 0x2c43, 0xc415,	0x2c4f, 0xc415,		0x21, 0
	.dw 0x2c51, 0xc415,	0x2c51, 0xc415,		0x21, 0
	.dw 0x2c53, 0xc415,	0x2c7f, 0xc415,		0x21, 0
	.dw 0x2c81, 0xc415,	0x2c81, 0xc415,		0x21, 0
	.dw 0x2c83, 0xc415,	0x2c8f, 0xc415,		0x21, 0
	.dw 0x2c91, 0xc415,	0x2c91, 0xc415,		0x21, 0
	.dw 0x2c93, 0xc415,	0x2cbf, 0xc415,		0x21, 0
	.dw 0x2cc1, 0xc415,	0x2cc1, 0xc415,		0x21, 0
	.dw 0x2cc3, 0xc415,	0x2ccf, 0xc415,		0x21, 0
	.dw 0x2cd1, 0xc415,	0x2cd1, 0xc415,		0x21, 0
	.dw 0x2cd3, 0xc415,	0x2cff, 0xc415,		0x21, 0
	.dw 0x2d01, 0xc415,	0x2d01, 0xc415,		0x21, 0
	.dw 0x2d03, 0xc415,	0x2d0f, 0xc415,		0x21, 0
	.dw 0x2d11, 0xc415,	0x2d11, 0xc415,		0x21, 0
	.dw 0x2d13, 0xc415,	0x2d3f, 0xc415,		0x21, 0
	.dw 0x2d41, 0xc415,	0x2d41, 0xc415,		0x21, 0
	.dw 0x2d43, 0xc415,	0x2d4f, 0xc415,		0x21, 0
	.dw 0x2d51, 0xc415,	0x2d51, 0xc415,		0x21, 0
	.dw 0x2d53, 0xc415,	0x2d7f, 0xc415,		0x21, 0
	.dw 0x2d80, 0xc415,	0x2d80, 0xc415,		0x22, 0
	.dw 0x2d81, 0xc415,	0x2d81, 0xc415,		0x21, 0
	.dw 0x2d82, 0xc415,	0x2d82, 0xc415,		0x22, 0
	.dw 0x2d83, 0xc415,	0x2d8f, 0xc415,		0x21, 0
	.dw 0x2d90, 0xc415,	0x2d90, 0xc415,		0x22, 0
	.dw 0x2d91, 0xc415,	0x2d91, 0xc415,		0x21, 0
	.dw 0x2d92, 0xc415,	0x2d92, 0xc415,		0x22, 0
	.dw 0x2d93, 0xc415,	0x2dbf, 0xc415,		0x21, 0
	.dw 0x2dc1, 0xc415,	0x2dc1, 0xc415,		0x21, 0
	.dw 0x2dc3, 0xc415,	0x2dcf, 0xc415,		0x21, 0
	.dw 0x2dd1, 0xc415,	0x2dd1, 0xc415,		0x21, 0
	.dw 0x2dd3, 0xc415,	0x2dff, 0xc415,		0x21, 0
	.dw 0x2e01, 0xc415,	0x2e01, 0xc415,		0x21, 0
	.dw 0x2e03, 0xc415,	0x2e0f, 0xc415,		0x21, 0
	.dw 0x2e11, 0xc415,	0x2e11, 0xc415,		0x21, 0
	.dw 0x2e13, 0xc415,	0x2e3f, 0xc415,		0x21, 0
	.dw 0x2e41, 0xc415,	0x2e41, 0xc415,		0x21, 0
	.dw 0x2e43, 0xc415,	0x2e4f, 0xc415,		0x21, 0
	.dw 0x2e51, 0xc415,	0x2e51, 0xc415,		0x21, 0
	.dw 0x2e53, 0xc415,	0x2e7f, 0xc415,		0x21, 0
	.dw 0x2e81, 0xc415,	0x2e81, 0xc415,		0x21, 0
	.dw 0x2e83, 0xc415,	0x2e8f, 0xc415,		0x21, 0
	.dw 0x2e91, 0xc415,	0x2e91, 0xc415,		0x21, 0
	.dw 0x2e93, 0xc415,	0x2ebf, 0xc415,		0x21, 0
	.dw 0x2ec1, 0xc415,	0x2ec1, 0xc415,		0x21, 0
	.dw 0x2ec3, 0xc415,	0x2ecf, 0xc415,		0x21, 0
	.dw 0x2ed1, 0xc415,	0x2ed1, 0xc415,		0x21, 0
	.dw 0x2ed3, 0xc415,	0x2eff, 0xc415,		0x21, 0
	.dw 0x2f01, 0xc415,	0x2f01, 0xc415,		0x21, 0
	.dw 0x2f03, 0xc415,	0x2f0f, 0xc415,		0x21, 0
	.dw 0x2f11, 0xc415,	0x2f11, 0xc415,		0x21, 0
	.dw 0x2f13, 0xc415,	0x2f3f, 0xc415,		0x21, 0
	.dw 0x2f41, 0xc415,	0x2f41, 0xc415,		0x21, 0
	.dw 0x2f43, 0xc415,	0x2f4f, 0xc415,		0x21, 0
	.dw 0x2f51, 0xc415,	0x2f51, 0xc415,		0x21, 0
	.dw 0x2f53, 0xc415,	0x2f7f, 0xc415,		0x21, 0
	.dw 0x2f81, 0xc415,	0x2f81, 0xc415,		0x21, 0
	.dw 0x2f83, 0xc415,	0x2f8f, 0xc415,		0x21, 0
	.dw 0x2f91, 0xc415,	0x2f91, 0xc415,		0x21, 0
	.dw 0x2f93, 0xc415,	0x2fbf, 0xc415,		0x21, 0
	.dw 0x2fc0, 0xc415,	0x2fc0, 0xc415,		0x22, 0
	.dw 0x2fc1, 0xc415,	0x2fc1, 0xc415,		0x21, 0
	.dw 0x2fc2, 0xc415,	0x2fc2, 0xc415,		0x22, 0
	.dw 0x2fc3, 0xc415,	0x2fcf, 0xc415,		0x21, 0
	.dw 0x2fd0, 0xc415,	0x2fd0, 0xc415,		0x22, 0
	.dw 0x2fd1, 0xc415,	0x2fd1, 0xc415,		0x21, 0
	.dw 0x2fd2, 0xc415,	0x2fd2, 0xc415,		0x22, 0
	.dw 0x2fd3, 0xc415,	0x3fff, 0xc415,		0x21, 0
	.dw 0x4000, 0xc415,	0x4000, 0xc415,		0x22, 0
	.dw 0x4001, 0xc415,	0x4001, 0xc415,		0x21, 0
	.dw 0x4002, 0xc415,	0x4002, 0xc415,		0x22, 0
	.dw 0x4003, 0xc415,	0x400f, 0xc415,		0x21, 0
	.dw 0x4010, 0xc415,	0x4010, 0xc415,		0x22, 0
	.dw 0x4011, 0xc415,	0x4011, 0xc415,		0x21, 0
	.dw 0x4012, 0xc415,	0x4012, 0xc415,		0x22, 0
	.dw 0x4013, 0xc415,	0x403f, 0xc415,		0x21, 0
	.dw 0x4041, 0xc415,	0x4041, 0xc415,		0x21, 0
	.dw 0x4043, 0xc415,	0x404f, 0xc415,		0x21, 0
	.dw 0x4051, 0xc415,	0x4051, 0xc415,		0x21, 0
	.dw 0x4053, 0xc415,	0x407f, 0xc415,		0x21, 0
	.dw 0x4081, 0xc415,	0x4081, 0xc415,		0x21, 0
	.dw 0x4083, 0xc415,	0x408f, 0xc415,		0x21, 0
	.dw 0x4091, 0xc415,	0x4091, 0xc415,		0x21, 0
	.dw 0x4093, 0xc415,	0x40bf, 0xc415,		0x21, 0
	.dw 0x40c1, 0xc415,	0x40c1, 0xc415,		0x21, 0
	.dw 0x40c3, 0xc415,	0x40cf, 0xc415,		0x21, 0
	.dw 0x40d1, 0xc415,	0x40d1, 0xc415,		0x21, 0
	.dw 0x40d3, 0xc415,	0x40ff, 0xc415,		0x21, 0
	.dw 0x4101, 0xc415,	0x4101, 0xc415,		0x21, 0
	.dw 0x4103, 0xc415,	0x410f, 0xc415,		0x21, 0
	.dw 0x4111, 0xc415,	0x4111, 0xc415,		0x21, 0
	.dw 0x4113, 0xc415,	0x413f, 0xc415,		0x21, 0
	.dw 0x4141, 0xc415,	0x4141, 0xc415,		0x21, 0
	.dw 0x4143, 0xc415,	0x414f, 0xc415,		0x21, 0
	.dw 0x4151, 0xc415,	0x4151, 0xc415,		0x21, 0
	.dw 0x4153, 0xc415,	0x417f, 0xc415,		0x21, 0
	.dw 0x4181, 0xc415,	0x4181, 0xc415,		0x21, 0
	.dw 0x4183, 0xc415,	0x418f, 0xc415,		0x21, 0
	.dw 0x4191, 0xc415,	0x4191, 0xc415,		0x21, 0
	.dw 0x4193, 0xc415,	0x41bf, 0xc415,		0x21, 0
	.dw 0x41c1, 0xc415,	0x41c1, 0xc415,		0x21, 0
	.dw 0x41c3, 0xc415,	0x41cf, 0xc415,		0x21, 0
	.dw 0x41d1, 0xc415,	0x41d1, 0xc415,		0x21, 0
	.dw 0x41d3, 0xc415,	0x41ff, 0xc415,		0x21, 0
	.dw 0x4201, 0xc415,	0x4201, 0xc415,		0x21, 0
	.dw 0x4203, 0xc415,	0x420f, 0xc415,		0x21, 0
	.dw 0x4211, 0xc415,	0x4211, 0xc415,		0x21, 0
	.dw 0x4213, 0xc415,	0x423f, 0xc415,		0x21, 0
	.dw 0x4240, 0xc415,	0x4240, 0xc415,		0x22, 0
	.dw 0x4241, 0xc415,	0x4241, 0xc415,		0x21, 0
	.dw 0x4242, 0xc415,	0x4242, 0xc415,		0x22, 0
	.dw 0x4243, 0xc415,	0x424f, 0xc415,		0x21, 0
	.dw 0x4250, 0xc415,	0x4250, 0xc415,		0x22, 0
	.dw 0x4251, 0xc415,	0x4251, 0xc415,		0x21, 0
	.dw 0x4252, 0xc415,	0x4252, 0xc415,		0x22, 0
	.dw 0x4253, 0xc415,	0x427f, 0xc415,		0x21, 0
	.dw 0x4281, 0xc415,	0x4281, 0xc415,		0x21, 0
	.dw 0x4283, 0xc415,	0x428f, 0xc415,		0x21, 0
	.dw 0x4291, 0xc415,	0x4291, 0xc415,		0x21, 0
	.dw 0x4293, 0xc415,	0x42bf, 0xc415,		0x21, 0
	.dw 0x42c1, 0xc415,	0x42c1, 0xc415,		0x21, 0
	.dw 0x42c3, 0xc415,	0x42cf, 0xc415,		0x21, 0
	.dw 0x42d1, 0xc415,	0x42d1, 0xc415,		0x21, 0
	.dw 0x42d3, 0xc415,	0x42ff, 0xc415,		0x21, 0
	.dw 0x4301, 0xc415,	0x4301, 0xc415,		0x21, 0
	.dw 0x4303, 0xc415,	0x430f, 0xc415,		0x21, 0
	.dw 0x4311, 0xc415,	0x4311, 0xc415,		0x21, 0
	.dw 0x4313, 0xc415,	0x433f, 0xc415,		0x21, 0
	.dw 0x4341, 0xc415,	0x4341, 0xc415,		0x21, 0
	.dw 0x4343, 0xc415,	0x434f, 0xc415,		0x21, 0
	.dw 0x4351, 0xc415,	0x4351, 0xc415,		0x21, 0
	.dw 0x4353, 0xc415,	0x437f, 0xc415,		0x21, 0
	.dw 0x4381, 0xc415,	0x4381, 0xc415,		0x21, 0
	.dw 0x4383, 0xc415,	0x438f, 0xc415,		0x21, 0
	.dw 0x4391, 0xc415,	0x4391, 0xc415,		0x21, 0
	.dw 0x4393, 0xc415,	0x43bf, 0xc415,		0x21, 0
	.dw 0x43c1, 0xc415,	0x43c1, 0xc415,		0x21, 0
	.dw 0x43c3, 0xc415,	0x43cf, 0xc415,		0x21, 0
	.dw 0x43d1, 0xc415,	0x43d1, 0xc415,		0x21, 0
	.dw 0x43d3, 0xc415,	0x43ff, 0xc415,		0x21, 0
	.dw 0x4401, 0xc415,	0x4401, 0xc415,		0x21, 0
	.dw 0x4403, 0xc415,	0x440f, 0xc415,		0x21, 0
	.dw 0x4411, 0xc415,	0x4411, 0xc415,		0x21, 0
	.dw 0x4413, 0xc415,	0x443f, 0xc415,		0x21, 0
	.dw 0x4441, 0xc415,	0x4441, 0xc415,		0x21, 0
	.dw 0x4443, 0xc415,	0x444f, 0xc415,		0x21, 0
	.dw 0x4451, 0xc415,	0x4451, 0xc415,		0x21, 0
	.dw 0x4453, 0xc415,	0x447f, 0xc415,		0x21, 0
	.dw 0x4480, 0xc415,	0x4480, 0xc415,		0x22, 0
	.dw 0x4481, 0xc415,	0x4481, 0xc415,		0x21, 0
	.dw 0x4482, 0xc415,	0x4482, 0xc415,		0x22, 0
	.dw 0x4483, 0xc415,	0x448f, 0xc415,		0x21, 0
	.dw 0x4490, 0xc415,	0x4490, 0xc415,		0x22, 0
	.dw 0x4491, 0xc415,	0x4491, 0xc415,		0x21, 0
	.dw 0x4492, 0xc415,	0x4492, 0xc415,		0x22, 0
	.dw 0x4493, 0xc415,	0x44bf, 0xc415,		0x21, 0
	.dw 0x44c1, 0xc415,	0x44c1, 0xc415,		0x21, 0
	.dw 0x44c3, 0xc415,	0x44cf, 0xc415,		0x21, 0
	.dw 0x44d1, 0xc415,	0x44d1, 0xc415,		0x21, 0
	.dw 0x44d3, 0xc415,	0x44ff, 0xc415,		0x21, 0
	.dw 0x4501, 0xc415,	0x4501, 0xc415,		0x21, 0
	.dw 0x4503, 0xc415,	0x450f, 0xc415,		0x21, 0
	.dw 0x4511, 0xc415,	0x4511, 0xc415,		0x21, 0
	.dw 0x4513, 0xc415,	0x453f, 0xc415,		0x21, 0
	.dw 0x4541, 0xc415,	0x4541, 0xc415,		0x21, 0
	.dw 0x4543, 0xc415,	0x454f, 0xc415,		0x21, 0
	.dw 0x4551, 0xc415,	0x4551, 0xc415,		0x21, 0
	.dw 0x4553, 0xc415,	0x457f, 0xc415,		0x21, 0
	.dw 0x4581, 0xc415,	0x4581, 0xc415,		0x21, 0
	.dw 0x4583, 0xc415,	0x458f, 0xc415,		0x21, 0
	.dw 0x4591, 0xc415,	0x4591, 0xc415,		0x21, 0
	.dw 0x4593, 0xc415,	0x45bf, 0xc415,		0x21, 0
	.dw 0x45c1, 0xc415,	0x45c1, 0xc415,		0x21, 0
	.dw 0x45c3, 0xc415,	0x45cf, 0xc415,		0x21, 0
	.dw 0x45d1, 0xc415,	0x45d1, 0xc415,		0x21, 0
	.dw 0x45d3, 0xc415,	0x45ff, 0xc415,		0x21, 0
	.dw 0x4601, 0xc415,	0x4601, 0xc415,		0x21, 0
	.dw 0x4603, 0xc415,	0x460f, 0xc415,		0x21, 0
	.dw 0x4611, 0xc415,	0x4611, 0xc415,		0x21, 0
	.dw 0x4613, 0xc415,	0x463f, 0xc415,		0x21, 0
	.dw 0x4641, 0xc415,	0x4641, 0xc415,		0x21, 0
	.dw 0x4643, 0xc415,	0x464f, 0xc415,		0x21, 0
	.dw 0x4651, 0xc415,	0x4651, 0xc415,		0x21, 0
	.dw 0x4653, 0xc415,	0x467f, 0xc415,		0x21, 0
	.dw 0x4681, 0xc415,	0x4681, 0xc415,		0x21, 0
	.dw 0x4683, 0xc415,	0x468f, 0xc415,		0x21, 0
	.dw 0x4691, 0xc415,	0x4691, 0xc415,		0x21, 0
	.dw 0x4693, 0xc415,	0x46bf, 0xc415,		0x21, 0
	.dw 0x46c0, 0xc415,	0x46c0, 0xc415,		0x22, 0
	.dw 0x46c1, 0xc415,	0x46c1, 0xc415,		0x21, 0
	.dw 0x46c2, 0xc415,	0x46c2, 0xc415,		0x22, 0
	.dw 0x46c3, 0xc415,	0x46cf, 0xc415,		0x21, 0
	.dw 0x46d0, 0xc415,	0x46d0, 0xc415,		0x22, 0
	.dw 0x46d1, 0xc415,	0x46d1, 0xc415,		0x21, 0
	.dw 0x46d2, 0xc415,	0x46d2, 0xc415,		0x22, 0
	.dw 0x46d3, 0xc415,	0x46ff, 0xc415,		0x21, 0
	.dw 0x4701, 0xc415,	0x4701, 0xc415,		0x21, 0
	.dw 0x4703, 0xc415,	0x470f, 0xc415,		0x21, 0
	.dw 0x4711, 0xc415,	0x4711, 0xc415,		0x21, 0
	.dw 0x4713, 0xc415,	0x473f, 0xc415,		0x21, 0
	.dw 0x4741, 0xc415,	0x4741, 0xc415,		0x21, 0
	.dw 0x4743, 0xc415,	0x474f, 0xc415,		0x21, 0
	.dw 0x4751, 0xc415,	0x4751, 0xc415,		0x21, 0
	.dw 0x4753, 0xc415,	0x477f, 0xc415,		0x21, 0
	.dw 0x4781, 0xc415,	0x4781, 0xc415,		0x21, 0
	.dw 0x4783, 0xc415,	0x478f, 0xc415,		0x21, 0
	.dw 0x4791, 0xc415,	0x4791, 0xc415,		0x21, 0
	.dw 0x4793, 0xc415,	0x47bf, 0xc415,		0x21, 0
	.dw 0x47c1, 0xc415,	0x47c1, 0xc415,		0x21, 0
	.dw 0x47c3, 0xc415,	0x47cf, 0xc415,		0x21, 0
	.dw 0x47d1, 0xc415,	0x47d1, 0xc415,		0x21, 0
	.dw 0x47d3, 0xc415,	0x47ff, 0xc415,		0x21, 0
	.dw 0x4801, 0xc415,	0x4801, 0xc415,		0x21, 0
	.dw 0x4803, 0xc415,	0x480f, 0xc415,		0x21, 0
	.dw 0x4811, 0xc415,	0x4811, 0xc415,		0x21, 0
	.dw 0x4813, 0xc415,	0x483f, 0xc415,		0x21, 0
	.dw 0x4841, 0xc415,	0x4841, 0xc415,		0x21, 0
	.dw 0x4843, 0xc415,	0x484f, 0xc415,		0x21, 0
	.dw 0x4851, 0xc415,	0x4851, 0xc415,		0x21, 0
	.dw 0x4853, 0xc415,	0x487f, 0xc415,		0x21, 0
	.dw 0x4881, 0xc415,	0x4881, 0xc415,		0x21, 0
	.dw 0x4883, 0xc415,	0x488f, 0xc415,		0x21, 0
	.dw 0x4891, 0xc415,	0x4891, 0xc415,		0x21, 0
	.dw 0x4893, 0xc415,	0x48bf, 0xc415,		0x21, 0
	.dw 0x48c1, 0xc415,	0x48c1, 0xc415,		0x21, 0
	.dw 0x48c3, 0xc415,	0x48cf, 0xc415,		0x21, 0
	.dw 0x48d1, 0xc415,	0x48d1, 0xc415,		0x21, 0
	.dw 0x48d3, 0xc415,	0x48ff, 0xc415,		0x21, 0
	.dw 0x4900, 0xc415,	0x4900, 0xc415,		0x22, 0
	.dw 0x4901, 0xc415,	0x4901, 0xc415,		0x21, 0
	.dw 0x4902, 0xc415,	0x4902, 0xc415,		0x22, 0
	.dw 0x4903, 0xc415,	0x490f, 0xc415,		0x21, 0
	.dw 0x4910, 0xc415,	0x4910, 0xc415,		0x22, 0
	.dw 0x4911, 0xc415,	0x4911, 0xc415,		0x21, 0
	.dw 0x4912, 0xc415,	0x4912, 0xc415,		0x22, 0
	.dw 0x4913, 0xc415,	0x493f, 0xc415,		0x21, 0
	.dw 0x4941, 0xc415,	0x4941, 0xc415,		0x21, 0
	.dw 0x4943, 0xc415,	0x494f, 0xc415,		0x21, 0
	.dw 0x4951, 0xc415,	0x4951, 0xc415,		0x21, 0
	.dw 0x4953, 0xc415,	0x497f, 0xc415,		0x21, 0
	.dw 0x4981, 0xc415,	0x4981, 0xc415,		0x21, 0
	.dw 0x4983, 0xc415,	0x498f, 0xc415,		0x21, 0
	.dw 0x4991, 0xc415,	0x4991, 0xc415,		0x21, 0
	.dw 0x4993, 0xc415,	0x49bf, 0xc415,		0x21, 0
	.dw 0x49c1, 0xc415,	0x49c1, 0xc415,		0x21, 0
	.dw 0x49c3, 0xc415,	0x49cf, 0xc415,		0x21, 0
	.dw 0x49d1, 0xc415,	0x49d1, 0xc415,		0x21, 0
	.dw 0x49d3, 0xc415,	0x49ff, 0xc415,		0x21, 0
	.dw 0x4a01, 0xc415,	0x4a01, 0xc415,		0x21, 0
	.dw 0x4a03, 0xc415,	0x4a0f, 0xc415,		0x21, 0
	.dw 0x4a11, 0xc415,	0x4a11, 0xc415,		0x21, 0
	.dw 0x4a13, 0xc415,	0x4a3f, 0xc415,		0x21, 0
	.dw 0x4a41, 0xc415,	0x4a41, 0xc415,		0x21, 0
	.dw 0x4a43, 0xc415,	0x4a4f, 0xc415,		0x21, 0
	.dw 0x4a51, 0xc415,	0x4a51, 0xc415,		0x21, 0
	.dw 0x4a53, 0xc415,	0x4a7f, 0xc415,		0x21, 0
	.dw 0x4a81, 0xc415,	0x4a81, 0xc415,		0x21, 0
	.dw 0x4a83, 0xc415,	0x4a8f, 0xc415,		0x21, 0
	.dw 0x4a91, 0xc415,	0x4a91, 0xc415,		0x21, 0
	.dw 0x4a93, 0xc415,	0x4abf, 0xc415,		0x21, 0
	.dw 0x4ac1, 0xc415,	0x4ac1, 0xc415,		0x21, 0
	.dw 0x4ac3, 0xc415,	0x4acf, 0xc415,		0x21, 0
	.dw 0x4ad1, 0xc415,	0x4ad1, 0xc415,		0x21, 0
	.dw 0x4ad3, 0xc415,	0x4aff, 0xc415,		0x21, 0
	.dw 0x4b01, 0xc415,	0x4b01, 0xc415,		0x21, 0
	.dw 0x4b03, 0xc415,	0x4b0f, 0xc415,		0x21, 0
	.dw 0x4b11, 0xc415,	0x4b11, 0xc415,		0x21, 0
	.dw 0x4b13, 0xc415,	0x4b3f, 0xc415,		0x21, 0
	.dw 0x4b40, 0xc415,	0x4b40, 0xc415,		0x22, 0
	.dw 0x4b41, 0xc415,	0x4b41, 0xc415,		0x21, 0
	.dw 0x4b42, 0xc415,	0x4b42, 0xc415,		0x22, 0
	.dw 0x4b43, 0xc415,	0x4b4f, 0xc415,		0x21, 0
	.dw 0x4b50, 0xc415,	0x4b50, 0xc415,		0x22, 0
	.dw 0x4b51, 0xc415,	0x4b51, 0xc415,		0x21, 0
	.dw 0x4b52, 0xc415,	0x4b52, 0xc415,		0x22, 0
	.dw 0x4b53, 0xc415,	0x4b7f, 0xc415,		0x21, 0
	.dw 0x4b81, 0xc415,	0x4b81, 0xc415,		0x21, 0
	.dw 0x4b83, 0xc415,	0x4b8f, 0xc415,		0x21, 0
	.dw 0x4b91, 0xc415,	0x4b91, 0xc415,		0x21, 0
	.dw 0x4b93, 0xc415,	0x4bbf, 0xc415,		0x21, 0
	.dw 0x4bc1, 0xc415,	0x4bc1, 0xc415,		0x21, 0
	.dw 0x4bc3, 0xc415,	0x4bcf, 0xc415,		0x21, 0
	.dw 0x4bd1, 0xc415,	0x4bd1, 0xc415,		0x21, 0
	.dw 0x4bd3, 0xc415,	0x4bff, 0xc415,		0x21, 0
	.dw 0x4c01, 0xc415,	0x4c01, 0xc415,		0x21, 0
	.dw 0x4c03, 0xc415,	0x4c0f, 0xc415,		0x21, 0
	.dw 0x4c11, 0xc415,	0x4c11, 0xc415,		0x21, 0
	.dw 0x4c13, 0xc415,	0x4c3f, 0xc415,		0x21, 0
	.dw 0x4c41, 0xc415,	0x4c41, 0xc415,		0x21, 0
	.dw 0x4c43, 0xc415,	0x4c4f, 0xc415,		0x21, 0
	.dw 0x4c51, 0xc415,	0x4c51, 0xc415,		0x21, 0
	.dw 0x4c53, 0xc415,	0x4c7f, 0xc415,		0x21, 0
	.dw 0x4c81, 0xc415,	0x4c81, 0xc415,		0x21, 0
	.dw 0x4c83, 0xc415,	0x4c8f, 0xc415,		0x21, 0
	.dw 0x4c91, 0xc415,	0x4c91, 0xc415,		0x21, 0
	.dw 0x4c93, 0xc415,	0x4cbf, 0xc415,		0x21, 0
	.dw 0x4cc1, 0xc415,	0x4cc1, 0xc415,		0x21, 0
	.dw 0x4cc3, 0xc415,	0x4ccf, 0xc415,		0x21, 0
	.dw 0x4cd1, 0xc415,	0x4cd1, 0xc415,		0x21, 0
	.dw 0x4cd3, 0xc415,	0x4cff, 0xc415,		0x21, 0
	.dw 0x4d01, 0xc415,	0x4d01, 0xc415,		0x21, 0
	.dw 0x4d03, 0xc415,	0x4d0f, 0xc415,		0x21, 0
	.dw 0x4d11, 0xc415,	0x4d11, 0xc415,		0x21, 0
	.dw 0x4d13, 0xc415,	0x4d3f, 0xc415,		0x21, 0
	.dw 0x4d41, 0xc415,	0x4d41, 0xc415,		0x21, 0
	.dw 0x4d43, 0xc415,	0x4d4f, 0xc415,		0x21, 0
	.dw 0x4d51, 0xc415,	0x4d51, 0xc415,		0x21, 0
	.dw 0x4d53, 0xc415,	0x4d7f, 0xc415,		0x21, 0
	.dw 0x4d80, 0xc415,	0x4d80, 0xc415,		0x22, 0
	.dw 0x4d81, 0xc415,	0x4d81, 0xc415,		0x21, 0
	.dw 0x4d82, 0xc415,	0x4d82, 0xc415,		0x22, 0
	.dw 0x4d83, 0xc415,	0x4d8f, 0xc415,		0x21, 0
	.dw 0x4d90, 0xc415,	0x4d90, 0xc415,		0x22, 0
	.dw 0x4d91, 0xc415,	0x4d91, 0xc415,		0x21, 0
	.dw 0x4d92, 0xc415,	0x4d92, 0xc415,		0x22, 0
	.dw 0x4d93, 0xc415,	0x4dbf, 0xc415,		0x21, 0
	.dw 0x4dc1, 0xc415,	0x4dc1, 0xc415,		0x21, 0
	.dw 0x4dc3, 0xc415,	0x4dcf, 0xc415,		0x21, 0
	.dw 0x4dd1, 0xc415,	0x4dd1, 0xc415,		0x21, 0
	.dw 0x4dd3, 0xc415,	0x4dff, 0xc415,		0x21, 0
	.dw 0x4e01, 0xc415,	0x4e01, 0xc415,		0x21, 0
	.dw 0x4e03, 0xc415,	0x4e0f, 0xc415,		0x21, 0
	.dw 0x4e11, 0xc415,	0x4e11, 0xc415,		0x21, 0
	.dw 0x4e13, 0xc415,	0x4e3f, 0xc415,		0x21, 0
	.dw 0x4e41, 0xc415,	0x4e41, 0xc415,		0x21, 0
	.dw 0x4e43, 0xc415,	0x4e4f, 0xc415,		0x21, 0
	.dw 0x4e51, 0xc415,	0x4e51, 0xc415,		0x21, 0
	.dw 0x4e53, 0xc415,	0x4e7f, 0xc415,		0x21, 0
	.dw 0x4e81, 0xc415,	0x4e81, 0xc415,		0x21, 0
	.dw 0x4e83, 0xc415,	0x4e8f, 0xc415,		0x21, 0
	.dw 0x4e91, 0xc415,	0x4e91, 0xc415,		0x21, 0
	.dw 0x4e93, 0xc415,	0x4ebf, 0xc415,		0x21, 0
	.dw 0x4ec1, 0xc415,	0x4ec1, 0xc415,		0x21, 0
	.dw 0x4ec3, 0xc415,	0x4ecf, 0xc415,		0x21, 0
	.dw 0x4ed1, 0xc415,	0x4ed1, 0xc415,		0x21, 0
	.dw 0x4ed3, 0xc415,	0x4eff, 0xc415,		0x21, 0
	.dw 0x4f01, 0xc415,	0x4f01, 0xc415,		0x21, 0
	.dw 0x4f03, 0xc415,	0x4f0f, 0xc415,		0x21, 0
	.dw 0x4f11, 0xc415,	0x4f11, 0xc415,		0x21, 0
	.dw 0x4f13, 0xc415,	0x4f3f, 0xc415,		0x21, 0
	.dw 0x4f41, 0xc415,	0x4f41, 0xc415,		0x21, 0
	.dw 0x4f43, 0xc415,	0x4f4f, 0xc415,		0x21, 0
	.dw 0x4f51, 0xc415,	0x4f51, 0xc415,		0x21, 0
	.dw 0x4f53, 0xc415,	0x4f7f, 0xc415,		0x21, 0
	.dw 0x4f81, 0xc415,	0x4f81, 0xc415,		0x21, 0
	.dw 0x4f83, 0xc415,	0x4f8f, 0xc415,		0x21, 0
	.dw 0x4f91, 0xc415,	0x4f91, 0xc415,		0x21, 0
	.dw 0x4f93, 0xc415,	0x4fbf, 0xc415,		0x21, 0
	.dw 0x4fc0, 0xc415,	0x4fc0, 0xc415,		0x22, 0
	.dw 0x4fc1, 0xc415,	0x4fc1, 0xc415,		0x21, 0
	.dw 0x4fc2, 0xc415,	0x4fc2, 0xc415,		0x22, 0
	.dw 0x4fc3, 0xc415,	0x4fcf, 0xc415,		0x21, 0
	.dw 0x4fd0, 0xc415,	0x4fd0, 0xc415,		0x22, 0
	.dw 0x4fd1, 0xc415,	0x4fd1, 0xc415,		0x21, 0
	.dw 0x4fd2, 0xc415,	0x4fd2, 0xc415,		0x22, 0
	.dw 0x4fd3, 0xc415,	0x5fff, 0xc415,		0x21, 0
	.dw 0x6000, 0xc415,	0x6000, 0xc415,		0x22, 0
	.dw 0x6001, 0xc415,	0x6001, 0xc415,		0x21, 0
	.dw 0x6002, 0xc415,	0x6002, 0xc415,		0x22, 0
	.dw 0x6003, 0xc415,	0x600f, 0xc415,		0x21, 0
	.dw 0x6010, 0xc415,	0x6010, 0xc415,		0x22, 0
	.dw 0x6011, 0xc415,	0x6011, 0xc415,		0x21, 0
	.dw 0x6012, 0xc415,	0x6012, 0xc415,		0x22, 0
	.dw 0x6013, 0xc415,	0x603f, 0xc415,		0x21, 0
	.dw 0x6041, 0xc415,	0x6041, 0xc415,		0x21, 0
	.dw 0x6043, 0xc415,	0x604f, 0xc415,		0x21, 0
	.dw 0x6051, 0xc415,	0x6051, 0xc415,		0x21, 0
	.dw 0x6053, 0xc415,	0x607f, 0xc415,		0x21, 0
	.dw 0x6081, 0xc415,	0x6081, 0xc415,		0x21, 0
	.dw 0x6083, 0xc415,	0x608f, 0xc415,		0x21, 0
	.dw 0x6091, 0xc415,	0x6091, 0xc415,		0x21, 0
	.dw 0x6093, 0xc415,	0x60bf, 0xc415,		0x21, 0
	.dw 0x60c1, 0xc415,	0x60c1, 0xc415,		0x21, 0
	.dw 0x60c3, 0xc415,	0x60cf, 0xc415,		0x21, 0
	.dw 0x60d1, 0xc415,	0x60d1, 0xc415,		0x21, 0
	.dw 0x60d3, 0xc415,	0x60ff, 0xc415,		0x21, 0
	.dw 0x6101, 0xc415,	0x6101, 0xc415,		0x21, 0
	.dw 0x6103, 0xc415,	0x610f, 0xc415,		0x21, 0
	.dw 0x6111, 0xc415,	0x6111, 0xc415,		0x21, 0
	.dw 0x6113, 0xc415,	0x613f, 0xc415,		0x21, 0
	.dw 0x6141, 0xc415,	0x6141, 0xc415,		0x21, 0
	.dw 0x6143, 0xc415,	0x614f, 0xc415,		0x21, 0
	.dw 0x6151, 0xc415,	0x6151, 0xc415,		0x21, 0
	.dw 0x6153, 0xc415,	0x617f, 0xc415,		0x21, 0
	.dw 0x6181, 0xc415,	0x6181, 0xc415,		0x21, 0
	.dw 0x6183, 0xc415,	0x618f, 0xc415,		0x21, 0
	.dw 0x6191, 0xc415,	0x6191, 0xc415,		0x21, 0
	.dw 0x6193, 0xc415,	0x61bf, 0xc415,		0x21, 0
	.dw 0x61c1, 0xc415,	0x61c1, 0xc415,		0x21, 0
	.dw 0x61c3, 0xc415,	0x61cf, 0xc415,		0x21, 0
	.dw 0x61d1, 0xc415,	0x61d1, 0xc415,		0x21, 0
	.dw 0x61d3, 0xc415,	0x61ff, 0xc415,		0x21, 0
	.dw 0x6201, 0xc415,	0x6201, 0xc415,		0x21, 0
	.dw 0x6203, 0xc415,	0x620f, 0xc415,		0x21, 0
	.dw 0x6211, 0xc415,	0x6211, 0xc415,		0x21, 0
	.dw 0x6213, 0xc415,	0x623f, 0xc415,		0x21, 0
	.dw 0x6240, 0xc415,	0x6240, 0xc415,		0x22, 0
	.dw 0x6241, 0xc415,	0x6241, 0xc415,		0x21, 0
	.dw 0x6242, 0xc415,	0x6242, 0xc415,		0x22, 0
	.dw 0x6243, 0xc415,	0x624f, 0xc415,		0x21, 0
	.dw 0x6250, 0xc415,	0x6250, 0xc415,		0x22, 0
	.dw 0x6251, 0xc415,	0x6251, 0xc415,		0x21, 0
	.dw 0x6252, 0xc415,	0x6252, 0xc415,		0x22, 0
	.dw 0x6253, 0xc415,	0x627f, 0xc415,		0x21, 0
	.dw 0x6281, 0xc415,	0x6281, 0xc415,		0x21, 0
	.dw 0x6283, 0xc415,	0x628f, 0xc415,		0x21, 0
	.dw 0x6291, 0xc415,	0x6291, 0xc415,		0x21, 0
	.dw 0x6293, 0xc415,	0x62bf, 0xc415,		0x21, 0
	.dw 0x62c1, 0xc415,	0x62c1, 0xc415,		0x21, 0
	.dw 0x62c3, 0xc415,	0x62cf, 0xc415,		0x21, 0
	.dw 0x62d1, 0xc415,	0x62d1, 0xc415,		0x21, 0
	.dw 0x62d3, 0xc415,	0x62ff, 0xc415,		0x21, 0
	.dw 0x6301, 0xc415,	0x6301, 0xc415,		0x21, 0
	.dw 0x6303, 0xc415,	0x630f, 0xc415,		0x21, 0
	.dw 0x6311, 0xc415,	0x6311, 0xc415,		0x21, 0
	.dw 0x6313, 0xc415,	0x633f, 0xc415,		0x21, 0
	.dw 0x6341, 0xc415,	0x6341, 0xc415,		0x21, 0
	.dw 0x6343, 0xc415,	0x634f, 0xc415,		0x21, 0
	.dw 0x6351, 0xc415,	0x6351, 0xc415,		0x21, 0
	.dw 0x6353, 0xc415,	0x637f, 0xc415,		0x21, 0
	.dw 0x6381, 0xc415,	0x6381, 0xc415,		0x21, 0
	.dw 0x6383, 0xc415,	0x638f, 0xc415,		0x21, 0
	.dw 0x6391, 0xc415,	0x6391, 0xc415,		0x21, 0
	.dw 0x6393, 0xc415,	0x63bf, 0xc415,		0x21, 0
	.dw 0x63c1, 0xc415,	0x63c1, 0xc415,		0x21, 0
	.dw 0x63c3, 0xc415,	0x63cf, 0xc415,		0x21, 0
	.dw 0x63d1, 0xc415,	0x63d1, 0xc415,		0x21, 0
	.dw 0x63d3, 0xc415,	0x63ff, 0xc415,		0x21, 0
	.dw 0x6401, 0xc415,	0x6401, 0xc415,		0x21, 0
	.dw 0x6403, 0xc415,	0x640f, 0xc415,		0x21, 0
	.dw 0x6411, 0xc415,	0x6411, 0xc415,		0x21, 0
	.dw 0x6413, 0xc415,	0x643f, 0xc415,		0x21, 0
	.dw 0x6441, 0xc415,	0x6441, 0xc415,		0x21, 0
	.dw 0x6443, 0xc415,	0x644f, 0xc415,		0x21, 0
	.dw 0x6451, 0xc415,	0x6451, 0xc415,		0x21, 0
	.dw 0x6453, 0xc415,	0x647f, 0xc415,		0x21, 0
	.dw 0x6480, 0xc415,	0x6480, 0xc415,		0x22, 0
	.dw 0x6481, 0xc415,	0x6481, 0xc415,		0x21, 0
	.dw 0x6482, 0xc415,	0x6482, 0xc415,		0x22, 0
	.dw 0x6483, 0xc415,	0x648f, 0xc415,		0x21, 0
	.dw 0x6490, 0xc415,	0x6490, 0xc415,		0x22, 0
	.dw 0x6491, 0xc415,	0x6491, 0xc415,		0x21, 0
	.dw 0x6492, 0xc415,	0x6492, 0xc415,		0x22, 0
	.dw 0x6493, 0xc415,	0x64bf, 0xc415,		0x21, 0
	.dw 0x64c1, 0xc415,	0x64c1, 0xc415,		0x21, 0
	.dw 0x64c3, 0xc415,	0x64cf, 0xc415,		0x21, 0
	.dw 0x64d1, 0xc415,	0x64d1, 0xc415,		0x21, 0
	.dw 0x64d3, 0xc415,	0x64ff, 0xc415,		0x21, 0
	.dw 0x6501, 0xc415,	0x6501, 0xc415,		0x21, 0
	.dw 0x6503, 0xc415,	0x650f, 0xc415,		0x21, 0
	.dw 0x6511, 0xc415,	0x6511, 0xc415,		0x21, 0
	.dw 0x6513, 0xc415,	0x653f, 0xc415,		0x21, 0
	.dw 0x6541, 0xc415,	0x6541, 0xc415,		0x21, 0
	.dw 0x6543, 0xc415,	0x654f, 0xc415,		0x21, 0
	.dw 0x6551, 0xc415,	0x6551, 0xc415,		0x21, 0
	.dw 0x6553, 0xc415,	0x657f, 0xc415,		0x21, 0
	.dw 0x6581, 0xc415,	0x6581, 0xc415,		0x21, 0
	.dw 0x6583, 0xc415,	0x658f, 0xc415,		0x21, 0
	.dw 0x6591, 0xc415,	0x6591, 0xc415,		0x21, 0
	.dw 0x6593, 0xc415,	0x65bf, 0xc415,		0x21, 0
	.dw 0x65c1, 0xc415,	0x65c1, 0xc415,		0x21, 0
	.dw 0x65c3, 0xc415,	0x65cf, 0xc415,		0x21, 0
	.dw 0x65d1, 0xc415,	0x65d1, 0xc415,		0x21, 0
	.dw 0x65d3, 0xc415,	0x65ff, 0xc415,		0x21, 0
	.dw 0x6601, 0xc415,	0x6601, 0xc415,		0x21, 0
	.dw 0x6603, 0xc415,	0x660f, 0xc415,		0x21, 0
	.dw 0x6611, 0xc415,	0x6611, 0xc415,		0x21, 0
	.dw 0x6613, 0xc415,	0x663f, 0xc415,		0x21, 0
	.dw 0x6641, 0xc415,	0x6641, 0xc415,		0x21, 0
	.dw 0x6643, 0xc415,	0x664f, 0xc415,		0x21, 0
	.dw 0x6651, 0xc415,	0x6651, 0xc415,		0x21, 0
	.dw 0x6653, 0xc415,	0x667f, 0xc415,		0x21, 0
	.dw 0x6681, 0xc415,	0x6681, 0xc415,		0x21, 0
	.dw 0x6683, 0xc415,	0x668f, 0xc415,		0x21, 0
	.dw 0x6691, 0xc415,	0x6691, 0xc415,		0x21, 0
	.dw 0x6693, 0xc415,	0x66bf, 0xc415,		0x21, 0
	.dw 0x66c0, 0xc415,	0x66c0, 0xc415,		0x22, 0
	.dw 0x66c1, 0xc415,	0x66c1, 0xc415,		0x21, 0
	.dw 0x66c2, 0xc415,	0x66c2, 0xc415,		0x22, 0
	.dw 0x66c3, 0xc415,	0x66cf, 0xc415,		0x21, 0
	.dw 0x66d0, 0xc415,	0x66d0, 0xc415,		0x22, 0
	.dw 0x66d1, 0xc415,	0x66d1, 0xc415,		0x21, 0
	.dw 0x66d2, 0xc415,	0x66d2, 0xc415,		0x22, 0
	.dw 0x66d3, 0xc415,	0x66ff, 0xc415,		0x21, 0
	.dw 0x6701, 0xc415,	0x6701, 0xc415,		0x21, 0
	.dw 0x6703, 0xc415,	0x670f, 0xc415,		0x21, 0
	.dw 0x6711, 0xc415,	0x6711, 0xc415,		0x21, 0
	.dw 0x6713, 0xc415,	0x673f, 0xc415,		0x21, 0
	.dw 0x6741, 0xc415,	0x6741, 0xc415,		0x21, 0
	.dw 0x6743, 0xc415,	0x674f, 0xc415,		0x21, 0
	.dw 0x6751, 0xc415,	0x6751, 0xc415,		0x21, 0
	.dw 0x6753, 0xc415,	0x677f, 0xc415,		0x21, 0
	.dw 0x6781, 0xc415,	0x6781, 0xc415,		0x21, 0
	.dw 0x6783, 0xc415,	0x678f, 0xc415,		0x21, 0
	.dw 0x6791, 0xc415,	0x6791, 0xc415,		0x21, 0
	.dw 0x6793, 0xc415,	0x67bf, 0xc415,		0x21, 0
	.dw 0x67c1, 0xc415,	0x67c1, 0xc415,		0x21, 0
	.dw 0x67c3, 0xc415,	0x67cf, 0xc415,		0x21, 0
	.dw 0x67d1, 0xc415,	0x67d1, 0xc415,		0x21, 0
	.dw 0x67d3, 0xc415,	0x67ff, 0xc415,		0x21, 0
	.dw 0x6801, 0xc415,	0x6801, 0xc415,		0x21, 0
	.dw 0x6803, 0xc415,	0x680f, 0xc415,		0x21, 0
	.dw 0x6811, 0xc415,	0x6811, 0xc415,		0x21, 0
	.dw 0x6813, 0xc415,	0x683f, 0xc415,		0x21, 0
	.dw 0x6841, 0xc415,	0x6841, 0xc415,		0x21, 0
	.dw 0x6843, 0xc415,	0x684f, 0xc415,		0x21, 0
	.dw 0x6851, 0xc415,	0x6851, 0xc415,		0x21, 0
	.dw 0x6853, 0xc415,	0x687f, 0xc415,		0x21, 0
	.dw 0x6881, 0xc415,	0x6881, 0xc415,		0x21, 0
	.dw 0x6883, 0xc415,	0x688f, 0xc415,		0x21, 0
	.dw 0x6891, 0xc415,	0x6891, 0xc415,		0x21, 0
	.dw 0x6893, 0xc415,	0x68bf, 0xc415,		0x21, 0
	.dw 0x68c1, 0xc415,	0x68c1, 0xc415,		0x21, 0
	.dw 0x68c3, 0xc415,	0x68cf, 0xc415,		0x21, 0
	.dw 0x68d1, 0xc415,	0x68d1, 0xc415,		0x21, 0
	.dw 0x68d3, 0xc415,	0x68ff, 0xc415,		0x21, 0
	.dw 0x6900, 0xc415,	0x6900, 0xc415,		0x22, 0
	.dw 0x6901, 0xc415,	0x6901, 0xc415,		0x21, 0
	.dw 0x6902, 0xc415,	0x6902, 0xc415,		0x22, 0
	.dw 0x6903, 0xc415,	0x690f, 0xc415,		0x21, 0
	.dw 0x6910, 0xc415,	0x6910, 0xc415,		0x22, 0
	.dw 0x6911, 0xc415,	0x6911, 0xc415,		0x21, 0
	.dw 0x6912, 0xc415,	0x6912, 0xc415,		0x22, 0
	.dw 0x6913, 0xc415,	0x693f, 0xc415,		0x21, 0
	.dw 0x6941, 0xc415,	0x6941, 0xc415,		0x21, 0
	.dw 0x6943, 0xc415,	0x694f, 0xc415,		0x21, 0
	.dw 0x6951, 0xc415,	0x6951, 0xc415,		0x21, 0
	.dw 0x6953, 0xc415,	0x697f, 0xc415,		0x21, 0
	.dw 0x6981, 0xc415,	0x6981, 0xc415,		0x21, 0
	.dw 0x6983, 0xc415,	0x698f, 0xc415,		0x21, 0
	.dw 0x6991, 0xc415,	0x6991, 0xc415,		0x21, 0
	.dw 0x6993, 0xc415,	0x69bf, 0xc415,		0x21, 0
	.dw 0x69c1, 0xc415,	0x69c1, 0xc415,		0x21, 0
	.dw 0x69c3, 0xc415,	0x69cf, 0xc415,		0x21, 0
	.dw 0x69d1, 0xc415,	0x69d1, 0xc415,		0x21, 0
	.dw 0x69d3, 0xc415,	0x69ff, 0xc415,		0x21, 0
	.dw 0x6a01, 0xc415,	0x6a01, 0xc415,		0x21, 0
	.dw 0x6a03, 0xc415,	0x6a0f, 0xc415,		0x21, 0
	.dw 0x6a11, 0xc415,	0x6a11, 0xc415,		0x21, 0
	.dw 0x6a13, 0xc415,	0x6a3f, 0xc415,		0x21, 0
	.dw 0x6a41, 0xc415,	0x6a41, 0xc415,		0x21, 0
	.dw 0x6a43, 0xc415,	0x6a4f, 0xc415,		0x21, 0
	.dw 0x6a51, 0xc415,	0x6a51, 0xc415,		0x21, 0
	.dw 0x6a53, 0xc415,	0x6a7f, 0xc415,		0x21, 0
	.dw 0x6a81, 0xc415,	0x6a81, 0xc415,		0x21, 0
	.dw 0x6a83, 0xc415,	0x6a8f, 0xc415,		0x21, 0
	.dw 0x6a91, 0xc415,	0x6a91, 0xc415,		0x21, 0
	.dw 0x6a93, 0xc415,	0x6abf, 0xc415,		0x21, 0
	.dw 0x6ac1, 0xc415,	0x6ac1, 0xc415,		0x21, 0
	.dw 0x6ac3, 0xc415,	0x6acf, 0xc415,		0x21, 0
	.dw 0x6ad1, 0xc415,	0x6ad1, 0xc415,		0x21, 0
	.dw 0x6ad3, 0xc415,	0x6aff, 0xc415,		0x21, 0
	.dw 0x6b01, 0xc415,	0x6b01, 0xc415,		0x21, 0
	.dw 0x6b03, 0xc415,	0x6b0f, 0xc415,		0x21, 0
	.dw 0x6b11, 0xc415,	0x6b11, 0xc415,		0x21, 0
	.dw 0x6b13, 0xc415,	0x6b3f, 0xc415,		0x21, 0
	.dw 0x6b40, 0xc415,	0x6b40, 0xc415,		0x22, 0
	.dw 0x6b41, 0xc415,	0x6b41, 0xc415,		0x21, 0
	.dw 0x6b42, 0xc415,	0x6b42, 0xc415,		0x22, 0
	.dw 0x6b43, 0xc415,	0x6b4f, 0xc415,		0x21, 0
	.dw 0x6b50, 0xc415,	0x6b50, 0xc415,		0x22, 0
	.dw 0x6b51, 0xc415,	0x6b51, 0xc415,		0x21, 0
	.dw 0x6b52, 0xc415,	0x6b52, 0xc415,		0x22, 0
	.dw 0x6b53, 0xc415,	0x6b7f, 0xc415,		0x21, 0
	.dw 0x6b81, 0xc415,	0x6b81, 0xc415,		0x21, 0
	.dw 0x6b83, 0xc415,	0x6b8f, 0xc415,		0x21, 0
	.dw 0x6b91, 0xc415,	0x6b91, 0xc415,		0x21, 0
	.dw 0x6b93, 0xc415,	0x6bbf, 0xc415,		0x21, 0
	.dw 0x6bc1, 0xc415,	0x6bc1, 0xc415,		0x21, 0
	.dw 0x6bc3, 0xc415,	0x6bcf, 0xc415,		0x21, 0
	.dw 0x6bd1, 0xc415,	0x6bd1, 0xc415,		0x21, 0
	.dw 0x6bd3, 0xc415,	0x6bff, 0xc415,		0x21, 0
	.dw 0x6c01, 0xc415,	0x6c01, 0xc415,		0x21, 0
	.dw 0x6c03, 0xc415,	0x6c0f, 0xc415,		0x21, 0
	.dw 0x6c11, 0xc415,	0x6c11, 0xc415,		0x21, 0
	.dw 0x6c13, 0xc415,	0x6c3f, 0xc415,		0x21, 0
	.dw 0x6c41, 0xc415,	0x6c41, 0xc415,		0x21, 0
	.dw 0x6c43, 0xc415,	0x6c4f, 0xc415,		0x21, 0
	.dw 0x6c51, 0xc415,	0x6c51, 0xc415,		0x21, 0
	.dw 0x6c53, 0xc415,	0x6c7f, 0xc415,		0x21, 0
	.dw 0x6c81, 0xc415,	0x6c81, 0xc415,		0x21, 0
	.dw 0x6c83, 0xc415,	0x6c8f, 0xc415,		0x21, 0
	.dw 0x6c91, 0xc415,	0x6c91, 0xc415,		0x21, 0
	.dw 0x6c93, 0xc415,	0x6cbf, 0xc415,		0x21, 0
	.dw 0x6cc1, 0xc415,	0x6cc1, 0xc415,		0x21, 0
	.dw 0x6cc3, 0xc415,	0x6ccf, 0xc415,		0x21, 0
	.dw 0x6cd1, 0xc415,	0x6cd1, 0xc415,		0x21, 0
	.dw 0x6cd3, 0xc415,	0x6cff, 0xc415,		0x21, 0
	.dw 0x6d01, 0xc415,	0x6d01, 0xc415,		0x21, 0
	.dw 0x6d03, 0xc415,	0x6d0f, 0xc415,		0x21, 0
	.dw 0x6d11, 0xc415,	0x6d11, 0xc415,		0x21, 0
	.dw 0x6d13, 0xc415,	0x6d3f, 0xc415,		0x21, 0
	.dw 0x6d41, 0xc415,	0x6d41, 0xc415,		0x21, 0
	.dw 0x6d43, 0xc415,	0x6d4f, 0xc415,		0x21, 0
	.dw 0x6d51, 0xc415,	0x6d51, 0xc415,		0x21, 0
	.dw 0x6d53, 0xc415,	0x6d7f, 0xc415,		0x21, 0
	.dw 0x6d80, 0xc415,	0x6d80, 0xc415,		0x22, 0
	.dw 0x6d81, 0xc415,	0x6d81, 0xc415,		0x21, 0
	.dw 0x6d82, 0xc415,	0x6d82, 0xc415,		0x22, 0
	.dw 0x6d83, 0xc415,	0x6d8f, 0xc415,		0x21, 0
	.dw 0x6d90, 0xc415,	0x6d90, 0xc415,		0x22, 0
	.dw 0x6d91, 0xc415,	0x6d91, 0xc415,		0x21, 0
	.dw 0x6d92, 0xc415,	0x6d92, 0xc415,		0x22, 0
	.dw 0x6d93, 0xc415,	0x6dbf, 0xc415,		0x21, 0
	.dw 0x6dc1, 0xc415,	0x6dc1, 0xc415,		0x21, 0
	.dw 0x6dc3, 0xc415,	0x6dcf, 0xc415,		0x21, 0
	.dw 0x6dd1, 0xc415,	0x6dd1, 0xc415,		0x21, 0
	.dw 0x6dd3, 0xc415,	0x6dff, 0xc415,		0x21, 0
	.dw 0x6e01, 0xc415,	0x6e01, 0xc415,		0x21, 0
	.dw 0x6e03, 0xc415,	0x6e0f, 0xc415,		0x21, 0
	.dw 0x6e11, 0xc415,	0x6e11, 0xc415,		0x21, 0
	.dw 0x6e13, 0xc415,	0x6e3f, 0xc415,		0x21, 0
	.dw 0x6e41, 0xc415,	0x6e41, 0xc415,		0x21, 0
	.dw 0x6e43, 0xc415,	0x6e4f, 0xc415,		0x21, 0
	.dw 0x6e51, 0xc415,	0x6e51, 0xc415,		0x21, 0
	.dw 0x6e53, 0xc415,	0x6e7f, 0xc415,		0x21, 0
	.dw 0x6e81, 0xc415,	0x6e81, 0xc415,		0x21, 0
	.dw 0x6e83, 0xc415,	0x6e8f, 0xc415,		0x21, 0
	.dw 0x6e91, 0xc415,	0x6e91, 0xc415,		0x21, 0
	.dw 0x6e93, 0xc415,	0x6ebf, 0xc415,		0x21, 0
	.dw 0x6ec1, 0xc415,	0x6ec1, 0xc415,		0x21, 0
	.dw 0x6ec3, 0xc415,	0x6ecf, 0xc415,		0x21, 0
	.dw 0x6ed1, 0xc415,	0x6ed1, 0xc415,		0x21, 0
	.dw 0x6ed3, 0xc415,	0x6eff, 0xc415,		0x21, 0
	.dw 0x6f01, 0xc415,	0x6f01, 0xc415,		0x21, 0
	.dw 0x6f03, 0xc415,	0x6f0f, 0xc415,		0x21, 0
	.dw 0x6f11, 0xc415,	0x6f11, 0xc415,		0x21, 0
	.dw 0x6f13, 0xc415,	0x6f3f, 0xc415,		0x21, 0
	.dw 0x6f41, 0xc415,	0x6f41, 0xc415,		0x21, 0
	.dw 0x6f43, 0xc415,	0x6f4f, 0xc415,		0x21, 0
	.dw 0x6f51, 0xc415,	0x6f51, 0xc415,		0x21, 0
	.dw 0x6f53, 0xc415,	0x6f7f, 0xc415,		0x21, 0
	.dw 0x6f81, 0xc415,	0x6f81, 0xc415,		0x21, 0
	.dw 0x6f83, 0xc415,	0x6f8f, 0xc415,		0x21, 0
	.dw 0x6f91, 0xc415,	0x6f91, 0xc415,		0x21, 0
	.dw 0x6f93, 0xc415,	0x6fbf, 0xc415,		0x21, 0
	.dw 0x6fc0, 0xc415,	0x6fc0, 0xc415,		0x22, 0
	.dw 0x6fc1, 0xc415,	0x6fc1, 0xc415,		0x21, 0
	.dw 0x6fc2, 0xc415,	0x6fc2, 0xc415,		0x22, 0
	.dw 0x6fc3, 0xc415,	0x6fcf, 0xc415,		0x21, 0
	.dw 0x6fd0, 0xc415,	0x6fd0, 0xc415,		0x22, 0
	.dw 0x6fd1, 0xc415,	0x6fd1, 0xc415,		0x21, 0
	.dw 0x6fd2, 0xc415,	0x6fd2, 0xc415,		0x22, 0
	.dw 0x6fd3, 0xc415,	0xffff, 0xc415,		0x21, 0
	.dw 0x0001, 0xc416,	0x0001, 0xc416,		0x21, 0
	.dw 0x0003, 0xc416,	0x000f, 0xc416,		0x21, 0
	.dw 0x0011, 0xc416,	0x0011, 0xc416,		0x21, 0
	.dw 0x0013, 0xc416,	0x003f, 0xc416,		0x21, 0
	.dw 0x0041, 0xc416,	0x0041, 0xc416,		0x21, 0
	.dw 0x0043, 0xc416,	0x004f, 0xc416,		0x21, 0
	.dw 0x0051, 0xc416,	0x0051, 0xc416,		0x21, 0
	.dw 0x0053, 0xc416,	0x007f, 0xc416,		0x21, 0
	.dw 0x0081, 0xc416,	0x0081, 0xc416,		0x21, 0
	.dw 0x0083, 0xc416,	0x008f, 0xc416,		0x21, 0
	.dw 0x0091, 0xc416,	0x0091, 0xc416,		0x21, 0
	.dw 0x0093, 0xc416,	0x00bf, 0xc416,		0x21, 0
	.dw 0x00c1, 0xc416,	0x00c1, 0xc416,		0x21, 0
	.dw 0x00c3, 0xc416,	0x00cf, 0xc416,		0x21, 0
	.dw 0x00d1, 0xc416,	0x00d1, 0xc416,		0x21, 0
	.dw 0x00d3, 0xc416,	0x00ff, 0xc416,		0x21, 0
	.dw 0x0101, 0xc416,	0x0101, 0xc416,		0x21, 0
	.dw 0x0103, 0xc416,	0x010f, 0xc416,		0x21, 0
	.dw 0x0111, 0xc416,	0x0111, 0xc416,		0x21, 0
	.dw 0x0113, 0xc416,	0x013f, 0xc416,		0x21, 0
	.dw 0x0141, 0xc416,	0x0141, 0xc416,		0x21, 0
	.dw 0x0143, 0xc416,	0x014f, 0xc416,		0x21, 0
	.dw 0x0151, 0xc416,	0x0151, 0xc416,		0x21, 0
	.dw 0x0153, 0xc416,	0x017f, 0xc416,		0x21, 0
	.dw 0x0181, 0xc416,	0x0181, 0xc416,		0x21, 0
	.dw 0x0183, 0xc416,	0x018f, 0xc416,		0x21, 0
	.dw 0x0191, 0xc416,	0x0191, 0xc416,		0x21, 0
	.dw 0x0193, 0xc416,	0x01bf, 0xc416,		0x21, 0
	.dw 0x01c1, 0xc416,	0x01c1, 0xc416,		0x21, 0
	.dw 0x01c3, 0xc416,	0x01cf, 0xc416,		0x21, 0
	.dw 0x01d1, 0xc416,	0x01d1, 0xc416,		0x21, 0
	.dw 0x01d3, 0xc416,	0x01ff, 0xc416,		0x21, 0
	.dw 0x0201, 0xc416,	0x0201, 0xc416,		0x21, 0
	.dw 0x0203, 0xc416,	0x020f, 0xc416,		0x21, 0
	.dw 0x0211, 0xc416,	0x0211, 0xc416,		0x21, 0
	.dw 0x0213, 0xc416,	0x023f, 0xc416,		0x21, 0
	.dw 0x0241, 0xc416,	0x0241, 0xc416,		0x21, 0
	.dw 0x0243, 0xc416,	0x024f, 0xc416,		0x21, 0
	.dw 0x0251, 0xc416,	0x0251, 0xc416,		0x21, 0
	.dw 0x0253, 0xc416,	0x027f, 0xc416,		0x21, 0
	.dw 0x0281, 0xc416,	0x0281, 0xc416,		0x21, 0
	.dw 0x0283, 0xc416,	0x028f, 0xc416,		0x21, 0
	.dw 0x0291, 0xc416,	0x0291, 0xc416,		0x21, 0
	.dw 0x0293, 0xc416,	0x02bf, 0xc416,		0x21, 0
	.dw 0x02c1, 0xc416,	0x02c1, 0xc416,		0x21, 0
	.dw 0x02c3, 0xc416,	0x02cf, 0xc416,		0x21, 0
	.dw 0x02d1, 0xc416,	0x02d1, 0xc416,		0x21, 0
	.dw 0x02d3, 0xc416,	0x02ff, 0xc416,		0x21, 0
	.dw 0x0301, 0xc416,	0x0301, 0xc416,		0x21, 0
	.dw 0x0303, 0xc416,	0x030f, 0xc416,		0x21, 0
	.dw 0x0311, 0xc416,	0x0311, 0xc416,		0x21, 0
	.dw 0x0313, 0xc416,	0x033f, 0xc416,		0x21, 0
	.dw 0x0341, 0xc416,	0x0341, 0xc416,		0x21, 0
	.dw 0x0343, 0xc416,	0x034f, 0xc416,		0x21, 0
	.dw 0x0351, 0xc416,	0x0351, 0xc416,		0x21, 0
	.dw 0x0353, 0xc416,	0x037f, 0xc416,		0x21, 0
	.dw 0x0381, 0xc416,	0x0381, 0xc416,		0x21, 0
	.dw 0x0383, 0xc416,	0x038f, 0xc416,		0x21, 0
	.dw 0x0391, 0xc416,	0x0391, 0xc416,		0x21, 0
	.dw 0x0393, 0xc416,	0x03bf, 0xc416,		0x21, 0
	.dw 0x03c1, 0xc416,	0x03c1, 0xc416,		0x21, 0
	.dw 0x03c3, 0xc416,	0x03cf, 0xc416,		0x21, 0
	.dw 0x03d1, 0xc416,	0x03d1, 0xc416,		0x21, 0
	.dw 0x03d3, 0xc416,	0x03ff, 0xc416,		0x21, 0
	.dw 0x0401, 0xc416,	0x0401, 0xc416,		0x21, 0
	.dw 0x0403, 0xc416,	0x040f, 0xc416,		0x21, 0
	.dw 0x0411, 0xc416,	0x0411, 0xc416,		0x21, 0
	.dw 0x0413, 0xc416,	0x043f, 0xc416,		0x21, 0
	.dw 0x0441, 0xc416,	0x0441, 0xc416,		0x21, 0
	.dw 0x0443, 0xc416,	0x044f, 0xc416,		0x21, 0
	.dw 0x0451, 0xc416,	0x0451, 0xc416,		0x21, 0
	.dw 0x0453, 0xc416,	0x047f, 0xc416,		0x21, 0
	.dw 0x0481, 0xc416,	0x0481, 0xc416,		0x21, 0
	.dw 0x0483, 0xc416,	0x048f, 0xc416,		0x21, 0
	.dw 0x0491, 0xc416,	0x0491, 0xc416,		0x21, 0
	.dw 0x0493, 0xc416,	0x04bf, 0xc416,		0x21, 0
	.dw 0x04c1, 0xc416,	0x04c1, 0xc416,		0x21, 0
	.dw 0x04c3, 0xc416,	0x04cf, 0xc416,		0x21, 0
	.dw 0x04d1, 0xc416,	0x04d1, 0xc416,		0x21, 0
	.dw 0x04d3, 0xc416,	0x04ff, 0xc416,		0x21, 0
	.dw 0x0501, 0xc416,	0x0501, 0xc416,		0x21, 0
	.dw 0x0503, 0xc416,	0x050f, 0xc416,		0x21, 0
	.dw 0x0511, 0xc416,	0x0511, 0xc416,		0x21, 0
	.dw 0x0513, 0xc416,	0x053f, 0xc416,		0x21, 0
	.dw 0x0541, 0xc416,	0x0541, 0xc416,		0x21, 0
	.dw 0x0543, 0xc416,	0x054f, 0xc416,		0x21, 0
	.dw 0x0551, 0xc416,	0x0551, 0xc416,		0x21, 0
	.dw 0x0553, 0xc416,	0x057f, 0xc416,		0x21, 0
	.dw 0x0581, 0xc416,	0x0581, 0xc416,		0x21, 0
	.dw 0x0583, 0xc416,	0x058f, 0xc416,		0x21, 0
	.dw 0x0591, 0xc416,	0x0591, 0xc416,		0x21, 0
	.dw 0x0593, 0xc416,	0x05bf, 0xc416,		0x21, 0
	.dw 0x05c1, 0xc416,	0x05c1, 0xc416,		0x21, 0
	.dw 0x05c3, 0xc416,	0x05cf, 0xc416,		0x21, 0
	.dw 0x05d1, 0xc416,	0x05d1, 0xc416,		0x21, 0
	.dw 0x05d3, 0xc416,	0x05ff, 0xc416,		0x21, 0
	.dw 0x0601, 0xc416,	0x0601, 0xc416,		0x21, 0
	.dw 0x0603, 0xc416,	0x060f, 0xc416,		0x21, 0
	.dw 0x0611, 0xc416,	0x0611, 0xc416,		0x21, 0
	.dw 0x0613, 0xc416,	0x063f, 0xc416,		0x21, 0
	.dw 0x0641, 0xc416,	0x0641, 0xc416,		0x21, 0
	.dw 0x0643, 0xc416,	0x064f, 0xc416,		0x21, 0
	.dw 0x0651, 0xc416,	0x0651, 0xc416,		0x21, 0
	.dw 0x0653, 0xc416,	0x067f, 0xc416,		0x21, 0
	.dw 0x0681, 0xc416,	0x0681, 0xc416,		0x21, 0
	.dw 0x0683, 0xc416,	0x068f, 0xc416,		0x21, 0
	.dw 0x0691, 0xc416,	0x0691, 0xc416,		0x21, 0
	.dw 0x0693, 0xc416,	0x06bf, 0xc416,		0x21, 0
	.dw 0x06c1, 0xc416,	0x06c1, 0xc416,		0x21, 0
	.dw 0x06c3, 0xc416,	0x06cf, 0xc416,		0x21, 0
	.dw 0x06d1, 0xc416,	0x06d1, 0xc416,		0x21, 0
	.dw 0x06d3, 0xc416,	0x06ff, 0xc416,		0x21, 0
	.dw 0x0701, 0xc416,	0x0701, 0xc416,		0x21, 0
	.dw 0x0703, 0xc416,	0x070f, 0xc416,		0x21, 0
	.dw 0x0711, 0xc416,	0x0711, 0xc416,		0x21, 0
	.dw 0x0713, 0xc416,	0x073f, 0xc416,		0x21, 0
	.dw 0x0741, 0xc416,	0x0741, 0xc416,		0x21, 0
	.dw 0x0743, 0xc416,	0x074f, 0xc416,		0x21, 0
	.dw 0x0751, 0xc416,	0x0751, 0xc416,		0x21, 0
	.dw 0x0753, 0xc416,	0x077f, 0xc416,		0x21, 0
	.dw 0x0781, 0xc416,	0x0781, 0xc416,		0x21, 0
	.dw 0x0783, 0xc416,	0x078f, 0xc416,		0x21, 0
	.dw 0x0791, 0xc416,	0x0791, 0xc416,		0x21, 0
	.dw 0x0793, 0xc416,	0x07bf, 0xc416,		0x21, 0
	.dw 0x07c1, 0xc416,	0x07c1, 0xc416,		0x21, 0
	.dw 0x07c3, 0xc416,	0x07cf, 0xc416,		0x21, 0
	.dw 0x07d1, 0xc416,	0x07d1, 0xc416,		0x21, 0
	.dw 0x07d3, 0xc416,	0x07ff, 0xc416,		0x21, 0
	.dw 0x0801, 0xc416,	0x0801, 0xc416,		0x21, 0
	.dw 0x0803, 0xc416,	0x080f, 0xc416,		0x21, 0
	.dw 0x0811, 0xc416,	0x0811, 0xc416,		0x21, 0
	.dw 0x0813, 0xc416,	0x083f, 0xc416,		0x21, 0
	.dw 0x0841, 0xc416,	0x0841, 0xc416,		0x21, 0
	.dw 0x0843, 0xc416,	0x084f, 0xc416,		0x21, 0
	.dw 0x0851, 0xc416,	0x0851, 0xc416,		0x21, 0
	.dw 0x0853, 0xc416,	0x087f, 0xc416,		0x21, 0
	.dw 0x0881, 0xc416,	0x0881, 0xc416,		0x21, 0
	.dw 0x0883, 0xc416,	0x088f, 0xc416,		0x21, 0
	.dw 0x0891, 0xc416,	0x0891, 0xc416,		0x21, 0
	.dw 0x0893, 0xc416,	0x08bf, 0xc416,		0x21, 0
	.dw 0x08c1, 0xc416,	0x08c1, 0xc416,		0x21, 0
	.dw 0x08c3, 0xc416,	0x08cf, 0xc416,		0x21, 0
	.dw 0x08d1, 0xc416,	0x08d1, 0xc416,		0x21, 0
	.dw 0x08d3, 0xc416,	0x08ff, 0xc416,		0x21, 0
	.dw 0x0901, 0xc416,	0x0901, 0xc416,		0x21, 0
	.dw 0x0903, 0xc416,	0x090f, 0xc416,		0x21, 0
	.dw 0x0911, 0xc416,	0x0911, 0xc416,		0x21, 0
	.dw 0x0913, 0xc416,	0x093f, 0xc416,		0x21, 0
	.dw 0x0941, 0xc416,	0x0941, 0xc416,		0x21, 0
	.dw 0x0943, 0xc416,	0x094f, 0xc416,		0x21, 0
	.dw 0x0951, 0xc416,	0x0951, 0xc416,		0x21, 0
	.dw 0x0953, 0xc416,	0x097f, 0xc416,		0x21, 0
	.dw 0x0981, 0xc416,	0x0981, 0xc416,		0x21, 0
	.dw 0x0983, 0xc416,	0x098f, 0xc416,		0x21, 0
	.dw 0x0991, 0xc416,	0x0991, 0xc416,		0x21, 0
	.dw 0x0993, 0xc416,	0x09bf, 0xc416,		0x21, 0
	.dw 0x09c1, 0xc416,	0x09c1, 0xc416,		0x21, 0
	.dw 0x09c3, 0xc416,	0x09cf, 0xc416,		0x21, 0
	.dw 0x09d1, 0xc416,	0x09d1, 0xc416,		0x21, 0
	.dw 0x09d3, 0xc416,	0x09ff, 0xc416,		0x21, 0
	.dw 0x0a01, 0xc416,	0x0a01, 0xc416,		0x21, 0
	.dw 0x0a03, 0xc416,	0x0a0f, 0xc416,		0x21, 0
	.dw 0x0a11, 0xc416,	0x0a11, 0xc416,		0x21, 0
	.dw 0x0a13, 0xc416,	0x0a3f, 0xc416,		0x21, 0
	.dw 0x0a41, 0xc416,	0x0a41, 0xc416,		0x21, 0
	.dw 0x0a43, 0xc416,	0x0a4f, 0xc416,		0x21, 0
	.dw 0x0a51, 0xc416,	0x0a51, 0xc416,		0x21, 0
	.dw 0x0a53, 0xc416,	0x0a7f, 0xc416,		0x21, 0
	.dw 0x0a81, 0xc416,	0x0a81, 0xc416,		0x21, 0
	.dw 0x0a83, 0xc416,	0x0a8f, 0xc416,		0x21, 0
	.dw 0x0a91, 0xc416,	0x0a91, 0xc416,		0x21, 0
	.dw 0x0a93, 0xc416,	0x0abf, 0xc416,		0x21, 0
	.dw 0x0ac1, 0xc416,	0x0ac1, 0xc416,		0x21, 0
	.dw 0x0ac3, 0xc416,	0x0acf, 0xc416,		0x21, 0
	.dw 0x0ad1, 0xc416,	0x0ad1, 0xc416,		0x21, 0
	.dw 0x0ad3, 0xc416,	0x0aff, 0xc416,		0x21, 0
	.dw 0x0b01, 0xc416,	0x0b01, 0xc416,		0x21, 0
	.dw 0x0b03, 0xc416,	0x0b0f, 0xc416,		0x21, 0
	.dw 0x0b11, 0xc416,	0x0b11, 0xc416,		0x21, 0
	.dw 0x0b13, 0xc416,	0x0b3f, 0xc416,		0x21, 0
	.dw 0x0b41, 0xc416,	0x0b41, 0xc416,		0x21, 0
	.dw 0x0b43, 0xc416,	0x0b4f, 0xc416,		0x21, 0
	.dw 0x0b51, 0xc416,	0x0b51, 0xc416,		0x21, 0
	.dw 0x0b53, 0xc416,	0x0b7f, 0xc416,		0x21, 0
	.dw 0x0b81, 0xc416,	0x0b81, 0xc416,		0x21, 0
	.dw 0x0b83, 0xc416,	0x0b8f, 0xc416,		0x21, 0
	.dw 0x0b91, 0xc416,	0x0b91, 0xc416,		0x21, 0
	.dw 0x0b93, 0xc416,	0x0bbf, 0xc416,		0x21, 0
	.dw 0x0bc1, 0xc416,	0x0bc1, 0xc416,		0x21, 0
	.dw 0x0bc3, 0xc416,	0x0bcf, 0xc416,		0x21, 0
	.dw 0x0bd1, 0xc416,	0x0bd1, 0xc416,		0x21, 0
	.dw 0x0bd3, 0xc416,	0x0bff, 0xc416,		0x21, 0
	.dw 0x0c01, 0xc416,	0x0c01, 0xc416,		0x21, 0
	.dw 0x0c03, 0xc416,	0x0c0f, 0xc416,		0x21, 0
	.dw 0x0c11, 0xc416,	0x0c11, 0xc416,		0x21, 0
	.dw 0x0c13, 0xc416,	0x0c3f, 0xc416,		0x21, 0
	.dw 0x0c41, 0xc416,	0x0c41, 0xc416,		0x21, 0
	.dw 0x0c43, 0xc416,	0x0c4f, 0xc416,		0x21, 0
	.dw 0x0c51, 0xc416,	0x0c51, 0xc416,		0x21, 0
	.dw 0x0c53, 0xc416,	0x0c7f, 0xc416,		0x21, 0
	.dw 0x0c81, 0xc416,	0x0c81, 0xc416,		0x21, 0
	.dw 0x0c83, 0xc416,	0x0c8f, 0xc416,		0x21, 0
	.dw 0x0c91, 0xc416,	0x0c91, 0xc416,		0x21, 0
	.dw 0x0c93, 0xc416,	0x0cbf, 0xc416,		0x21, 0
	.dw 0x0cc1, 0xc416,	0x0cc1, 0xc416,		0x21, 0
	.dw 0x0cc3, 0xc416,	0x0ccf, 0xc416,		0x21, 0
	.dw 0x0cd1, 0xc416,	0x0cd1, 0xc416,		0x21, 0
	.dw 0x0cd3, 0xc416,	0x0cff, 0xc416,		0x21, 0
	.dw 0x0d01, 0xc416,	0x0d01, 0xc416,		0x21, 0
	.dw 0x0d03, 0xc416,	0x0d0f, 0xc416,		0x21, 0
	.dw 0x0d11, 0xc416,	0x0d11, 0xc416,		0x21, 0
	.dw 0x0d13, 0xc416,	0x0d3f, 0xc416,		0x21, 0
	.dw 0x0d41, 0xc416,	0x0d41, 0xc416,		0x21, 0
	.dw 0x0d43, 0xc416,	0x0d4f, 0xc416,		0x21, 0
	.dw 0x0d51, 0xc416,	0x0d51, 0xc416,		0x21, 0
	.dw 0x0d53, 0xc416,	0x0d7f, 0xc416,		0x21, 0
	.dw 0x0d81, 0xc416,	0x0d81, 0xc416,		0x21, 0
	.dw 0x0d83, 0xc416,	0x0d8f, 0xc416,		0x21, 0
	.dw 0x0d91, 0xc416,	0x0d91, 0xc416,		0x21, 0
	.dw 0x0d93, 0xc416,	0x0dbf, 0xc416,		0x21, 0
	.dw 0x0dc1, 0xc416,	0x0dc1, 0xc416,		0x21, 0
	.dw 0x0dc3, 0xc416,	0x0dcf, 0xc416,		0x21, 0
	.dw 0x0dd1, 0xc416,	0x0dd1, 0xc416,		0x21, 0
	.dw 0x0dd3, 0xc416,	0x0dff, 0xc416,		0x21, 0
	.dw 0x0e01, 0xc416,	0x0e01, 0xc416,		0x21, 0
	.dw 0x0e03, 0xc416,	0x0e0f, 0xc416,		0x21, 0
	.dw 0x0e11, 0xc416,	0x0e11, 0xc416,		0x21, 0
	.dw 0x0e13, 0xc416,	0x0e3f, 0xc416,		0x21, 0
	.dw 0x0e41, 0xc416,	0x0e41, 0xc416,		0x21, 0
	.dw 0x0e43, 0xc416,	0x0e4f, 0xc416,		0x21, 0
	.dw 0x0e51, 0xc416,	0x0e51, 0xc416,		0x21, 0
	.dw 0x0e53, 0xc416,	0x0e7f, 0xc416,		0x21, 0
	.dw 0x0e81, 0xc416,	0x0e81, 0xc416,		0x21, 0
	.dw 0x0e83, 0xc416,	0x0e8f, 0xc416,		0x21, 0
	.dw 0x0e91, 0xc416,	0x0e91, 0xc416,		0x21, 0
	.dw 0x0e93, 0xc416,	0x0ebf, 0xc416,		0x21, 0
	.dw 0x0ec1, 0xc416,	0x0ec1, 0xc416,		0x21, 0
	.dw 0x0ec3, 0xc416,	0x0ecf, 0xc416,		0x21, 0
	.dw 0x0ed1, 0xc416,	0x0ed1, 0xc416,		0x21, 0
	.dw 0x0ed3, 0xc416,	0x0eff, 0xc416,		0x21, 0
	.dw 0x0f01, 0xc416,	0x0f01, 0xc416,		0x21, 0
	.dw 0x0f03, 0xc416,	0x0f0f, 0xc416,		0x21, 0
	.dw 0x0f11, 0xc416,	0x0f11, 0xc416,		0x21, 0
	.dw 0x0f13, 0xc416,	0x0f3f, 0xc416,		0x21, 0
	.dw 0x0f41, 0xc416,	0x0f41, 0xc416,		0x21, 0
	.dw 0x0f43, 0xc416,	0x0f4f, 0xc416,		0x21, 0
	.dw 0x0f51, 0xc416,	0x0f51, 0xc416,		0x21, 0
	.dw 0x0f53, 0xc416,	0x0f7f, 0xc416,		0x21, 0
	.dw 0x0f81, 0xc416,	0x0f81, 0xc416,		0x21, 0
	.dw 0x0f83, 0xc416,	0x0f8f, 0xc416,		0x21, 0
	.dw 0x0f91, 0xc416,	0x0f91, 0xc416,		0x21, 0
	.dw 0x0f93, 0xc416,	0x0fbf, 0xc416,		0x21, 0
	.dw 0x0fc1, 0xc416,	0x0fc1, 0xc416,		0x21, 0
	.dw 0x0fc3, 0xc416,	0x0fcf, 0xc416,		0x21, 0
	.dw 0x0fd1, 0xc416,	0x0fd1, 0xc416,		0x21, 0
	.dw 0x0fd3, 0xc416,	0x1fff, 0xc416,		0x21, 0
	.dw 0x2001, 0xc416,	0x2001, 0xc416,		0x21, 0
	.dw 0x2003, 0xc416,	0x200f, 0xc416,		0x21, 0
	.dw 0x2011, 0xc416,	0x2011, 0xc416,		0x21, 0
	.dw 0x2013, 0xc416,	0x203f, 0xc416,		0x21, 0
	.dw 0x2041, 0xc416,	0x2041, 0xc416,		0x21, 0
	.dw 0x2043, 0xc416,	0x204f, 0xc416,		0x21, 0
	.dw 0x2051, 0xc416,	0x2051, 0xc416,		0x21, 0
	.dw 0x2053, 0xc416,	0x207f, 0xc416,		0x21, 0
	.dw 0x2081, 0xc416,	0x2081, 0xc416,		0x21, 0
	.dw 0x2083, 0xc416,	0x208f, 0xc416,		0x21, 0
	.dw 0x2091, 0xc416,	0x2091, 0xc416,		0x21, 0
	.dw 0x2093, 0xc416,	0x20bf, 0xc416,		0x21, 0
	.dw 0x20c1, 0xc416,	0x20c1, 0xc416,		0x21, 0
	.dw 0x20c3, 0xc416,	0x20cf, 0xc416,		0x21, 0
	.dw 0x20d1, 0xc416,	0x20d1, 0xc416,		0x21, 0
	.dw 0x20d3, 0xc416,	0x20ff, 0xc416,		0x21, 0
	.dw 0x2101, 0xc416,	0x2101, 0xc416,		0x21, 0
	.dw 0x2103, 0xc416,	0x210f, 0xc416,		0x21, 0
	.dw 0x2111, 0xc416,	0x2111, 0xc416,		0x21, 0
	.dw 0x2113, 0xc416,	0x213f, 0xc416,		0x21, 0
	.dw 0x2141, 0xc416,	0x2141, 0xc416,		0x21, 0
	.dw 0x2143, 0xc416,	0x214f, 0xc416,		0x21, 0
	.dw 0x2151, 0xc416,	0x2151, 0xc416,		0x21, 0
	.dw 0x2153, 0xc416,	0x217f, 0xc416,		0x21, 0
	.dw 0x2181, 0xc416,	0x2181, 0xc416,		0x21, 0
	.dw 0x2183, 0xc416,	0x218f, 0xc416,		0x21, 0
	.dw 0x2191, 0xc416,	0x2191, 0xc416,		0x21, 0
	.dw 0x2193, 0xc416,	0x21bf, 0xc416,		0x21, 0
	.dw 0x21c1, 0xc416,	0x21c1, 0xc416,		0x21, 0
	.dw 0x21c3, 0xc416,	0x21cf, 0xc416,		0x21, 0
	.dw 0x21d1, 0xc416,	0x21d1, 0xc416,		0x21, 0
	.dw 0x21d3, 0xc416,	0x21ff, 0xc416,		0x21, 0
	.dw 0x2201, 0xc416,	0x2201, 0xc416,		0x21, 0
	.dw 0x2203, 0xc416,	0x220f, 0xc416,		0x21, 0
	.dw 0x2211, 0xc416,	0x2211, 0xc416,		0x21, 0
	.dw 0x2213, 0xc416,	0x223f, 0xc416,		0x21, 0
	.dw 0x2241, 0xc416,	0x2241, 0xc416,		0x21, 0
	.dw 0x2243, 0xc416,	0x224f, 0xc416,		0x21, 0
	.dw 0x2251, 0xc416,	0x2251, 0xc416,		0x21, 0
	.dw 0x2253, 0xc416,	0x227f, 0xc416,		0x21, 0
	.dw 0x2281, 0xc416,	0x2281, 0xc416,		0x21, 0
	.dw 0x2283, 0xc416,	0x228f, 0xc416,		0x21, 0
	.dw 0x2291, 0xc416,	0x2291, 0xc416,		0x21, 0
	.dw 0x2293, 0xc416,	0x22bf, 0xc416,		0x21, 0
	.dw 0x22c1, 0xc416,	0x22c1, 0xc416,		0x21, 0
	.dw 0x22c3, 0xc416,	0x22cf, 0xc416,		0x21, 0
	.dw 0x22d1, 0xc416,	0x22d1, 0xc416,		0x21, 0
	.dw 0x22d3, 0xc416,	0x22ff, 0xc416,		0x21, 0
	.dw 0x2301, 0xc416,	0x2301, 0xc416,		0x21, 0
	.dw 0x2303, 0xc416,	0x230f, 0xc416,		0x21, 0
	.dw 0x2311, 0xc416,	0x2311, 0xc416,		0x21, 0
	.dw 0x2313, 0xc416,	0x233f, 0xc416,		0x21, 0
	.dw 0x2341, 0xc416,	0x2341, 0xc416,		0x21, 0
	.dw 0x2343, 0xc416,	0x234f, 0xc416,		0x21, 0
	.dw 0x2351, 0xc416,	0x2351, 0xc416,		0x21, 0
	.dw 0x2353, 0xc416,	0x237f, 0xc416,		0x21, 0
	.dw 0x2381, 0xc416,	0x2381, 0xc416,		0x21, 0
	.dw 0x2383, 0xc416,	0x238f, 0xc416,		0x21, 0
	.dw 0x2391, 0xc416,	0x2391, 0xc416,		0x21, 0
	.dw 0x2393, 0xc416,	0x23bf, 0xc416,		0x21, 0
	.dw 0x23c1, 0xc416,	0x23c1, 0xc416,		0x21, 0
	.dw 0x23c3, 0xc416,	0x23cf, 0xc416,		0x21, 0
	.dw 0x23d1, 0xc416,	0x23d1, 0xc416,		0x21, 0
	.dw 0x23d3, 0xc416,	0x23ff, 0xc416,		0x21, 0
	.dw 0x2401, 0xc416,	0x2401, 0xc416,		0x21, 0
	.dw 0x2403, 0xc416,	0x240f, 0xc416,		0x21, 0
	.dw 0x2411, 0xc416,	0x2411, 0xc416,		0x21, 0
	.dw 0x2413, 0xc416,	0x243f, 0xc416,		0x21, 0
	.dw 0x2441, 0xc416,	0x2441, 0xc416,		0x21, 0
	.dw 0x2443, 0xc416,	0x244f, 0xc416,		0x21, 0
	.dw 0x2451, 0xc416,	0x2451, 0xc416,		0x21, 0
	.dw 0x2453, 0xc416,	0x247f, 0xc416,		0x21, 0
	.dw 0x2481, 0xc416,	0x2481, 0xc416,		0x21, 0
	.dw 0x2483, 0xc416,	0x248f, 0xc416,		0x21, 0
	.dw 0x2491, 0xc416,	0x2491, 0xc416,		0x21, 0
	.dw 0x2493, 0xc416,	0x24bf, 0xc416,		0x21, 0
	.dw 0x24c1, 0xc416,	0x24c1, 0xc416,		0x21, 0
	.dw 0x24c3, 0xc416,	0x24cf, 0xc416,		0x21, 0
	.dw 0x24d1, 0xc416,	0x24d1, 0xc416,		0x21, 0
	.dw 0x24d3, 0xc416,	0x24ff, 0xc416,		0x21, 0
	.dw 0x2501, 0xc416,	0x2501, 0xc416,		0x21, 0
	.dw 0x2503, 0xc416,	0x250f, 0xc416,		0x21, 0
	.dw 0x2511, 0xc416,	0x2511, 0xc416,		0x21, 0
	.dw 0x2513, 0xc416,	0x253f, 0xc416,		0x21, 0
	.dw 0x2541, 0xc416,	0x2541, 0xc416,		0x21, 0
	.dw 0x2543, 0xc416,	0x254f, 0xc416,		0x21, 0
	.dw 0x2551, 0xc416,	0x2551, 0xc416,		0x21, 0
	.dw 0x2553, 0xc416,	0x257f, 0xc416,		0x21, 0
	.dw 0x2581, 0xc416,	0x2581, 0xc416,		0x21, 0
	.dw 0x2583, 0xc416,	0x258f, 0xc416,		0x21, 0
	.dw 0x2591, 0xc416,	0x2591, 0xc416,		0x21, 0
	.dw 0x2593, 0xc416,	0x25bf, 0xc416,		0x21, 0
	.dw 0x25c1, 0xc416,	0x25c1, 0xc416,		0x21, 0
	.dw 0x25c3, 0xc416,	0x25cf, 0xc416,		0x21, 0
	.dw 0x25d1, 0xc416,	0x25d1, 0xc416,		0x21, 0
	.dw 0x25d3, 0xc416,	0x25ff, 0xc416,		0x21, 0
	.dw 0x2601, 0xc416,	0x2601, 0xc416,		0x21, 0
	.dw 0x2603, 0xc416,	0x260f, 0xc416,		0x21, 0
	.dw 0x2611, 0xc416,	0x2611, 0xc416,		0x21, 0
	.dw 0x2613, 0xc416,	0x263f, 0xc416,		0x21, 0
	.dw 0x2641, 0xc416,	0x2641, 0xc416,		0x21, 0
	.dw 0x2643, 0xc416,	0x264f, 0xc416,		0x21, 0
	.dw 0x2651, 0xc416,	0x2651, 0xc416,		0x21, 0
	.dw 0x2653, 0xc416,	0x267f, 0xc416,		0x21, 0
	.dw 0x2681, 0xc416,	0x2681, 0xc416,		0x21, 0
	.dw 0x2683, 0xc416,	0x268f, 0xc416,		0x21, 0
	.dw 0x2691, 0xc416,	0x2691, 0xc416,		0x21, 0
	.dw 0x2693, 0xc416,	0x26bf, 0xc416,		0x21, 0
	.dw 0x26c1, 0xc416,	0x26c1, 0xc416,		0x21, 0
	.dw 0x26c3, 0xc416,	0x26cf, 0xc416,		0x21, 0
	.dw 0x26d1, 0xc416,	0x26d1, 0xc416,		0x21, 0
	.dw 0x26d3, 0xc416,	0x26ff, 0xc416,		0x21, 0
	.dw 0x2701, 0xc416,	0x2701, 0xc416,		0x21, 0
	.dw 0x2703, 0xc416,	0x270f, 0xc416,		0x21, 0
	.dw 0x2711, 0xc416,	0x2711, 0xc416,		0x21, 0
	.dw 0x2713, 0xc416,	0x273f, 0xc416,		0x21, 0
	.dw 0x2741, 0xc416,	0x2741, 0xc416,		0x21, 0
	.dw 0x2743, 0xc416,	0x274f, 0xc416,		0x21, 0
	.dw 0x2751, 0xc416,	0x2751, 0xc416,		0x21, 0
	.dw 0x2753, 0xc416,	0x277f, 0xc416,		0x21, 0
	.dw 0x2781, 0xc416,	0x2781, 0xc416,		0x21, 0
	.dw 0x2783, 0xc416,	0x278f, 0xc416,		0x21, 0
	.dw 0x2791, 0xc416,	0x2791, 0xc416,		0x21, 0
	.dw 0x2793, 0xc416,	0x27bf, 0xc416,		0x21, 0
	.dw 0x27c1, 0xc416,	0x27c1, 0xc416,		0x21, 0
	.dw 0x27c3, 0xc416,	0x27cf, 0xc416,		0x21, 0
	.dw 0x27d1, 0xc416,	0x27d1, 0xc416,		0x21, 0
	.dw 0x27d3, 0xc416,	0x27ff, 0xc416,		0x21, 0
	.dw 0x2801, 0xc416,	0x2801, 0xc416,		0x21, 0
	.dw 0x2803, 0xc416,	0x280f, 0xc416,		0x21, 0
	.dw 0x2811, 0xc416,	0x2811, 0xc416,		0x21, 0
	.dw 0x2813, 0xc416,	0x283f, 0xc416,		0x21, 0
	.dw 0x2841, 0xc416,	0x2841, 0xc416,		0x21, 0
	.dw 0x2843, 0xc416,	0x284f, 0xc416,		0x21, 0
	.dw 0x2851, 0xc416,	0x2851, 0xc416,		0x21, 0
	.dw 0x2853, 0xc416,	0x287f, 0xc416,		0x21, 0
	.dw 0x2881, 0xc416,	0x2881, 0xc416,		0x21, 0
	.dw 0x2883, 0xc416,	0x288f, 0xc416,		0x21, 0
	.dw 0x2891, 0xc416,	0x2891, 0xc416,		0x21, 0
	.dw 0x2893, 0xc416,	0x28bf, 0xc416,		0x21, 0
	.dw 0x28c1, 0xc416,	0x28c1, 0xc416,		0x21, 0
	.dw 0x28c3, 0xc416,	0x28cf, 0xc416,		0x21, 0
	.dw 0x28d1, 0xc416,	0x28d1, 0xc416,		0x21, 0
	.dw 0x28d3, 0xc416,	0x28ff, 0xc416,		0x21, 0
	.dw 0x2901, 0xc416,	0x2901, 0xc416,		0x21, 0
	.dw 0x2903, 0xc416,	0x290f, 0xc416,		0x21, 0
	.dw 0x2911, 0xc416,	0x2911, 0xc416,		0x21, 0
	.dw 0x2913, 0xc416,	0x293f, 0xc416,		0x21, 0
	.dw 0x2941, 0xc416,	0x2941, 0xc416,		0x21, 0
	.dw 0x2943, 0xc416,	0x294f, 0xc416,		0x21, 0
	.dw 0x2951, 0xc416,	0x2951, 0xc416,		0x21, 0
	.dw 0x2953, 0xc416,	0x297f, 0xc416,		0x21, 0
	.dw 0x2981, 0xc416,	0x2981, 0xc416,		0x21, 0
	.dw 0x2983, 0xc416,	0x298f, 0xc416,		0x21, 0
	.dw 0x2991, 0xc416,	0x2991, 0xc416,		0x21, 0
	.dw 0x2993, 0xc416,	0x29bf, 0xc416,		0x21, 0
	.dw 0x29c1, 0xc416,	0x29c1, 0xc416,		0x21, 0
	.dw 0x29c3, 0xc416,	0x29cf, 0xc416,		0x21, 0
	.dw 0x29d1, 0xc416,	0x29d1, 0xc416,		0x21, 0
	.dw 0x29d3, 0xc416,	0x29ff, 0xc416,		0x21, 0
	.dw 0x2a01, 0xc416,	0x2a01, 0xc416,		0x21, 0
	.dw 0x2a03, 0xc416,	0x2a0f, 0xc416,		0x21, 0
	.dw 0x2a11, 0xc416,	0x2a11, 0xc416,		0x21, 0
	.dw 0x2a13, 0xc416,	0x2a3f, 0xc416,		0x21, 0
	.dw 0x2a41, 0xc416,	0x2a41, 0xc416,		0x21, 0
	.dw 0x2a43, 0xc416,	0x2a4f, 0xc416,		0x21, 0
	.dw 0x2a51, 0xc416,	0x2a51, 0xc416,		0x21, 0
	.dw 0x2a53, 0xc416,	0x2a7f, 0xc416,		0x21, 0
	.dw 0x2a81, 0xc416,	0x2a81, 0xc416,		0x21, 0
	.dw 0x2a83, 0xc416,	0x2a8f, 0xc416,		0x21, 0
	.dw 0x2a91, 0xc416,	0x2a91, 0xc416,		0x21, 0
	.dw 0x2a93, 0xc416,	0x2abf, 0xc416,		0x21, 0
	.dw 0x2ac1, 0xc416,	0x2ac1, 0xc416,		0x21, 0
	.dw 0x2ac3, 0xc416,	0x2acf, 0xc416,		0x21, 0
	.dw 0x2ad1, 0xc416,	0x2ad1, 0xc416,		0x21, 0
	.dw 0x2ad3, 0xc416,	0x2aff, 0xc416,		0x21, 0
	.dw 0x2b01, 0xc416,	0x2b01, 0xc416,		0x21, 0
	.dw 0x2b03, 0xc416,	0x2b0f, 0xc416,		0x21, 0
	.dw 0x2b11, 0xc416,	0x2b11, 0xc416,		0x21, 0
	.dw 0x2b13, 0xc416,	0x2b3f, 0xc416,		0x21, 0
	.dw 0x2b41, 0xc416,	0x2b41, 0xc416,		0x21, 0
	.dw 0x2b43, 0xc416,	0x2b4f, 0xc416,		0x21, 0
	.dw 0x2b51, 0xc416,	0x2b51, 0xc416,		0x21, 0
	.dw 0x2b53, 0xc416,	0x2b7f, 0xc416,		0x21, 0
	.dw 0x2b81, 0xc416,	0x2b81, 0xc416,		0x21, 0
	.dw 0x2b83, 0xc416,	0x2b8f, 0xc416,		0x21, 0
	.dw 0x2b91, 0xc416,	0x2b91, 0xc416,		0x21, 0
	.dw 0x2b93, 0xc416,	0x2bbf, 0xc416,		0x21, 0
	.dw 0x2bc1, 0xc416,	0x2bc1, 0xc416,		0x21, 0
	.dw 0x2bc3, 0xc416,	0x2bcf, 0xc416,		0x21, 0
	.dw 0x2bd1, 0xc416,	0x2bd1, 0xc416,		0x21, 0
	.dw 0x2bd3, 0xc416,	0x2bff, 0xc416,		0x21, 0
	.dw 0x2c01, 0xc416,	0x2c01, 0xc416,		0x21, 0
	.dw 0x2c03, 0xc416,	0x2c0f, 0xc416,		0x21, 0
	.dw 0x2c11, 0xc416,	0x2c11, 0xc416,		0x21, 0
	.dw 0x2c13, 0xc416,	0x2c3f, 0xc416,		0x21, 0
	.dw 0x2c41, 0xc416,	0x2c41, 0xc416,		0x21, 0
	.dw 0x2c43, 0xc416,	0x2c4f, 0xc416,		0x21, 0
	.dw 0x2c51, 0xc416,	0x2c51, 0xc416,		0x21, 0
	.dw 0x2c53, 0xc416,	0x2c7f, 0xc416,		0x21, 0
	.dw 0x2c81, 0xc416,	0x2c81, 0xc416,		0x21, 0
	.dw 0x2c83, 0xc416,	0x2c8f, 0xc416,		0x21, 0
	.dw 0x2c91, 0xc416,	0x2c91, 0xc416,		0x21, 0
	.dw 0x2c93, 0xc416,	0x2cbf, 0xc416,		0x21, 0
	.dw 0x2cc1, 0xc416,	0x2cc1, 0xc416,		0x21, 0
	.dw 0x2cc3, 0xc416,	0x2ccf, 0xc416,		0x21, 0
	.dw 0x2cd1, 0xc416,	0x2cd1, 0xc416,		0x21, 0
	.dw 0x2cd3, 0xc416,	0x2cff, 0xc416,		0x21, 0
	.dw 0x2d01, 0xc416,	0x2d01, 0xc416,		0x21, 0
	.dw 0x2d03, 0xc416,	0x2d0f, 0xc416,		0x21, 0
	.dw 0x2d11, 0xc416,	0x2d11, 0xc416,		0x21, 0
	.dw 0x2d13, 0xc416,	0x2d3f, 0xc416,		0x21, 0
	.dw 0x2d41, 0xc416,	0x2d41, 0xc416,		0x21, 0
	.dw 0x2d43, 0xc416,	0x2d4f, 0xc416,		0x21, 0
	.dw 0x2d51, 0xc416,	0x2d51, 0xc416,		0x21, 0
	.dw 0x2d53, 0xc416,	0x2d7f, 0xc416,		0x21, 0
	.dw 0x2d81, 0xc416,	0x2d81, 0xc416,		0x21, 0
	.dw 0x2d83, 0xc416,	0x2d8f, 0xc416,		0x21, 0
	.dw 0x2d91, 0xc416,	0x2d91, 0xc416,		0x21, 0
	.dw 0x2d93, 0xc416,	0x2dbf, 0xc416,		0x21, 0
	.dw 0x2dc1, 0xc416,	0x2dc1, 0xc416,		0x21, 0
	.dw 0x2dc3, 0xc416,	0x2dcf, 0xc416,		0x21, 0
	.dw 0x2dd1, 0xc416,	0x2dd1, 0xc416,		0x21, 0
	.dw 0x2dd3, 0xc416,	0x2dff, 0xc416,		0x21, 0
	.dw 0x2e01, 0xc416,	0x2e01, 0xc416,		0x21, 0
	.dw 0x2e03, 0xc416,	0x2e0f, 0xc416,		0x21, 0
	.dw 0x2e11, 0xc416,	0x2e11, 0xc416,		0x21, 0
	.dw 0x2e13, 0xc416,	0x2e3f, 0xc416,		0x21, 0
	.dw 0x2e41, 0xc416,	0x2e41, 0xc416,		0x21, 0
	.dw 0x2e43, 0xc416,	0x2e4f, 0xc416,		0x21, 0
	.dw 0x2e51, 0xc416,	0x2e51, 0xc416,		0x21, 0
	.dw 0x2e53, 0xc416,	0x2e7f, 0xc416,		0x21, 0
	.dw 0x2e81, 0xc416,	0x2e81, 0xc416,		0x21, 0
	.dw 0x2e83, 0xc416,	0x2e8f, 0xc416,		0x21, 0
	.dw 0x2e91, 0xc416,	0x2e91, 0xc416,		0x21, 0
	.dw 0x2e93, 0xc416,	0x2ebf, 0xc416,		0x21, 0
	.dw 0x2ec1, 0xc416,	0x2ec1, 0xc416,		0x21, 0
	.dw 0x2ec3, 0xc416,	0x2ecf, 0xc416,		0x21, 0
	.dw 0x2ed1, 0xc416,	0x2ed1, 0xc416,		0x21, 0
	.dw 0x2ed3, 0xc416,	0x2eff, 0xc416,		0x21, 0
	.dw 0x2f01, 0xc416,	0x2f01, 0xc416,		0x21, 0
	.dw 0x2f03, 0xc416,	0x2f0f, 0xc416,		0x21, 0
	.dw 0x2f11, 0xc416,	0x2f11, 0xc416,		0x21, 0
	.dw 0x2f13, 0xc416,	0x2f3f, 0xc416,		0x21, 0
	.dw 0x2f41, 0xc416,	0x2f41, 0xc416,		0x21, 0
	.dw 0x2f43, 0xc416,	0x2f4f, 0xc416,		0x21, 0
	.dw 0x2f51, 0xc416,	0x2f51, 0xc416,		0x21, 0
	.dw 0x2f53, 0xc416,	0x2f7f, 0xc416,		0x21, 0
	.dw 0x2f81, 0xc416,	0x2f81, 0xc416,		0x21, 0
	.dw 0x2f83, 0xc416,	0x2f8f, 0xc416,		0x21, 0
	.dw 0x2f91, 0xc416,	0x2f91, 0xc416,		0x21, 0
	.dw 0x2f93, 0xc416,	0x2fbf, 0xc416,		0x21, 0
	.dw 0x2fc1, 0xc416,	0x2fc1, 0xc416,		0x21, 0
	.dw 0x2fc3, 0xc416,	0x2fcf, 0xc416,		0x21, 0
	.dw 0x2fd1, 0xc416,	0x2fd1, 0xc416,		0x21, 0
	.dw 0x2fd3, 0xc416,	0x3fff, 0xc416,		0x21, 0
	.dw 0x4001, 0xc416,	0x4001, 0xc416,		0x21, 0
	.dw 0x4003, 0xc416,	0x400f, 0xc416,		0x21, 0
	.dw 0x4011, 0xc416,	0x4011, 0xc416,		0x21, 0
	.dw 0x4013, 0xc416,	0x403f, 0xc416,		0x21, 0
	.dw 0x4041, 0xc416,	0x4041, 0xc416,		0x21, 0
	.dw 0x4043, 0xc416,	0x404f, 0xc416,		0x21, 0
	.dw 0x4051, 0xc416,	0x4051, 0xc416,		0x21, 0
	.dw 0x4053, 0xc416,	0x407f, 0xc416,		0x21, 0
	.dw 0x4081, 0xc416,	0x4081, 0xc416,		0x21, 0
	.dw 0x4083, 0xc416,	0x408f, 0xc416,		0x21, 0
	.dw 0x4091, 0xc416,	0x4091, 0xc416,		0x21, 0
	.dw 0x4093, 0xc416,	0x40bf, 0xc416,		0x21, 0
	.dw 0x40c1, 0xc416,	0x40c1, 0xc416,		0x21, 0
	.dw 0x40c3, 0xc416,	0x40cf, 0xc416,		0x21, 0
	.dw 0x40d1, 0xc416,	0x40d1, 0xc416,		0x21, 0
	.dw 0x40d3, 0xc416,	0x40ff, 0xc416,		0x21, 0
	.dw 0x4101, 0xc416,	0x4101, 0xc416,		0x21, 0
	.dw 0x4103, 0xc416,	0x410f, 0xc416,		0x21, 0
	.dw 0x4111, 0xc416,	0x4111, 0xc416,		0x21, 0
	.dw 0x4113, 0xc416,	0x413f, 0xc416,		0x21, 0
	.dw 0x4141, 0xc416,	0x4141, 0xc416,		0x21, 0
	.dw 0x4143, 0xc416,	0x414f, 0xc416,		0x21, 0
	.dw 0x4151, 0xc416,	0x4151, 0xc416,		0x21, 0
	.dw 0x4153, 0xc416,	0x417f, 0xc416,		0x21, 0
	.dw 0x4181, 0xc416,	0x4181, 0xc416,		0x21, 0
	.dw 0x4183, 0xc416,	0x418f, 0xc416,		0x21, 0
	.dw 0x4191, 0xc416,	0x4191, 0xc416,		0x21, 0
	.dw 0x4193, 0xc416,	0x41bf, 0xc416,		0x21, 0
	.dw 0x41c1, 0xc416,	0x41c1, 0xc416,		0x21, 0
	.dw 0x41c3, 0xc416,	0x41cf, 0xc416,		0x21, 0
	.dw 0x41d1, 0xc416,	0x41d1, 0xc416,		0x21, 0
	.dw 0x41d3, 0xc416,	0x41ff, 0xc416,		0x21, 0
	.dw 0x4201, 0xc416,	0x4201, 0xc416,		0x21, 0
	.dw 0x4203, 0xc416,	0x420f, 0xc416,		0x21, 0
	.dw 0x4211, 0xc416,	0x4211, 0xc416,		0x21, 0
	.dw 0x4213, 0xc416,	0x423f, 0xc416,		0x21, 0
	.dw 0x4241, 0xc416,	0x4241, 0xc416,		0x21, 0
	.dw 0x4243, 0xc416,	0x424f, 0xc416,		0x21, 0
	.dw 0x4251, 0xc416,	0x4251, 0xc416,		0x21, 0
	.dw 0x4253, 0xc416,	0x427f, 0xc416,		0x21, 0
	.dw 0x4281, 0xc416,	0x4281, 0xc416,		0x21, 0
	.dw 0x4283, 0xc416,	0x428f, 0xc416,		0x21, 0
	.dw 0x4291, 0xc416,	0x4291, 0xc416,		0x21, 0
	.dw 0x4293, 0xc416,	0x42bf, 0xc416,		0x21, 0
	.dw 0x42c1, 0xc416,	0x42c1, 0xc416,		0x21, 0
	.dw 0x42c3, 0xc416,	0x42cf, 0xc416,		0x21, 0
	.dw 0x42d1, 0xc416,	0x42d1, 0xc416,		0x21, 0
	.dw 0x42d3, 0xc416,	0x42ff, 0xc416,		0x21, 0
	.dw 0x4301, 0xc416,	0x4301, 0xc416,		0x21, 0
	.dw 0x4303, 0xc416,	0x430f, 0xc416,		0x21, 0
	.dw 0x4311, 0xc416,	0x4311, 0xc416,		0x21, 0
	.dw 0x4313, 0xc416,	0x433f, 0xc416,		0x21, 0
	.dw 0x4341, 0xc416,	0x4341, 0xc416,		0x21, 0
	.dw 0x4343, 0xc416,	0x434f, 0xc416,		0x21, 0
	.dw 0x4351, 0xc416,	0x4351, 0xc416,		0x21, 0
	.dw 0x4353, 0xc416,	0x437f, 0xc416,		0x21, 0
	.dw 0x4381, 0xc416,	0x4381, 0xc416,		0x21, 0
	.dw 0x4383, 0xc416,	0x438f, 0xc416,		0x21, 0
	.dw 0x4391, 0xc416,	0x4391, 0xc416,		0x21, 0
	.dw 0x4393, 0xc416,	0x43bf, 0xc416,		0x21, 0
	.dw 0x43c1, 0xc416,	0x43c1, 0xc416,		0x21, 0
	.dw 0x43c3, 0xc416,	0x43cf, 0xc416,		0x21, 0
	.dw 0x43d1, 0xc416,	0x43d1, 0xc416,		0x21, 0
	.dw 0x43d3, 0xc416,	0x43ff, 0xc416,		0x21, 0
	.dw 0x4401, 0xc416,	0x4401, 0xc416,		0x21, 0
	.dw 0x4403, 0xc416,	0x440f, 0xc416,		0x21, 0
	.dw 0x4411, 0xc416,	0x4411, 0xc416,		0x21, 0
	.dw 0x4413, 0xc416,	0x443f, 0xc416,		0x21, 0
	.dw 0x4441, 0xc416,	0x4441, 0xc416,		0x21, 0
	.dw 0x4443, 0xc416,	0x444f, 0xc416,		0x21, 0
	.dw 0x4451, 0xc416,	0x4451, 0xc416,		0x21, 0
	.dw 0x4453, 0xc416,	0x447f, 0xc416,		0x21, 0
	.dw 0x4481, 0xc416,	0x4481, 0xc416,		0x21, 0
	.dw 0x4483, 0xc416,	0x448f, 0xc416,		0x21, 0
	.dw 0x4491, 0xc416,	0x4491, 0xc416,		0x21, 0
	.dw 0x4493, 0xc416,	0x44bf, 0xc416,		0x21, 0
	.dw 0x44c1, 0xc416,	0x44c1, 0xc416,		0x21, 0
	.dw 0x44c3, 0xc416,	0x44cf, 0xc416,		0x21, 0
	.dw 0x44d1, 0xc416,	0x44d1, 0xc416,		0x21, 0
	.dw 0x44d3, 0xc416,	0x44ff, 0xc416,		0x21, 0
	.dw 0x4501, 0xc416,	0x4501, 0xc416,		0x21, 0
	.dw 0x4503, 0xc416,	0x450f, 0xc416,		0x21, 0
	.dw 0x4511, 0xc416,	0x4511, 0xc416,		0x21, 0
	.dw 0x4513, 0xc416,	0x453f, 0xc416,		0x21, 0
	.dw 0x4541, 0xc416,	0x4541, 0xc416,		0x21, 0
	.dw 0x4543, 0xc416,	0x454f, 0xc416,		0x21, 0
	.dw 0x4551, 0xc416,	0x4551, 0xc416,		0x21, 0
	.dw 0x4553, 0xc416,	0x457f, 0xc416,		0x21, 0
	.dw 0x4581, 0xc416,	0x4581, 0xc416,		0x21, 0
	.dw 0x4583, 0xc416,	0x458f, 0xc416,		0x21, 0
	.dw 0x4591, 0xc416,	0x4591, 0xc416,		0x21, 0
	.dw 0x4593, 0xc416,	0x45bf, 0xc416,		0x21, 0
	.dw 0x45c1, 0xc416,	0x45c1, 0xc416,		0x21, 0
	.dw 0x45c3, 0xc416,	0x45cf, 0xc416,		0x21, 0
	.dw 0x45d1, 0xc416,	0x45d1, 0xc416,		0x21, 0
	.dw 0x45d3, 0xc416,	0x45ff, 0xc416,		0x21, 0
	.dw 0x4601, 0xc416,	0x4601, 0xc416,		0x21, 0
	.dw 0x4603, 0xc416,	0x460f, 0xc416,		0x21, 0
	.dw 0x4611, 0xc416,	0x4611, 0xc416,		0x21, 0
	.dw 0x4613, 0xc416,	0x463f, 0xc416,		0x21, 0
	.dw 0x4641, 0xc416,	0x4641, 0xc416,		0x21, 0
	.dw 0x4643, 0xc416,	0x464f, 0xc416,		0x21, 0
	.dw 0x4651, 0xc416,	0x4651, 0xc416,		0x21, 0
	.dw 0x4653, 0xc416,	0x467f, 0xc416,		0x21, 0
	.dw 0x4681, 0xc416,	0x4681, 0xc416,		0x21, 0
	.dw 0x4683, 0xc416,	0x468f, 0xc416,		0x21, 0
	.dw 0x4691, 0xc416,	0x4691, 0xc416,		0x21, 0
	.dw 0x4693, 0xc416,	0x46bf, 0xc416,		0x21, 0
	.dw 0x46c1, 0xc416,	0x46c1, 0xc416,		0x21, 0
	.dw 0x46c3, 0xc416,	0x46cf, 0xc416,		0x21, 0
	.dw 0x46d1, 0xc416,	0x46d1, 0xc416,		0x21, 0
	.dw 0x46d3, 0xc416,	0x46ff, 0xc416,		0x21, 0
	.dw 0x4701, 0xc416,	0x4701, 0xc416,		0x21, 0
	.dw 0x4703, 0xc416,	0x470f, 0xc416,		0x21, 0
	.dw 0x4711, 0xc416,	0x4711, 0xc416,		0x21, 0
	.dw 0x4713, 0xc416,	0x473f, 0xc416,		0x21, 0
	.dw 0x4741, 0xc416,	0x4741, 0xc416,		0x21, 0
	.dw 0x4743, 0xc416,	0x474f, 0xc416,		0x21, 0
	.dw 0x4751, 0xc416,	0x4751, 0xc416,		0x21, 0
	.dw 0x4753, 0xc416,	0x477f, 0xc416,		0x21, 0
	.dw 0x4781, 0xc416,	0x4781, 0xc416,		0x21, 0
	.dw 0x4783, 0xc416,	0x478f, 0xc416,		0x21, 0
	.dw 0x4791, 0xc416,	0x4791, 0xc416,		0x21, 0
	.dw 0x4793, 0xc416,	0x47bf, 0xc416,		0x21, 0
	.dw 0x47c1, 0xc416,	0x47c1, 0xc416,		0x21, 0
	.dw 0x47c3, 0xc416,	0x47cf, 0xc416,		0x21, 0
	.dw 0x47d1, 0xc416,	0x47d1, 0xc416,		0x21, 0
	.dw 0x47d3, 0xc416,	0x47ff, 0xc416,		0x21, 0
	.dw 0x4801, 0xc416,	0x4801, 0xc416,		0x21, 0
	.dw 0x4803, 0xc416,	0x480f, 0xc416,		0x21, 0
	.dw 0x4811, 0xc416,	0x4811, 0xc416,		0x21, 0
	.dw 0x4813, 0xc416,	0x483f, 0xc416,		0x21, 0
	.dw 0x4841, 0xc416,	0x4841, 0xc416,		0x21, 0
	.dw 0x4843, 0xc416,	0x484f, 0xc416,		0x21, 0
	.dw 0x4851, 0xc416,	0x4851, 0xc416,		0x21, 0
	.dw 0x4853, 0xc416,	0x487f, 0xc416,		0x21, 0
	.dw 0x4881, 0xc416,	0x4881, 0xc416,		0x21, 0
	.dw 0x4883, 0xc416,	0x488f, 0xc416,		0x21, 0
	.dw 0x4891, 0xc416,	0x4891, 0xc416,		0x21, 0
	.dw 0x4893, 0xc416,	0x48bf, 0xc416,		0x21, 0
	.dw 0x48c1, 0xc416,	0x48c1, 0xc416,		0x21, 0
	.dw 0x48c3, 0xc416,	0x48cf, 0xc416,		0x21, 0
	.dw 0x48d1, 0xc416,	0x48d1, 0xc416,		0x21, 0
	.dw 0x48d3, 0xc416,	0x48ff, 0xc416,		0x21, 0
	.dw 0x4901, 0xc416,	0x4901, 0xc416,		0x21, 0
	.dw 0x4903, 0xc416,	0x490f, 0xc416,		0x21, 0
	.dw 0x4911, 0xc416,	0x4911, 0xc416,		0x21, 0
	.dw 0x4913, 0xc416,	0x493f, 0xc416,		0x21, 0
	.dw 0x4941, 0xc416,	0x4941, 0xc416,		0x21, 0
	.dw 0x4943, 0xc416,	0x494f, 0xc416,		0x21, 0
	.dw 0x4951, 0xc416,	0x4951, 0xc416,		0x21, 0
	.dw 0x4953, 0xc416,	0x497f, 0xc416,		0x21, 0
	.dw 0x4981, 0xc416,	0x4981, 0xc416,		0x21, 0
	.dw 0x4983, 0xc416,	0x498f, 0xc416,		0x21, 0
	.dw 0x4991, 0xc416,	0x4991, 0xc416,		0x21, 0
	.dw 0x4993, 0xc416,	0x49bf, 0xc416,		0x21, 0
	.dw 0x49c1, 0xc416,	0x49c1, 0xc416,		0x21, 0
	.dw 0x49c3, 0xc416,	0x49cf, 0xc416,		0x21, 0
	.dw 0x49d1, 0xc416,	0x49d1, 0xc416,		0x21, 0
	.dw 0x49d3, 0xc416,	0x49ff, 0xc416,		0x21, 0
	.dw 0x4a01, 0xc416,	0x4a01, 0xc416,		0x21, 0
	.dw 0x4a03, 0xc416,	0x4a0f, 0xc416,		0x21, 0
	.dw 0x4a11, 0xc416,	0x4a11, 0xc416,		0x21, 0
	.dw 0x4a13, 0xc416,	0x4a3f, 0xc416,		0x21, 0
	.dw 0x4a41, 0xc416,	0x4a41, 0xc416,		0x21, 0
	.dw 0x4a43, 0xc416,	0x4a4f, 0xc416,		0x21, 0
	.dw 0x4a51, 0xc416,	0x4a51, 0xc416,		0x21, 0
	.dw 0x4a53, 0xc416,	0x4a7f, 0xc416,		0x21, 0
	.dw 0x4a81, 0xc416,	0x4a81, 0xc416,		0x21, 0
	.dw 0x4a83, 0xc416,	0x4a8f, 0xc416,		0x21, 0
	.dw 0x4a91, 0xc416,	0x4a91, 0xc416,		0x21, 0
	.dw 0x4a93, 0xc416,	0x4abf, 0xc416,		0x21, 0
	.dw 0x4ac1, 0xc416,	0x4ac1, 0xc416,		0x21, 0
	.dw 0x4ac3, 0xc416,	0x4acf, 0xc416,		0x21, 0
	.dw 0x4ad1, 0xc416,	0x4ad1, 0xc416,		0x21, 0
	.dw 0x4ad3, 0xc416,	0x4aff, 0xc416,		0x21, 0
	.dw 0x4b01, 0xc416,	0x4b01, 0xc416,		0x21, 0
	.dw 0x4b03, 0xc416,	0x4b0f, 0xc416,		0x21, 0
	.dw 0x4b11, 0xc416,	0x4b11, 0xc416,		0x21, 0
	.dw 0x4b13, 0xc416,	0x4b3f, 0xc416,		0x21, 0
	.dw 0x4b41, 0xc416,	0x4b41, 0xc416,		0x21, 0
	.dw 0x4b43, 0xc416,	0x4b4f, 0xc416,		0x21, 0
	.dw 0x4b51, 0xc416,	0x4b51, 0xc416,		0x21, 0
	.dw 0x4b53, 0xc416,	0x4b7f, 0xc416,		0x21, 0
	.dw 0x4b81, 0xc416,	0x4b81, 0xc416,		0x21, 0
	.dw 0x4b83, 0xc416,	0x4b8f, 0xc416,		0x21, 0
	.dw 0x4b91, 0xc416,	0x4b91, 0xc416,		0x21, 0
	.dw 0x4b93, 0xc416,	0x4bbf, 0xc416,		0x21, 0
	.dw 0x4bc1, 0xc416,	0x4bc1, 0xc416,		0x21, 0
	.dw 0x4bc3, 0xc416,	0x4bcf, 0xc416,		0x21, 0
	.dw 0x4bd1, 0xc416,	0x4bd1, 0xc416,		0x21, 0
	.dw 0x4bd3, 0xc416,	0x4bff, 0xc416,		0x21, 0
	.dw 0x4c01, 0xc416,	0x4c01, 0xc416,		0x21, 0
	.dw 0x4c03, 0xc416,	0x4c0f, 0xc416,		0x21, 0
	.dw 0x4c11, 0xc416,	0x4c11, 0xc416,		0x21, 0
	.dw 0x4c13, 0xc416,	0x4c3f, 0xc416,		0x21, 0
	.dw 0x4c41, 0xc416,	0x4c41, 0xc416,		0x21, 0
	.dw 0x4c43, 0xc416,	0x4c4f, 0xc416,		0x21, 0
	.dw 0x4c51, 0xc416,	0x4c51, 0xc416,		0x21, 0
	.dw 0x4c53, 0xc416,	0x4c7f, 0xc416,		0x21, 0
	.dw 0x4c81, 0xc416,	0x4c81, 0xc416,		0x21, 0
	.dw 0x4c83, 0xc416,	0x4c8f, 0xc416,		0x21, 0
	.dw 0x4c91, 0xc416,	0x4c91, 0xc416,		0x21, 0
	.dw 0x4c93, 0xc416,	0x4cbf, 0xc416,		0x21, 0
	.dw 0x4cc1, 0xc416,	0x4cc1, 0xc416,		0x21, 0
	.dw 0x4cc3, 0xc416,	0x4ccf, 0xc416,		0x21, 0
	.dw 0x4cd1, 0xc416,	0x4cd1, 0xc416,		0x21, 0
	.dw 0x4cd3, 0xc416,	0x4cff, 0xc416,		0x21, 0
	.dw 0x4d01, 0xc416,	0x4d01, 0xc416,		0x21, 0
	.dw 0x4d03, 0xc416,	0x4d0f, 0xc416,		0x21, 0
	.dw 0x4d11, 0xc416,	0x4d11, 0xc416,		0x21, 0
	.dw 0x4d13, 0xc416,	0x4d3f, 0xc416,		0x21, 0
	.dw 0x4d41, 0xc416,	0x4d41, 0xc416,		0x21, 0
	.dw 0x4d43, 0xc416,	0x4d4f, 0xc416,		0x21, 0
	.dw 0x4d51, 0xc416,	0x4d51, 0xc416,		0x21, 0
	.dw 0x4d53, 0xc416,	0x4d7f, 0xc416,		0x21, 0
	.dw 0x4d81, 0xc416,	0x4d81, 0xc416,		0x21, 0
	.dw 0x4d83, 0xc416,	0x4d8f, 0xc416,		0x21, 0
	.dw 0x4d91, 0xc416,	0x4d91, 0xc416,		0x21, 0
	.dw 0x4d93, 0xc416,	0x4dbf, 0xc416,		0x21, 0
	.dw 0x4dc1, 0xc416,	0x4dc1, 0xc416,		0x21, 0
	.dw 0x4dc3, 0xc416,	0x4dcf, 0xc416,		0x21, 0
	.dw 0x4dd1, 0xc416,	0x4dd1, 0xc416,		0x21, 0
	.dw 0x4dd3, 0xc416,	0x4dff, 0xc416,		0x21, 0
	.dw 0x4e01, 0xc416,	0x4e01, 0xc416,		0x21, 0
	.dw 0x4e03, 0xc416,	0x4e0f, 0xc416,		0x21, 0
	.dw 0x4e11, 0xc416,	0x4e11, 0xc416,		0x21, 0
	.dw 0x4e13, 0xc416,	0x4e3f, 0xc416,		0x21, 0
	.dw 0x4e41, 0xc416,	0x4e41, 0xc416,		0x21, 0
	.dw 0x4e43, 0xc416,	0x4e4f, 0xc416,		0x21, 0
	.dw 0x4e51, 0xc416,	0x4e51, 0xc416,		0x21, 0
	.dw 0x4e53, 0xc416,	0x4e7f, 0xc416,		0x21, 0
	.dw 0x4e81, 0xc416,	0x4e81, 0xc416,		0x21, 0
	.dw 0x4e83, 0xc416,	0x4e8f, 0xc416,		0x21, 0
	.dw 0x4e91, 0xc416,	0x4e91, 0xc416,		0x21, 0
	.dw 0x4e93, 0xc416,	0x4ebf, 0xc416,		0x21, 0
	.dw 0x4ec1, 0xc416,	0x4ec1, 0xc416,		0x21, 0
	.dw 0x4ec3, 0xc416,	0x4ecf, 0xc416,		0x21, 0
	.dw 0x4ed1, 0xc416,	0x4ed1, 0xc416,		0x21, 0
	.dw 0x4ed3, 0xc416,	0x4eff, 0xc416,		0x21, 0
	.dw 0x4f01, 0xc416,	0x4f01, 0xc416,		0x21, 0
	.dw 0x4f03, 0xc416,	0x4f0f, 0xc416,		0x21, 0
	.dw 0x4f11, 0xc416,	0x4f11, 0xc416,		0x21, 0
	.dw 0x4f13, 0xc416,	0x4f3f, 0xc416,		0x21, 0
	.dw 0x4f41, 0xc416,	0x4f41, 0xc416,		0x21, 0
	.dw 0x4f43, 0xc416,	0x4f4f, 0xc416,		0x21, 0
	.dw 0x4f51, 0xc416,	0x4f51, 0xc416,		0x21, 0
	.dw 0x4f53, 0xc416,	0x4f7f, 0xc416,		0x21, 0
	.dw 0x4f81, 0xc416,	0x4f81, 0xc416,		0x21, 0
	.dw 0x4f83, 0xc416,	0x4f8f, 0xc416,		0x21, 0
	.dw 0x4f91, 0xc416,	0x4f91, 0xc416,		0x21, 0
	.dw 0x4f93, 0xc416,	0x4fbf, 0xc416,		0x21, 0
	.dw 0x4fc1, 0xc416,	0x4fc1, 0xc416,		0x21, 0
	.dw 0x4fc3, 0xc416,	0x4fcf, 0xc416,		0x21, 0
	.dw 0x4fd1, 0xc416,	0x4fd1, 0xc416,		0x21, 0
	.dw 0x4fd3, 0xc416,	0x5fff, 0xc416,		0x21, 0
	.dw 0x6001, 0xc416,	0x6001, 0xc416,		0x21, 0
	.dw 0x6003, 0xc416,	0x600f, 0xc416,		0x21, 0
	.dw 0x6011, 0xc416,	0x6011, 0xc416,		0x21, 0
	.dw 0x6013, 0xc416,	0x603f, 0xc416,		0x21, 0
	.dw 0x6041, 0xc416,	0x6041, 0xc416,		0x21, 0
	.dw 0x6043, 0xc416,	0x604f, 0xc416,		0x21, 0
	.dw 0x6051, 0xc416,	0x6051, 0xc416,		0x21, 0
	.dw 0x6053, 0xc416,	0x607f, 0xc416,		0x21, 0
	.dw 0x6081, 0xc416,	0x6081, 0xc416,		0x21, 0
	.dw 0x6083, 0xc416,	0x608f, 0xc416,		0x21, 0
	.dw 0x6091, 0xc416,	0x6091, 0xc416,		0x21, 0
	.dw 0x6093, 0xc416,	0x60bf, 0xc416,		0x21, 0
	.dw 0x60c1, 0xc416,	0x60c1, 0xc416,		0x21, 0
	.dw 0x60c3, 0xc416,	0x60cf, 0xc416,		0x21, 0
	.dw 0x60d1, 0xc416,	0x60d1, 0xc416,		0x21, 0
	.dw 0x60d3, 0xc416,	0x60ff, 0xc416,		0x21, 0
	.dw 0x6101, 0xc416,	0x6101, 0xc416,		0x21, 0
	.dw 0x6103, 0xc416,	0x610f, 0xc416,		0x21, 0
	.dw 0x6111, 0xc416,	0x6111, 0xc416,		0x21, 0
	.dw 0x6113, 0xc416,	0x613f, 0xc416,		0x21, 0
	.dw 0x6141, 0xc416,	0x6141, 0xc416,		0x21, 0
	.dw 0x6143, 0xc416,	0x614f, 0xc416,		0x21, 0
	.dw 0x6151, 0xc416,	0x6151, 0xc416,		0x21, 0
	.dw 0x6153, 0xc416,	0x617f, 0xc416,		0x21, 0
	.dw 0x6181, 0xc416,	0x6181, 0xc416,		0x21, 0
	.dw 0x6183, 0xc416,	0x618f, 0xc416,		0x21, 0
	.dw 0x6191, 0xc416,	0x6191, 0xc416,		0x21, 0
	.dw 0x6193, 0xc416,	0x61bf, 0xc416,		0x21, 0
	.dw 0x61c1, 0xc416,	0x61c1, 0xc416,		0x21, 0
	.dw 0x61c3, 0xc416,	0x61cf, 0xc416,		0x21, 0
	.dw 0x61d1, 0xc416,	0x61d1, 0xc416,		0x21, 0
	.dw 0x61d3, 0xc416,	0x61ff, 0xc416,		0x21, 0
	.dw 0x6201, 0xc416,	0x6201, 0xc416,		0x21, 0
	.dw 0x6203, 0xc416,	0x620f, 0xc416,		0x21, 0
	.dw 0x6211, 0xc416,	0x6211, 0xc416,		0x21, 0
	.dw 0x6213, 0xc416,	0x623f, 0xc416,		0x21, 0
	.dw 0x6241, 0xc416,	0x6241, 0xc416,		0x21, 0
	.dw 0x6243, 0xc416,	0x624f, 0xc416,		0x21, 0
	.dw 0x6251, 0xc416,	0x6251, 0xc416,		0x21, 0
	.dw 0x6253, 0xc416,	0x627f, 0xc416,		0x21, 0
	.dw 0x6281, 0xc416,	0x6281, 0xc416,		0x21, 0
	.dw 0x6283, 0xc416,	0x628f, 0xc416,		0x21, 0
	.dw 0x6291, 0xc416,	0x6291, 0xc416,		0x21, 0
	.dw 0x6293, 0xc416,	0x62bf, 0xc416,		0x21, 0
	.dw 0x62c1, 0xc416,	0x62c1, 0xc416,		0x21, 0
	.dw 0x62c3, 0xc416,	0x62cf, 0xc416,		0x21, 0
	.dw 0x62d1, 0xc416,	0x62d1, 0xc416,		0x21, 0
	.dw 0x62d3, 0xc416,	0x62ff, 0xc416,		0x21, 0
	.dw 0x6301, 0xc416,	0x6301, 0xc416,		0x21, 0
	.dw 0x6303, 0xc416,	0x630f, 0xc416,		0x21, 0
	.dw 0x6311, 0xc416,	0x6311, 0xc416,		0x21, 0
	.dw 0x6313, 0xc416,	0x633f, 0xc416,		0x21, 0
	.dw 0x6341, 0xc416,	0x6341, 0xc416,		0x21, 0
	.dw 0x6343, 0xc416,	0x634f, 0xc416,		0x21, 0
	.dw 0x6351, 0xc416,	0x6351, 0xc416,		0x21, 0
	.dw 0x6353, 0xc416,	0x637f, 0xc416,		0x21, 0
	.dw 0x6381, 0xc416,	0x6381, 0xc416,		0x21, 0
	.dw 0x6383, 0xc416,	0x638f, 0xc416,		0x21, 0
	.dw 0x6391, 0xc416,	0x6391, 0xc416,		0x21, 0
	.dw 0x6393, 0xc416,	0x63bf, 0xc416,		0x21, 0
	.dw 0x63c1, 0xc416,	0x63c1, 0xc416,		0x21, 0
	.dw 0x63c3, 0xc416,	0x63cf, 0xc416,		0x21, 0
	.dw 0x63d1, 0xc416,	0x63d1, 0xc416,		0x21, 0
	.dw 0x63d3, 0xc416,	0x63ff, 0xc416,		0x21, 0
	.dw 0x6401, 0xc416,	0x6401, 0xc416,		0x21, 0
	.dw 0x6403, 0xc416,	0x640f, 0xc416,		0x21, 0
	.dw 0x6411, 0xc416,	0x6411, 0xc416,		0x21, 0
	.dw 0x6413, 0xc416,	0x643f, 0xc416,		0x21, 0
	.dw 0x6441, 0xc416,	0x6441, 0xc416,		0x21, 0
	.dw 0x6443, 0xc416,	0x644f, 0xc416,		0x21, 0
	.dw 0x6451, 0xc416,	0x6451, 0xc416,		0x21, 0
	.dw 0x6453, 0xc416,	0x647f, 0xc416,		0x21, 0
	.dw 0x6481, 0xc416,	0x6481, 0xc416,		0x21, 0
	.dw 0x6483, 0xc416,	0x648f, 0xc416,		0x21, 0
	.dw 0x6491, 0xc416,	0x6491, 0xc416,		0x21, 0
	.dw 0x6493, 0xc416,	0x64bf, 0xc416,		0x21, 0
	.dw 0x64c1, 0xc416,	0x64c1, 0xc416,		0x21, 0
	.dw 0x64c3, 0xc416,	0x64cf, 0xc416,		0x21, 0
	.dw 0x64d1, 0xc416,	0x64d1, 0xc416,		0x21, 0
	.dw 0x64d3, 0xc416,	0x64ff, 0xc416,		0x21, 0
	.dw 0x6501, 0xc416,	0x6501, 0xc416,		0x21, 0
	.dw 0x6503, 0xc416,	0x650f, 0xc416,		0x21, 0
	.dw 0x6511, 0xc416,	0x6511, 0xc416,		0x21, 0
	.dw 0x6513, 0xc416,	0x653f, 0xc416,		0x21, 0
	.dw 0x6541, 0xc416,	0x6541, 0xc416,		0x21, 0
	.dw 0x6543, 0xc416,	0x654f, 0xc416,		0x21, 0
	.dw 0x6551, 0xc416,	0x6551, 0xc416,		0x21, 0
	.dw 0x6553, 0xc416,	0x657f, 0xc416,		0x21, 0
	.dw 0x6581, 0xc416,	0x6581, 0xc416,		0x21, 0
	.dw 0x6583, 0xc416,	0x658f, 0xc416,		0x21, 0
	.dw 0x6591, 0xc416,	0x6591, 0xc416,		0x21, 0
	.dw 0x6593, 0xc416,	0x65bf, 0xc416,		0x21, 0
	.dw 0x65c1, 0xc416,	0x65c1, 0xc416,		0x21, 0
	.dw 0x65c3, 0xc416,	0x65cf, 0xc416,		0x21, 0
	.dw 0x65d1, 0xc416,	0x65d1, 0xc416,		0x21, 0
	.dw 0x65d3, 0xc416,	0x65ff, 0xc416,		0x21, 0
	.dw 0x6601, 0xc416,	0x6601, 0xc416,		0x21, 0
	.dw 0x6603, 0xc416,	0x660f, 0xc416,		0x21, 0
	.dw 0x6611, 0xc416,	0x6611, 0xc416,		0x21, 0
	.dw 0x6613, 0xc416,	0x663f, 0xc416,		0x21, 0
	.dw 0x6641, 0xc416,	0x6641, 0xc416,		0x21, 0
	.dw 0x6643, 0xc416,	0x664f, 0xc416,		0x21, 0
	.dw 0x6651, 0xc416,	0x6651, 0xc416,		0x21, 0
	.dw 0x6653, 0xc416,	0x667f, 0xc416,		0x21, 0
	.dw 0x6681, 0xc416,	0x6681, 0xc416,		0x21, 0
	.dw 0x6683, 0xc416,	0x668f, 0xc416,		0x21, 0
	.dw 0x6691, 0xc416,	0x6691, 0xc416,		0x21, 0
	.dw 0x6693, 0xc416,	0x66bf, 0xc416,		0x21, 0
	.dw 0x66c1, 0xc416,	0x66c1, 0xc416,		0x21, 0
	.dw 0x66c3, 0xc416,	0x66cf, 0xc416,		0x21, 0
	.dw 0x66d1, 0xc416,	0x66d1, 0xc416,		0x21, 0
	.dw 0x66d3, 0xc416,	0x66ff, 0xc416,		0x21, 0
	.dw 0x6701, 0xc416,	0x6701, 0xc416,		0x21, 0
	.dw 0x6703, 0xc416,	0x670f, 0xc416,		0x21, 0
	.dw 0x6711, 0xc416,	0x6711, 0xc416,		0x21, 0
	.dw 0x6713, 0xc416,	0x673f, 0xc416,		0x21, 0
	.dw 0x6741, 0xc416,	0x6741, 0xc416,		0x21, 0
	.dw 0x6743, 0xc416,	0x674f, 0xc416,		0x21, 0
	.dw 0x6751, 0xc416,	0x6751, 0xc416,		0x21, 0
	.dw 0x6753, 0xc416,	0x677f, 0xc416,		0x21, 0
	.dw 0x6781, 0xc416,	0x6781, 0xc416,		0x21, 0
	.dw 0x6783, 0xc416,	0x678f, 0xc416,		0x21, 0
	.dw 0x6791, 0xc416,	0x6791, 0xc416,		0x21, 0
	.dw 0x6793, 0xc416,	0x67bf, 0xc416,		0x21, 0
	.dw 0x67c1, 0xc416,	0x67c1, 0xc416,		0x21, 0
	.dw 0x67c3, 0xc416,	0x67cf, 0xc416,		0x21, 0
	.dw 0x67d1, 0xc416,	0x67d1, 0xc416,		0x21, 0
	.dw 0x67d3, 0xc416,	0x67ff, 0xc416,		0x21, 0
	.dw 0x6801, 0xc416,	0x6801, 0xc416,		0x21, 0
	.dw 0x6803, 0xc416,	0x680f, 0xc416,		0x21, 0
	.dw 0x6811, 0xc416,	0x6811, 0xc416,		0x21, 0
	.dw 0x6813, 0xc416,	0x683f, 0xc416,		0x21, 0
	.dw 0x6841, 0xc416,	0x6841, 0xc416,		0x21, 0
	.dw 0x6843, 0xc416,	0x684f, 0xc416,		0x21, 0
	.dw 0x6851, 0xc416,	0x6851, 0xc416,		0x21, 0
	.dw 0x6853, 0xc416,	0x687f, 0xc416,		0x21, 0
	.dw 0x6881, 0xc416,	0x6881, 0xc416,		0x21, 0
	.dw 0x6883, 0xc416,	0x688f, 0xc416,		0x21, 0
	.dw 0x6891, 0xc416,	0x6891, 0xc416,		0x21, 0
	.dw 0x6893, 0xc416,	0x68bf, 0xc416,		0x21, 0
	.dw 0x68c1, 0xc416,	0x68c1, 0xc416,		0x21, 0
	.dw 0x68c3, 0xc416,	0x68cf, 0xc416,		0x21, 0
	.dw 0x68d1, 0xc416,	0x68d1, 0xc416,		0x21, 0
	.dw 0x68d3, 0xc416,	0x68ff, 0xc416,		0x21, 0
	.dw 0x6901, 0xc416,	0x6901, 0xc416,		0x21, 0
	.dw 0x6903, 0xc416,	0x690f, 0xc416,		0x21, 0
	.dw 0x6911, 0xc416,	0x6911, 0xc416,		0x21, 0
	.dw 0x6913, 0xc416,	0x693f, 0xc416,		0x21, 0
	.dw 0x6941, 0xc416,	0x6941, 0xc416,		0x21, 0
	.dw 0x6943, 0xc416,	0x694f, 0xc416,		0x21, 0
	.dw 0x6951, 0xc416,	0x6951, 0xc416,		0x21, 0
	.dw 0x6953, 0xc416,	0x697f, 0xc416,		0x21, 0
	.dw 0x6981, 0xc416,	0x6981, 0xc416,		0x21, 0
	.dw 0x6983, 0xc416,	0x698f, 0xc416,		0x21, 0
	.dw 0x6991, 0xc416,	0x6991, 0xc416,		0x21, 0
	.dw 0x6993, 0xc416,	0x69bf, 0xc416,		0x21, 0
	.dw 0x69c1, 0xc416,	0x69c1, 0xc416,		0x21, 0
	.dw 0x69c3, 0xc416,	0x69cf, 0xc416,		0x21, 0
	.dw 0x69d1, 0xc416,	0x69d1, 0xc416,		0x21, 0
	.dw 0x69d3, 0xc416,	0x69ff, 0xc416,		0x21, 0
	.dw 0x6a01, 0xc416,	0x6a01, 0xc416,		0x21, 0
	.dw 0x6a03, 0xc416,	0x6a0f, 0xc416,		0x21, 0
	.dw 0x6a11, 0xc416,	0x6a11, 0xc416,		0x21, 0
	.dw 0x6a13, 0xc416,	0x6a3f, 0xc416,		0x21, 0
	.dw 0x6a41, 0xc416,	0x6a41, 0xc416,		0x21, 0
	.dw 0x6a43, 0xc416,	0x6a4f, 0xc416,		0x21, 0
	.dw 0x6a51, 0xc416,	0x6a51, 0xc416,		0x21, 0
	.dw 0x6a53, 0xc416,	0x6a7f, 0xc416,		0x21, 0
	.dw 0x6a81, 0xc416,	0x6a81, 0xc416,		0x21, 0
	.dw 0x6a83, 0xc416,	0x6a8f, 0xc416,		0x21, 0
	.dw 0x6a91, 0xc416,	0x6a91, 0xc416,		0x21, 0
	.dw 0x6a93, 0xc416,	0x6abf, 0xc416,		0x21, 0
	.dw 0x6ac1, 0xc416,	0x6ac1, 0xc416,		0x21, 0
	.dw 0x6ac3, 0xc416,	0x6acf, 0xc416,		0x21, 0
	.dw 0x6ad1, 0xc416,	0x6ad1, 0xc416,		0x21, 0
	.dw 0x6ad3, 0xc416,	0x6aff, 0xc416,		0x21, 0
	.dw 0x6b01, 0xc416,	0x6b01, 0xc416,		0x21, 0
	.dw 0x6b03, 0xc416,	0x6b0f, 0xc416,		0x21, 0
	.dw 0x6b11, 0xc416,	0x6b11, 0xc416,		0x21, 0
	.dw 0x6b13, 0xc416,	0x6b3f, 0xc416,		0x21, 0
	.dw 0x6b41, 0xc416,	0x6b41, 0xc416,		0x21, 0
	.dw 0x6b43, 0xc416,	0x6b4f, 0xc416,		0x21, 0
	.dw 0x6b51, 0xc416,	0x6b51, 0xc416,		0x21, 0
	.dw 0x6b53, 0xc416,	0x6b7f, 0xc416,		0x21, 0
	.dw 0x6b81, 0xc416,	0x6b81, 0xc416,		0x21, 0
	.dw 0x6b83, 0xc416,	0x6b8f, 0xc416,		0x21, 0
	.dw 0x6b91, 0xc416,	0x6b91, 0xc416,		0x21, 0
	.dw 0x6b93, 0xc416,	0x6bbf, 0xc416,		0x21, 0
	.dw 0x6bc1, 0xc416,	0x6bc1, 0xc416,		0x21, 0
	.dw 0x6bc3, 0xc416,	0x6bcf, 0xc416,		0x21, 0
	.dw 0x6bd1, 0xc416,	0x6bd1, 0xc416,		0x21, 0
	.dw 0x6bd3, 0xc416,	0x6bff, 0xc416,		0x21, 0
	.dw 0x6c01, 0xc416,	0x6c01, 0xc416,		0x21, 0
	.dw 0x6c03, 0xc416,	0x6c0f, 0xc416,		0x21, 0
	.dw 0x6c11, 0xc416,	0x6c11, 0xc416,		0x21, 0
	.dw 0x6c13, 0xc416,	0x6c3f, 0xc416,		0x21, 0
	.dw 0x6c41, 0xc416,	0x6c41, 0xc416,		0x21, 0
	.dw 0x6c43, 0xc416,	0x6c4f, 0xc416,		0x21, 0
	.dw 0x6c51, 0xc416,	0x6c51, 0xc416,		0x21, 0
	.dw 0x6c53, 0xc416,	0x6c7f, 0xc416,		0x21, 0
	.dw 0x6c81, 0xc416,	0x6c81, 0xc416,		0x21, 0
	.dw 0x6c83, 0xc416,	0x6c8f, 0xc416,		0x21, 0
	.dw 0x6c91, 0xc416,	0x6c91, 0xc416,		0x21, 0
	.dw 0x6c93, 0xc416,	0x6cbf, 0xc416,		0x21, 0
	.dw 0x6cc1, 0xc416,	0x6cc1, 0xc416,		0x21, 0
	.dw 0x6cc3, 0xc416,	0x6ccf, 0xc416,		0x21, 0
	.dw 0x6cd1, 0xc416,	0x6cd1, 0xc416,		0x21, 0
	.dw 0x6cd3, 0xc416,	0x6cff, 0xc416,		0x21, 0
	.dw 0x6d01, 0xc416,	0x6d01, 0xc416,		0x21, 0
	.dw 0x6d03, 0xc416,	0x6d0f, 0xc416,		0x21, 0
	.dw 0x6d11, 0xc416,	0x6d11, 0xc416,		0x21, 0
	.dw 0x6d13, 0xc416,	0x6d3f, 0xc416,		0x21, 0
	.dw 0x6d41, 0xc416,	0x6d41, 0xc416,		0x21, 0
	.dw 0x6d43, 0xc416,	0x6d4f, 0xc416,		0x21, 0
	.dw 0x6d51, 0xc416,	0x6d51, 0xc416,		0x21, 0
	.dw 0x6d53, 0xc416,	0x6d7f, 0xc416,		0x21, 0
	.dw 0x6d81, 0xc416,	0x6d81, 0xc416,		0x21, 0
	.dw 0x6d83, 0xc416,	0x6d8f, 0xc416,		0x21, 0
	.dw 0x6d91, 0xc416,	0x6d91, 0xc416,		0x21, 0
	.dw 0x6d93, 0xc416,	0x6dbf, 0xc416,		0x21, 0
	.dw 0x6dc1, 0xc416,	0x6dc1, 0xc416,		0x21, 0
	.dw 0x6dc3, 0xc416,	0x6dcf, 0xc416,		0x21, 0
	.dw 0x6dd1, 0xc416,	0x6dd1, 0xc416,		0x21, 0
	.dw 0x6dd3, 0xc416,	0x6dff, 0xc416,		0x21, 0
	.dw 0x6e01, 0xc416,	0x6e01, 0xc416,		0x21, 0
	.dw 0x6e03, 0xc416,	0x6e0f, 0xc416,		0x21, 0
	.dw 0x6e11, 0xc416,	0x6e11, 0xc416,		0x21, 0
	.dw 0x6e13, 0xc416,	0x6e3f, 0xc416,		0x21, 0
	.dw 0x6e41, 0xc416,	0x6e41, 0xc416,		0x21, 0
	.dw 0x6e43, 0xc416,	0x6e4f, 0xc416,		0x21, 0
	.dw 0x6e51, 0xc416,	0x6e51, 0xc416,		0x21, 0
	.dw 0x6e53, 0xc416,	0x6e7f, 0xc416,		0x21, 0
	.dw 0x6e81, 0xc416,	0x6e81, 0xc416,		0x21, 0
	.dw 0x6e83, 0xc416,	0x6e8f, 0xc416,		0x21, 0
	.dw 0x6e91, 0xc416,	0x6e91, 0xc416,		0x21, 0
	.dw 0x6e93, 0xc416,	0x6ebf, 0xc416,		0x21, 0
	.dw 0x6ec1, 0xc416,	0x6ec1, 0xc416,		0x21, 0
	.dw 0x6ec3, 0xc416,	0x6ecf, 0xc416,		0x21, 0
	.dw 0x6ed1, 0xc416,	0x6ed1, 0xc416,		0x21, 0
	.dw 0x6ed3, 0xc416,	0x6eff, 0xc416,		0x21, 0
	.dw 0x6f01, 0xc416,	0x6f01, 0xc416,		0x21, 0
	.dw 0x6f03, 0xc416,	0x6f0f, 0xc416,		0x21, 0
	.dw 0x6f11, 0xc416,	0x6f11, 0xc416,		0x21, 0
	.dw 0x6f13, 0xc416,	0x6f3f, 0xc416,		0x21, 0
	.dw 0x6f41, 0xc416,	0x6f41, 0xc416,		0x21, 0
	.dw 0x6f43, 0xc416,	0x6f4f, 0xc416,		0x21, 0
	.dw 0x6f51, 0xc416,	0x6f51, 0xc416,		0x21, 0
	.dw 0x6f53, 0xc416,	0x6f7f, 0xc416,		0x21, 0
	.dw 0x6f81, 0xc416,	0x6f81, 0xc416,		0x21, 0
	.dw 0x6f83, 0xc416,	0x6f8f, 0xc416,		0x21, 0
	.dw 0x6f91, 0xc416,	0x6f91, 0xc416,		0x21, 0
	.dw 0x6f93, 0xc416,	0x6fbf, 0xc416,		0x21, 0
	.dw 0x6fc1, 0xc416,	0x6fc1, 0xc416,		0x21, 0
	.dw 0x6fc3, 0xc416,	0x6fcf, 0xc416,		0x21, 0
	.dw 0x6fd1, 0xc416,	0x6fd1, 0xc416,		0x21, 0
	.dw 0x6fd3, 0xc416,	0xffff, 0xc416,		0x21, 0
	.dw 0x0001, 0xc417,	0x0001, 0xc417,		0x21, 0
	.dw 0x0003, 0xc417,	0x000f, 0xc417,		0x21, 0
	.dw 0x0011, 0xc417,	0x0011, 0xc417,		0x21, 0
	.dw 0x0013, 0xc417,	0x003f, 0xc417,		0x21, 0
	.dw 0x0041, 0xc417,	0x0041, 0xc417,		0x21, 0
	.dw 0x0043, 0xc417,	0x004f, 0xc417,		0x21, 0
	.dw 0x0051, 0xc417,	0x0051, 0xc417,		0x21, 0
	.dw 0x0053, 0xc417,	0x007f, 0xc417,		0x21, 0
	.dw 0x0081, 0xc417,	0x0081, 0xc417,		0x21, 0
	.dw 0x0083, 0xc417,	0x008f, 0xc417,		0x21, 0
	.dw 0x0091, 0xc417,	0x0091, 0xc417,		0x21, 0
	.dw 0x0093, 0xc417,	0x00bf, 0xc417,		0x21, 0
	.dw 0x00c1, 0xc417,	0x00c1, 0xc417,		0x21, 0
	.dw 0x00c3, 0xc417,	0x00cf, 0xc417,		0x21, 0
	.dw 0x00d1, 0xc417,	0x00d1, 0xc417,		0x21, 0
	.dw 0x00d3, 0xc417,	0x00ff, 0xc417,		0x21, 0
	.dw 0x0101, 0xc417,	0x0101, 0xc417,		0x21, 0
	.dw 0x0103, 0xc417,	0x010f, 0xc417,		0x21, 0
	.dw 0x0111, 0xc417,	0x0111, 0xc417,		0x21, 0
	.dw 0x0113, 0xc417,	0x013f, 0xc417,		0x21, 0
	.dw 0x0141, 0xc417,	0x0141, 0xc417,		0x21, 0
	.dw 0x0143, 0xc417,	0x014f, 0xc417,		0x21, 0
	.dw 0x0151, 0xc417,	0x0151, 0xc417,		0x21, 0
	.dw 0x0153, 0xc417,	0x017f, 0xc417,		0x21, 0
	.dw 0x0181, 0xc417,	0x0181, 0xc417,		0x21, 0
	.dw 0x0183, 0xc417,	0x018f, 0xc417,		0x21, 0
	.dw 0x0191, 0xc417,	0x0191, 0xc417,		0x21, 0
	.dw 0x0193, 0xc417,	0x01bf, 0xc417,		0x21, 0
	.dw 0x01c1, 0xc417,	0x01c1, 0xc417,		0x21, 0
	.dw 0x01c3, 0xc417,	0x01cf, 0xc417,		0x21, 0
	.dw 0x01d1, 0xc417,	0x01d1, 0xc417,		0x21, 0
	.dw 0x01d3, 0xc417,	0x01ff, 0xc417,		0x21, 0
	.dw 0x0201, 0xc417,	0x0201, 0xc417,		0x21, 0
	.dw 0x0203, 0xc417,	0x020f, 0xc417,		0x21, 0
	.dw 0x0211, 0xc417,	0x0211, 0xc417,		0x21, 0
	.dw 0x0213, 0xc417,	0x023f, 0xc417,		0x21, 0
	.dw 0x0241, 0xc417,	0x0241, 0xc417,		0x21, 0
	.dw 0x0243, 0xc417,	0x024f, 0xc417,		0x21, 0
	.dw 0x0251, 0xc417,	0x0251, 0xc417,		0x21, 0
	.dw 0x0253, 0xc417,	0x027f, 0xc417,		0x21, 0
	.dw 0x0281, 0xc417,	0x0281, 0xc417,		0x21, 0
	.dw 0x0283, 0xc417,	0x028f, 0xc417,		0x21, 0
	.dw 0x0291, 0xc417,	0x0291, 0xc417,		0x21, 0
	.dw 0x0293, 0xc417,	0x02bf, 0xc417,		0x21, 0
	.dw 0x02c1, 0xc417,	0x02c1, 0xc417,		0x21, 0
	.dw 0x02c3, 0xc417,	0x02cf, 0xc417,		0x21, 0
	.dw 0x02d1, 0xc417,	0x02d1, 0xc417,		0x21, 0
	.dw 0x02d3, 0xc417,	0x02ff, 0xc417,		0x21, 0
	.dw 0x0301, 0xc417,	0x0301, 0xc417,		0x21, 0
	.dw 0x0303, 0xc417,	0x030f, 0xc417,		0x21, 0
	.dw 0x0311, 0xc417,	0x0311, 0xc417,		0x21, 0
	.dw 0x0313, 0xc417,	0x033f, 0xc417,		0x21, 0
	.dw 0x0341, 0xc417,	0x0341, 0xc417,		0x21, 0
	.dw 0x0343, 0xc417,	0x034f, 0xc417,		0x21, 0
	.dw 0x0351, 0xc417,	0x0351, 0xc417,		0x21, 0
	.dw 0x0353, 0xc417,	0x037f, 0xc417,		0x21, 0
	.dw 0x0381, 0xc417,	0x0381, 0xc417,		0x21, 0
	.dw 0x0383, 0xc417,	0x038f, 0xc417,		0x21, 0
	.dw 0x0391, 0xc417,	0x0391, 0xc417,		0x21, 0
	.dw 0x0393, 0xc417,	0x03bf, 0xc417,		0x21, 0
	.dw 0x03c1, 0xc417,	0x03c1, 0xc417,		0x21, 0
	.dw 0x03c3, 0xc417,	0x03cf, 0xc417,		0x21, 0
	.dw 0x03d1, 0xc417,	0x03d1, 0xc417,		0x21, 0
	.dw 0x03d3, 0xc417,	0x03ff, 0xc417,		0x21, 0
	.dw 0x0401, 0xc417,	0x0401, 0xc417,		0x21, 0
	.dw 0x0403, 0xc417,	0x040f, 0xc417,		0x21, 0
	.dw 0x0411, 0xc417,	0x0411, 0xc417,		0x21, 0
	.dw 0x0413, 0xc417,	0x043f, 0xc417,		0x21, 0
	.dw 0x0441, 0xc417,	0x0441, 0xc417,		0x21, 0
	.dw 0x0443, 0xc417,	0x044f, 0xc417,		0x21, 0
	.dw 0x0451, 0xc417,	0x0451, 0xc417,		0x21, 0
	.dw 0x0453, 0xc417,	0x047f, 0xc417,		0x21, 0
	.dw 0x0481, 0xc417,	0x0481, 0xc417,		0x21, 0
	.dw 0x0483, 0xc417,	0x048f, 0xc417,		0x21, 0
	.dw 0x0491, 0xc417,	0x0491, 0xc417,		0x21, 0
	.dw 0x0493, 0xc417,	0x04bf, 0xc417,		0x21, 0
	.dw 0x04c1, 0xc417,	0x04c1, 0xc417,		0x21, 0
	.dw 0x04c3, 0xc417,	0x04cf, 0xc417,		0x21, 0
	.dw 0x04d1, 0xc417,	0x04d1, 0xc417,		0x21, 0
	.dw 0x04d3, 0xc417,	0x04ff, 0xc417,		0x21, 0
	.dw 0x0501, 0xc417,	0x0501, 0xc417,		0x21, 0
	.dw 0x0503, 0xc417,	0x050f, 0xc417,		0x21, 0
	.dw 0x0511, 0xc417,	0x0511, 0xc417,		0x21, 0
	.dw 0x0513, 0xc417,	0x053f, 0xc417,		0x21, 0
	.dw 0x0541, 0xc417,	0x0541, 0xc417,		0x21, 0
	.dw 0x0543, 0xc417,	0x054f, 0xc417,		0x21, 0
	.dw 0x0551, 0xc417,	0x0551, 0xc417,		0x21, 0
	.dw 0x0553, 0xc417,	0x057f, 0xc417,		0x21, 0
	.dw 0x0581, 0xc417,	0x0581, 0xc417,		0x21, 0
	.dw 0x0583, 0xc417,	0x058f, 0xc417,		0x21, 0
	.dw 0x0591, 0xc417,	0x0591, 0xc417,		0x21, 0
	.dw 0x0593, 0xc417,	0x05bf, 0xc417,		0x21, 0
	.dw 0x05c1, 0xc417,	0x05c1, 0xc417,		0x21, 0
	.dw 0x05c3, 0xc417,	0x05cf, 0xc417,		0x21, 0
	.dw 0x05d1, 0xc417,	0x05d1, 0xc417,		0x21, 0
	.dw 0x05d3, 0xc417,	0x05ff, 0xc417,		0x21, 0
	.dw 0x0601, 0xc417,	0x0601, 0xc417,		0x21, 0
	.dw 0x0603, 0xc417,	0x060f, 0xc417,		0x21, 0
	.dw 0x0611, 0xc417,	0x0611, 0xc417,		0x21, 0
	.dw 0x0613, 0xc417,	0x063f, 0xc417,		0x21, 0
	.dw 0x0641, 0xc417,	0x0641, 0xc417,		0x21, 0
	.dw 0x0643, 0xc417,	0x064f, 0xc417,		0x21, 0
	.dw 0x0651, 0xc417,	0x0651, 0xc417,		0x21, 0
	.dw 0x0653, 0xc417,	0x067f, 0xc417,		0x21, 0
	.dw 0x0681, 0xc417,	0x0681, 0xc417,		0x21, 0
	.dw 0x0683, 0xc417,	0x068f, 0xc417,		0x21, 0
	.dw 0x0691, 0xc417,	0x0691, 0xc417,		0x21, 0
	.dw 0x0693, 0xc417,	0x06bf, 0xc417,		0x21, 0
	.dw 0x06c1, 0xc417,	0x06c1, 0xc417,		0x21, 0
	.dw 0x06c3, 0xc417,	0x06cf, 0xc417,		0x21, 0
	.dw 0x06d1, 0xc417,	0x06d1, 0xc417,		0x21, 0
	.dw 0x06d3, 0xc417,	0x06ff, 0xc417,		0x21, 0
	.dw 0x0701, 0xc417,	0x0701, 0xc417,		0x21, 0
	.dw 0x0703, 0xc417,	0x070f, 0xc417,		0x21, 0
	.dw 0x0711, 0xc417,	0x0711, 0xc417,		0x21, 0
	.dw 0x0713, 0xc417,	0x073f, 0xc417,		0x21, 0
	.dw 0x0741, 0xc417,	0x0741, 0xc417,		0x21, 0
	.dw 0x0743, 0xc417,	0x074f, 0xc417,		0x21, 0
	.dw 0x0751, 0xc417,	0x0751, 0xc417,		0x21, 0
	.dw 0x0753, 0xc417,	0x077f, 0xc417,		0x21, 0
	.dw 0x0781, 0xc417,	0x0781, 0xc417,		0x21, 0
	.dw 0x0783, 0xc417,	0x078f, 0xc417,		0x21, 0
	.dw 0x0791, 0xc417,	0x0791, 0xc417,		0x21, 0
	.dw 0x0793, 0xc417,	0x07bf, 0xc417,		0x21, 0
	.dw 0x07c1, 0xc417,	0x07c1, 0xc417,		0x21, 0
	.dw 0x07c3, 0xc417,	0x07cf, 0xc417,		0x21, 0
	.dw 0x07d1, 0xc417,	0x07d1, 0xc417,		0x21, 0
	.dw 0x07d3, 0xc417,	0x07ff, 0xc417,		0x21, 0
	.dw 0x0801, 0xc417,	0x0801, 0xc417,		0x21, 0
	.dw 0x0803, 0xc417,	0x080f, 0xc417,		0x21, 0
	.dw 0x0811, 0xc417,	0x0811, 0xc417,		0x21, 0
	.dw 0x0813, 0xc417,	0x083f, 0xc417,		0x21, 0
	.dw 0x0841, 0xc417,	0x0841, 0xc417,		0x21, 0
	.dw 0x0843, 0xc417,	0x084f, 0xc417,		0x21, 0
	.dw 0x0851, 0xc417,	0x0851, 0xc417,		0x21, 0
	.dw 0x0853, 0xc417,	0x087f, 0xc417,		0x21, 0
	.dw 0x0881, 0xc417,	0x0881, 0xc417,		0x21, 0
	.dw 0x0883, 0xc417,	0x088f, 0xc417,		0x21, 0
	.dw 0x0891, 0xc417,	0x0891, 0xc417,		0x21, 0
	.dw 0x0893, 0xc417,	0x08bf, 0xc417,		0x21, 0
	.dw 0x08c1, 0xc417,	0x08c1, 0xc417,		0x21, 0
	.dw 0x08c3, 0xc417,	0x08cf, 0xc417,		0x21, 0
	.dw 0x08d1, 0xc417,	0x08d1, 0xc417,		0x21, 0
	.dw 0x08d3, 0xc417,	0x08ff, 0xc417,		0x21, 0
	.dw 0x0901, 0xc417,	0x0901, 0xc417,		0x21, 0
	.dw 0x0903, 0xc417,	0x090f, 0xc417,		0x21, 0
	.dw 0x0911, 0xc417,	0x0911, 0xc417,		0x21, 0
	.dw 0x0913, 0xc417,	0x093f, 0xc417,		0x21, 0
	.dw 0x0941, 0xc417,	0x0941, 0xc417,		0x21, 0
	.dw 0x0943, 0xc417,	0x094f, 0xc417,		0x21, 0
	.dw 0x0951, 0xc417,	0x0951, 0xc417,		0x21, 0
	.dw 0x0953, 0xc417,	0x097f, 0xc417,		0x21, 0
	.dw 0x0981, 0xc417,	0x0981, 0xc417,		0x21, 0
	.dw 0x0983, 0xc417,	0x098f, 0xc417,		0x21, 0
	.dw 0x0991, 0xc417,	0x0991, 0xc417,		0x21, 0
	.dw 0x0993, 0xc417,	0x09bf, 0xc417,		0x21, 0
	.dw 0x09c1, 0xc417,	0x09c1, 0xc417,		0x21, 0
	.dw 0x09c3, 0xc417,	0x09cf, 0xc417,		0x21, 0
	.dw 0x09d1, 0xc417,	0x09d1, 0xc417,		0x21, 0
	.dw 0x09d3, 0xc417,	0x09ff, 0xc417,		0x21, 0
	.dw 0x0a01, 0xc417,	0x0a01, 0xc417,		0x21, 0
	.dw 0x0a03, 0xc417,	0x0a0f, 0xc417,		0x21, 0
	.dw 0x0a11, 0xc417,	0x0a11, 0xc417,		0x21, 0
	.dw 0x0a13, 0xc417,	0x0a3f, 0xc417,		0x21, 0
	.dw 0x0a41, 0xc417,	0x0a41, 0xc417,		0x21, 0
	.dw 0x0a43, 0xc417,	0x0a4f, 0xc417,		0x21, 0
	.dw 0x0a51, 0xc417,	0x0a51, 0xc417,		0x21, 0
	.dw 0x0a53, 0xc417,	0x0a7f, 0xc417,		0x21, 0
	.dw 0x0a81, 0xc417,	0x0a81, 0xc417,		0x21, 0
	.dw 0x0a83, 0xc417,	0x0a8f, 0xc417,		0x21, 0
	.dw 0x0a91, 0xc417,	0x0a91, 0xc417,		0x21, 0
	.dw 0x0a93, 0xc417,	0x0abf, 0xc417,		0x21, 0
	.dw 0x0ac1, 0xc417,	0x0ac1, 0xc417,		0x21, 0
	.dw 0x0ac3, 0xc417,	0x0acf, 0xc417,		0x21, 0
	.dw 0x0ad1, 0xc417,	0x0ad1, 0xc417,		0x21, 0
	.dw 0x0ad3, 0xc417,	0x0aff, 0xc417,		0x21, 0
	.dw 0x0b01, 0xc417,	0x0b01, 0xc417,		0x21, 0
	.dw 0x0b03, 0xc417,	0x0b0f, 0xc417,		0x21, 0
	.dw 0x0b11, 0xc417,	0x0b11, 0xc417,		0x21, 0
	.dw 0x0b13, 0xc417,	0x0b3f, 0xc417,		0x21, 0
	.dw 0x0b41, 0xc417,	0x0b41, 0xc417,		0x21, 0
	.dw 0x0b43, 0xc417,	0x0b4f, 0xc417,		0x21, 0
	.dw 0x0b51, 0xc417,	0x0b51, 0xc417,		0x21, 0
	.dw 0x0b53, 0xc417,	0x0b7f, 0xc417,		0x21, 0
	.dw 0x0b81, 0xc417,	0x0b81, 0xc417,		0x21, 0
	.dw 0x0b83, 0xc417,	0x0b8f, 0xc417,		0x21, 0
	.dw 0x0b91, 0xc417,	0x0b91, 0xc417,		0x21, 0
	.dw 0x0b93, 0xc417,	0x0bbf, 0xc417,		0x21, 0
	.dw 0x0bc1, 0xc417,	0x0bc1, 0xc417,		0x21, 0
	.dw 0x0bc3, 0xc417,	0x0bcf, 0xc417,		0x21, 0
	.dw 0x0bd1, 0xc417,	0x0bd1, 0xc417,		0x21, 0
	.dw 0x0bd3, 0xc417,	0x0bff, 0xc417,		0x21, 0
	.dw 0x0c01, 0xc417,	0x0c01, 0xc417,		0x21, 0
	.dw 0x0c03, 0xc417,	0x0c0f, 0xc417,		0x21, 0
	.dw 0x0c11, 0xc417,	0x0c11, 0xc417,		0x21, 0
	.dw 0x0c13, 0xc417,	0x0c3f, 0xc417,		0x21, 0
	.dw 0x0c41, 0xc417,	0x0c41, 0xc417,		0x21, 0
	.dw 0x0c43, 0xc417,	0x0c4f, 0xc417,		0x21, 0
	.dw 0x0c51, 0xc417,	0x0c51, 0xc417,		0x21, 0
	.dw 0x0c53, 0xc417,	0x0c7f, 0xc417,		0x21, 0
	.dw 0x0c81, 0xc417,	0x0c81, 0xc417,		0x21, 0
	.dw 0x0c83, 0xc417,	0x0c8f, 0xc417,		0x21, 0
	.dw 0x0c91, 0xc417,	0x0c91, 0xc417,		0x21, 0
	.dw 0x0c93, 0xc417,	0x0cbf, 0xc417,		0x21, 0
	.dw 0x0cc1, 0xc417,	0x0cc1, 0xc417,		0x21, 0
	.dw 0x0cc3, 0xc417,	0x0ccf, 0xc417,		0x21, 0
	.dw 0x0cd1, 0xc417,	0x0cd1, 0xc417,		0x21, 0
	.dw 0x0cd3, 0xc417,	0x0cff, 0xc417,		0x21, 0
	.dw 0x0d01, 0xc417,	0x0d01, 0xc417,		0x21, 0
	.dw 0x0d03, 0xc417,	0x0d0f, 0xc417,		0x21, 0
	.dw 0x0d11, 0xc417,	0x0d11, 0xc417,		0x21, 0
	.dw 0x0d13, 0xc417,	0x0d3f, 0xc417,		0x21, 0
	.dw 0x0d41, 0xc417,	0x0d41, 0xc417,		0x21, 0
	.dw 0x0d43, 0xc417,	0x0d4f, 0xc417,		0x21, 0
	.dw 0x0d51, 0xc417,	0x0d51, 0xc417,		0x21, 0
	.dw 0x0d53, 0xc417,	0x0d7f, 0xc417,		0x21, 0
	.dw 0x0d81, 0xc417,	0x0d81, 0xc417,		0x21, 0
	.dw 0x0d83, 0xc417,	0x0d8f, 0xc417,		0x21, 0
	.dw 0x0d91, 0xc417,	0x0d91, 0xc417,		0x21, 0
	.dw 0x0d93, 0xc417,	0x0dbf, 0xc417,		0x21, 0
	.dw 0x0dc1, 0xc417,	0x0dc1, 0xc417,		0x21, 0
	.dw 0x0dc3, 0xc417,	0x0dcf, 0xc417,		0x21, 0
	.dw 0x0dd1, 0xc417,	0x0dd1, 0xc417,		0x21, 0
	.dw 0x0dd3, 0xc417,	0x0dff, 0xc417,		0x21, 0
	.dw 0x0e01, 0xc417,	0x0e01, 0xc417,		0x21, 0
	.dw 0x0e03, 0xc417,	0x0e0f, 0xc417,		0x21, 0
	.dw 0x0e11, 0xc417,	0x0e11, 0xc417,		0x21, 0
	.dw 0x0e13, 0xc417,	0x0e3f, 0xc417,		0x21, 0
	.dw 0x0e41, 0xc417,	0x0e41, 0xc417,		0x21, 0
	.dw 0x0e43, 0xc417,	0x0e4f, 0xc417,		0x21, 0
	.dw 0x0e51, 0xc417,	0x0e51, 0xc417,		0x21, 0
	.dw 0x0e53, 0xc417,	0x0e7f, 0xc417,		0x21, 0
	.dw 0x0e81, 0xc417,	0x0e81, 0xc417,		0x21, 0
	.dw 0x0e83, 0xc417,	0x0e8f, 0xc417,		0x21, 0
	.dw 0x0e91, 0xc417,	0x0e91, 0xc417,		0x21, 0
	.dw 0x0e93, 0xc417,	0x0ebf, 0xc417,		0x21, 0
	.dw 0x0ec1, 0xc417,	0x0ec1, 0xc417,		0x21, 0
	.dw 0x0ec3, 0xc417,	0x0ecf, 0xc417,		0x21, 0
	.dw 0x0ed1, 0xc417,	0x0ed1, 0xc417,		0x21, 0
	.dw 0x0ed3, 0xc417,	0x0eff, 0xc417,		0x21, 0
	.dw 0x0f01, 0xc417,	0x0f01, 0xc417,		0x21, 0
	.dw 0x0f03, 0xc417,	0x0f0f, 0xc417,		0x21, 0
	.dw 0x0f11, 0xc417,	0x0f11, 0xc417,		0x21, 0
	.dw 0x0f13, 0xc417,	0x0f3f, 0xc417,		0x21, 0
	.dw 0x0f41, 0xc417,	0x0f41, 0xc417,		0x21, 0
	.dw 0x0f43, 0xc417,	0x0f4f, 0xc417,		0x21, 0
	.dw 0x0f51, 0xc417,	0x0f51, 0xc417,		0x21, 0
	.dw 0x0f53, 0xc417,	0x0f7f, 0xc417,		0x21, 0
	.dw 0x0f81, 0xc417,	0x0f81, 0xc417,		0x21, 0
	.dw 0x0f83, 0xc417,	0x0f8f, 0xc417,		0x21, 0
	.dw 0x0f91, 0xc417,	0x0f91, 0xc417,		0x21, 0
	.dw 0x0f93, 0xc417,	0x0fbf, 0xc417,		0x21, 0
	.dw 0x0fc1, 0xc417,	0x0fc1, 0xc417,		0x21, 0
	.dw 0x0fc3, 0xc417,	0x0fcf, 0xc417,		0x21, 0
	.dw 0x0fd1, 0xc417,	0x0fd1, 0xc417,		0x21, 0
	.dw 0x0fd3, 0xc417,	0x1fff, 0xc417,		0x21, 0
	.dw 0x2001, 0xc417,	0x2001, 0xc417,		0x21, 0
	.dw 0x2003, 0xc417,	0x200f, 0xc417,		0x21, 0
	.dw 0x2011, 0xc417,	0x2011, 0xc417,		0x21, 0
	.dw 0x2013, 0xc417,	0x203f, 0xc417,		0x21, 0
	.dw 0x2041, 0xc417,	0x2041, 0xc417,		0x21, 0
	.dw 0x2043, 0xc417,	0x204f, 0xc417,		0x21, 0
	.dw 0x2051, 0xc417,	0x2051, 0xc417,		0x21, 0
	.dw 0x2053, 0xc417,	0x207f, 0xc417,		0x21, 0
	.dw 0x2081, 0xc417,	0x2081, 0xc417,		0x21, 0
	.dw 0x2083, 0xc417,	0x208f, 0xc417,		0x21, 0
	.dw 0x2091, 0xc417,	0x2091, 0xc417,		0x21, 0
	.dw 0x2093, 0xc417,	0x20bf, 0xc417,		0x21, 0
	.dw 0x20c1, 0xc417,	0x20c1, 0xc417,		0x21, 0
	.dw 0x20c3, 0xc417,	0x20cf, 0xc417,		0x21, 0
	.dw 0x20d1, 0xc417,	0x20d1, 0xc417,		0x21, 0
	.dw 0x20d3, 0xc417,	0x20ff, 0xc417,		0x21, 0
	.dw 0x2101, 0xc417,	0x2101, 0xc417,		0x21, 0
	.dw 0x2103, 0xc417,	0x210f, 0xc417,		0x21, 0
	.dw 0x2111, 0xc417,	0x2111, 0xc417,		0x21, 0
	.dw 0x2113, 0xc417,	0x213f, 0xc417,		0x21, 0
	.dw 0x2141, 0xc417,	0x2141, 0xc417,		0x21, 0
	.dw 0x2143, 0xc417,	0x214f, 0xc417,		0x21, 0
	.dw 0x2151, 0xc417,	0x2151, 0xc417,		0x21, 0
	.dw 0x2153, 0xc417,	0x217f, 0xc417,		0x21, 0
	.dw 0x2181, 0xc417,	0x2181, 0xc417,		0x21, 0
	.dw 0x2183, 0xc417,	0x218f, 0xc417,		0x21, 0
	.dw 0x2191, 0xc417,	0x2191, 0xc417,		0x21, 0
	.dw 0x2193, 0xc417,	0x21bf, 0xc417,		0x21, 0
	.dw 0x21c1, 0xc417,	0x21c1, 0xc417,		0x21, 0
	.dw 0x21c3, 0xc417,	0x21cf, 0xc417,		0x21, 0
	.dw 0x21d1, 0xc417,	0x21d1, 0xc417,		0x21, 0
	.dw 0x21d3, 0xc417,	0x21ff, 0xc417,		0x21, 0
	.dw 0x2201, 0xc417,	0x2201, 0xc417,		0x21, 0
	.dw 0x2203, 0xc417,	0x220f, 0xc417,		0x21, 0
	.dw 0x2211, 0xc417,	0x2211, 0xc417,		0x21, 0
	.dw 0x2213, 0xc417,	0x223f, 0xc417,		0x21, 0
	.dw 0x2241, 0xc417,	0x2241, 0xc417,		0x21, 0
	.dw 0x2243, 0xc417,	0x224f, 0xc417,		0x21, 0
	.dw 0x2251, 0xc417,	0x2251, 0xc417,		0x21, 0
	.dw 0x2253, 0xc417,	0x227f, 0xc417,		0x21, 0
	.dw 0x2281, 0xc417,	0x2281, 0xc417,		0x21, 0
	.dw 0x2283, 0xc417,	0x228f, 0xc417,		0x21, 0
	.dw 0x2291, 0xc417,	0x2291, 0xc417,		0x21, 0
	.dw 0x2293, 0xc417,	0x22bf, 0xc417,		0x21, 0
	.dw 0x22c1, 0xc417,	0x22c1, 0xc417,		0x21, 0
	.dw 0x22c3, 0xc417,	0x22cf, 0xc417,		0x21, 0
	.dw 0x22d1, 0xc417,	0x22d1, 0xc417,		0x21, 0
	.dw 0x22d3, 0xc417,	0x22ff, 0xc417,		0x21, 0
	.dw 0x2301, 0xc417,	0x2301, 0xc417,		0x21, 0
	.dw 0x2303, 0xc417,	0x230f, 0xc417,		0x21, 0
	.dw 0x2311, 0xc417,	0x2311, 0xc417,		0x21, 0
	.dw 0x2313, 0xc417,	0x233f, 0xc417,		0x21, 0
	.dw 0x2341, 0xc417,	0x2341, 0xc417,		0x21, 0
	.dw 0x2343, 0xc417,	0x234f, 0xc417,		0x21, 0
	.dw 0x2351, 0xc417,	0x2351, 0xc417,		0x21, 0
	.dw 0x2353, 0xc417,	0x237f, 0xc417,		0x21, 0
	.dw 0x2381, 0xc417,	0x2381, 0xc417,		0x21, 0
	.dw 0x2383, 0xc417,	0x238f, 0xc417,		0x21, 0
	.dw 0x2391, 0xc417,	0x2391, 0xc417,		0x21, 0
	.dw 0x2393, 0xc417,	0x23bf, 0xc417,		0x21, 0
	.dw 0x23c1, 0xc417,	0x23c1, 0xc417,		0x21, 0
	.dw 0x23c3, 0xc417,	0x23cf, 0xc417,		0x21, 0
	.dw 0x23d1, 0xc417,	0x23d1, 0xc417,		0x21, 0
	.dw 0x23d3, 0xc417,	0x23ff, 0xc417,		0x21, 0
	.dw 0x2401, 0xc417,	0x2401, 0xc417,		0x21, 0
	.dw 0x2403, 0xc417,	0x240f, 0xc417,		0x21, 0
	.dw 0x2411, 0xc417,	0x2411, 0xc417,		0x21, 0
	.dw 0x2413, 0xc417,	0x243f, 0xc417,		0x21, 0
	.dw 0x2441, 0xc417,	0x2441, 0xc417,		0x21, 0
	.dw 0x2443, 0xc417,	0x244f, 0xc417,		0x21, 0
	.dw 0x2451, 0xc417,	0x2451, 0xc417,		0x21, 0
	.dw 0x2453, 0xc417,	0x247f, 0xc417,		0x21, 0
	.dw 0x2481, 0xc417,	0x2481, 0xc417,		0x21, 0
	.dw 0x2483, 0xc417,	0x248f, 0xc417,		0x21, 0
	.dw 0x2491, 0xc417,	0x2491, 0xc417,		0x21, 0
	.dw 0x2493, 0xc417,	0x24bf, 0xc417,		0x21, 0
	.dw 0x24c1, 0xc417,	0x24c1, 0xc417,		0x21, 0
	.dw 0x24c3, 0xc417,	0x24cf, 0xc417,		0x21, 0
	.dw 0x24d1, 0xc417,	0x24d1, 0xc417,		0x21, 0
	.dw 0x24d3, 0xc417,	0x24ff, 0xc417,		0x21, 0
	.dw 0x2501, 0xc417,	0x2501, 0xc417,		0x21, 0
	.dw 0x2503, 0xc417,	0x250f, 0xc417,		0x21, 0
	.dw 0x2511, 0xc417,	0x2511, 0xc417,		0x21, 0
	.dw 0x2513, 0xc417,	0x253f, 0xc417,		0x21, 0
	.dw 0x2541, 0xc417,	0x2541, 0xc417,		0x21, 0
	.dw 0x2543, 0xc417,	0x254f, 0xc417,		0x21, 0
	.dw 0x2551, 0xc417,	0x2551, 0xc417,		0x21, 0
	.dw 0x2553, 0xc417,	0x257f, 0xc417,		0x21, 0
	.dw 0x2581, 0xc417,	0x2581, 0xc417,		0x21, 0
	.dw 0x2583, 0xc417,	0x258f, 0xc417,		0x21, 0
	.dw 0x2591, 0xc417,	0x2591, 0xc417,		0x21, 0
	.dw 0x2593, 0xc417,	0x25bf, 0xc417,		0x21, 0
	.dw 0x25c1, 0xc417,	0x25c1, 0xc417,		0x21, 0
	.dw 0x25c3, 0xc417,	0x25cf, 0xc417,		0x21, 0
	.dw 0x25d1, 0xc417,	0x25d1, 0xc417,		0x21, 0
	.dw 0x25d3, 0xc417,	0x25ff, 0xc417,		0x21, 0
	.dw 0x2601, 0xc417,	0x2601, 0xc417,		0x21, 0
	.dw 0x2603, 0xc417,	0x260f, 0xc417,		0x21, 0
	.dw 0x2611, 0xc417,	0x2611, 0xc417,		0x21, 0
	.dw 0x2613, 0xc417,	0x263f, 0xc417,		0x21, 0
	.dw 0x2641, 0xc417,	0x2641, 0xc417,		0x21, 0
	.dw 0x2643, 0xc417,	0x264f, 0xc417,		0x21, 0
	.dw 0x2651, 0xc417,	0x2651, 0xc417,		0x21, 0
	.dw 0x2653, 0xc417,	0x267f, 0xc417,		0x21, 0
	.dw 0x2681, 0xc417,	0x2681, 0xc417,		0x21, 0
	.dw 0x2683, 0xc417,	0x268f, 0xc417,		0x21, 0
	.dw 0x2691, 0xc417,	0x2691, 0xc417,		0x21, 0
	.dw 0x2693, 0xc417,	0x26bf, 0xc417,		0x21, 0
	.dw 0x26c1, 0xc417,	0x26c1, 0xc417,		0x21, 0
	.dw 0x26c3, 0xc417,	0x26cf, 0xc417,		0x21, 0
	.dw 0x26d1, 0xc417,	0x26d1, 0xc417,		0x21, 0
	.dw 0x26d3, 0xc417,	0x26ff, 0xc417,		0x21, 0
	.dw 0x2701, 0xc417,	0x2701, 0xc417,		0x21, 0
	.dw 0x2703, 0xc417,	0x270f, 0xc417,		0x21, 0
	.dw 0x2711, 0xc417,	0x2711, 0xc417,		0x21, 0
	.dw 0x2713, 0xc417,	0x273f, 0xc417,		0x21, 0
	.dw 0x2741, 0xc417,	0x2741, 0xc417,		0x21, 0
	.dw 0x2743, 0xc417,	0x274f, 0xc417,		0x21, 0
	.dw 0x2751, 0xc417,	0x2751, 0xc417,		0x21, 0
	.dw 0x2753, 0xc417,	0x277f, 0xc417,		0x21, 0
	.dw 0x2781, 0xc417,	0x2781, 0xc417,		0x21, 0
	.dw 0x2783, 0xc417,	0x278f, 0xc417,		0x21, 0
	.dw 0x2791, 0xc417,	0x2791, 0xc417,		0x21, 0
	.dw 0x2793, 0xc417,	0x27bf, 0xc417,		0x21, 0
	.dw 0x27c1, 0xc417,	0x27c1, 0xc417,		0x21, 0
	.dw 0x27c3, 0xc417,	0x27cf, 0xc417,		0x21, 0
	.dw 0x27d1, 0xc417,	0x27d1, 0xc417,		0x21, 0
	.dw 0x27d3, 0xc417,	0x27ff, 0xc417,		0x21, 0
	.dw 0x2801, 0xc417,	0x2801, 0xc417,		0x21, 0
	.dw 0x2803, 0xc417,	0x280f, 0xc417,		0x21, 0
	.dw 0x2811, 0xc417,	0x2811, 0xc417,		0x21, 0
	.dw 0x2813, 0xc417,	0x283f, 0xc417,		0x21, 0
	.dw 0x2841, 0xc417,	0x2841, 0xc417,		0x21, 0
	.dw 0x2843, 0xc417,	0x284f, 0xc417,		0x21, 0
	.dw 0x2851, 0xc417,	0x2851, 0xc417,		0x21, 0
	.dw 0x2853, 0xc417,	0x287f, 0xc417,		0x21, 0
	.dw 0x2881, 0xc417,	0x2881, 0xc417,		0x21, 0
	.dw 0x2883, 0xc417,	0x288f, 0xc417,		0x21, 0
	.dw 0x2891, 0xc417,	0x2891, 0xc417,		0x21, 0
	.dw 0x2893, 0xc417,	0x28bf, 0xc417,		0x21, 0
	.dw 0x28c1, 0xc417,	0x28c1, 0xc417,		0x21, 0
	.dw 0x28c3, 0xc417,	0x28cf, 0xc417,		0x21, 0
	.dw 0x28d1, 0xc417,	0x28d1, 0xc417,		0x21, 0
	.dw 0x28d3, 0xc417,	0x28ff, 0xc417,		0x21, 0
	.dw 0x2901, 0xc417,	0x2901, 0xc417,		0x21, 0
	.dw 0x2903, 0xc417,	0x290f, 0xc417,		0x21, 0
	.dw 0x2911, 0xc417,	0x2911, 0xc417,		0x21, 0
	.dw 0x2913, 0xc417,	0x293f, 0xc417,		0x21, 0
	.dw 0x2941, 0xc417,	0x2941, 0xc417,		0x21, 0
	.dw 0x2943, 0xc417,	0x294f, 0xc417,		0x21, 0
	.dw 0x2951, 0xc417,	0x2951, 0xc417,		0x21, 0
	.dw 0x2953, 0xc417,	0x297f, 0xc417,		0x21, 0
	.dw 0x2981, 0xc417,	0x2981, 0xc417,		0x21, 0
	.dw 0x2983, 0xc417,	0x298f, 0xc417,		0x21, 0
	.dw 0x2991, 0xc417,	0x2991, 0xc417,		0x21, 0
	.dw 0x2993, 0xc417,	0x29bf, 0xc417,		0x21, 0
	.dw 0x29c1, 0xc417,	0x29c1, 0xc417,		0x21, 0
	.dw 0x29c3, 0xc417,	0x29cf, 0xc417,		0x21, 0
	.dw 0x29d1, 0xc417,	0x29d1, 0xc417,		0x21, 0
	.dw 0x29d3, 0xc417,	0x29ff, 0xc417,		0x21, 0
	.dw 0x2a01, 0xc417,	0x2a01, 0xc417,		0x21, 0
	.dw 0x2a03, 0xc417,	0x2a0f, 0xc417,		0x21, 0
	.dw 0x2a11, 0xc417,	0x2a11, 0xc417,		0x21, 0
	.dw 0x2a13, 0xc417,	0x2a3f, 0xc417,		0x21, 0
	.dw 0x2a41, 0xc417,	0x2a41, 0xc417,		0x21, 0
	.dw 0x2a43, 0xc417,	0x2a4f, 0xc417,		0x21, 0
	.dw 0x2a51, 0xc417,	0x2a51, 0xc417,		0x21, 0
	.dw 0x2a53, 0xc417,	0x2a7f, 0xc417,		0x21, 0
	.dw 0x2a81, 0xc417,	0x2a81, 0xc417,		0x21, 0
	.dw 0x2a83, 0xc417,	0x2a8f, 0xc417,		0x21, 0
	.dw 0x2a91, 0xc417,	0x2a91, 0xc417,		0x21, 0
	.dw 0x2a93, 0xc417,	0x2abf, 0xc417,		0x21, 0
	.dw 0x2ac1, 0xc417,	0x2ac1, 0xc417,		0x21, 0
	.dw 0x2ac3, 0xc417,	0x2acf, 0xc417,		0x21, 0
	.dw 0x2ad1, 0xc417,	0x2ad1, 0xc417,		0x21, 0
	.dw 0x2ad3, 0xc417,	0x2aff, 0xc417,		0x21, 0
	.dw 0x2b01, 0xc417,	0x2b01, 0xc417,		0x21, 0
	.dw 0x2b03, 0xc417,	0x2b0f, 0xc417,		0x21, 0
	.dw 0x2b11, 0xc417,	0x2b11, 0xc417,		0x21, 0
	.dw 0x2b13, 0xc417,	0x2b3f, 0xc417,		0x21, 0
	.dw 0x2b41, 0xc417,	0x2b41, 0xc417,		0x21, 0
	.dw 0x2b43, 0xc417,	0x2b4f, 0xc417,		0x21, 0
	.dw 0x2b51, 0xc417,	0x2b51, 0xc417,		0x21, 0
	.dw 0x2b53, 0xc417,	0x2b7f, 0xc417,		0x21, 0
	.dw 0x2b81, 0xc417,	0x2b81, 0xc417,		0x21, 0
	.dw 0x2b83, 0xc417,	0x2b8f, 0xc417,		0x21, 0
	.dw 0x2b91, 0xc417,	0x2b91, 0xc417,		0x21, 0
	.dw 0x2b93, 0xc417,	0x2bbf, 0xc417,		0x21, 0
	.dw 0x2bc1, 0xc417,	0x2bc1, 0xc417,		0x21, 0
	.dw 0x2bc3, 0xc417,	0x2bcf, 0xc417,		0x21, 0
	.dw 0x2bd1, 0xc417,	0x2bd1, 0xc417,		0x21, 0
	.dw 0x2bd3, 0xc417,	0x2bff, 0xc417,		0x21, 0
	.dw 0x2c01, 0xc417,	0x2c01, 0xc417,		0x21, 0
	.dw 0x2c03, 0xc417,	0x2c0f, 0xc417,		0x21, 0
	.dw 0x2c11, 0xc417,	0x2c11, 0xc417,		0x21, 0
	.dw 0x2c13, 0xc417,	0x2c3f, 0xc417,		0x21, 0
	.dw 0x2c41, 0xc417,	0x2c41, 0xc417,		0x21, 0
	.dw 0x2c43, 0xc417,	0x2c4f, 0xc417,		0x21, 0
	.dw 0x2c51, 0xc417,	0x2c51, 0xc417,		0x21, 0
	.dw 0x2c53, 0xc417,	0x2c7f, 0xc417,		0x21, 0
	.dw 0x2c81, 0xc417,	0x2c81, 0xc417,		0x21, 0
	.dw 0x2c83, 0xc417,	0x2c8f, 0xc417,		0x21, 0
	.dw 0x2c91, 0xc417,	0x2c91, 0xc417,		0x21, 0
	.dw 0x2c93, 0xc417,	0x2cbf, 0xc417,		0x21, 0
	.dw 0x2cc1, 0xc417,	0x2cc1, 0xc417,		0x21, 0
	.dw 0x2cc3, 0xc417,	0x2ccf, 0xc417,		0x21, 0
	.dw 0x2cd1, 0xc417,	0x2cd1, 0xc417,		0x21, 0
	.dw 0x2cd3, 0xc417,	0x2cff, 0xc417,		0x21, 0
	.dw 0x2d01, 0xc417,	0x2d01, 0xc417,		0x21, 0
	.dw 0x2d03, 0xc417,	0x2d0f, 0xc417,		0x21, 0
	.dw 0x2d11, 0xc417,	0x2d11, 0xc417,		0x21, 0
	.dw 0x2d13, 0xc417,	0x2d3f, 0xc417,		0x21, 0
	.dw 0x2d41, 0xc417,	0x2d41, 0xc417,		0x21, 0
	.dw 0x2d43, 0xc417,	0x2d4f, 0xc417,		0x21, 0
	.dw 0x2d51, 0xc417,	0x2d51, 0xc417,		0x21, 0
	.dw 0x2d53, 0xc417,	0x2d7f, 0xc417,		0x21, 0
	.dw 0x2d81, 0xc417,	0x2d81, 0xc417,		0x21, 0
	.dw 0x2d83, 0xc417,	0x2d8f, 0xc417,		0x21, 0
	.dw 0x2d91, 0xc417,	0x2d91, 0xc417,		0x21, 0
	.dw 0x2d93, 0xc417,	0x2dbf, 0xc417,		0x21, 0
	.dw 0x2dc1, 0xc417,	0x2dc1, 0xc417,		0x21, 0
	.dw 0x2dc3, 0xc417,	0x2dcf, 0xc417,		0x21, 0
	.dw 0x2dd1, 0xc417,	0x2dd1, 0xc417,		0x21, 0
	.dw 0x2dd3, 0xc417,	0x2dff, 0xc417,		0x21, 0
	.dw 0x2e01, 0xc417,	0x2e01, 0xc417,		0x21, 0
	.dw 0x2e03, 0xc417,	0x2e0f, 0xc417,		0x21, 0
	.dw 0x2e11, 0xc417,	0x2e11, 0xc417,		0x21, 0
	.dw 0x2e13, 0xc417,	0x2e3f, 0xc417,		0x21, 0
	.dw 0x2e41, 0xc417,	0x2e41, 0xc417,		0x21, 0
	.dw 0x2e43, 0xc417,	0x2e4f, 0xc417,		0x21, 0
	.dw 0x2e51, 0xc417,	0x2e51, 0xc417,		0x21, 0
	.dw 0x2e53, 0xc417,	0x2e7f, 0xc417,		0x21, 0
	.dw 0x2e81, 0xc417,	0x2e81, 0xc417,		0x21, 0
	.dw 0x2e83, 0xc417,	0x2e8f, 0xc417,		0x21, 0
	.dw 0x2e91, 0xc417,	0x2e91, 0xc417,		0x21, 0
	.dw 0x2e93, 0xc417,	0x2ebf, 0xc417,		0x21, 0
	.dw 0x2ec1, 0xc417,	0x2ec1, 0xc417,		0x21, 0
	.dw 0x2ec3, 0xc417,	0x2ecf, 0xc417,		0x21, 0
	.dw 0x2ed1, 0xc417,	0x2ed1, 0xc417,		0x21, 0
	.dw 0x2ed3, 0xc417,	0x2eff, 0xc417,		0x21, 0
	.dw 0x2f01, 0xc417,	0x2f01, 0xc417,		0x21, 0
	.dw 0x2f03, 0xc417,	0x2f0f, 0xc417,		0x21, 0
	.dw 0x2f11, 0xc417,	0x2f11, 0xc417,		0x21, 0
	.dw 0x2f13, 0xc417,	0x2f3f, 0xc417,		0x21, 0
	.dw 0x2f41, 0xc417,	0x2f41, 0xc417,		0x21, 0
	.dw 0x2f43, 0xc417,	0x2f4f, 0xc417,		0x21, 0
	.dw 0x2f51, 0xc417,	0x2f51, 0xc417,		0x21, 0
	.dw 0x2f53, 0xc417,	0x2f7f, 0xc417,		0x21, 0
	.dw 0x2f81, 0xc417,	0x2f81, 0xc417,		0x21, 0
	.dw 0x2f83, 0xc417,	0x2f8f, 0xc417,		0x21, 0
	.dw 0x2f91, 0xc417,	0x2f91, 0xc417,		0x21, 0
	.dw 0x2f93, 0xc417,	0x2fbf, 0xc417,		0x21, 0
	.dw 0x2fc1, 0xc417,	0x2fc1, 0xc417,		0x21, 0
	.dw 0x2fc3, 0xc417,	0x2fcf, 0xc417,		0x21, 0
	.dw 0x2fd1, 0xc417,	0x2fd1, 0xc417,		0x21, 0
	.dw 0x2fd3, 0xc417,	0xffff, 0xc417,		0x21, 0
	.dw 0x1000, 0xc418,	0x3fff, 0xc418,		0x21, 0
	.dw 0x4000, 0xc418,	0x4000, 0xc418,		0x22, 0
	.dw 0x4001, 0xc418,	0x4001, 0xc418,		0x21, 0
	.dw 0x4002, 0xc418,	0x4002, 0xc418,		0x22, 0
	.dw 0x4003, 0xc418,	0x400f, 0xc418,		0x21, 0
	.dw 0x4010, 0xc418,	0x4010, 0xc418,		0x22, 0
	.dw 0x4011, 0xc418,	0x4011, 0xc418,		0x21, 0
	.dw 0x4012, 0xc418,	0x4012, 0xc418,		0x22, 0
	.dw 0x4013, 0xc418,	0x403f, 0xc418,		0x21, 0
	.dw 0x4041, 0xc418,	0x4041, 0xc418,		0x21, 0
	.dw 0x4043, 0xc418,	0x404f, 0xc418,		0x21, 0
	.dw 0x4051, 0xc418,	0x4051, 0xc418,		0x21, 0
	.dw 0x4053, 0xc418,	0x407f, 0xc418,		0x21, 0
	.dw 0x4081, 0xc418,	0x4081, 0xc418,		0x21, 0
	.dw 0x4083, 0xc418,	0x408f, 0xc418,		0x21, 0
	.dw 0x4091, 0xc418,	0x4091, 0xc418,		0x21, 0
	.dw 0x4093, 0xc418,	0x40bf, 0xc418,		0x21, 0
	.dw 0x40c1, 0xc418,	0x40c1, 0xc418,		0x21, 0
	.dw 0x40c3, 0xc418,	0x40cf, 0xc418,		0x21, 0
	.dw 0x40d1, 0xc418,	0x40d1, 0xc418,		0x21, 0
	.dw 0x40d3, 0xc418,	0x40ff, 0xc418,		0x21, 0
	.dw 0x4101, 0xc418,	0x4101, 0xc418,		0x21, 0
	.dw 0x4103, 0xc418,	0x410f, 0xc418,		0x21, 0
	.dw 0x4111, 0xc418,	0x4111, 0xc418,		0x21, 0
	.dw 0x4113, 0xc418,	0x413f, 0xc418,		0x21, 0
	.dw 0x4141, 0xc418,	0x4141, 0xc418,		0x21, 0
	.dw 0x4143, 0xc418,	0x414f, 0xc418,		0x21, 0
	.dw 0x4151, 0xc418,	0x4151, 0xc418,		0x21, 0
	.dw 0x4153, 0xc418,	0x417f, 0xc418,		0x21, 0
	.dw 0x4181, 0xc418,	0x4181, 0xc418,		0x21, 0
	.dw 0x4183, 0xc418,	0x418f, 0xc418,		0x21, 0
	.dw 0x4191, 0xc418,	0x4191, 0xc418,		0x21, 0
	.dw 0x4193, 0xc418,	0x41bf, 0xc418,		0x21, 0
	.dw 0x41c1, 0xc418,	0x41c1, 0xc418,		0x21, 0
	.dw 0x41c3, 0xc418,	0x41cf, 0xc418,		0x21, 0
	.dw 0x41d1, 0xc418,	0x41d1, 0xc418,		0x21, 0
	.dw 0x41d3, 0xc418,	0x41ff, 0xc418,		0x21, 0
	.dw 0x4201, 0xc418,	0x4201, 0xc418,		0x21, 0
	.dw 0x4203, 0xc418,	0x420f, 0xc418,		0x21, 0
	.dw 0x4211, 0xc418,	0x4211, 0xc418,		0x21, 0
	.dw 0x4213, 0xc418,	0x423f, 0xc418,		0x21, 0
	.dw 0x4240, 0xc418,	0x4240, 0xc418,		0x22, 0
	.dw 0x4241, 0xc418,	0x4241, 0xc418,		0x21, 0
	.dw 0x4242, 0xc418,	0x4242, 0xc418,		0x22, 0
	.dw 0x4243, 0xc418,	0x424f, 0xc418,		0x21, 0
	.dw 0x4250, 0xc418,	0x4250, 0xc418,		0x22, 0
	.dw 0x4251, 0xc418,	0x4251, 0xc418,		0x21, 0
	.dw 0x4252, 0xc418,	0x4252, 0xc418,		0x22, 0
	.dw 0x4253, 0xc418,	0x427f, 0xc418,		0x21, 0
	.dw 0x4281, 0xc418,	0x4281, 0xc418,		0x21, 0
	.dw 0x4283, 0xc418,	0x428f, 0xc418,		0x21, 0
	.dw 0x4291, 0xc418,	0x4291, 0xc418,		0x21, 0
	.dw 0x4293, 0xc418,	0x42bf, 0xc418,		0x21, 0
	.dw 0x42c1, 0xc418,	0x42c1, 0xc418,		0x21, 0
	.dw 0x42c3, 0xc418,	0x42cf, 0xc418,		0x21, 0
	.dw 0x42d1, 0xc418,	0x42d1, 0xc418,		0x21, 0
	.dw 0x42d3, 0xc418,	0x42ff, 0xc418,		0x21, 0
	.dw 0x4301, 0xc418,	0x4301, 0xc418,		0x21, 0
	.dw 0x4303, 0xc418,	0x430f, 0xc418,		0x21, 0
	.dw 0x4311, 0xc418,	0x4311, 0xc418,		0x21, 0
	.dw 0x4313, 0xc418,	0x433f, 0xc418,		0x21, 0
	.dw 0x4341, 0xc418,	0x4341, 0xc418,		0x21, 0
	.dw 0x4343, 0xc418,	0x434f, 0xc418,		0x21, 0
	.dw 0x4351, 0xc418,	0x4351, 0xc418,		0x21, 0
	.dw 0x4353, 0xc418,	0x437f, 0xc418,		0x21, 0
	.dw 0x4381, 0xc418,	0x4381, 0xc418,		0x21, 0
	.dw 0x4383, 0xc418,	0x438f, 0xc418,		0x21, 0
	.dw 0x4391, 0xc418,	0x4391, 0xc418,		0x21, 0
	.dw 0x4393, 0xc418,	0x43bf, 0xc418,		0x21, 0
	.dw 0x43c1, 0xc418,	0x43c1, 0xc418,		0x21, 0
	.dw 0x43c3, 0xc418,	0x43cf, 0xc418,		0x21, 0
	.dw 0x43d1, 0xc418,	0x43d1, 0xc418,		0x21, 0
	.dw 0x43d3, 0xc418,	0x43ff, 0xc418,		0x21, 0
	.dw 0x4401, 0xc418,	0x4401, 0xc418,		0x21, 0
	.dw 0x4403, 0xc418,	0x440f, 0xc418,		0x21, 0
	.dw 0x4411, 0xc418,	0x4411, 0xc418,		0x21, 0
	.dw 0x4413, 0xc418,	0x443f, 0xc418,		0x21, 0
	.dw 0x4441, 0xc418,	0x4441, 0xc418,		0x21, 0
	.dw 0x4443, 0xc418,	0x444f, 0xc418,		0x21, 0
	.dw 0x4451, 0xc418,	0x4451, 0xc418,		0x21, 0
	.dw 0x4453, 0xc418,	0x447f, 0xc418,		0x21, 0
	.dw 0x4480, 0xc418,	0x4480, 0xc418,		0x22, 0
	.dw 0x4481, 0xc418,	0x4481, 0xc418,		0x21, 0
	.dw 0x4482, 0xc418,	0x4482, 0xc418,		0x22, 0
	.dw 0x4483, 0xc418,	0x448f, 0xc418,		0x21, 0
	.dw 0x4490, 0xc418,	0x4490, 0xc418,		0x22, 0
	.dw 0x4491, 0xc418,	0x4491, 0xc418,		0x21, 0
	.dw 0x4492, 0xc418,	0x4492, 0xc418,		0x22, 0
	.dw 0x4493, 0xc418,	0x44bf, 0xc418,		0x21, 0
	.dw 0x44c1, 0xc418,	0x44c1, 0xc418,		0x21, 0
	.dw 0x44c3, 0xc418,	0x44cf, 0xc418,		0x21, 0
	.dw 0x44d1, 0xc418,	0x44d1, 0xc418,		0x21, 0
	.dw 0x44d3, 0xc418,	0x44ff, 0xc418,		0x21, 0
	.dw 0x4501, 0xc418,	0x4501, 0xc418,		0x21, 0
	.dw 0x4503, 0xc418,	0x450f, 0xc418,		0x21, 0
	.dw 0x4511, 0xc418,	0x4511, 0xc418,		0x21, 0
	.dw 0x4513, 0xc418,	0x453f, 0xc418,		0x21, 0
	.dw 0x4541, 0xc418,	0x4541, 0xc418,		0x21, 0
	.dw 0x4543, 0xc418,	0x454f, 0xc418,		0x21, 0
	.dw 0x4551, 0xc418,	0x4551, 0xc418,		0x21, 0
	.dw 0x4553, 0xc418,	0x457f, 0xc418,		0x21, 0
	.dw 0x4581, 0xc418,	0x4581, 0xc418,		0x21, 0
	.dw 0x4583, 0xc418,	0x458f, 0xc418,		0x21, 0
	.dw 0x4591, 0xc418,	0x4591, 0xc418,		0x21, 0
	.dw 0x4593, 0xc418,	0x45bf, 0xc418,		0x21, 0
	.dw 0x45c1, 0xc418,	0x45c1, 0xc418,		0x21, 0
	.dw 0x45c3, 0xc418,	0x45cf, 0xc418,		0x21, 0
	.dw 0x45d1, 0xc418,	0x45d1, 0xc418,		0x21, 0
	.dw 0x45d3, 0xc418,	0x45ff, 0xc418,		0x21, 0
	.dw 0x4601, 0xc418,	0x4601, 0xc418,		0x21, 0
	.dw 0x4603, 0xc418,	0x460f, 0xc418,		0x21, 0
	.dw 0x4611, 0xc418,	0x4611, 0xc418,		0x21, 0
	.dw 0x4613, 0xc418,	0x463f, 0xc418,		0x21, 0
	.dw 0x4641, 0xc418,	0x4641, 0xc418,		0x21, 0
	.dw 0x4643, 0xc418,	0x464f, 0xc418,		0x21, 0
	.dw 0x4651, 0xc418,	0x4651, 0xc418,		0x21, 0
	.dw 0x4653, 0xc418,	0x467f, 0xc418,		0x21, 0
	.dw 0x4681, 0xc418,	0x4681, 0xc418,		0x21, 0
	.dw 0x4683, 0xc418,	0x468f, 0xc418,		0x21, 0
	.dw 0x4691, 0xc418,	0x4691, 0xc418,		0x21, 0
	.dw 0x4693, 0xc418,	0x46bf, 0xc418,		0x21, 0
	.dw 0x46c0, 0xc418,	0x46c0, 0xc418,		0x22, 0
	.dw 0x46c1, 0xc418,	0x46c1, 0xc418,		0x21, 0
	.dw 0x46c2, 0xc418,	0x46c2, 0xc418,		0x22, 0
	.dw 0x46c3, 0xc418,	0x46cf, 0xc418,		0x21, 0
	.dw 0x46d0, 0xc418,	0x46d0, 0xc418,		0x22, 0
	.dw 0x46d1, 0xc418,	0x46d1, 0xc418,		0x21, 0
	.dw 0x46d2, 0xc418,	0x46d2, 0xc418,		0x22, 0
	.dw 0x46d3, 0xc418,	0x46ff, 0xc418,		0x21, 0
	.dw 0x4701, 0xc418,	0x4701, 0xc418,		0x21, 0
	.dw 0x4703, 0xc418,	0x470f, 0xc418,		0x21, 0
	.dw 0x4711, 0xc418,	0x4711, 0xc418,		0x21, 0
	.dw 0x4713, 0xc418,	0x473f, 0xc418,		0x21, 0
	.dw 0x4741, 0xc418,	0x4741, 0xc418,		0x21, 0
	.dw 0x4743, 0xc418,	0x474f, 0xc418,		0x21, 0
	.dw 0x4751, 0xc418,	0x4751, 0xc418,		0x21, 0
	.dw 0x4753, 0xc418,	0x477f, 0xc418,		0x21, 0
	.dw 0x4781, 0xc418,	0x4781, 0xc418,		0x21, 0
	.dw 0x4783, 0xc418,	0x478f, 0xc418,		0x21, 0
	.dw 0x4791, 0xc418,	0x4791, 0xc418,		0x21, 0
	.dw 0x4793, 0xc418,	0x47bf, 0xc418,		0x21, 0
	.dw 0x47c1, 0xc418,	0x47c1, 0xc418,		0x21, 0
	.dw 0x47c3, 0xc418,	0x47cf, 0xc418,		0x21, 0
	.dw 0x47d1, 0xc418,	0x47d1, 0xc418,		0x21, 0
	.dw 0x47d3, 0xc418,	0x47ff, 0xc418,		0x21, 0
	.dw 0x4801, 0xc418,	0x4801, 0xc418,		0x21, 0
	.dw 0x4803, 0xc418,	0x480f, 0xc418,		0x21, 0
	.dw 0x4811, 0xc418,	0x4811, 0xc418,		0x21, 0
	.dw 0x4813, 0xc418,	0x483f, 0xc418,		0x21, 0
	.dw 0x4841, 0xc418,	0x4841, 0xc418,		0x21, 0
	.dw 0x4843, 0xc418,	0x484f, 0xc418,		0x21, 0
	.dw 0x4851, 0xc418,	0x4851, 0xc418,		0x21, 0
	.dw 0x4853, 0xc418,	0x487f, 0xc418,		0x21, 0
	.dw 0x4881, 0xc418,	0x4881, 0xc418,		0x21, 0
	.dw 0x4883, 0xc418,	0x488f, 0xc418,		0x21, 0
	.dw 0x4891, 0xc418,	0x4891, 0xc418,		0x21, 0
	.dw 0x4893, 0xc418,	0x48bf, 0xc418,		0x21, 0
	.dw 0x48c1, 0xc418,	0x48c1, 0xc418,		0x21, 0
	.dw 0x48c3, 0xc418,	0x48cf, 0xc418,		0x21, 0
	.dw 0x48d1, 0xc418,	0x48d1, 0xc418,		0x21, 0
	.dw 0x48d3, 0xc418,	0x48ff, 0xc418,		0x21, 0
	.dw 0x4900, 0xc418,	0x4900, 0xc418,		0x22, 0
	.dw 0x4901, 0xc418,	0x4901, 0xc418,		0x21, 0
	.dw 0x4902, 0xc418,	0x4902, 0xc418,		0x22, 0
	.dw 0x4903, 0xc418,	0x490f, 0xc418,		0x21, 0
	.dw 0x4910, 0xc418,	0x4910, 0xc418,		0x22, 0
	.dw 0x4911, 0xc418,	0x4911, 0xc418,		0x21, 0
	.dw 0x4912, 0xc418,	0x4912, 0xc418,		0x22, 0
	.dw 0x4913, 0xc418,	0x493f, 0xc418,		0x21, 0
	.dw 0x4941, 0xc418,	0x4941, 0xc418,		0x21, 0
	.dw 0x4943, 0xc418,	0x494f, 0xc418,		0x21, 0
	.dw 0x4951, 0xc418,	0x4951, 0xc418,		0x21, 0
	.dw 0x4953, 0xc418,	0x497f, 0xc418,		0x21, 0
	.dw 0x4981, 0xc418,	0x4981, 0xc418,		0x21, 0
	.dw 0x4983, 0xc418,	0x498f, 0xc418,		0x21, 0
	.dw 0x4991, 0xc418,	0x4991, 0xc418,		0x21, 0
	.dw 0x4993, 0xc418,	0x49bf, 0xc418,		0x21, 0
	.dw 0x49c1, 0xc418,	0x49c1, 0xc418,		0x21, 0
	.dw 0x49c3, 0xc418,	0x49cf, 0xc418,		0x21, 0
	.dw 0x49d1, 0xc418,	0x49d1, 0xc418,		0x21, 0
	.dw 0x49d3, 0xc418,	0x49ff, 0xc418,		0x21, 0
	.dw 0x4a01, 0xc418,	0x4a01, 0xc418,		0x21, 0
	.dw 0x4a03, 0xc418,	0x4a0f, 0xc418,		0x21, 0
	.dw 0x4a11, 0xc418,	0x4a11, 0xc418,		0x21, 0
	.dw 0x4a13, 0xc418,	0x4a3f, 0xc418,		0x21, 0
	.dw 0x4a41, 0xc418,	0x4a41, 0xc418,		0x21, 0
	.dw 0x4a43, 0xc418,	0x4a4f, 0xc418,		0x21, 0
	.dw 0x4a51, 0xc418,	0x4a51, 0xc418,		0x21, 0
	.dw 0x4a53, 0xc418,	0x4a7f, 0xc418,		0x21, 0
	.dw 0x4a81, 0xc418,	0x4a81, 0xc418,		0x21, 0
	.dw 0x4a83, 0xc418,	0x4a8f, 0xc418,		0x21, 0
	.dw 0x4a91, 0xc418,	0x4a91, 0xc418,		0x21, 0
	.dw 0x4a93, 0xc418,	0x4abf, 0xc418,		0x21, 0
	.dw 0x4ac1, 0xc418,	0x4ac1, 0xc418,		0x21, 0
	.dw 0x4ac3, 0xc418,	0x4acf, 0xc418,		0x21, 0
	.dw 0x4ad1, 0xc418,	0x4ad1, 0xc418,		0x21, 0
	.dw 0x4ad3, 0xc418,	0x4aff, 0xc418,		0x21, 0
	.dw 0x4b01, 0xc418,	0x4b01, 0xc418,		0x21, 0
	.dw 0x4b03, 0xc418,	0x4b0f, 0xc418,		0x21, 0
	.dw 0x4b11, 0xc418,	0x4b11, 0xc418,		0x21, 0
	.dw 0x4b13, 0xc418,	0x4b3f, 0xc418,		0x21, 0
	.dw 0x4b40, 0xc418,	0x4b40, 0xc418,		0x22, 0
	.dw 0x4b41, 0xc418,	0x4b41, 0xc418,		0x21, 0
	.dw 0x4b42, 0xc418,	0x4b42, 0xc418,		0x22, 0
	.dw 0x4b43, 0xc418,	0x4b4f, 0xc418,		0x21, 0
	.dw 0x4b50, 0xc418,	0x4b50, 0xc418,		0x22, 0
	.dw 0x4b51, 0xc418,	0x4b51, 0xc418,		0x21, 0
	.dw 0x4b52, 0xc418,	0x4b52, 0xc418,		0x22, 0
	.dw 0x4b53, 0xc418,	0x4b7f, 0xc418,		0x21, 0
	.dw 0x4b81, 0xc418,	0x4b81, 0xc418,		0x21, 0
	.dw 0x4b83, 0xc418,	0x4b8f, 0xc418,		0x21, 0
	.dw 0x4b91, 0xc418,	0x4b91, 0xc418,		0x21, 0
	.dw 0x4b93, 0xc418,	0x4bbf, 0xc418,		0x21, 0
	.dw 0x4bc1, 0xc418,	0x4bc1, 0xc418,		0x21, 0
	.dw 0x4bc3, 0xc418,	0x4bcf, 0xc418,		0x21, 0
	.dw 0x4bd1, 0xc418,	0x4bd1, 0xc418,		0x21, 0
	.dw 0x4bd3, 0xc418,	0x4bff, 0xc418,		0x21, 0
	.dw 0x4c01, 0xc418,	0x4c01, 0xc418,		0x21, 0
	.dw 0x4c03, 0xc418,	0x4c0f, 0xc418,		0x21, 0
	.dw 0x4c11, 0xc418,	0x4c11, 0xc418,		0x21, 0
	.dw 0x4c13, 0xc418,	0x4c3f, 0xc418,		0x21, 0
	.dw 0x4c41, 0xc418,	0x4c41, 0xc418,		0x21, 0
	.dw 0x4c43, 0xc418,	0x4c4f, 0xc418,		0x21, 0
	.dw 0x4c51, 0xc418,	0x4c51, 0xc418,		0x21, 0
	.dw 0x4c53, 0xc418,	0x4c7f, 0xc418,		0x21, 0
	.dw 0x4c81, 0xc418,	0x4c81, 0xc418,		0x21, 0
	.dw 0x4c83, 0xc418,	0x4c8f, 0xc418,		0x21, 0
	.dw 0x4c91, 0xc418,	0x4c91, 0xc418,		0x21, 0
	.dw 0x4c93, 0xc418,	0x4cbf, 0xc418,		0x21, 0
	.dw 0x4cc1, 0xc418,	0x4cc1, 0xc418,		0x21, 0
	.dw 0x4cc3, 0xc418,	0x4ccf, 0xc418,		0x21, 0
	.dw 0x4cd1, 0xc418,	0x4cd1, 0xc418,		0x21, 0
	.dw 0x4cd3, 0xc418,	0x4cff, 0xc418,		0x21, 0
	.dw 0x4d01, 0xc418,	0x4d01, 0xc418,		0x21, 0
	.dw 0x4d03, 0xc418,	0x4d0f, 0xc418,		0x21, 0
	.dw 0x4d11, 0xc418,	0x4d11, 0xc418,		0x21, 0
	.dw 0x4d13, 0xc418,	0x4d3f, 0xc418,		0x21, 0
	.dw 0x4d41, 0xc418,	0x4d41, 0xc418,		0x21, 0
	.dw 0x4d43, 0xc418,	0x4d4f, 0xc418,		0x21, 0
	.dw 0x4d51, 0xc418,	0x4d51, 0xc418,		0x21, 0
	.dw 0x4d53, 0xc418,	0x4d7f, 0xc418,		0x21, 0
	.dw 0x4d80, 0xc418,	0x4d80, 0xc418,		0x22, 0
	.dw 0x4d81, 0xc418,	0x4d81, 0xc418,		0x21, 0
	.dw 0x4d82, 0xc418,	0x4d82, 0xc418,		0x22, 0
	.dw 0x4d83, 0xc418,	0x4d8f, 0xc418,		0x21, 0
	.dw 0x4d90, 0xc418,	0x4d90, 0xc418,		0x22, 0
	.dw 0x4d91, 0xc418,	0x4d91, 0xc418,		0x21, 0
	.dw 0x4d92, 0xc418,	0x4d92, 0xc418,		0x22, 0
	.dw 0x4d93, 0xc418,	0x4dbf, 0xc418,		0x21, 0
	.dw 0x4dc1, 0xc418,	0x4dc1, 0xc418,		0x21, 0
	.dw 0x4dc3, 0xc418,	0x4dcf, 0xc418,		0x21, 0
	.dw 0x4dd1, 0xc418,	0x4dd1, 0xc418,		0x21, 0
	.dw 0x4dd3, 0xc418,	0x4dff, 0xc418,		0x21, 0
	.dw 0x4e01, 0xc418,	0x4e01, 0xc418,		0x21, 0
	.dw 0x4e03, 0xc418,	0x4e0f, 0xc418,		0x21, 0
	.dw 0x4e11, 0xc418,	0x4e11, 0xc418,		0x21, 0
	.dw 0x4e13, 0xc418,	0x4e3f, 0xc418,		0x21, 0
	.dw 0x4e41, 0xc418,	0x4e41, 0xc418,		0x21, 0
	.dw 0x4e43, 0xc418,	0x4e4f, 0xc418,		0x21, 0
	.dw 0x4e51, 0xc418,	0x4e51, 0xc418,		0x21, 0
	.dw 0x4e53, 0xc418,	0x4e7f, 0xc418,		0x21, 0
	.dw 0x4e81, 0xc418,	0x4e81, 0xc418,		0x21, 0
	.dw 0x4e83, 0xc418,	0x4e8f, 0xc418,		0x21, 0
	.dw 0x4e91, 0xc418,	0x4e91, 0xc418,		0x21, 0
	.dw 0x4e93, 0xc418,	0x4ebf, 0xc418,		0x21, 0
	.dw 0x4ec1, 0xc418,	0x4ec1, 0xc418,		0x21, 0
	.dw 0x4ec3, 0xc418,	0x4ecf, 0xc418,		0x21, 0
	.dw 0x4ed1, 0xc418,	0x4ed1, 0xc418,		0x21, 0
	.dw 0x4ed3, 0xc418,	0x4eff, 0xc418,		0x21, 0
	.dw 0x4f01, 0xc418,	0x4f01, 0xc418,		0x21, 0
	.dw 0x4f03, 0xc418,	0x4f0f, 0xc418,		0x21, 0
	.dw 0x4f11, 0xc418,	0x4f11, 0xc418,		0x21, 0
	.dw 0x4f13, 0xc418,	0x4f3f, 0xc418,		0x21, 0
	.dw 0x4f41, 0xc418,	0x4f41, 0xc418,		0x21, 0
	.dw 0x4f43, 0xc418,	0x4f4f, 0xc418,		0x21, 0
	.dw 0x4f51, 0xc418,	0x4f51, 0xc418,		0x21, 0
	.dw 0x4f53, 0xc418,	0x4f7f, 0xc418,		0x21, 0
	.dw 0x4f81, 0xc418,	0x4f81, 0xc418,		0x21, 0
	.dw 0x4f83, 0xc418,	0x4f8f, 0xc418,		0x21, 0
	.dw 0x4f91, 0xc418,	0x4f91, 0xc418,		0x21, 0
	.dw 0x4f93, 0xc418,	0x4fbf, 0xc418,		0x21, 0
	.dw 0x4fc0, 0xc418,	0x4fc0, 0xc418,		0x22, 0
	.dw 0x4fc1, 0xc418,	0x4fc1, 0xc418,		0x21, 0
	.dw 0x4fc2, 0xc418,	0x4fc2, 0xc418,		0x22, 0
	.dw 0x4fc3, 0xc418,	0x4fcf, 0xc418,		0x21, 0
	.dw 0x4fd0, 0xc418,	0x4fd0, 0xc418,		0x22, 0
	.dw 0x4fd1, 0xc418,	0x4fd1, 0xc418,		0x21, 0
	.dw 0x4fd2, 0xc418,	0x4fd2, 0xc418,		0x22, 0
	.dw 0x4fd3, 0xc418,	0x5fff, 0xc418,		0x21, 0
	.dw 0x6000, 0xc418,	0x6000, 0xc418,		0x22, 0
	.dw 0x6001, 0xc418,	0x6001, 0xc418,		0x21, 0
	.dw 0x6002, 0xc418,	0x6002, 0xc418,		0x22, 0
	.dw 0x6003, 0xc418,	0x600f, 0xc418,		0x21, 0
	.dw 0x6010, 0xc418,	0x6010, 0xc418,		0x22, 0
	.dw 0x6011, 0xc418,	0x6011, 0xc418,		0x21, 0
	.dw 0x6012, 0xc418,	0x6012, 0xc418,		0x22, 0
	.dw 0x6013, 0xc418,	0x603f, 0xc418,		0x21, 0
	.dw 0x6041, 0xc418,	0x6041, 0xc418,		0x21, 0
	.dw 0x6043, 0xc418,	0x604f, 0xc418,		0x21, 0
	.dw 0x6051, 0xc418,	0x6051, 0xc418,		0x21, 0
	.dw 0x6053, 0xc418,	0x607f, 0xc418,		0x21, 0
	.dw 0x6081, 0xc418,	0x6081, 0xc418,		0x21, 0
	.dw 0x6083, 0xc418,	0x608f, 0xc418,		0x21, 0
	.dw 0x6091, 0xc418,	0x6091, 0xc418,		0x21, 0
	.dw 0x6093, 0xc418,	0x60bf, 0xc418,		0x21, 0
	.dw 0x60c1, 0xc418,	0x60c1, 0xc418,		0x21, 0
	.dw 0x60c3, 0xc418,	0x60cf, 0xc418,		0x21, 0
	.dw 0x60d1, 0xc418,	0x60d1, 0xc418,		0x21, 0
	.dw 0x60d3, 0xc418,	0x60ff, 0xc418,		0x21, 0
	.dw 0x6101, 0xc418,	0x6101, 0xc418,		0x21, 0
	.dw 0x6103, 0xc418,	0x610f, 0xc418,		0x21, 0
	.dw 0x6111, 0xc418,	0x6111, 0xc418,		0x21, 0
	.dw 0x6113, 0xc418,	0x613f, 0xc418,		0x21, 0
	.dw 0x6141, 0xc418,	0x6141, 0xc418,		0x21, 0
	.dw 0x6143, 0xc418,	0x614f, 0xc418,		0x21, 0
	.dw 0x6151, 0xc418,	0x6151, 0xc418,		0x21, 0
	.dw 0x6153, 0xc418,	0x617f, 0xc418,		0x21, 0
	.dw 0x6181, 0xc418,	0x6181, 0xc418,		0x21, 0
	.dw 0x6183, 0xc418,	0x618f, 0xc418,		0x21, 0
	.dw 0x6191, 0xc418,	0x6191, 0xc418,		0x21, 0
	.dw 0x6193, 0xc418,	0x61bf, 0xc418,		0x21, 0
	.dw 0x61c1, 0xc418,	0x61c1, 0xc418,		0x21, 0
	.dw 0x61c3, 0xc418,	0x61cf, 0xc418,		0x21, 0
	.dw 0x61d1, 0xc418,	0x61d1, 0xc418,		0x21, 0
	.dw 0x61d3, 0xc418,	0x61ff, 0xc418,		0x21, 0
	.dw 0x6201, 0xc418,	0x6201, 0xc418,		0x21, 0
	.dw 0x6203, 0xc418,	0x620f, 0xc418,		0x21, 0
	.dw 0x6211, 0xc418,	0x6211, 0xc418,		0x21, 0
	.dw 0x6213, 0xc418,	0x623f, 0xc418,		0x21, 0
	.dw 0x6240, 0xc418,	0x6240, 0xc418,		0x22, 0
	.dw 0x6241, 0xc418,	0x6241, 0xc418,		0x21, 0
	.dw 0x6242, 0xc418,	0x6242, 0xc418,		0x22, 0
	.dw 0x6243, 0xc418,	0x624f, 0xc418,		0x21, 0
	.dw 0x6250, 0xc418,	0x6250, 0xc418,		0x22, 0
	.dw 0x6251, 0xc418,	0x6251, 0xc418,		0x21, 0
	.dw 0x6252, 0xc418,	0x6252, 0xc418,		0x22, 0
	.dw 0x6253, 0xc418,	0x627f, 0xc418,		0x21, 0
	.dw 0x6281, 0xc418,	0x6281, 0xc418,		0x21, 0
	.dw 0x6283, 0xc418,	0x628f, 0xc418,		0x21, 0
	.dw 0x6291, 0xc418,	0x6291, 0xc418,		0x21, 0
	.dw 0x6293, 0xc418,	0x62bf, 0xc418,		0x21, 0
	.dw 0x62c1, 0xc418,	0x62c1, 0xc418,		0x21, 0
	.dw 0x62c3, 0xc418,	0x62cf, 0xc418,		0x21, 0
	.dw 0x62d1, 0xc418,	0x62d1, 0xc418,		0x21, 0
	.dw 0x62d3, 0xc418,	0x62ff, 0xc418,		0x21, 0
	.dw 0x6301, 0xc418,	0x6301, 0xc418,		0x21, 0
	.dw 0x6303, 0xc418,	0x630f, 0xc418,		0x21, 0
	.dw 0x6311, 0xc418,	0x6311, 0xc418,		0x21, 0
	.dw 0x6313, 0xc418,	0x633f, 0xc418,		0x21, 0
	.dw 0x6341, 0xc418,	0x6341, 0xc418,		0x21, 0
	.dw 0x6343, 0xc418,	0x634f, 0xc418,		0x21, 0
	.dw 0x6351, 0xc418,	0x6351, 0xc418,		0x21, 0
	.dw 0x6353, 0xc418,	0x637f, 0xc418,		0x21, 0
	.dw 0x6381, 0xc418,	0x6381, 0xc418,		0x21, 0
	.dw 0x6383, 0xc418,	0x638f, 0xc418,		0x21, 0
	.dw 0x6391, 0xc418,	0x6391, 0xc418,		0x21, 0
	.dw 0x6393, 0xc418,	0x63bf, 0xc418,		0x21, 0
	.dw 0x63c1, 0xc418,	0x63c1, 0xc418,		0x21, 0
	.dw 0x63c3, 0xc418,	0x63cf, 0xc418,		0x21, 0
	.dw 0x63d1, 0xc418,	0x63d1, 0xc418,		0x21, 0
	.dw 0x63d3, 0xc418,	0x63ff, 0xc418,		0x21, 0
	.dw 0x6401, 0xc418,	0x6401, 0xc418,		0x21, 0
	.dw 0x6403, 0xc418,	0x640f, 0xc418,		0x21, 0
	.dw 0x6411, 0xc418,	0x6411, 0xc418,		0x21, 0
	.dw 0x6413, 0xc418,	0x643f, 0xc418,		0x21, 0
	.dw 0x6441, 0xc418,	0x6441, 0xc418,		0x21, 0
	.dw 0x6443, 0xc418,	0x644f, 0xc418,		0x21, 0
	.dw 0x6451, 0xc418,	0x6451, 0xc418,		0x21, 0
	.dw 0x6453, 0xc418,	0x647f, 0xc418,		0x21, 0
	.dw 0x6480, 0xc418,	0x6480, 0xc418,		0x22, 0
	.dw 0x6481, 0xc418,	0x6481, 0xc418,		0x21, 0
	.dw 0x6482, 0xc418,	0x6482, 0xc418,		0x22, 0
	.dw 0x6483, 0xc418,	0x648f, 0xc418,		0x21, 0
	.dw 0x6490, 0xc418,	0x6490, 0xc418,		0x22, 0
	.dw 0x6491, 0xc418,	0x6491, 0xc418,		0x21, 0
	.dw 0x6492, 0xc418,	0x6492, 0xc418,		0x22, 0
	.dw 0x6493, 0xc418,	0x64bf, 0xc418,		0x21, 0
	.dw 0x64c1, 0xc418,	0x64c1, 0xc418,		0x21, 0
	.dw 0x64c3, 0xc418,	0x64cf, 0xc418,		0x21, 0
	.dw 0x64d1, 0xc418,	0x64d1, 0xc418,		0x21, 0
	.dw 0x64d3, 0xc418,	0x64ff, 0xc418,		0x21, 0
	.dw 0x6501, 0xc418,	0x6501, 0xc418,		0x21, 0
	.dw 0x6503, 0xc418,	0x650f, 0xc418,		0x21, 0
	.dw 0x6511, 0xc418,	0x6511, 0xc418,		0x21, 0
	.dw 0x6513, 0xc418,	0x653f, 0xc418,		0x21, 0
	.dw 0x6541, 0xc418,	0x6541, 0xc418,		0x21, 0
	.dw 0x6543, 0xc418,	0x654f, 0xc418,		0x21, 0
	.dw 0x6551, 0xc418,	0x6551, 0xc418,		0x21, 0
	.dw 0x6553, 0xc418,	0x657f, 0xc418,		0x21, 0
	.dw 0x6581, 0xc418,	0x6581, 0xc418,		0x21, 0
	.dw 0x6583, 0xc418,	0x658f, 0xc418,		0x21, 0
	.dw 0x6591, 0xc418,	0x6591, 0xc418,		0x21, 0
	.dw 0x6593, 0xc418,	0x65bf, 0xc418,		0x21, 0
	.dw 0x65c1, 0xc418,	0x65c1, 0xc418,		0x21, 0
	.dw 0x65c3, 0xc418,	0x65cf, 0xc418,		0x21, 0
	.dw 0x65d1, 0xc418,	0x65d1, 0xc418,		0x21, 0
	.dw 0x65d3, 0xc418,	0x65ff, 0xc418,		0x21, 0
	.dw 0x6601, 0xc418,	0x6601, 0xc418,		0x21, 0
	.dw 0x6603, 0xc418,	0x660f, 0xc418,		0x21, 0
	.dw 0x6611, 0xc418,	0x6611, 0xc418,		0x21, 0
	.dw 0x6613, 0xc418,	0x663f, 0xc418,		0x21, 0
	.dw 0x6641, 0xc418,	0x6641, 0xc418,		0x21, 0
	.dw 0x6643, 0xc418,	0x664f, 0xc418,		0x21, 0
	.dw 0x6651, 0xc418,	0x6651, 0xc418,		0x21, 0
	.dw 0x6653, 0xc418,	0x667f, 0xc418,		0x21, 0
	.dw 0x6681, 0xc418,	0x6681, 0xc418,		0x21, 0
	.dw 0x6683, 0xc418,	0x668f, 0xc418,		0x21, 0
	.dw 0x6691, 0xc418,	0x6691, 0xc418,		0x21, 0
	.dw 0x6693, 0xc418,	0x66bf, 0xc418,		0x21, 0
	.dw 0x66c0, 0xc418,	0x66c0, 0xc418,		0x22, 0
	.dw 0x66c1, 0xc418,	0x66c1, 0xc418,		0x21, 0
	.dw 0x66c2, 0xc418,	0x66c2, 0xc418,		0x22, 0
	.dw 0x66c3, 0xc418,	0x66cf, 0xc418,		0x21, 0
	.dw 0x66d0, 0xc418,	0x66d0, 0xc418,		0x22, 0
	.dw 0x66d1, 0xc418,	0x66d1, 0xc418,		0x21, 0
	.dw 0x66d2, 0xc418,	0x66d2, 0xc418,		0x22, 0
	.dw 0x66d3, 0xc418,	0x66ff, 0xc418,		0x21, 0
	.dw 0x6701, 0xc418,	0x6701, 0xc418,		0x21, 0
	.dw 0x6703, 0xc418,	0x670f, 0xc418,		0x21, 0
	.dw 0x6711, 0xc418,	0x6711, 0xc418,		0x21, 0
	.dw 0x6713, 0xc418,	0x673f, 0xc418,		0x21, 0
	.dw 0x6741, 0xc418,	0x6741, 0xc418,		0x21, 0
	.dw 0x6743, 0xc418,	0x674f, 0xc418,		0x21, 0
	.dw 0x6751, 0xc418,	0x6751, 0xc418,		0x21, 0
	.dw 0x6753, 0xc418,	0x677f, 0xc418,		0x21, 0
	.dw 0x6781, 0xc418,	0x6781, 0xc418,		0x21, 0
	.dw 0x6783, 0xc418,	0x678f, 0xc418,		0x21, 0
	.dw 0x6791, 0xc418,	0x6791, 0xc418,		0x21, 0
	.dw 0x6793, 0xc418,	0x67bf, 0xc418,		0x21, 0
	.dw 0x67c1, 0xc418,	0x67c1, 0xc418,		0x21, 0
	.dw 0x67c3, 0xc418,	0x67cf, 0xc418,		0x21, 0
	.dw 0x67d1, 0xc418,	0x67d1, 0xc418,		0x21, 0
	.dw 0x67d3, 0xc418,	0x67ff, 0xc418,		0x21, 0
	.dw 0x6801, 0xc418,	0x6801, 0xc418,		0x21, 0
	.dw 0x6803, 0xc418,	0x680f, 0xc418,		0x21, 0
	.dw 0x6811, 0xc418,	0x6811, 0xc418,		0x21, 0
	.dw 0x6813, 0xc418,	0x683f, 0xc418,		0x21, 0
	.dw 0x6841, 0xc418,	0x6841, 0xc418,		0x21, 0
	.dw 0x6843, 0xc418,	0x684f, 0xc418,		0x21, 0
	.dw 0x6851, 0xc418,	0x6851, 0xc418,		0x21, 0
	.dw 0x6853, 0xc418,	0x687f, 0xc418,		0x21, 0
	.dw 0x6881, 0xc418,	0x6881, 0xc418,		0x21, 0
	.dw 0x6883, 0xc418,	0x688f, 0xc418,		0x21, 0
	.dw 0x6891, 0xc418,	0x6891, 0xc418,		0x21, 0
	.dw 0x6893, 0xc418,	0x68bf, 0xc418,		0x21, 0
	.dw 0x68c1, 0xc418,	0x68c1, 0xc418,		0x21, 0
	.dw 0x68c3, 0xc418,	0x68cf, 0xc418,		0x21, 0
	.dw 0x68d1, 0xc418,	0x68d1, 0xc418,		0x21, 0
	.dw 0x68d3, 0xc418,	0x68ff, 0xc418,		0x21, 0
	.dw 0x6900, 0xc418,	0x6900, 0xc418,		0x22, 0
	.dw 0x6901, 0xc418,	0x6901, 0xc418,		0x21, 0
	.dw 0x6902, 0xc418,	0x6902, 0xc418,		0x22, 0
	.dw 0x6903, 0xc418,	0x690f, 0xc418,		0x21, 0
	.dw 0x6910, 0xc418,	0x6910, 0xc418,		0x22, 0
	.dw 0x6911, 0xc418,	0x6911, 0xc418,		0x21, 0
	.dw 0x6912, 0xc418,	0x6912, 0xc418,		0x22, 0
	.dw 0x6913, 0xc418,	0x693f, 0xc418,		0x21, 0
	.dw 0x6941, 0xc418,	0x6941, 0xc418,		0x21, 0
	.dw 0x6943, 0xc418,	0x694f, 0xc418,		0x21, 0
	.dw 0x6951, 0xc418,	0x6951, 0xc418,		0x21, 0
	.dw 0x6953, 0xc418,	0x697f, 0xc418,		0x21, 0
	.dw 0x6981, 0xc418,	0x6981, 0xc418,		0x21, 0
	.dw 0x6983, 0xc418,	0x698f, 0xc418,		0x21, 0
	.dw 0x6991, 0xc418,	0x6991, 0xc418,		0x21, 0
	.dw 0x6993, 0xc418,	0x69bf, 0xc418,		0x21, 0
	.dw 0x69c1, 0xc418,	0x69c1, 0xc418,		0x21, 0
	.dw 0x69c3, 0xc418,	0x69cf, 0xc418,		0x21, 0
	.dw 0x69d1, 0xc418,	0x69d1, 0xc418,		0x21, 0
	.dw 0x69d3, 0xc418,	0x69ff, 0xc418,		0x21, 0
	.dw 0x6a01, 0xc418,	0x6a01, 0xc418,		0x21, 0
	.dw 0x6a03, 0xc418,	0x6a0f, 0xc418,		0x21, 0
	.dw 0x6a11, 0xc418,	0x6a11, 0xc418,		0x21, 0
	.dw 0x6a13, 0xc418,	0x6a3f, 0xc418,		0x21, 0
	.dw 0x6a41, 0xc418,	0x6a41, 0xc418,		0x21, 0
	.dw 0x6a43, 0xc418,	0x6a4f, 0xc418,		0x21, 0
	.dw 0x6a51, 0xc418,	0x6a51, 0xc418,		0x21, 0
	.dw 0x6a53, 0xc418,	0x6a7f, 0xc418,		0x21, 0
	.dw 0x6a81, 0xc418,	0x6a81, 0xc418,		0x21, 0
	.dw 0x6a83, 0xc418,	0x6a8f, 0xc418,		0x21, 0
	.dw 0x6a91, 0xc418,	0x6a91, 0xc418,		0x21, 0
	.dw 0x6a93, 0xc418,	0x6abf, 0xc418,		0x21, 0
	.dw 0x6ac1, 0xc418,	0x6ac1, 0xc418,		0x21, 0
	.dw 0x6ac3, 0xc418,	0x6acf, 0xc418,		0x21, 0
	.dw 0x6ad1, 0xc418,	0x6ad1, 0xc418,		0x21, 0
	.dw 0x6ad3, 0xc418,	0x6aff, 0xc418,		0x21, 0
	.dw 0x6b01, 0xc418,	0x6b01, 0xc418,		0x21, 0
	.dw 0x6b03, 0xc418,	0x6b0f, 0xc418,		0x21, 0
	.dw 0x6b11, 0xc418,	0x6b11, 0xc418,		0x21, 0
	.dw 0x6b13, 0xc418,	0x6b3f, 0xc418,		0x21, 0
	.dw 0x6b40, 0xc418,	0x6b40, 0xc418,		0x22, 0
	.dw 0x6b41, 0xc418,	0x6b41, 0xc418,		0x21, 0
	.dw 0x6b42, 0xc418,	0x6b42, 0xc418,		0x22, 0
	.dw 0x6b43, 0xc418,	0x6b4f, 0xc418,		0x21, 0
	.dw 0x6b50, 0xc418,	0x6b50, 0xc418,		0x22, 0
	.dw 0x6b51, 0xc418,	0x6b51, 0xc418,		0x21, 0
	.dw 0x6b52, 0xc418,	0x6b52, 0xc418,		0x22, 0
	.dw 0x6b53, 0xc418,	0x6b7f, 0xc418,		0x21, 0
	.dw 0x6b81, 0xc418,	0x6b81, 0xc418,		0x21, 0
	.dw 0x6b83, 0xc418,	0x6b8f, 0xc418,		0x21, 0
	.dw 0x6b91, 0xc418,	0x6b91, 0xc418,		0x21, 0
	.dw 0x6b93, 0xc418,	0x6bbf, 0xc418,		0x21, 0
	.dw 0x6bc1, 0xc418,	0x6bc1, 0xc418,		0x21, 0
	.dw 0x6bc3, 0xc418,	0x6bcf, 0xc418,		0x21, 0
	.dw 0x6bd1, 0xc418,	0x6bd1, 0xc418,		0x21, 0
	.dw 0x6bd3, 0xc418,	0x6bff, 0xc418,		0x21, 0
	.dw 0x6c01, 0xc418,	0x6c01, 0xc418,		0x21, 0
	.dw 0x6c03, 0xc418,	0x6c0f, 0xc418,		0x21, 0
	.dw 0x6c11, 0xc418,	0x6c11, 0xc418,		0x21, 0
	.dw 0x6c13, 0xc418,	0x6c3f, 0xc418,		0x21, 0
	.dw 0x6c41, 0xc418,	0x6c41, 0xc418,		0x21, 0
	.dw 0x6c43, 0xc418,	0x6c4f, 0xc418,		0x21, 0
	.dw 0x6c51, 0xc418,	0x6c51, 0xc418,		0x21, 0
	.dw 0x6c53, 0xc418,	0x6c7f, 0xc418,		0x21, 0
	.dw 0x6c81, 0xc418,	0x6c81, 0xc418,		0x21, 0
	.dw 0x6c83, 0xc418,	0x6c8f, 0xc418,		0x21, 0
	.dw 0x6c91, 0xc418,	0x6c91, 0xc418,		0x21, 0
	.dw 0x6c93, 0xc418,	0x6cbf, 0xc418,		0x21, 0
	.dw 0x6cc1, 0xc418,	0x6cc1, 0xc418,		0x21, 0
	.dw 0x6cc3, 0xc418,	0x6ccf, 0xc418,		0x21, 0
	.dw 0x6cd1, 0xc418,	0x6cd1, 0xc418,		0x21, 0
	.dw 0x6cd3, 0xc418,	0x6cff, 0xc418,		0x21, 0
	.dw 0x6d01, 0xc418,	0x6d01, 0xc418,		0x21, 0
	.dw 0x6d03, 0xc418,	0x6d0f, 0xc418,		0x21, 0
	.dw 0x6d11, 0xc418,	0x6d11, 0xc418,		0x21, 0
	.dw 0x6d13, 0xc418,	0x6d3f, 0xc418,		0x21, 0
	.dw 0x6d41, 0xc418,	0x6d41, 0xc418,		0x21, 0
	.dw 0x6d43, 0xc418,	0x6d4f, 0xc418,		0x21, 0
	.dw 0x6d51, 0xc418,	0x6d51, 0xc418,		0x21, 0
	.dw 0x6d53, 0xc418,	0x6d7f, 0xc418,		0x21, 0
	.dw 0x6d80, 0xc418,	0x6d80, 0xc418,		0x22, 0
	.dw 0x6d81, 0xc418,	0x6d81, 0xc418,		0x21, 0
	.dw 0x6d82, 0xc418,	0x6d82, 0xc418,		0x22, 0
	.dw 0x6d83, 0xc418,	0x6d8f, 0xc418,		0x21, 0
	.dw 0x6d90, 0xc418,	0x6d90, 0xc418,		0x22, 0
	.dw 0x6d91, 0xc418,	0x6d91, 0xc418,		0x21, 0
	.dw 0x6d92, 0xc418,	0x6d92, 0xc418,		0x22, 0
	.dw 0x6d93, 0xc418,	0x6dbf, 0xc418,		0x21, 0
	.dw 0x6dc1, 0xc418,	0x6dc1, 0xc418,		0x21, 0
	.dw 0x6dc3, 0xc418,	0x6dcf, 0xc418,		0x21, 0
	.dw 0x6dd1, 0xc418,	0x6dd1, 0xc418,		0x21, 0
	.dw 0x6dd3, 0xc418,	0x6dff, 0xc418,		0x21, 0
	.dw 0x6e01, 0xc418,	0x6e01, 0xc418,		0x21, 0
	.dw 0x6e03, 0xc418,	0x6e0f, 0xc418,		0x21, 0
	.dw 0x6e11, 0xc418,	0x6e11, 0xc418,		0x21, 0
	.dw 0x6e13, 0xc418,	0x6e3f, 0xc418,		0x21, 0
	.dw 0x6e41, 0xc418,	0x6e41, 0xc418,		0x21, 0
	.dw 0x6e43, 0xc418,	0x6e4f, 0xc418,		0x21, 0
	.dw 0x6e51, 0xc418,	0x6e51, 0xc418,		0x21, 0
	.dw 0x6e53, 0xc418,	0x6e7f, 0xc418,		0x21, 0
	.dw 0x6e81, 0xc418,	0x6e81, 0xc418,		0x21, 0
	.dw 0x6e83, 0xc418,	0x6e8f, 0xc418,		0x21, 0
	.dw 0x6e91, 0xc418,	0x6e91, 0xc418,		0x21, 0
	.dw 0x6e93, 0xc418,	0x6ebf, 0xc418,		0x21, 0
	.dw 0x6ec1, 0xc418,	0x6ec1, 0xc418,		0x21, 0
	.dw 0x6ec3, 0xc418,	0x6ecf, 0xc418,		0x21, 0
	.dw 0x6ed1, 0xc418,	0x6ed1, 0xc418,		0x21, 0
	.dw 0x6ed3, 0xc418,	0x6eff, 0xc418,		0x21, 0
	.dw 0x6f01, 0xc418,	0x6f01, 0xc418,		0x21, 0
	.dw 0x6f03, 0xc418,	0x6f0f, 0xc418,		0x21, 0
	.dw 0x6f11, 0xc418,	0x6f11, 0xc418,		0x21, 0
	.dw 0x6f13, 0xc418,	0x6f3f, 0xc418,		0x21, 0
	.dw 0x6f41, 0xc418,	0x6f41, 0xc418,		0x21, 0
	.dw 0x6f43, 0xc418,	0x6f4f, 0xc418,		0x21, 0
	.dw 0x6f51, 0xc418,	0x6f51, 0xc418,		0x21, 0
	.dw 0x6f53, 0xc418,	0x6f7f, 0xc418,		0x21, 0
	.dw 0x6f81, 0xc418,	0x6f81, 0xc418,		0x21, 0
	.dw 0x6f83, 0xc418,	0x6f8f, 0xc418,		0x21, 0
	.dw 0x6f91, 0xc418,	0x6f91, 0xc418,		0x21, 0
	.dw 0x6f93, 0xc418,	0x6fbf, 0xc418,		0x21, 0
	.dw 0x6fc0, 0xc418,	0x6fc0, 0xc418,		0x22, 0
	.dw 0x6fc1, 0xc418,	0x6fc1, 0xc418,		0x21, 0
	.dw 0x6fc2, 0xc418,	0x6fc2, 0xc418,		0x22, 0
	.dw 0x6fc3, 0xc418,	0x6fcf, 0xc418,		0x21, 0
	.dw 0x6fd0, 0xc418,	0x6fd0, 0xc418,		0x22, 0
	.dw 0x6fd1, 0xc418,	0x6fd1, 0xc418,		0x21, 0
	.dw 0x6fd2, 0xc418,	0x6fd2, 0xc418,		0x22, 0
	.dw 0x6fd3, 0xc418,	0xffff, 0xc420,		0x21, 0
	.dw 0x0000, 0xc421,	0x003f, 0xc421,		0x22, 0
	.dw 0x0240, 0xc421,	0x027f, 0xc421,		0x22, 0
	.dw 0x0480, 0xc421,	0x04bf, 0xc421,		0x22, 0
	.dw 0x06c0, 0xc421,	0x06ff, 0xc421,		0x22, 0
	.dw 0x0900, 0xc421,	0x093f, 0xc421,		0x22, 0
	.dw 0x0b40, 0xc421,	0x0b7f, 0xc421,		0x22, 0
	.dw 0x0d80, 0xc421,	0x0dbf, 0xc421,		0x22, 0
	.dw 0x0fc0, 0xc421,	0x103f, 0xc421,		0x22, 0
	.dw 0x1240, 0xc421,	0x127f, 0xc421,		0x22, 0
	.dw 0x1480, 0xc421,	0x14bf, 0xc421,		0x22, 0
	.dw 0x16c0, 0xc421,	0x16ff, 0xc421,		0x22, 0
	.dw 0x1900, 0xc421,	0x193f, 0xc421,		0x22, 0
	.dw 0x1b40, 0xc421,	0x1b7f, 0xc421,		0x22, 0
	.dw 0x1d80, 0xc421,	0x1dbf, 0xc421,		0x22, 0
	.dw 0x1fc0, 0xc421,	0x203f, 0xc421,		0x22, 0
	.dw 0x2240, 0xc421,	0x227f, 0xc421,		0x22, 0
	.dw 0x2480, 0xc421,	0x24bf, 0xc421,		0x22, 0
	.dw 0x26c0, 0xc421,	0x26ff, 0xc421,		0x22, 0
	.dw 0x2900, 0xc421,	0x293f, 0xc421,		0x22, 0
	.dw 0x2b40, 0xc421,	0x2b7f, 0xc421,		0x22, 0
	.dw 0x2d80, 0xc421,	0x2dbf, 0xc421,		0x22, 0
	.dw 0x2fc0, 0xc421,	0x303f, 0xc421,		0x22, 0
	.dw 0x3240, 0xc421,	0x327f, 0xc421,		0x22, 0
	.dw 0x3480, 0xc421,	0x34bf, 0xc421,		0x22, 0
	.dw 0x36c0, 0xc421,	0x36ff, 0xc421,		0x22, 0
	.dw 0x3900, 0xc421,	0x393f, 0xc421,		0x22, 0
	.dw 0x3b40, 0xc421,	0x3b7f, 0xc421,		0x22, 0
	.dw 0x3d80, 0xc421,	0x3dbf, 0xc421,		0x22, 0
	.dw 0x3fc0, 0xc421,	0x3fff, 0xc421,		0x22, 0
	.dw 0x4000, 0xc421,	0x7fff, 0xc421,		0x21, 0
	.dw 0x8000, 0xc421,	0x803f, 0xc421,		0x22, 0
	.dw 0x8240, 0xc421,	0x827f, 0xc421,		0x22, 0
	.dw 0x8480, 0xc421,	0x84bf, 0xc421,		0x22, 0
	.dw 0x86c0, 0xc421,	0x86ff, 0xc421,		0x22, 0
	.dw 0x8900, 0xc421,	0x893f, 0xc421,		0x22, 0
	.dw 0x8b40, 0xc421,	0x8b7f, 0xc421,		0x22, 0
	.dw 0x8d80, 0xc421,	0x8dbf, 0xc421,		0x22, 0
	.dw 0x8fc0, 0xc421,	0x903f, 0xc421,		0x22, 0
	.dw 0x9240, 0xc421,	0x927f, 0xc421,		0x22, 0
	.dw 0x9480, 0xc421,	0x94bf, 0xc421,		0x22, 0
	.dw 0x96c0, 0xc421,	0x96ff, 0xc421,		0x22, 0
	.dw 0x9900, 0xc421,	0x993f, 0xc421,		0x22, 0
	.dw 0x9b40, 0xc421,	0x9b7f, 0xc421,		0x22, 0
	.dw 0x9d80, 0xc421,	0x9dbf, 0xc421,		0x22, 0
	.dw 0x9fc0, 0xc421,	0xa03f, 0xc421,		0x22, 0
	.dw 0xa240, 0xc421,	0xa27f, 0xc421,		0x22, 0
	.dw 0xa480, 0xc421,	0xa4bf, 0xc421,		0x22, 0
	.dw 0xa6c0, 0xc421,	0xa6ff, 0xc421,		0x22, 0
	.dw 0xa900, 0xc421,	0xa93f, 0xc421,		0x22, 0
	.dw 0xab40, 0xc421,	0xab7f, 0xc421,		0x22, 0
	.dw 0xad80, 0xc421,	0xadbf, 0xc421,		0x22, 0
	.dw 0xafc0, 0xc421,	0xb03f, 0xc421,		0x22, 0
	.dw 0xb240, 0xc421,	0xb27f, 0xc421,		0x22, 0
	.dw 0xb480, 0xc421,	0xb4bf, 0xc421,		0x22, 0
	.dw 0xb6c0, 0xc421,	0xb6ff, 0xc421,		0x22, 0
	.dw 0xb900, 0xc421,	0xb93f, 0xc421,		0x22, 0
	.dw 0xbb40, 0xc421,	0xbb7f, 0xc421,		0x22, 0
	.dw 0xbd80, 0xc421,	0xbdbf, 0xc421,		0x22, 0
	.dw 0xbfc0, 0xc421,	0xc03f, 0xc421,		0x22, 0
	.dw 0xc240, 0xc421,	0xc27f, 0xc421,		0x22, 0
	.dw 0xc480, 0xc421,	0xc4bf, 0xc421,		0x22, 0
	.dw 0xc6c0, 0xc421,	0xc6ff, 0xc421,		0x22, 0
	.dw 0xc900, 0xc421,	0xc93f, 0xc421,		0x22, 0
	.dw 0xcb40, 0xc421,	0xcb7f, 0xc421,		0x22, 0
	.dw 0xcd80, 0xc421,	0xcdbf, 0xc421,		0x22, 0
	.dw 0xcfc0, 0xc421,	0xd03f, 0xc421,		0x22, 0
	.dw 0xd240, 0xc421,	0xd27f, 0xc421,		0x22, 0
	.dw 0xd480, 0xc421,	0xd4bf, 0xc421,		0x22, 0
	.dw 0xd6c0, 0xc421,	0xd6ff, 0xc421,		0x22, 0
	.dw 0xd900, 0xc421,	0xd93f, 0xc421,		0x22, 0
	.dw 0xdb40, 0xc421,	0xdb7f, 0xc421,		0x22, 0
	.dw 0xdd80, 0xc421,	0xddbf, 0xc421,		0x22, 0
	.dw 0xdfc0, 0xc421,	0xe03f, 0xc421,		0x22, 0
	.dw 0xe240, 0xc421,	0xe27f, 0xc421,		0x22, 0
	.dw 0xe480, 0xc421,	0xe4bf, 0xc421,		0x22, 0
	.dw 0xe6c0, 0xc421,	0xe6ff, 0xc421,		0x22, 0
	.dw 0xe900, 0xc421,	0xe93f, 0xc421,		0x22, 0
	.dw 0xeb40, 0xc421,	0xeb7f, 0xc421,		0x22, 0
	.dw 0xed80, 0xc421,	0xedbf, 0xc421,		0x22, 0
	.dw 0xefc0, 0xc421,	0xf03f, 0xc421,		0x22, 0
	.dw 0xf240, 0xc421,	0xf27f, 0xc421,		0x22, 0
	.dw 0xf480, 0xc421,	0xf4bf, 0xc421,		0x22, 0
	.dw 0xf6c0, 0xc421,	0xf6ff, 0xc421,		0x22, 0
	.dw 0xf900, 0xc421,	0xf93f, 0xc421,		0x22, 0
	.dw 0xfb40, 0xc421,	0xfb7f, 0xc421,		0x22, 0
	.dw 0xfd80, 0xc421,	0xfdbf, 0xc421,		0x22, 0
	.dw 0xffc0, 0xc421,	0xffff, 0xc421,		0x22, 0
	.dw 0x1000, 0xc422,	0x1fff, 0xc422,		0x21, 0
	.dw 0x3000, 0xc422,	0x3fff, 0xc422,		0x21, 0
	.dw 0x5000, 0xc422,	0x5fff, 0xc422,		0x21, 0
	.dw 0x7000, 0xc422,	0x7fff, 0xc422,		0x21, 0
	.dw 0x9000, 0xc422,	0x9fff, 0xc422,		0x21, 0
	.dw 0xb000, 0xc422,	0xbfff, 0xc422,		0x21, 0
	.dw 0xd000, 0xc422,	0xdfff, 0xc422,		0x21, 0
	.dw 0xf000, 0xc422,	0xffff, 0xc422,		0x21, 0
	.dw 0x1000, 0xc423,	0x1fff, 0xc423,		0x21, 0
	.dw 0x3000, 0xc423,	0x3fff, 0xc423,		0x21, 0
	.dw 0x5000, 0xc423,	0x5fff, 0xc423,		0x21, 0
	.dw 0x7000, 0xc423,	0x7fff, 0xc423,		0x21, 0
	.dw 0x9000, 0xc423,	0x9fff, 0xc423,		0x21, 0
	.dw 0xb000, 0xc423,	0xbfff, 0xc423,		0x21, 0
	.dw 0xd000, 0xc423,	0xdfff, 0xc423,		0x21, 0
	.dw 0xf000, 0xc423,	0xffff, 0xc424,		0x21, 0
	.dw 0x1000, 0xc425,	0x3fff, 0xc425,		0x21, 0
	.dw 0x5000, 0xc425,	0x8fff, 0xc425,		0x21, 0
	.dw 0xa000, 0xc425,	0xcfff, 0xc425,		0x21, 0
	.dw 0xe000, 0xc425,	0xffff, 0xc428,		0x21, 0
	.dw 0x1000, 0xc429,	0x7fff, 0xc429,		0x21, 0
	.dw 0x9000, 0xc429,	0xffff, 0xc42a,		0x21, 0
	.dw 0x1000, 0xc42b,	0x3fff, 0xc42b,		0x21, 0
	.dw 0x5000, 0xc42b,	0xbfff, 0xc42c,		0x21, 0
	.dw 0xd000, 0xc42c,	0xffff, 0xc42d,		0x21, 0
	.dw 0x1000, 0xc42e,	0x3fff, 0xc42e,		0x21, 0
	.dw 0x5000, 0xc42e,	0xffff, 0xc42f,		0x21, 0
	.dw 0x1000, 0xc430,	0x3fff, 0xc430,		0x21, 0
	.dw 0x5000, 0xc430,	0xffff, 0xc435,		0x21, 0
	.dw 0x0001, 0xc436,	0x0001, 0xc436,		0x21, 0
	.dw 0x0003, 0xc436,	0x000f, 0xc436,		0x21, 0
	.dw 0x0011, 0xc436,	0x0011, 0xc436,		0x21, 0
	.dw 0x0013, 0xc436,	0x003f, 0xc436,		0x21, 0
	.dw 0x0041, 0xc436,	0x0041, 0xc436,		0x21, 0
	.dw 0x0043, 0xc436,	0x004f, 0xc436,		0x21, 0
	.dw 0x0051, 0xc436,	0x0051, 0xc436,		0x21, 0
	.dw 0x0053, 0xc436,	0x007f, 0xc436,		0x21, 0
	.dw 0x0081, 0xc436,	0x0081, 0xc436,		0x21, 0
	.dw 0x0083, 0xc436,	0x008f, 0xc436,		0x21, 0
	.dw 0x0091, 0xc436,	0x0091, 0xc436,		0x21, 0
	.dw 0x0093, 0xc436,	0x00bf, 0xc436,		0x21, 0
	.dw 0x00c1, 0xc436,	0x00c1, 0xc436,		0x21, 0
	.dw 0x00c3, 0xc436,	0x00cf, 0xc436,		0x21, 0
	.dw 0x00d1, 0xc436,	0x00d1, 0xc436,		0x21, 0
	.dw 0x00d3, 0xc436,	0x00ff, 0xc436,		0x21, 0
	.dw 0x0101, 0xc436,	0x0101, 0xc436,		0x21, 0
	.dw 0x0103, 0xc436,	0x010f, 0xc436,		0x21, 0
	.dw 0x0111, 0xc436,	0x0111, 0xc436,		0x21, 0
	.dw 0x0113, 0xc436,	0x013f, 0xc436,		0x21, 0
	.dw 0x0141, 0xc436,	0x0141, 0xc436,		0x21, 0
	.dw 0x0143, 0xc436,	0x014f, 0xc436,		0x21, 0
	.dw 0x0151, 0xc436,	0x0151, 0xc436,		0x21, 0
	.dw 0x0153, 0xc436,	0x017f, 0xc436,		0x21, 0
	.dw 0x0181, 0xc436,	0x0181, 0xc436,		0x21, 0
	.dw 0x0183, 0xc436,	0x018f, 0xc436,		0x21, 0
	.dw 0x0191, 0xc436,	0x0191, 0xc436,		0x21, 0
	.dw 0x0193, 0xc436,	0x01bf, 0xc436,		0x21, 0
	.dw 0x01c1, 0xc436,	0x01c1, 0xc436,		0x21, 0
	.dw 0x01c3, 0xc436,	0x01cf, 0xc436,		0x21, 0
	.dw 0x01d1, 0xc436,	0x01d1, 0xc436,		0x21, 0
	.dw 0x01d3, 0xc436,	0x01ff, 0xc436,		0x21, 0
	.dw 0x0201, 0xc436,	0x0201, 0xc436,		0x21, 0
	.dw 0x0203, 0xc436,	0x020f, 0xc436,		0x21, 0
	.dw 0x0211, 0xc436,	0x0211, 0xc436,		0x21, 0
	.dw 0x0213, 0xc436,	0x023f, 0xc436,		0x21, 0
	.dw 0x0241, 0xc436,	0x0241, 0xc436,		0x21, 0
	.dw 0x0243, 0xc436,	0x024f, 0xc436,		0x21, 0
	.dw 0x0251, 0xc436,	0x0251, 0xc436,		0x21, 0
	.dw 0x0253, 0xc436,	0x027f, 0xc436,		0x21, 0
	.dw 0x0281, 0xc436,	0x0281, 0xc436,		0x21, 0
	.dw 0x0283, 0xc436,	0x028f, 0xc436,		0x21, 0
	.dw 0x0291, 0xc436,	0x0291, 0xc436,		0x21, 0
	.dw 0x0293, 0xc436,	0x02bf, 0xc436,		0x21, 0
	.dw 0x02c1, 0xc436,	0x02c1, 0xc436,		0x21, 0
	.dw 0x02c3, 0xc436,	0x02cf, 0xc436,		0x21, 0
	.dw 0x02d1, 0xc436,	0x02d1, 0xc436,		0x21, 0
	.dw 0x02d3, 0xc436,	0x02ff, 0xc436,		0x21, 0
	.dw 0x0301, 0xc436,	0x0301, 0xc436,		0x21, 0
	.dw 0x0303, 0xc436,	0x030f, 0xc436,		0x21, 0
	.dw 0x0311, 0xc436,	0x0311, 0xc436,		0x21, 0
	.dw 0x0313, 0xc436,	0x033f, 0xc436,		0x21, 0
	.dw 0x0341, 0xc436,	0x0341, 0xc436,		0x21, 0
	.dw 0x0343, 0xc436,	0x034f, 0xc436,		0x21, 0
	.dw 0x0351, 0xc436,	0x0351, 0xc436,		0x21, 0
	.dw 0x0353, 0xc436,	0x037f, 0xc436,		0x21, 0
	.dw 0x0381, 0xc436,	0x0381, 0xc436,		0x21, 0
	.dw 0x0383, 0xc436,	0x038f, 0xc436,		0x21, 0
	.dw 0x0391, 0xc436,	0x0391, 0xc436,		0x21, 0
	.dw 0x0393, 0xc436,	0x03bf, 0xc436,		0x21, 0
	.dw 0x03c1, 0xc436,	0x03c1, 0xc436,		0x21, 0
	.dw 0x03c3, 0xc436,	0x03cf, 0xc436,		0x21, 0
	.dw 0x03d1, 0xc436,	0x03d1, 0xc436,		0x21, 0
	.dw 0x03d3, 0xc436,	0x03ff, 0xc436,		0x21, 0
	.dw 0x0401, 0xc436,	0x0401, 0xc436,		0x21, 0
	.dw 0x0403, 0xc436,	0x040f, 0xc436,		0x21, 0
	.dw 0x0411, 0xc436,	0x0411, 0xc436,		0x21, 0
	.dw 0x0413, 0xc436,	0x043f, 0xc436,		0x21, 0
	.dw 0x0441, 0xc436,	0x0441, 0xc436,		0x21, 0
	.dw 0x0443, 0xc436,	0x044f, 0xc436,		0x21, 0
	.dw 0x0451, 0xc436,	0x0451, 0xc436,		0x21, 0
	.dw 0x0453, 0xc436,	0x047f, 0xc436,		0x21, 0
	.dw 0x0481, 0xc436,	0x0481, 0xc436,		0x21, 0
	.dw 0x0483, 0xc436,	0x048f, 0xc436,		0x21, 0
	.dw 0x0491, 0xc436,	0x0491, 0xc436,		0x21, 0
	.dw 0x0493, 0xc436,	0x04bf, 0xc436,		0x21, 0
	.dw 0x04c1, 0xc436,	0x04c1, 0xc436,		0x21, 0
	.dw 0x04c3, 0xc436,	0x04cf, 0xc436,		0x21, 0
	.dw 0x04d1, 0xc436,	0x04d1, 0xc436,		0x21, 0
	.dw 0x04d3, 0xc436,	0x04ff, 0xc436,		0x21, 0
	.dw 0x0501, 0xc436,	0x0501, 0xc436,		0x21, 0
	.dw 0x0503, 0xc436,	0x050f, 0xc436,		0x21, 0
	.dw 0x0511, 0xc436,	0x0511, 0xc436,		0x21, 0
	.dw 0x0513, 0xc436,	0x053f, 0xc436,		0x21, 0
	.dw 0x0541, 0xc436,	0x0541, 0xc436,		0x21, 0
	.dw 0x0543, 0xc436,	0x054f, 0xc436,		0x21, 0
	.dw 0x0551, 0xc436,	0x0551, 0xc436,		0x21, 0
	.dw 0x0553, 0xc436,	0x057f, 0xc436,		0x21, 0
	.dw 0x0581, 0xc436,	0x0581, 0xc436,		0x21, 0
	.dw 0x0583, 0xc436,	0x058f, 0xc436,		0x21, 0
	.dw 0x0591, 0xc436,	0x0591, 0xc436,		0x21, 0
	.dw 0x0593, 0xc436,	0x05bf, 0xc436,		0x21, 0
	.dw 0x05c1, 0xc436,	0x05c1, 0xc436,		0x21, 0
	.dw 0x05c3, 0xc436,	0x05cf, 0xc436,		0x21, 0
	.dw 0x05d1, 0xc436,	0x05d1, 0xc436,		0x21, 0
	.dw 0x05d3, 0xc436,	0x05ff, 0xc436,		0x21, 0
	.dw 0x0601, 0xc436,	0x0601, 0xc436,		0x21, 0
	.dw 0x0603, 0xc436,	0x060f, 0xc436,		0x21, 0
	.dw 0x0611, 0xc436,	0x0611, 0xc436,		0x21, 0
	.dw 0x0613, 0xc436,	0x063f, 0xc436,		0x21, 0
	.dw 0x0641, 0xc436,	0x0641, 0xc436,		0x21, 0
	.dw 0x0643, 0xc436,	0x064f, 0xc436,		0x21, 0
	.dw 0x0651, 0xc436,	0x0651, 0xc436,		0x21, 0
	.dw 0x0653, 0xc436,	0x067f, 0xc436,		0x21, 0
	.dw 0x0681, 0xc436,	0x0681, 0xc436,		0x21, 0
	.dw 0x0683, 0xc436,	0x068f, 0xc436,		0x21, 0
	.dw 0x0691, 0xc436,	0x0691, 0xc436,		0x21, 0
	.dw 0x0693, 0xc436,	0x06bf, 0xc436,		0x21, 0
	.dw 0x06c1, 0xc436,	0x06c1, 0xc436,		0x21, 0
	.dw 0x06c3, 0xc436,	0x06cf, 0xc436,		0x21, 0
	.dw 0x06d1, 0xc436,	0x06d1, 0xc436,		0x21, 0
	.dw 0x06d3, 0xc436,	0x06ff, 0xc436,		0x21, 0
	.dw 0x0701, 0xc436,	0x0701, 0xc436,		0x21, 0
	.dw 0x0703, 0xc436,	0x070f, 0xc436,		0x21, 0
	.dw 0x0711, 0xc436,	0x0711, 0xc436,		0x21, 0
	.dw 0x0713, 0xc436,	0x073f, 0xc436,		0x21, 0
	.dw 0x0741, 0xc436,	0x0741, 0xc436,		0x21, 0
	.dw 0x0743, 0xc436,	0x074f, 0xc436,		0x21, 0
	.dw 0x0751, 0xc436,	0x0751, 0xc436,		0x21, 0
	.dw 0x0753, 0xc436,	0x077f, 0xc436,		0x21, 0
	.dw 0x0781, 0xc436,	0x0781, 0xc436,		0x21, 0
	.dw 0x0783, 0xc436,	0x078f, 0xc436,		0x21, 0
	.dw 0x0791, 0xc436,	0x0791, 0xc436,		0x21, 0
	.dw 0x0793, 0xc436,	0x07bf, 0xc436,		0x21, 0
	.dw 0x07c1, 0xc436,	0x07c1, 0xc436,		0x21, 0
	.dw 0x07c3, 0xc436,	0x07cf, 0xc436,		0x21, 0
	.dw 0x07d1, 0xc436,	0x07d1, 0xc436,		0x21, 0
	.dw 0x07d3, 0xc436,	0x07ff, 0xc436,		0x21, 0
	.dw 0x0801, 0xc436,	0x0801, 0xc436,		0x21, 0
	.dw 0x0803, 0xc436,	0x080f, 0xc436,		0x21, 0
	.dw 0x0811, 0xc436,	0x0811, 0xc436,		0x21, 0
	.dw 0x0813, 0xc436,	0x083f, 0xc436,		0x21, 0
	.dw 0x0841, 0xc436,	0x0841, 0xc436,		0x21, 0
	.dw 0x0843, 0xc436,	0x084f, 0xc436,		0x21, 0
	.dw 0x0851, 0xc436,	0x0851, 0xc436,		0x21, 0
	.dw 0x0853, 0xc436,	0x087f, 0xc436,		0x21, 0
	.dw 0x0881, 0xc436,	0x0881, 0xc436,		0x21, 0
	.dw 0x0883, 0xc436,	0x088f, 0xc436,		0x21, 0
	.dw 0x0891, 0xc436,	0x0891, 0xc436,		0x21, 0
	.dw 0x0893, 0xc436,	0x08bf, 0xc436,		0x21, 0
	.dw 0x08c1, 0xc436,	0x08c1, 0xc436,		0x21, 0
	.dw 0x08c3, 0xc436,	0x08cf, 0xc436,		0x21, 0
	.dw 0x08d1, 0xc436,	0x08d1, 0xc436,		0x21, 0
	.dw 0x08d3, 0xc436,	0x08ff, 0xc436,		0x21, 0
	.dw 0x0901, 0xc436,	0x0901, 0xc436,		0x21, 0
	.dw 0x0903, 0xc436,	0x090f, 0xc436,		0x21, 0
	.dw 0x0911, 0xc436,	0x0911, 0xc436,		0x21, 0
	.dw 0x0913, 0xc436,	0x093f, 0xc436,		0x21, 0
	.dw 0x0941, 0xc436,	0x0941, 0xc436,		0x21, 0
	.dw 0x0943, 0xc436,	0x094f, 0xc436,		0x21, 0
	.dw 0x0951, 0xc436,	0x0951, 0xc436,		0x21, 0
	.dw 0x0953, 0xc436,	0x097f, 0xc436,		0x21, 0
	.dw 0x0981, 0xc436,	0x0981, 0xc436,		0x21, 0
	.dw 0x0983, 0xc436,	0x098f, 0xc436,		0x21, 0
	.dw 0x0991, 0xc436,	0x0991, 0xc436,		0x21, 0
	.dw 0x0993, 0xc436,	0x09bf, 0xc436,		0x21, 0
	.dw 0x09c1, 0xc436,	0x09c1, 0xc436,		0x21, 0
	.dw 0x09c3, 0xc436,	0x09cf, 0xc436,		0x21, 0
	.dw 0x09d1, 0xc436,	0x09d1, 0xc436,		0x21, 0
	.dw 0x09d3, 0xc436,	0x09ff, 0xc436,		0x21, 0
	.dw 0x0a01, 0xc436,	0x0a01, 0xc436,		0x21, 0
	.dw 0x0a03, 0xc436,	0x0a0f, 0xc436,		0x21, 0
	.dw 0x0a11, 0xc436,	0x0a11, 0xc436,		0x21, 0
	.dw 0x0a13, 0xc436,	0x0a3f, 0xc436,		0x21, 0
	.dw 0x0a41, 0xc436,	0x0a41, 0xc436,		0x21, 0
	.dw 0x0a43, 0xc436,	0x0a4f, 0xc436,		0x21, 0
	.dw 0x0a51, 0xc436,	0x0a51, 0xc436,		0x21, 0
	.dw 0x0a53, 0xc436,	0x0a7f, 0xc436,		0x21, 0
	.dw 0x0a81, 0xc436,	0x0a81, 0xc436,		0x21, 0
	.dw 0x0a83, 0xc436,	0x0a8f, 0xc436,		0x21, 0
	.dw 0x0a91, 0xc436,	0x0a91, 0xc436,		0x21, 0
	.dw 0x0a93, 0xc436,	0x0abf, 0xc436,		0x21, 0
	.dw 0x0ac1, 0xc436,	0x0ac1, 0xc436,		0x21, 0
	.dw 0x0ac3, 0xc436,	0x0acf, 0xc436,		0x21, 0
	.dw 0x0ad1, 0xc436,	0x0ad1, 0xc436,		0x21, 0
	.dw 0x0ad3, 0xc436,	0x0aff, 0xc436,		0x21, 0
	.dw 0x0b01, 0xc436,	0x0b01, 0xc436,		0x21, 0
	.dw 0x0b03, 0xc436,	0x0b0f, 0xc436,		0x21, 0
	.dw 0x0b11, 0xc436,	0x0b11, 0xc436,		0x21, 0
	.dw 0x0b13, 0xc436,	0x0b3f, 0xc436,		0x21, 0
	.dw 0x0b41, 0xc436,	0x0b41, 0xc436,		0x21, 0
	.dw 0x0b43, 0xc436,	0x0b4f, 0xc436,		0x21, 0
	.dw 0x0b51, 0xc436,	0x0b51, 0xc436,		0x21, 0
	.dw 0x0b53, 0xc436,	0x0b7f, 0xc436,		0x21, 0
	.dw 0x0b81, 0xc436,	0x0b81, 0xc436,		0x21, 0
	.dw 0x0b83, 0xc436,	0x0b8f, 0xc436,		0x21, 0
	.dw 0x0b91, 0xc436,	0x0b91, 0xc436,		0x21, 0
	.dw 0x0b93, 0xc436,	0x0bbf, 0xc436,		0x21, 0
	.dw 0x0bc1, 0xc436,	0x0bc1, 0xc436,		0x21, 0
	.dw 0x0bc3, 0xc436,	0x0bcf, 0xc436,		0x21, 0
	.dw 0x0bd1, 0xc436,	0x0bd1, 0xc436,		0x21, 0
	.dw 0x0bd3, 0xc436,	0x0bff, 0xc436,		0x21, 0
	.dw 0x0c01, 0xc436,	0x0c01, 0xc436,		0x21, 0
	.dw 0x0c03, 0xc436,	0x0c0f, 0xc436,		0x21, 0
	.dw 0x0c11, 0xc436,	0x0c11, 0xc436,		0x21, 0
	.dw 0x0c13, 0xc436,	0x0c3f, 0xc436,		0x21, 0
	.dw 0x0c41, 0xc436,	0x0c41, 0xc436,		0x21, 0
	.dw 0x0c43, 0xc436,	0x0c4f, 0xc436,		0x21, 0
	.dw 0x0c51, 0xc436,	0x0c51, 0xc436,		0x21, 0
	.dw 0x0c53, 0xc436,	0x0c7f, 0xc436,		0x21, 0
	.dw 0x0c81, 0xc436,	0x0c81, 0xc436,		0x21, 0
	.dw 0x0c83, 0xc436,	0x0c8f, 0xc436,		0x21, 0
	.dw 0x0c91, 0xc436,	0x0c91, 0xc436,		0x21, 0
	.dw 0x0c93, 0xc436,	0x0cbf, 0xc436,		0x21, 0
	.dw 0x0cc1, 0xc436,	0x0cc1, 0xc436,		0x21, 0
	.dw 0x0cc3, 0xc436,	0x0ccf, 0xc436,		0x21, 0
	.dw 0x0cd1, 0xc436,	0x0cd1, 0xc436,		0x21, 0
	.dw 0x0cd3, 0xc436,	0x0cff, 0xc436,		0x21, 0
	.dw 0x0d01, 0xc436,	0x0d01, 0xc436,		0x21, 0
	.dw 0x0d03, 0xc436,	0x0d0f, 0xc436,		0x21, 0
	.dw 0x0d11, 0xc436,	0x0d11, 0xc436,		0x21, 0
	.dw 0x0d13, 0xc436,	0x0d3f, 0xc436,		0x21, 0
	.dw 0x0d41, 0xc436,	0x0d41, 0xc436,		0x21, 0
	.dw 0x0d43, 0xc436,	0x0d4f, 0xc436,		0x21, 0
	.dw 0x0d51, 0xc436,	0x0d51, 0xc436,		0x21, 0
	.dw 0x0d53, 0xc436,	0x0d7f, 0xc436,		0x21, 0
	.dw 0x0d81, 0xc436,	0x0d81, 0xc436,		0x21, 0
	.dw 0x0d83, 0xc436,	0x0d8f, 0xc436,		0x21, 0
	.dw 0x0d91, 0xc436,	0x0d91, 0xc436,		0x21, 0
	.dw 0x0d93, 0xc436,	0x0dbf, 0xc436,		0x21, 0
	.dw 0x0dc1, 0xc436,	0x0dc1, 0xc436,		0x21, 0
	.dw 0x0dc3, 0xc436,	0x0dcf, 0xc436,		0x21, 0
	.dw 0x0dd1, 0xc436,	0x0dd1, 0xc436,		0x21, 0
	.dw 0x0dd3, 0xc436,	0x0dff, 0xc436,		0x21, 0
	.dw 0x0e01, 0xc436,	0x0e01, 0xc436,		0x21, 0
	.dw 0x0e03, 0xc436,	0x0e0f, 0xc436,		0x21, 0
	.dw 0x0e11, 0xc436,	0x0e11, 0xc436,		0x21, 0
	.dw 0x0e13, 0xc436,	0x0e3f, 0xc436,		0x21, 0
	.dw 0x0e41, 0xc436,	0x0e41, 0xc436,		0x21, 0
	.dw 0x0e43, 0xc436,	0x0e4f, 0xc436,		0x21, 0
	.dw 0x0e51, 0xc436,	0x0e51, 0xc436,		0x21, 0
	.dw 0x0e53, 0xc436,	0x0e7f, 0xc436,		0x21, 0
	.dw 0x0e81, 0xc436,	0x0e81, 0xc436,		0x21, 0
	.dw 0x0e83, 0xc436,	0x0e8f, 0xc436,		0x21, 0
	.dw 0x0e91, 0xc436,	0x0e91, 0xc436,		0x21, 0
	.dw 0x0e93, 0xc436,	0x0ebf, 0xc436,		0x21, 0
	.dw 0x0ec1, 0xc436,	0x0ec1, 0xc436,		0x21, 0
	.dw 0x0ec3, 0xc436,	0x0ecf, 0xc436,		0x21, 0
	.dw 0x0ed1, 0xc436,	0x0ed1, 0xc436,		0x21, 0
	.dw 0x0ed3, 0xc436,	0x0eff, 0xc436,		0x21, 0
	.dw 0x0f01, 0xc436,	0x0f01, 0xc436,		0x21, 0
	.dw 0x0f03, 0xc436,	0x0f0f, 0xc436,		0x21, 0
	.dw 0x0f11, 0xc436,	0x0f11, 0xc436,		0x21, 0
	.dw 0x0f13, 0xc436,	0x0f3f, 0xc436,		0x21, 0
	.dw 0x0f41, 0xc436,	0x0f41, 0xc436,		0x21, 0
	.dw 0x0f43, 0xc436,	0x0f4f, 0xc436,		0x21, 0
	.dw 0x0f51, 0xc436,	0x0f51, 0xc436,		0x21, 0
	.dw 0x0f53, 0xc436,	0x0f7f, 0xc436,		0x21, 0
	.dw 0x0f81, 0xc436,	0x0f81, 0xc436,		0x21, 0
	.dw 0x0f83, 0xc436,	0x0f8f, 0xc436,		0x21, 0
	.dw 0x0f91, 0xc436,	0x0f91, 0xc436,		0x21, 0
	.dw 0x0f93, 0xc436,	0x0fbf, 0xc436,		0x21, 0
	.dw 0x0fc1, 0xc436,	0x0fc1, 0xc436,		0x21, 0
	.dw 0x0fc3, 0xc436,	0x0fcf, 0xc436,		0x21, 0
	.dw 0x0fd1, 0xc436,	0x0fd1, 0xc436,		0x21, 0
	.dw 0x0fd3, 0xc436,	0x1fff, 0xc436,		0x21, 0
	.dw 0x2001, 0xc436,	0x2001, 0xc436,		0x21, 0
	.dw 0x2003, 0xc436,	0x200f, 0xc436,		0x21, 0
	.dw 0x2011, 0xc436,	0x2011, 0xc436,		0x21, 0
	.dw 0x2013, 0xc436,	0x203f, 0xc436,		0x21, 0
	.dw 0x2041, 0xc436,	0x2041, 0xc436,		0x21, 0
	.dw 0x2043, 0xc436,	0x204f, 0xc436,		0x21, 0
	.dw 0x2051, 0xc436,	0x2051, 0xc436,		0x21, 0
	.dw 0x2053, 0xc436,	0x207f, 0xc436,		0x21, 0
	.dw 0x2081, 0xc436,	0x2081, 0xc436,		0x21, 0
	.dw 0x2083, 0xc436,	0x208f, 0xc436,		0x21, 0
	.dw 0x2091, 0xc436,	0x2091, 0xc436,		0x21, 0
	.dw 0x2093, 0xc436,	0x20bf, 0xc436,		0x21, 0
	.dw 0x20c1, 0xc436,	0x20c1, 0xc436,		0x21, 0
	.dw 0x20c3, 0xc436,	0x20cf, 0xc436,		0x21, 0
	.dw 0x20d1, 0xc436,	0x20d1, 0xc436,		0x21, 0
	.dw 0x20d3, 0xc436,	0x20ff, 0xc436,		0x21, 0
	.dw 0x2101, 0xc436,	0x2101, 0xc436,		0x21, 0
	.dw 0x2103, 0xc436,	0x210f, 0xc436,		0x21, 0
	.dw 0x2111, 0xc436,	0x2111, 0xc436,		0x21, 0
	.dw 0x2113, 0xc436,	0x213f, 0xc436,		0x21, 0
	.dw 0x2141, 0xc436,	0x2141, 0xc436,		0x21, 0
	.dw 0x2143, 0xc436,	0x214f, 0xc436,		0x21, 0
	.dw 0x2151, 0xc436,	0x2151, 0xc436,		0x21, 0
	.dw 0x2153, 0xc436,	0x217f, 0xc436,		0x21, 0
	.dw 0x2181, 0xc436,	0x2181, 0xc436,		0x21, 0
	.dw 0x2183, 0xc436,	0x218f, 0xc436,		0x21, 0
	.dw 0x2191, 0xc436,	0x2191, 0xc436,		0x21, 0
	.dw 0x2193, 0xc436,	0x21bf, 0xc436,		0x21, 0
	.dw 0x21c1, 0xc436,	0x21c1, 0xc436,		0x21, 0
	.dw 0x21c3, 0xc436,	0x21cf, 0xc436,		0x21, 0
	.dw 0x21d1, 0xc436,	0x21d1, 0xc436,		0x21, 0
	.dw 0x21d3, 0xc436,	0x21ff, 0xc436,		0x21, 0
	.dw 0x2201, 0xc436,	0x2201, 0xc436,		0x21, 0
	.dw 0x2203, 0xc436,	0x220f, 0xc436,		0x21, 0
	.dw 0x2211, 0xc436,	0x2211, 0xc436,		0x21, 0
	.dw 0x2213, 0xc436,	0x223f, 0xc436,		0x21, 0
	.dw 0x2241, 0xc436,	0x2241, 0xc436,		0x21, 0
	.dw 0x2243, 0xc436,	0x224f, 0xc436,		0x21, 0
	.dw 0x2251, 0xc436,	0x2251, 0xc436,		0x21, 0
	.dw 0x2253, 0xc436,	0x227f, 0xc436,		0x21, 0
	.dw 0x2281, 0xc436,	0x2281, 0xc436,		0x21, 0
	.dw 0x2283, 0xc436,	0x228f, 0xc436,		0x21, 0
	.dw 0x2291, 0xc436,	0x2291, 0xc436,		0x21, 0
	.dw 0x2293, 0xc436,	0x22bf, 0xc436,		0x21, 0
	.dw 0x22c1, 0xc436,	0x22c1, 0xc436,		0x21, 0
	.dw 0x22c3, 0xc436,	0x22cf, 0xc436,		0x21, 0
	.dw 0x22d1, 0xc436,	0x22d1, 0xc436,		0x21, 0
	.dw 0x22d3, 0xc436,	0x22ff, 0xc436,		0x21, 0
	.dw 0x2301, 0xc436,	0x2301, 0xc436,		0x21, 0
	.dw 0x2303, 0xc436,	0x230f, 0xc436,		0x21, 0
	.dw 0x2311, 0xc436,	0x2311, 0xc436,		0x21, 0
	.dw 0x2313, 0xc436,	0x233f, 0xc436,		0x21, 0
	.dw 0x2341, 0xc436,	0x2341, 0xc436,		0x21, 0
	.dw 0x2343, 0xc436,	0x234f, 0xc436,		0x21, 0
	.dw 0x2351, 0xc436,	0x2351, 0xc436,		0x21, 0
	.dw 0x2353, 0xc436,	0x237f, 0xc436,		0x21, 0
	.dw 0x2381, 0xc436,	0x2381, 0xc436,		0x21, 0
	.dw 0x2383, 0xc436,	0x238f, 0xc436,		0x21, 0
	.dw 0x2391, 0xc436,	0x2391, 0xc436,		0x21, 0
	.dw 0x2393, 0xc436,	0x23bf, 0xc436,		0x21, 0
	.dw 0x23c1, 0xc436,	0x23c1, 0xc436,		0x21, 0
	.dw 0x23c3, 0xc436,	0x23cf, 0xc436,		0x21, 0
	.dw 0x23d1, 0xc436,	0x23d1, 0xc436,		0x21, 0
	.dw 0x23d3, 0xc436,	0x23ff, 0xc436,		0x21, 0
	.dw 0x2401, 0xc436,	0x2401, 0xc436,		0x21, 0
	.dw 0x2403, 0xc436,	0x240f, 0xc436,		0x21, 0
	.dw 0x2411, 0xc436,	0x2411, 0xc436,		0x21, 0
	.dw 0x2413, 0xc436,	0x243f, 0xc436,		0x21, 0
	.dw 0x2441, 0xc436,	0x2441, 0xc436,		0x21, 0
	.dw 0x2443, 0xc436,	0x244f, 0xc436,		0x21, 0
	.dw 0x2451, 0xc436,	0x2451, 0xc436,		0x21, 0
	.dw 0x2453, 0xc436,	0x247f, 0xc436,		0x21, 0
	.dw 0x2481, 0xc436,	0x2481, 0xc436,		0x21, 0
	.dw 0x2483, 0xc436,	0x248f, 0xc436,		0x21, 0
	.dw 0x2491, 0xc436,	0x2491, 0xc436,		0x21, 0
	.dw 0x2493, 0xc436,	0x24bf, 0xc436,		0x21, 0
	.dw 0x24c1, 0xc436,	0x24c1, 0xc436,		0x21, 0
	.dw 0x24c3, 0xc436,	0x24cf, 0xc436,		0x21, 0
	.dw 0x24d1, 0xc436,	0x24d1, 0xc436,		0x21, 0
	.dw 0x24d3, 0xc436,	0x24ff, 0xc436,		0x21, 0
	.dw 0x2501, 0xc436,	0x2501, 0xc436,		0x21, 0
	.dw 0x2503, 0xc436,	0x250f, 0xc436,		0x21, 0
	.dw 0x2511, 0xc436,	0x2511, 0xc436,		0x21, 0
	.dw 0x2513, 0xc436,	0x253f, 0xc436,		0x21, 0
	.dw 0x2541, 0xc436,	0x2541, 0xc436,		0x21, 0
	.dw 0x2543, 0xc436,	0x254f, 0xc436,		0x21, 0
	.dw 0x2551, 0xc436,	0x2551, 0xc436,		0x21, 0
	.dw 0x2553, 0xc436,	0x257f, 0xc436,		0x21, 0
	.dw 0x2581, 0xc436,	0x2581, 0xc436,		0x21, 0
	.dw 0x2583, 0xc436,	0x258f, 0xc436,		0x21, 0
	.dw 0x2591, 0xc436,	0x2591, 0xc436,		0x21, 0
	.dw 0x2593, 0xc436,	0x25bf, 0xc436,		0x21, 0
	.dw 0x25c1, 0xc436,	0x25c1, 0xc436,		0x21, 0
	.dw 0x25c3, 0xc436,	0x25cf, 0xc436,		0x21, 0
	.dw 0x25d1, 0xc436,	0x25d1, 0xc436,		0x21, 0
	.dw 0x25d3, 0xc436,	0x25ff, 0xc436,		0x21, 0
	.dw 0x2601, 0xc436,	0x2601, 0xc436,		0x21, 0
	.dw 0x2603, 0xc436,	0x260f, 0xc436,		0x21, 0
	.dw 0x2611, 0xc436,	0x2611, 0xc436,		0x21, 0
	.dw 0x2613, 0xc436,	0x263f, 0xc436,		0x21, 0
	.dw 0x2641, 0xc436,	0x2641, 0xc436,		0x21, 0
	.dw 0x2643, 0xc436,	0x264f, 0xc436,		0x21, 0
	.dw 0x2651, 0xc436,	0x2651, 0xc436,		0x21, 0
	.dw 0x2653, 0xc436,	0x267f, 0xc436,		0x21, 0
	.dw 0x2681, 0xc436,	0x2681, 0xc436,		0x21, 0
	.dw 0x2683, 0xc436,	0x268f, 0xc436,		0x21, 0
	.dw 0x2691, 0xc436,	0x2691, 0xc436,		0x21, 0
	.dw 0x2693, 0xc436,	0x26bf, 0xc436,		0x21, 0
	.dw 0x26c1, 0xc436,	0x26c1, 0xc436,		0x21, 0
	.dw 0x26c3, 0xc436,	0x26cf, 0xc436,		0x21, 0
	.dw 0x26d1, 0xc436,	0x26d1, 0xc436,		0x21, 0
	.dw 0x26d3, 0xc436,	0x26ff, 0xc436,		0x21, 0
	.dw 0x2701, 0xc436,	0x2701, 0xc436,		0x21, 0
	.dw 0x2703, 0xc436,	0x270f, 0xc436,		0x21, 0
	.dw 0x2711, 0xc436,	0x2711, 0xc436,		0x21, 0
	.dw 0x2713, 0xc436,	0x273f, 0xc436,		0x21, 0
	.dw 0x2741, 0xc436,	0x2741, 0xc436,		0x21, 0
	.dw 0x2743, 0xc436,	0x274f, 0xc436,		0x21, 0
	.dw 0x2751, 0xc436,	0x2751, 0xc436,		0x21, 0
	.dw 0x2753, 0xc436,	0x277f, 0xc436,		0x21, 0
	.dw 0x2781, 0xc436,	0x2781, 0xc436,		0x21, 0
	.dw 0x2783, 0xc436,	0x278f, 0xc436,		0x21, 0
	.dw 0x2791, 0xc436,	0x2791, 0xc436,		0x21, 0
	.dw 0x2793, 0xc436,	0x27bf, 0xc436,		0x21, 0
	.dw 0x27c1, 0xc436,	0x27c1, 0xc436,		0x21, 0
	.dw 0x27c3, 0xc436,	0x27cf, 0xc436,		0x21, 0
	.dw 0x27d1, 0xc436,	0x27d1, 0xc436,		0x21, 0
	.dw 0x27d3, 0xc436,	0x27ff, 0xc436,		0x21, 0
	.dw 0x2801, 0xc436,	0x2801, 0xc436,		0x21, 0
	.dw 0x2803, 0xc436,	0x280f, 0xc436,		0x21, 0
	.dw 0x2811, 0xc436,	0x2811, 0xc436,		0x21, 0
	.dw 0x2813, 0xc436,	0x283f, 0xc436,		0x21, 0
	.dw 0x2841, 0xc436,	0x2841, 0xc436,		0x21, 0
	.dw 0x2843, 0xc436,	0x284f, 0xc436,		0x21, 0
	.dw 0x2851, 0xc436,	0x2851, 0xc436,		0x21, 0
	.dw 0x2853, 0xc436,	0x287f, 0xc436,		0x21, 0
	.dw 0x2881, 0xc436,	0x2881, 0xc436,		0x21, 0
	.dw 0x2883, 0xc436,	0x288f, 0xc436,		0x21, 0
	.dw 0x2891, 0xc436,	0x2891, 0xc436,		0x21, 0
	.dw 0x2893, 0xc436,	0x28bf, 0xc436,		0x21, 0
	.dw 0x28c1, 0xc436,	0x28c1, 0xc436,		0x21, 0
	.dw 0x28c3, 0xc436,	0x28cf, 0xc436,		0x21, 0
	.dw 0x28d1, 0xc436,	0x28d1, 0xc436,		0x21, 0
	.dw 0x28d3, 0xc436,	0x28ff, 0xc436,		0x21, 0
	.dw 0x2901, 0xc436,	0x2901, 0xc436,		0x21, 0
	.dw 0x2903, 0xc436,	0x290f, 0xc436,		0x21, 0
	.dw 0x2911, 0xc436,	0x2911, 0xc436,		0x21, 0
	.dw 0x2913, 0xc436,	0x293f, 0xc436,		0x21, 0
	.dw 0x2941, 0xc436,	0x2941, 0xc436,		0x21, 0
	.dw 0x2943, 0xc436,	0x294f, 0xc436,		0x21, 0
	.dw 0x2951, 0xc436,	0x2951, 0xc436,		0x21, 0
	.dw 0x2953, 0xc436,	0x297f, 0xc436,		0x21, 0
	.dw 0x2981, 0xc436,	0x2981, 0xc436,		0x21, 0
	.dw 0x2983, 0xc436,	0x298f, 0xc436,		0x21, 0
	.dw 0x2991, 0xc436,	0x2991, 0xc436,		0x21, 0
	.dw 0x2993, 0xc436,	0x29bf, 0xc436,		0x21, 0
	.dw 0x29c1, 0xc436,	0x29c1, 0xc436,		0x21, 0
	.dw 0x29c3, 0xc436,	0x29cf, 0xc436,		0x21, 0
	.dw 0x29d1, 0xc436,	0x29d1, 0xc436,		0x21, 0
	.dw 0x29d3, 0xc436,	0x29ff, 0xc436,		0x21, 0
	.dw 0x2a01, 0xc436,	0x2a01, 0xc436,		0x21, 0
	.dw 0x2a03, 0xc436,	0x2a0f, 0xc436,		0x21, 0
	.dw 0x2a11, 0xc436,	0x2a11, 0xc436,		0x21, 0
	.dw 0x2a13, 0xc436,	0x2a3f, 0xc436,		0x21, 0
	.dw 0x2a41, 0xc436,	0x2a41, 0xc436,		0x21, 0
	.dw 0x2a43, 0xc436,	0x2a4f, 0xc436,		0x21, 0
	.dw 0x2a51, 0xc436,	0x2a51, 0xc436,		0x21, 0
	.dw 0x2a53, 0xc436,	0x2a7f, 0xc436,		0x21, 0
	.dw 0x2a81, 0xc436,	0x2a81, 0xc436,		0x21, 0
	.dw 0x2a83, 0xc436,	0x2a8f, 0xc436,		0x21, 0
	.dw 0x2a91, 0xc436,	0x2a91, 0xc436,		0x21, 0
	.dw 0x2a93, 0xc436,	0x2abf, 0xc436,		0x21, 0
	.dw 0x2ac1, 0xc436,	0x2ac1, 0xc436,		0x21, 0
	.dw 0x2ac3, 0xc436,	0x2acf, 0xc436,		0x21, 0
	.dw 0x2ad1, 0xc436,	0x2ad1, 0xc436,		0x21, 0
	.dw 0x2ad3, 0xc436,	0x2aff, 0xc436,		0x21, 0
	.dw 0x2b01, 0xc436,	0x2b01, 0xc436,		0x21, 0
	.dw 0x2b03, 0xc436,	0x2b0f, 0xc436,		0x21, 0
	.dw 0x2b11, 0xc436,	0x2b11, 0xc436,		0x21, 0
	.dw 0x2b13, 0xc436,	0x2b3f, 0xc436,		0x21, 0
	.dw 0x2b41, 0xc436,	0x2b41, 0xc436,		0x21, 0
	.dw 0x2b43, 0xc436,	0x2b4f, 0xc436,		0x21, 0
	.dw 0x2b51, 0xc436,	0x2b51, 0xc436,		0x21, 0
	.dw 0x2b53, 0xc436,	0x2b7f, 0xc436,		0x21, 0
	.dw 0x2b81, 0xc436,	0x2b81, 0xc436,		0x21, 0
	.dw 0x2b83, 0xc436,	0x2b8f, 0xc436,		0x21, 0
	.dw 0x2b91, 0xc436,	0x2b91, 0xc436,		0x21, 0
	.dw 0x2b93, 0xc436,	0x2bbf, 0xc436,		0x21, 0
	.dw 0x2bc1, 0xc436,	0x2bc1, 0xc436,		0x21, 0
	.dw 0x2bc3, 0xc436,	0x2bcf, 0xc436,		0x21, 0
	.dw 0x2bd1, 0xc436,	0x2bd1, 0xc436,		0x21, 0
	.dw 0x2bd3, 0xc436,	0x2bff, 0xc436,		0x21, 0
	.dw 0x2c01, 0xc436,	0x2c01, 0xc436,		0x21, 0
	.dw 0x2c03, 0xc436,	0x2c0f, 0xc436,		0x21, 0
	.dw 0x2c11, 0xc436,	0x2c11, 0xc436,		0x21, 0
	.dw 0x2c13, 0xc436,	0x2c3f, 0xc436,		0x21, 0
	.dw 0x2c41, 0xc436,	0x2c41, 0xc436,		0x21, 0
	.dw 0x2c43, 0xc436,	0x2c4f, 0xc436,		0x21, 0
	.dw 0x2c51, 0xc436,	0x2c51, 0xc436,		0x21, 0
	.dw 0x2c53, 0xc436,	0x2c7f, 0xc436,		0x21, 0
	.dw 0x2c81, 0xc436,	0x2c81, 0xc436,		0x21, 0
	.dw 0x2c83, 0xc436,	0x2c8f, 0xc436,		0x21, 0
	.dw 0x2c91, 0xc436,	0x2c91, 0xc436,		0x21, 0
	.dw 0x2c93, 0xc436,	0x2cbf, 0xc436,		0x21, 0
	.dw 0x2cc1, 0xc436,	0x2cc1, 0xc436,		0x21, 0
	.dw 0x2cc3, 0xc436,	0x2ccf, 0xc436,		0x21, 0
	.dw 0x2cd1, 0xc436,	0x2cd1, 0xc436,		0x21, 0
	.dw 0x2cd3, 0xc436,	0x2cff, 0xc436,		0x21, 0
	.dw 0x2d01, 0xc436,	0x2d01, 0xc436,		0x21, 0
	.dw 0x2d03, 0xc436,	0x2d0f, 0xc436,		0x21, 0
	.dw 0x2d11, 0xc436,	0x2d11, 0xc436,		0x21, 0
	.dw 0x2d13, 0xc436,	0x2d3f, 0xc436,		0x21, 0
	.dw 0x2d41, 0xc436,	0x2d41, 0xc436,		0x21, 0
	.dw 0x2d43, 0xc436,	0x2d4f, 0xc436,		0x21, 0
	.dw 0x2d51, 0xc436,	0x2d51, 0xc436,		0x21, 0
	.dw 0x2d53, 0xc436,	0x2d7f, 0xc436,		0x21, 0
	.dw 0x2d81, 0xc436,	0x2d81, 0xc436,		0x21, 0
	.dw 0x2d83, 0xc436,	0x2d8f, 0xc436,		0x21, 0
	.dw 0x2d91, 0xc436,	0x2d91, 0xc436,		0x21, 0
	.dw 0x2d93, 0xc436,	0x2dbf, 0xc436,		0x21, 0
	.dw 0x2dc1, 0xc436,	0x2dc1, 0xc436,		0x21, 0
	.dw 0x2dc3, 0xc436,	0x2dcf, 0xc436,		0x21, 0
	.dw 0x2dd1, 0xc436,	0x2dd1, 0xc436,		0x21, 0
	.dw 0x2dd3, 0xc436,	0x2dff, 0xc436,		0x21, 0
	.dw 0x2e01, 0xc436,	0x2e01, 0xc436,		0x21, 0
	.dw 0x2e03, 0xc436,	0x2e0f, 0xc436,		0x21, 0
	.dw 0x2e11, 0xc436,	0x2e11, 0xc436,		0x21, 0
	.dw 0x2e13, 0xc436,	0x2e3f, 0xc436,		0x21, 0
	.dw 0x2e41, 0xc436,	0x2e41, 0xc436,		0x21, 0
	.dw 0x2e43, 0xc436,	0x2e4f, 0xc436,		0x21, 0
	.dw 0x2e51, 0xc436,	0x2e51, 0xc436,		0x21, 0
	.dw 0x2e53, 0xc436,	0x2e7f, 0xc436,		0x21, 0
	.dw 0x2e81, 0xc436,	0x2e81, 0xc436,		0x21, 0
	.dw 0x2e83, 0xc436,	0x2e8f, 0xc436,		0x21, 0
	.dw 0x2e91, 0xc436,	0x2e91, 0xc436,		0x21, 0
	.dw 0x2e93, 0xc436,	0x2ebf, 0xc436,		0x21, 0
	.dw 0x2ec1, 0xc436,	0x2ec1, 0xc436,		0x21, 0
	.dw 0x2ec3, 0xc436,	0x2ecf, 0xc436,		0x21, 0
	.dw 0x2ed1, 0xc436,	0x2ed1, 0xc436,		0x21, 0
	.dw 0x2ed3, 0xc436,	0x2eff, 0xc436,		0x21, 0
	.dw 0x2f01, 0xc436,	0x2f01, 0xc436,		0x21, 0
	.dw 0x2f03, 0xc436,	0x2f0f, 0xc436,		0x21, 0
	.dw 0x2f11, 0xc436,	0x2f11, 0xc436,		0x21, 0
	.dw 0x2f13, 0xc436,	0x2f3f, 0xc436,		0x21, 0
	.dw 0x2f41, 0xc436,	0x2f41, 0xc436,		0x21, 0
	.dw 0x2f43, 0xc436,	0x2f4f, 0xc436,		0x21, 0
	.dw 0x2f51, 0xc436,	0x2f51, 0xc436,		0x21, 0
	.dw 0x2f53, 0xc436,	0x2f7f, 0xc436,		0x21, 0
	.dw 0x2f81, 0xc436,	0x2f81, 0xc436,		0x21, 0
	.dw 0x2f83, 0xc436,	0x2f8f, 0xc436,		0x21, 0
	.dw 0x2f91, 0xc436,	0x2f91, 0xc436,		0x21, 0
	.dw 0x2f93, 0xc436,	0x2fbf, 0xc436,		0x21, 0
	.dw 0x2fc1, 0xc436,	0x2fc1, 0xc436,		0x21, 0
	.dw 0x2fc3, 0xc436,	0x2fcf, 0xc436,		0x21, 0
	.dw 0x2fd1, 0xc436,	0x2fd1, 0xc436,		0x21, 0
	.dw 0x2fd3, 0xc436,	0x3fff, 0xc436,		0x21, 0
	.dw 0x4001, 0xc436,	0x4001, 0xc436,		0x21, 0
	.dw 0x4003, 0xc436,	0x400f, 0xc436,		0x21, 0
	.dw 0x4011, 0xc436,	0x4011, 0xc436,		0x21, 0
	.dw 0x4013, 0xc436,	0x403f, 0xc436,		0x21, 0
	.dw 0x4041, 0xc436,	0x4041, 0xc436,		0x21, 0
	.dw 0x4043, 0xc436,	0x404f, 0xc436,		0x21, 0
	.dw 0x4051, 0xc436,	0x4051, 0xc436,		0x21, 0
	.dw 0x4053, 0xc436,	0x407f, 0xc436,		0x21, 0
	.dw 0x4081, 0xc436,	0x4081, 0xc436,		0x21, 0
	.dw 0x4083, 0xc436,	0x408f, 0xc436,		0x21, 0
	.dw 0x4091, 0xc436,	0x4091, 0xc436,		0x21, 0
	.dw 0x4093, 0xc436,	0x40bf, 0xc436,		0x21, 0
	.dw 0x40c1, 0xc436,	0x40c1, 0xc436,		0x21, 0
	.dw 0x40c3, 0xc436,	0x40cf, 0xc436,		0x21, 0
	.dw 0x40d1, 0xc436,	0x40d1, 0xc436,		0x21, 0
	.dw 0x40d3, 0xc436,	0x40ff, 0xc436,		0x21, 0
	.dw 0x4101, 0xc436,	0x4101, 0xc436,		0x21, 0
	.dw 0x4103, 0xc436,	0x410f, 0xc436,		0x21, 0
	.dw 0x4111, 0xc436,	0x4111, 0xc436,		0x21, 0
	.dw 0x4113, 0xc436,	0x413f, 0xc436,		0x21, 0
	.dw 0x4141, 0xc436,	0x4141, 0xc436,		0x21, 0
	.dw 0x4143, 0xc436,	0x414f, 0xc436,		0x21, 0
	.dw 0x4151, 0xc436,	0x4151, 0xc436,		0x21, 0
	.dw 0x4153, 0xc436,	0x417f, 0xc436,		0x21, 0
	.dw 0x4181, 0xc436,	0x4181, 0xc436,		0x21, 0
	.dw 0x4183, 0xc436,	0x418f, 0xc436,		0x21, 0
	.dw 0x4191, 0xc436,	0x4191, 0xc436,		0x21, 0
	.dw 0x4193, 0xc436,	0x41bf, 0xc436,		0x21, 0
	.dw 0x41c1, 0xc436,	0x41c1, 0xc436,		0x21, 0
	.dw 0x41c3, 0xc436,	0x41cf, 0xc436,		0x21, 0
	.dw 0x41d1, 0xc436,	0x41d1, 0xc436,		0x21, 0
	.dw 0x41d3, 0xc436,	0x41ff, 0xc436,		0x21, 0
	.dw 0x4201, 0xc436,	0x4201, 0xc436,		0x21, 0
	.dw 0x4203, 0xc436,	0x420f, 0xc436,		0x21, 0
	.dw 0x4211, 0xc436,	0x4211, 0xc436,		0x21, 0
	.dw 0x4213, 0xc436,	0x423f, 0xc436,		0x21, 0
	.dw 0x4241, 0xc436,	0x4241, 0xc436,		0x21, 0
	.dw 0x4243, 0xc436,	0x424f, 0xc436,		0x21, 0
	.dw 0x4251, 0xc436,	0x4251, 0xc436,		0x21, 0
	.dw 0x4253, 0xc436,	0x427f, 0xc436,		0x21, 0
	.dw 0x4281, 0xc436,	0x4281, 0xc436,		0x21, 0
	.dw 0x4283, 0xc436,	0x428f, 0xc436,		0x21, 0
	.dw 0x4291, 0xc436,	0x4291, 0xc436,		0x21, 0
	.dw 0x4293, 0xc436,	0x42bf, 0xc436,		0x21, 0
	.dw 0x42c1, 0xc436,	0x42c1, 0xc436,		0x21, 0
	.dw 0x42c3, 0xc436,	0x42cf, 0xc436,		0x21, 0
	.dw 0x42d1, 0xc436,	0x42d1, 0xc436,		0x21, 0
	.dw 0x42d3, 0xc436,	0x42ff, 0xc436,		0x21, 0
	.dw 0x4301, 0xc436,	0x4301, 0xc436,		0x21, 0
	.dw 0x4303, 0xc436,	0x430f, 0xc436,		0x21, 0
	.dw 0x4311, 0xc436,	0x4311, 0xc436,		0x21, 0
	.dw 0x4313, 0xc436,	0x433f, 0xc436,		0x21, 0
	.dw 0x4341, 0xc436,	0x4341, 0xc436,		0x21, 0
	.dw 0x4343, 0xc436,	0x434f, 0xc436,		0x21, 0
	.dw 0x4351, 0xc436,	0x4351, 0xc436,		0x21, 0
	.dw 0x4353, 0xc436,	0x437f, 0xc436,		0x21, 0
	.dw 0x4381, 0xc436,	0x4381, 0xc436,		0x21, 0
	.dw 0x4383, 0xc436,	0x438f, 0xc436,		0x21, 0
	.dw 0x4391, 0xc436,	0x4391, 0xc436,		0x21, 0
	.dw 0x4393, 0xc436,	0x43bf, 0xc436,		0x21, 0
	.dw 0x43c1, 0xc436,	0x43c1, 0xc436,		0x21, 0
	.dw 0x43c3, 0xc436,	0x43cf, 0xc436,		0x21, 0
	.dw 0x43d1, 0xc436,	0x43d1, 0xc436,		0x21, 0
	.dw 0x43d3, 0xc436,	0x43ff, 0xc436,		0x21, 0
	.dw 0x4401, 0xc436,	0x4401, 0xc436,		0x21, 0
	.dw 0x4403, 0xc436,	0x440f, 0xc436,		0x21, 0
	.dw 0x4411, 0xc436,	0x4411, 0xc436,		0x21, 0
	.dw 0x4413, 0xc436,	0x443f, 0xc436,		0x21, 0
	.dw 0x4441, 0xc436,	0x4441, 0xc436,		0x21, 0
	.dw 0x4443, 0xc436,	0x444f, 0xc436,		0x21, 0
	.dw 0x4451, 0xc436,	0x4451, 0xc436,		0x21, 0
	.dw 0x4453, 0xc436,	0x447f, 0xc436,		0x21, 0
	.dw 0x4481, 0xc436,	0x4481, 0xc436,		0x21, 0
	.dw 0x4483, 0xc436,	0x448f, 0xc436,		0x21, 0
	.dw 0x4491, 0xc436,	0x4491, 0xc436,		0x21, 0
	.dw 0x4493, 0xc436,	0x44bf, 0xc436,		0x21, 0
	.dw 0x44c1, 0xc436,	0x44c1, 0xc436,		0x21, 0
	.dw 0x44c3, 0xc436,	0x44cf, 0xc436,		0x21, 0
	.dw 0x44d1, 0xc436,	0x44d1, 0xc436,		0x21, 0
	.dw 0x44d3, 0xc436,	0x44ff, 0xc436,		0x21, 0
	.dw 0x4501, 0xc436,	0x4501, 0xc436,		0x21, 0
	.dw 0x4503, 0xc436,	0x450f, 0xc436,		0x21, 0
	.dw 0x4511, 0xc436,	0x4511, 0xc436,		0x21, 0
	.dw 0x4513, 0xc436,	0x453f, 0xc436,		0x21, 0
	.dw 0x4541, 0xc436,	0x4541, 0xc436,		0x21, 0
	.dw 0x4543, 0xc436,	0x454f, 0xc436,		0x21, 0
	.dw 0x4551, 0xc436,	0x4551, 0xc436,		0x21, 0
	.dw 0x4553, 0xc436,	0x457f, 0xc436,		0x21, 0
	.dw 0x4581, 0xc436,	0x4581, 0xc436,		0x21, 0
	.dw 0x4583, 0xc436,	0x458f, 0xc436,		0x21, 0
	.dw 0x4591, 0xc436,	0x4591, 0xc436,		0x21, 0
	.dw 0x4593, 0xc436,	0x45bf, 0xc436,		0x21, 0
	.dw 0x45c1, 0xc436,	0x45c1, 0xc436,		0x21, 0
	.dw 0x45c3, 0xc436,	0x45cf, 0xc436,		0x21, 0
	.dw 0x45d1, 0xc436,	0x45d1, 0xc436,		0x21, 0
	.dw 0x45d3, 0xc436,	0x45ff, 0xc436,		0x21, 0
	.dw 0x4601, 0xc436,	0x4601, 0xc436,		0x21, 0
	.dw 0x4603, 0xc436,	0x460f, 0xc436,		0x21, 0
	.dw 0x4611, 0xc436,	0x4611, 0xc436,		0x21, 0
	.dw 0x4613, 0xc436,	0x463f, 0xc436,		0x21, 0
	.dw 0x4641, 0xc436,	0x4641, 0xc436,		0x21, 0
	.dw 0x4643, 0xc436,	0x464f, 0xc436,		0x21, 0
	.dw 0x4651, 0xc436,	0x4651, 0xc436,		0x21, 0
	.dw 0x4653, 0xc436,	0x467f, 0xc436,		0x21, 0
	.dw 0x4681, 0xc436,	0x4681, 0xc436,		0x21, 0
	.dw 0x4683, 0xc436,	0x468f, 0xc436,		0x21, 0
	.dw 0x4691, 0xc436,	0x4691, 0xc436,		0x21, 0
	.dw 0x4693, 0xc436,	0x46bf, 0xc436,		0x21, 0
	.dw 0x46c1, 0xc436,	0x46c1, 0xc436,		0x21, 0
	.dw 0x46c3, 0xc436,	0x46cf, 0xc436,		0x21, 0
	.dw 0x46d1, 0xc436,	0x46d1, 0xc436,		0x21, 0
	.dw 0x46d3, 0xc436,	0x46ff, 0xc436,		0x21, 0
	.dw 0x4701, 0xc436,	0x4701, 0xc436,		0x21, 0
	.dw 0x4703, 0xc436,	0x470f, 0xc436,		0x21, 0
	.dw 0x4711, 0xc436,	0x4711, 0xc436,		0x21, 0
	.dw 0x4713, 0xc436,	0x473f, 0xc436,		0x21, 0
	.dw 0x4741, 0xc436,	0x4741, 0xc436,		0x21, 0
	.dw 0x4743, 0xc436,	0x474f, 0xc436,		0x21, 0
	.dw 0x4751, 0xc436,	0x4751, 0xc436,		0x21, 0
	.dw 0x4753, 0xc436,	0x477f, 0xc436,		0x21, 0
	.dw 0x4781, 0xc436,	0x4781, 0xc436,		0x21, 0
	.dw 0x4783, 0xc436,	0x478f, 0xc436,		0x21, 0
	.dw 0x4791, 0xc436,	0x4791, 0xc436,		0x21, 0
	.dw 0x4793, 0xc436,	0x47bf, 0xc436,		0x21, 0
	.dw 0x47c1, 0xc436,	0x47c1, 0xc436,		0x21, 0
	.dw 0x47c3, 0xc436,	0x47cf, 0xc436,		0x21, 0
	.dw 0x47d1, 0xc436,	0x47d1, 0xc436,		0x21, 0
	.dw 0x47d3, 0xc436,	0x47ff, 0xc436,		0x21, 0
	.dw 0x4801, 0xc436,	0x4801, 0xc436,		0x21, 0
	.dw 0x4803, 0xc436,	0x480f, 0xc436,		0x21, 0
	.dw 0x4811, 0xc436,	0x4811, 0xc436,		0x21, 0
	.dw 0x4813, 0xc436,	0x483f, 0xc436,		0x21, 0
	.dw 0x4841, 0xc436,	0x4841, 0xc436,		0x21, 0
	.dw 0x4843, 0xc436,	0x484f, 0xc436,		0x21, 0
	.dw 0x4851, 0xc436,	0x4851, 0xc436,		0x21, 0
	.dw 0x4853, 0xc436,	0x487f, 0xc436,		0x21, 0
	.dw 0x4881, 0xc436,	0x4881, 0xc436,		0x21, 0
	.dw 0x4883, 0xc436,	0x488f, 0xc436,		0x21, 0
	.dw 0x4891, 0xc436,	0x4891, 0xc436,		0x21, 0
	.dw 0x4893, 0xc436,	0x48bf, 0xc436,		0x21, 0
	.dw 0x48c1, 0xc436,	0x48c1, 0xc436,		0x21, 0
	.dw 0x48c3, 0xc436,	0x48cf, 0xc436,		0x21, 0
	.dw 0x48d1, 0xc436,	0x48d1, 0xc436,		0x21, 0
	.dw 0x48d3, 0xc436,	0x48ff, 0xc436,		0x21, 0
	.dw 0x4901, 0xc436,	0x4901, 0xc436,		0x21, 0
	.dw 0x4903, 0xc436,	0x490f, 0xc436,		0x21, 0
	.dw 0x4911, 0xc436,	0x4911, 0xc436,		0x21, 0
	.dw 0x4913, 0xc436,	0x493f, 0xc436,		0x21, 0
	.dw 0x4941, 0xc436,	0x4941, 0xc436,		0x21, 0
	.dw 0x4943, 0xc436,	0x494f, 0xc436,		0x21, 0
	.dw 0x4951, 0xc436,	0x4951, 0xc436,		0x21, 0
	.dw 0x4953, 0xc436,	0x497f, 0xc436,		0x21, 0
	.dw 0x4981, 0xc436,	0x4981, 0xc436,		0x21, 0
	.dw 0x4983, 0xc436,	0x498f, 0xc436,		0x21, 0
	.dw 0x4991, 0xc436,	0x4991, 0xc436,		0x21, 0
	.dw 0x4993, 0xc436,	0x49bf, 0xc436,		0x21, 0
	.dw 0x49c1, 0xc436,	0x49c1, 0xc436,		0x21, 0
	.dw 0x49c3, 0xc436,	0x49cf, 0xc436,		0x21, 0
	.dw 0x49d1, 0xc436,	0x49d1, 0xc436,		0x21, 0
	.dw 0x49d3, 0xc436,	0x49ff, 0xc436,		0x21, 0
	.dw 0x4a01, 0xc436,	0x4a01, 0xc436,		0x21, 0
	.dw 0x4a03, 0xc436,	0x4a0f, 0xc436,		0x21, 0
	.dw 0x4a11, 0xc436,	0x4a11, 0xc436,		0x21, 0
	.dw 0x4a13, 0xc436,	0x4a3f, 0xc436,		0x21, 0
	.dw 0x4a41, 0xc436,	0x4a41, 0xc436,		0x21, 0
	.dw 0x4a43, 0xc436,	0x4a4f, 0xc436,		0x21, 0
	.dw 0x4a51, 0xc436,	0x4a51, 0xc436,		0x21, 0
	.dw 0x4a53, 0xc436,	0x4a7f, 0xc436,		0x21, 0
	.dw 0x4a81, 0xc436,	0x4a81, 0xc436,		0x21, 0
	.dw 0x4a83, 0xc436,	0x4a8f, 0xc436,		0x21, 0
	.dw 0x4a91, 0xc436,	0x4a91, 0xc436,		0x21, 0
	.dw 0x4a93, 0xc436,	0x4abf, 0xc436,		0x21, 0
	.dw 0x4ac1, 0xc436,	0x4ac1, 0xc436,		0x21, 0
	.dw 0x4ac3, 0xc436,	0x4acf, 0xc436,		0x21, 0
	.dw 0x4ad1, 0xc436,	0x4ad1, 0xc436,		0x21, 0
	.dw 0x4ad3, 0xc436,	0x4aff, 0xc436,		0x21, 0
	.dw 0x4b01, 0xc436,	0x4b01, 0xc436,		0x21, 0
	.dw 0x4b03, 0xc436,	0x4b0f, 0xc436,		0x21, 0
	.dw 0x4b11, 0xc436,	0x4b11, 0xc436,		0x21, 0
	.dw 0x4b13, 0xc436,	0x4b3f, 0xc436,		0x21, 0
	.dw 0x4b41, 0xc436,	0x4b41, 0xc436,		0x21, 0
	.dw 0x4b43, 0xc436,	0x4b4f, 0xc436,		0x21, 0
	.dw 0x4b51, 0xc436,	0x4b51, 0xc436,		0x21, 0
	.dw 0x4b53, 0xc436,	0x4b7f, 0xc436,		0x21, 0
	.dw 0x4b81, 0xc436,	0x4b81, 0xc436,		0x21, 0
	.dw 0x4b83, 0xc436,	0x4b8f, 0xc436,		0x21, 0
	.dw 0x4b91, 0xc436,	0x4b91, 0xc436,		0x21, 0
	.dw 0x4b93, 0xc436,	0x4bbf, 0xc436,		0x21, 0
	.dw 0x4bc1, 0xc436,	0x4bc1, 0xc436,		0x21, 0
	.dw 0x4bc3, 0xc436,	0x4bcf, 0xc436,		0x21, 0
	.dw 0x4bd1, 0xc436,	0x4bd1, 0xc436,		0x21, 0
	.dw 0x4bd3, 0xc436,	0x4bff, 0xc436,		0x21, 0
	.dw 0x4c01, 0xc436,	0x4c01, 0xc436,		0x21, 0
	.dw 0x4c03, 0xc436,	0x4c0f, 0xc436,		0x21, 0
	.dw 0x4c11, 0xc436,	0x4c11, 0xc436,		0x21, 0
	.dw 0x4c13, 0xc436,	0x4c3f, 0xc436,		0x21, 0
	.dw 0x4c41, 0xc436,	0x4c41, 0xc436,		0x21, 0
	.dw 0x4c43, 0xc436,	0x4c4f, 0xc436,		0x21, 0
	.dw 0x4c51, 0xc436,	0x4c51, 0xc436,		0x21, 0
	.dw 0x4c53, 0xc436,	0x4c7f, 0xc436,		0x21, 0
	.dw 0x4c81, 0xc436,	0x4c81, 0xc436,		0x21, 0
	.dw 0x4c83, 0xc436,	0x4c8f, 0xc436,		0x21, 0
	.dw 0x4c91, 0xc436,	0x4c91, 0xc436,		0x21, 0
	.dw 0x4c93, 0xc436,	0x4cbf, 0xc436,		0x21, 0
	.dw 0x4cc1, 0xc436,	0x4cc1, 0xc436,		0x21, 0
	.dw 0x4cc3, 0xc436,	0x4ccf, 0xc436,		0x21, 0
	.dw 0x4cd1, 0xc436,	0x4cd1, 0xc436,		0x21, 0
	.dw 0x4cd3, 0xc436,	0x4cff, 0xc436,		0x21, 0
	.dw 0x4d01, 0xc436,	0x4d01, 0xc436,		0x21, 0
	.dw 0x4d03, 0xc436,	0x4d0f, 0xc436,		0x21, 0
	.dw 0x4d11, 0xc436,	0x4d11, 0xc436,		0x21, 0
	.dw 0x4d13, 0xc436,	0x4d3f, 0xc436,		0x21, 0
	.dw 0x4d41, 0xc436,	0x4d41, 0xc436,		0x21, 0
	.dw 0x4d43, 0xc436,	0x4d4f, 0xc436,		0x21, 0
	.dw 0x4d51, 0xc436,	0x4d51, 0xc436,		0x21, 0
	.dw 0x4d53, 0xc436,	0x4d7f, 0xc436,		0x21, 0
	.dw 0x4d81, 0xc436,	0x4d81, 0xc436,		0x21, 0
	.dw 0x4d83, 0xc436,	0x4d8f, 0xc436,		0x21, 0
	.dw 0x4d91, 0xc436,	0x4d91, 0xc436,		0x21, 0
	.dw 0x4d93, 0xc436,	0x4dbf, 0xc436,		0x21, 0
	.dw 0x4dc1, 0xc436,	0x4dc1, 0xc436,		0x21, 0
	.dw 0x4dc3, 0xc436,	0x4dcf, 0xc436,		0x21, 0
	.dw 0x4dd1, 0xc436,	0x4dd1, 0xc436,		0x21, 0
	.dw 0x4dd3, 0xc436,	0x4dff, 0xc436,		0x21, 0
	.dw 0x4e01, 0xc436,	0x4e01, 0xc436,		0x21, 0
	.dw 0x4e03, 0xc436,	0x4e0f, 0xc436,		0x21, 0
	.dw 0x4e11, 0xc436,	0x4e11, 0xc436,		0x21, 0
	.dw 0x4e13, 0xc436,	0x4e3f, 0xc436,		0x21, 0
	.dw 0x4e41, 0xc436,	0x4e41, 0xc436,		0x21, 0
	.dw 0x4e43, 0xc436,	0x4e4f, 0xc436,		0x21, 0
	.dw 0x4e51, 0xc436,	0x4e51, 0xc436,		0x21, 0
	.dw 0x4e53, 0xc436,	0x4e7f, 0xc436,		0x21, 0
	.dw 0x4e81, 0xc436,	0x4e81, 0xc436,		0x21, 0
	.dw 0x4e83, 0xc436,	0x4e8f, 0xc436,		0x21, 0
	.dw 0x4e91, 0xc436,	0x4e91, 0xc436,		0x21, 0
	.dw 0x4e93, 0xc436,	0x4ebf, 0xc436,		0x21, 0
	.dw 0x4ec1, 0xc436,	0x4ec1, 0xc436,		0x21, 0
	.dw 0x4ec3, 0xc436,	0x4ecf, 0xc436,		0x21, 0
	.dw 0x4ed1, 0xc436,	0x4ed1, 0xc436,		0x21, 0
	.dw 0x4ed3, 0xc436,	0x4eff, 0xc436,		0x21, 0
	.dw 0x4f01, 0xc436,	0x4f01, 0xc436,		0x21, 0
	.dw 0x4f03, 0xc436,	0x4f0f, 0xc436,		0x21, 0
	.dw 0x4f11, 0xc436,	0x4f11, 0xc436,		0x21, 0
	.dw 0x4f13, 0xc436,	0x4f3f, 0xc436,		0x21, 0
	.dw 0x4f41, 0xc436,	0x4f41, 0xc436,		0x21, 0
	.dw 0x4f43, 0xc436,	0x4f4f, 0xc436,		0x21, 0
	.dw 0x4f51, 0xc436,	0x4f51, 0xc436,		0x21, 0
	.dw 0x4f53, 0xc436,	0x4f7f, 0xc436,		0x21, 0
	.dw 0x4f81, 0xc436,	0x4f81, 0xc436,		0x21, 0
	.dw 0x4f83, 0xc436,	0x4f8f, 0xc436,		0x21, 0
	.dw 0x4f91, 0xc436,	0x4f91, 0xc436,		0x21, 0
	.dw 0x4f93, 0xc436,	0x4fbf, 0xc436,		0x21, 0
	.dw 0x4fc1, 0xc436,	0x4fc1, 0xc436,		0x21, 0
	.dw 0x4fc3, 0xc436,	0x4fcf, 0xc436,		0x21, 0
	.dw 0x4fd1, 0xc436,	0x4fd1, 0xc436,		0x21, 0
	.dw 0x4fd3, 0xc436,	0x5fff, 0xc436,		0x21, 0
	.dw 0x6001, 0xc436,	0x6001, 0xc436,		0x21, 0
	.dw 0x6003, 0xc436,	0x600f, 0xc436,		0x21, 0
	.dw 0x6011, 0xc436,	0x6011, 0xc436,		0x21, 0
	.dw 0x6013, 0xc436,	0x603f, 0xc436,		0x21, 0
	.dw 0x6041, 0xc436,	0x6041, 0xc436,		0x21, 0
	.dw 0x6043, 0xc436,	0x604f, 0xc436,		0x21, 0
	.dw 0x6051, 0xc436,	0x6051, 0xc436,		0x21, 0
	.dw 0x6053, 0xc436,	0x607f, 0xc436,		0x21, 0
	.dw 0x6081, 0xc436,	0x6081, 0xc436,		0x21, 0
	.dw 0x6083, 0xc436,	0x608f, 0xc436,		0x21, 0
	.dw 0x6091, 0xc436,	0x6091, 0xc436,		0x21, 0
	.dw 0x6093, 0xc436,	0x60bf, 0xc436,		0x21, 0
	.dw 0x60c1, 0xc436,	0x60c1, 0xc436,		0x21, 0
	.dw 0x60c3, 0xc436,	0x60cf, 0xc436,		0x21, 0
	.dw 0x60d1, 0xc436,	0x60d1, 0xc436,		0x21, 0
	.dw 0x60d3, 0xc436,	0x60ff, 0xc436,		0x21, 0
	.dw 0x6101, 0xc436,	0x6101, 0xc436,		0x21, 0
	.dw 0x6103, 0xc436,	0x610f, 0xc436,		0x21, 0
	.dw 0x6111, 0xc436,	0x6111, 0xc436,		0x21, 0
	.dw 0x6113, 0xc436,	0x613f, 0xc436,		0x21, 0
	.dw 0x6141, 0xc436,	0x6141, 0xc436,		0x21, 0
	.dw 0x6143, 0xc436,	0x614f, 0xc436,		0x21, 0
	.dw 0x6151, 0xc436,	0x6151, 0xc436,		0x21, 0
	.dw 0x6153, 0xc436,	0x617f, 0xc436,		0x21, 0
	.dw 0x6181, 0xc436,	0x6181, 0xc436,		0x21, 0
	.dw 0x6183, 0xc436,	0x618f, 0xc436,		0x21, 0
	.dw 0x6191, 0xc436,	0x6191, 0xc436,		0x21, 0
	.dw 0x6193, 0xc436,	0x61bf, 0xc436,		0x21, 0
	.dw 0x61c1, 0xc436,	0x61c1, 0xc436,		0x21, 0
	.dw 0x61c3, 0xc436,	0x61cf, 0xc436,		0x21, 0
	.dw 0x61d1, 0xc436,	0x61d1, 0xc436,		0x21, 0
	.dw 0x61d3, 0xc436,	0x61ff, 0xc436,		0x21, 0
	.dw 0x6201, 0xc436,	0x6201, 0xc436,		0x21, 0
	.dw 0x6203, 0xc436,	0x620f, 0xc436,		0x21, 0
	.dw 0x6211, 0xc436,	0x6211, 0xc436,		0x21, 0
	.dw 0x6213, 0xc436,	0x623f, 0xc436,		0x21, 0
	.dw 0x6241, 0xc436,	0x6241, 0xc436,		0x21, 0
	.dw 0x6243, 0xc436,	0x624f, 0xc436,		0x21, 0
	.dw 0x6251, 0xc436,	0x6251, 0xc436,		0x21, 0
	.dw 0x6253, 0xc436,	0x627f, 0xc436,		0x21, 0
	.dw 0x6281, 0xc436,	0x6281, 0xc436,		0x21, 0
	.dw 0x6283, 0xc436,	0x628f, 0xc436,		0x21, 0
	.dw 0x6291, 0xc436,	0x6291, 0xc436,		0x21, 0
	.dw 0x6293, 0xc436,	0x62bf, 0xc436,		0x21, 0
	.dw 0x62c1, 0xc436,	0x62c1, 0xc436,		0x21, 0
	.dw 0x62c3, 0xc436,	0x62cf, 0xc436,		0x21, 0
	.dw 0x62d1, 0xc436,	0x62d1, 0xc436,		0x21, 0
	.dw 0x62d3, 0xc436,	0x62ff, 0xc436,		0x21, 0
	.dw 0x6301, 0xc436,	0x6301, 0xc436,		0x21, 0
	.dw 0x6303, 0xc436,	0x630f, 0xc436,		0x21, 0
	.dw 0x6311, 0xc436,	0x6311, 0xc436,		0x21, 0
	.dw 0x6313, 0xc436,	0x633f, 0xc436,		0x21, 0
	.dw 0x6341, 0xc436,	0x6341, 0xc436,		0x21, 0
	.dw 0x6343, 0xc436,	0x634f, 0xc436,		0x21, 0
	.dw 0x6351, 0xc436,	0x6351, 0xc436,		0x21, 0
	.dw 0x6353, 0xc436,	0x637f, 0xc436,		0x21, 0
	.dw 0x6381, 0xc436,	0x6381, 0xc436,		0x21, 0
	.dw 0x6383, 0xc436,	0x638f, 0xc436,		0x21, 0
	.dw 0x6391, 0xc436,	0x6391, 0xc436,		0x21, 0
	.dw 0x6393, 0xc436,	0x63bf, 0xc436,		0x21, 0
	.dw 0x63c1, 0xc436,	0x63c1, 0xc436,		0x21, 0
	.dw 0x63c3, 0xc436,	0x63cf, 0xc436,		0x21, 0
	.dw 0x63d1, 0xc436,	0x63d1, 0xc436,		0x21, 0
	.dw 0x63d3, 0xc436,	0x63ff, 0xc436,		0x21, 0
	.dw 0x6401, 0xc436,	0x6401, 0xc436,		0x21, 0
	.dw 0x6403, 0xc436,	0x640f, 0xc436,		0x21, 0
	.dw 0x6411, 0xc436,	0x6411, 0xc436,		0x21, 0
	.dw 0x6413, 0xc436,	0x643f, 0xc436,		0x21, 0
	.dw 0x6441, 0xc436,	0x6441, 0xc436,		0x21, 0
	.dw 0x6443, 0xc436,	0x644f, 0xc436,		0x21, 0
	.dw 0x6451, 0xc436,	0x6451, 0xc436,		0x21, 0
	.dw 0x6453, 0xc436,	0x647f, 0xc436,		0x21, 0
	.dw 0x6481, 0xc436,	0x6481, 0xc436,		0x21, 0
	.dw 0x6483, 0xc436,	0x648f, 0xc436,		0x21, 0
	.dw 0x6491, 0xc436,	0x6491, 0xc436,		0x21, 0
	.dw 0x6493, 0xc436,	0x64bf, 0xc436,		0x21, 0
	.dw 0x64c1, 0xc436,	0x64c1, 0xc436,		0x21, 0
	.dw 0x64c3, 0xc436,	0x64cf, 0xc436,		0x21, 0
	.dw 0x64d1, 0xc436,	0x64d1, 0xc436,		0x21, 0
	.dw 0x64d3, 0xc436,	0x64ff, 0xc436,		0x21, 0
	.dw 0x6501, 0xc436,	0x6501, 0xc436,		0x21, 0
	.dw 0x6503, 0xc436,	0x650f, 0xc436,		0x21, 0
	.dw 0x6511, 0xc436,	0x6511, 0xc436,		0x21, 0
	.dw 0x6513, 0xc436,	0x653f, 0xc436,		0x21, 0
	.dw 0x6541, 0xc436,	0x6541, 0xc436,		0x21, 0
	.dw 0x6543, 0xc436,	0x654f, 0xc436,		0x21, 0
	.dw 0x6551, 0xc436,	0x6551, 0xc436,		0x21, 0
	.dw 0x6553, 0xc436,	0x657f, 0xc436,		0x21, 0
	.dw 0x6581, 0xc436,	0x6581, 0xc436,		0x21, 0
	.dw 0x6583, 0xc436,	0x658f, 0xc436,		0x21, 0
	.dw 0x6591, 0xc436,	0x6591, 0xc436,		0x21, 0
	.dw 0x6593, 0xc436,	0x65bf, 0xc436,		0x21, 0
	.dw 0x65c1, 0xc436,	0x65c1, 0xc436,		0x21, 0
	.dw 0x65c3, 0xc436,	0x65cf, 0xc436,		0x21, 0
	.dw 0x65d1, 0xc436,	0x65d1, 0xc436,		0x21, 0
	.dw 0x65d3, 0xc436,	0x65ff, 0xc436,		0x21, 0
	.dw 0x6601, 0xc436,	0x6601, 0xc436,		0x21, 0
	.dw 0x6603, 0xc436,	0x660f, 0xc436,		0x21, 0
	.dw 0x6611, 0xc436,	0x6611, 0xc436,		0x21, 0
	.dw 0x6613, 0xc436,	0x663f, 0xc436,		0x21, 0
	.dw 0x6641, 0xc436,	0x6641, 0xc436,		0x21, 0
	.dw 0x6643, 0xc436,	0x664f, 0xc436,		0x21, 0
	.dw 0x6651, 0xc436,	0x6651, 0xc436,		0x21, 0
	.dw 0x6653, 0xc436,	0x667f, 0xc436,		0x21, 0
	.dw 0x6681, 0xc436,	0x6681, 0xc436,		0x21, 0
	.dw 0x6683, 0xc436,	0x668f, 0xc436,		0x21, 0
	.dw 0x6691, 0xc436,	0x6691, 0xc436,		0x21, 0
	.dw 0x6693, 0xc436,	0x66bf, 0xc436,		0x21, 0
	.dw 0x66c1, 0xc436,	0x66c1, 0xc436,		0x21, 0
	.dw 0x66c3, 0xc436,	0x66cf, 0xc436,		0x21, 0
	.dw 0x66d1, 0xc436,	0x66d1, 0xc436,		0x21, 0
	.dw 0x66d3, 0xc436,	0x66ff, 0xc436,		0x21, 0
	.dw 0x6701, 0xc436,	0x6701, 0xc436,		0x21, 0
	.dw 0x6703, 0xc436,	0x670f, 0xc436,		0x21, 0
	.dw 0x6711, 0xc436,	0x6711, 0xc436,		0x21, 0
	.dw 0x6713, 0xc436,	0x673f, 0xc436,		0x21, 0
	.dw 0x6741, 0xc436,	0x6741, 0xc436,		0x21, 0
	.dw 0x6743, 0xc436,	0x674f, 0xc436,		0x21, 0
	.dw 0x6751, 0xc436,	0x6751, 0xc436,		0x21, 0
	.dw 0x6753, 0xc436,	0x677f, 0xc436,		0x21, 0
	.dw 0x6781, 0xc436,	0x6781, 0xc436,		0x21, 0
	.dw 0x6783, 0xc436,	0x678f, 0xc436,		0x21, 0
	.dw 0x6791, 0xc436,	0x6791, 0xc436,		0x21, 0
	.dw 0x6793, 0xc436,	0x67bf, 0xc436,		0x21, 0
	.dw 0x67c1, 0xc436,	0x67c1, 0xc436,		0x21, 0
	.dw 0x67c3, 0xc436,	0x67cf, 0xc436,		0x21, 0
	.dw 0x67d1, 0xc436,	0x67d1, 0xc436,		0x21, 0
	.dw 0x67d3, 0xc436,	0x67ff, 0xc436,		0x21, 0
	.dw 0x6801, 0xc436,	0x6801, 0xc436,		0x21, 0
	.dw 0x6803, 0xc436,	0x680f, 0xc436,		0x21, 0
	.dw 0x6811, 0xc436,	0x6811, 0xc436,		0x21, 0
	.dw 0x6813, 0xc436,	0x683f, 0xc436,		0x21, 0
	.dw 0x6841, 0xc436,	0x6841, 0xc436,		0x21, 0
	.dw 0x6843, 0xc436,	0x684f, 0xc436,		0x21, 0
	.dw 0x6851, 0xc436,	0x6851, 0xc436,		0x21, 0
	.dw 0x6853, 0xc436,	0x687f, 0xc436,		0x21, 0
	.dw 0x6881, 0xc436,	0x6881, 0xc436,		0x21, 0
	.dw 0x6883, 0xc436,	0x688f, 0xc436,		0x21, 0
	.dw 0x6891, 0xc436,	0x6891, 0xc436,		0x21, 0
	.dw 0x6893, 0xc436,	0x68bf, 0xc436,		0x21, 0
	.dw 0x68c1, 0xc436,	0x68c1, 0xc436,		0x21, 0
	.dw 0x68c3, 0xc436,	0x68cf, 0xc436,		0x21, 0
	.dw 0x68d1, 0xc436,	0x68d1, 0xc436,		0x21, 0
	.dw 0x68d3, 0xc436,	0x68ff, 0xc436,		0x21, 0
	.dw 0x6901, 0xc436,	0x6901, 0xc436,		0x21, 0
	.dw 0x6903, 0xc436,	0x690f, 0xc436,		0x21, 0
	.dw 0x6911, 0xc436,	0x6911, 0xc436,		0x21, 0
	.dw 0x6913, 0xc436,	0x693f, 0xc436,		0x21, 0
	.dw 0x6941, 0xc436,	0x6941, 0xc436,		0x21, 0
	.dw 0x6943, 0xc436,	0x694f, 0xc436,		0x21, 0
	.dw 0x6951, 0xc436,	0x6951, 0xc436,		0x21, 0
	.dw 0x6953, 0xc436,	0x697f, 0xc436,		0x21, 0
	.dw 0x6981, 0xc436,	0x6981, 0xc436,		0x21, 0
	.dw 0x6983, 0xc436,	0x698f, 0xc436,		0x21, 0
	.dw 0x6991, 0xc436,	0x6991, 0xc436,		0x21, 0
	.dw 0x6993, 0xc436,	0x69bf, 0xc436,		0x21, 0
	.dw 0x69c1, 0xc436,	0x69c1, 0xc436,		0x21, 0
	.dw 0x69c3, 0xc436,	0x69cf, 0xc436,		0x21, 0
	.dw 0x69d1, 0xc436,	0x69d1, 0xc436,		0x21, 0
	.dw 0x69d3, 0xc436,	0x69ff, 0xc436,		0x21, 0
	.dw 0x6a01, 0xc436,	0x6a01, 0xc436,		0x21, 0
	.dw 0x6a03, 0xc436,	0x6a0f, 0xc436,		0x21, 0
	.dw 0x6a11, 0xc436,	0x6a11, 0xc436,		0x21, 0
	.dw 0x6a13, 0xc436,	0x6a3f, 0xc436,		0x21, 0
	.dw 0x6a41, 0xc436,	0x6a41, 0xc436,		0x21, 0
	.dw 0x6a43, 0xc436,	0x6a4f, 0xc436,		0x21, 0
	.dw 0x6a51, 0xc436,	0x6a51, 0xc436,		0x21, 0
	.dw 0x6a53, 0xc436,	0x6a7f, 0xc436,		0x21, 0
	.dw 0x6a81, 0xc436,	0x6a81, 0xc436,		0x21, 0
	.dw 0x6a83, 0xc436,	0x6a8f, 0xc436,		0x21, 0
	.dw 0x6a91, 0xc436,	0x6a91, 0xc436,		0x21, 0
	.dw 0x6a93, 0xc436,	0x6abf, 0xc436,		0x21, 0
	.dw 0x6ac1, 0xc436,	0x6ac1, 0xc436,		0x21, 0
	.dw 0x6ac3, 0xc436,	0x6acf, 0xc436,		0x21, 0
	.dw 0x6ad1, 0xc436,	0x6ad1, 0xc436,		0x21, 0
	.dw 0x6ad3, 0xc436,	0x6aff, 0xc436,		0x21, 0
	.dw 0x6b01, 0xc436,	0x6b01, 0xc436,		0x21, 0
	.dw 0x6b03, 0xc436,	0x6b0f, 0xc436,		0x21, 0
	.dw 0x6b11, 0xc436,	0x6b11, 0xc436,		0x21, 0
	.dw 0x6b13, 0xc436,	0x6b3f, 0xc436,		0x21, 0
	.dw 0x6b41, 0xc436,	0x6b41, 0xc436,		0x21, 0
	.dw 0x6b43, 0xc436,	0x6b4f, 0xc436,		0x21, 0
	.dw 0x6b51, 0xc436,	0x6b51, 0xc436,		0x21, 0
	.dw 0x6b53, 0xc436,	0x6b7f, 0xc436,		0x21, 0
	.dw 0x6b81, 0xc436,	0x6b81, 0xc436,		0x21, 0
	.dw 0x6b83, 0xc436,	0x6b8f, 0xc436,		0x21, 0
	.dw 0x6b91, 0xc436,	0x6b91, 0xc436,		0x21, 0
	.dw 0x6b93, 0xc436,	0x6bbf, 0xc436,		0x21, 0
	.dw 0x6bc1, 0xc436,	0x6bc1, 0xc436,		0x21, 0
	.dw 0x6bc3, 0xc436,	0x6bcf, 0xc436,		0x21, 0
	.dw 0x6bd1, 0xc436,	0x6bd1, 0xc436,		0x21, 0
	.dw 0x6bd3, 0xc436,	0x6bff, 0xc436,		0x21, 0
	.dw 0x6c01, 0xc436,	0x6c01, 0xc436,		0x21, 0
	.dw 0x6c03, 0xc436,	0x6c0f, 0xc436,		0x21, 0
	.dw 0x6c11, 0xc436,	0x6c11, 0xc436,		0x21, 0
	.dw 0x6c13, 0xc436,	0x6c3f, 0xc436,		0x21, 0
	.dw 0x6c41, 0xc436,	0x6c41, 0xc436,		0x21, 0
	.dw 0x6c43, 0xc436,	0x6c4f, 0xc436,		0x21, 0
	.dw 0x6c51, 0xc436,	0x6c51, 0xc436,		0x21, 0
	.dw 0x6c53, 0xc436,	0x6c7f, 0xc436,		0x21, 0
	.dw 0x6c81, 0xc436,	0x6c81, 0xc436,		0x21, 0
	.dw 0x6c83, 0xc436,	0x6c8f, 0xc436,		0x21, 0
	.dw 0x6c91, 0xc436,	0x6c91, 0xc436,		0x21, 0
	.dw 0x6c93, 0xc436,	0x6cbf, 0xc436,		0x21, 0
	.dw 0x6cc1, 0xc436,	0x6cc1, 0xc436,		0x21, 0
	.dw 0x6cc3, 0xc436,	0x6ccf, 0xc436,		0x21, 0
	.dw 0x6cd1, 0xc436,	0x6cd1, 0xc436,		0x21, 0
	.dw 0x6cd3, 0xc436,	0x6cff, 0xc436,		0x21, 0
	.dw 0x6d01, 0xc436,	0x6d01, 0xc436,		0x21, 0
	.dw 0x6d03, 0xc436,	0x6d0f, 0xc436,		0x21, 0
	.dw 0x6d11, 0xc436,	0x6d11, 0xc436,		0x21, 0
	.dw 0x6d13, 0xc436,	0x6d3f, 0xc436,		0x21, 0
	.dw 0x6d41, 0xc436,	0x6d41, 0xc436,		0x21, 0
	.dw 0x6d43, 0xc436,	0x6d4f, 0xc436,		0x21, 0
	.dw 0x6d51, 0xc436,	0x6d51, 0xc436,		0x21, 0
	.dw 0x6d53, 0xc436,	0x6d7f, 0xc436,		0x21, 0
	.dw 0x6d81, 0xc436,	0x6d81, 0xc436,		0x21, 0
	.dw 0x6d83, 0xc436,	0x6d8f, 0xc436,		0x21, 0
	.dw 0x6d91, 0xc436,	0x6d91, 0xc436,		0x21, 0
	.dw 0x6d93, 0xc436,	0x6dbf, 0xc436,		0x21, 0
	.dw 0x6dc1, 0xc436,	0x6dc1, 0xc436,		0x21, 0
	.dw 0x6dc3, 0xc436,	0x6dcf, 0xc436,		0x21, 0
	.dw 0x6dd1, 0xc436,	0x6dd1, 0xc436,		0x21, 0
	.dw 0x6dd3, 0xc436,	0x6dff, 0xc436,		0x21, 0
	.dw 0x6e01, 0xc436,	0x6e01, 0xc436,		0x21, 0
	.dw 0x6e03, 0xc436,	0x6e0f, 0xc436,		0x21, 0
	.dw 0x6e11, 0xc436,	0x6e11, 0xc436,		0x21, 0
	.dw 0x6e13, 0xc436,	0x6e3f, 0xc436,		0x21, 0
	.dw 0x6e41, 0xc436,	0x6e41, 0xc436,		0x21, 0
	.dw 0x6e43, 0xc436,	0x6e4f, 0xc436,		0x21, 0
	.dw 0x6e51, 0xc436,	0x6e51, 0xc436,		0x21, 0
	.dw 0x6e53, 0xc436,	0x6e7f, 0xc436,		0x21, 0
	.dw 0x6e81, 0xc436,	0x6e81, 0xc436,		0x21, 0
	.dw 0x6e83, 0xc436,	0x6e8f, 0xc436,		0x21, 0
	.dw 0x6e91, 0xc436,	0x6e91, 0xc436,		0x21, 0
	.dw 0x6e93, 0xc436,	0x6ebf, 0xc436,		0x21, 0
	.dw 0x6ec1, 0xc436,	0x6ec1, 0xc436,		0x21, 0
	.dw 0x6ec3, 0xc436,	0x6ecf, 0xc436,		0x21, 0
	.dw 0x6ed1, 0xc436,	0x6ed1, 0xc436,		0x21, 0
	.dw 0x6ed3, 0xc436,	0x6eff, 0xc436,		0x21, 0
	.dw 0x6f01, 0xc436,	0x6f01, 0xc436,		0x21, 0
	.dw 0x6f03, 0xc436,	0x6f0f, 0xc436,		0x21, 0
	.dw 0x6f11, 0xc436,	0x6f11, 0xc436,		0x21, 0
	.dw 0x6f13, 0xc436,	0x6f3f, 0xc436,		0x21, 0
	.dw 0x6f41, 0xc436,	0x6f41, 0xc436,		0x21, 0
	.dw 0x6f43, 0xc436,	0x6f4f, 0xc436,		0x21, 0
	.dw 0x6f51, 0xc436,	0x6f51, 0xc436,		0x21, 0
	.dw 0x6f53, 0xc436,	0x6f7f, 0xc436,		0x21, 0
	.dw 0x6f81, 0xc436,	0x6f81, 0xc436,		0x21, 0
	.dw 0x6f83, 0xc436,	0x6f8f, 0xc436,		0x21, 0
	.dw 0x6f91, 0xc436,	0x6f91, 0xc436,		0x21, 0
	.dw 0x6f93, 0xc436,	0x6fbf, 0xc436,		0x21, 0
	.dw 0x6fc1, 0xc436,	0x6fc1, 0xc436,		0x21, 0
	.dw 0x6fc3, 0xc436,	0x6fcf, 0xc436,		0x21, 0
	.dw 0x6fd1, 0xc436,	0x6fd1, 0xc436,		0x21, 0
	.dw 0x6fd3, 0xc436,	0xffff, 0xc436,		0x21, 0
	.dw 0x0001, 0xc437,	0x0001, 0xc437,		0x21, 0
	.dw 0x0003, 0xc437,	0x000f, 0xc437,		0x21, 0
	.dw 0x0011, 0xc437,	0x0011, 0xc437,		0x21, 0
	.dw 0x0013, 0xc437,	0x003f, 0xc437,		0x21, 0
	.dw 0x0041, 0xc437,	0x0041, 0xc437,		0x21, 0
	.dw 0x0043, 0xc437,	0x004f, 0xc437,		0x21, 0
	.dw 0x0051, 0xc437,	0x0051, 0xc437,		0x21, 0
	.dw 0x0053, 0xc437,	0x007f, 0xc437,		0x21, 0
	.dw 0x0081, 0xc437,	0x0081, 0xc437,		0x21, 0
	.dw 0x0083, 0xc437,	0x008f, 0xc437,		0x21, 0
	.dw 0x0091, 0xc437,	0x0091, 0xc437,		0x21, 0
	.dw 0x0093, 0xc437,	0x00bf, 0xc437,		0x21, 0
	.dw 0x00c1, 0xc437,	0x00c1, 0xc437,		0x21, 0
	.dw 0x00c3, 0xc437,	0x00cf, 0xc437,		0x21, 0
	.dw 0x00d1, 0xc437,	0x00d1, 0xc437,		0x21, 0
	.dw 0x00d3, 0xc437,	0x00ff, 0xc437,		0x21, 0
	.dw 0x0101, 0xc437,	0x0101, 0xc437,		0x21, 0
	.dw 0x0103, 0xc437,	0x010f, 0xc437,		0x21, 0
	.dw 0x0111, 0xc437,	0x0111, 0xc437,		0x21, 0
	.dw 0x0113, 0xc437,	0x013f, 0xc437,		0x21, 0
	.dw 0x0141, 0xc437,	0x0141, 0xc437,		0x21, 0
	.dw 0x0143, 0xc437,	0x014f, 0xc437,		0x21, 0
	.dw 0x0151, 0xc437,	0x0151, 0xc437,		0x21, 0
	.dw 0x0153, 0xc437,	0x017f, 0xc437,		0x21, 0
	.dw 0x0181, 0xc437,	0x0181, 0xc437,		0x21, 0
	.dw 0x0183, 0xc437,	0x018f, 0xc437,		0x21, 0
	.dw 0x0191, 0xc437,	0x0191, 0xc437,		0x21, 0
	.dw 0x0193, 0xc437,	0x01bf, 0xc437,		0x21, 0
	.dw 0x01c1, 0xc437,	0x01c1, 0xc437,		0x21, 0
	.dw 0x01c3, 0xc437,	0x01cf, 0xc437,		0x21, 0
	.dw 0x01d1, 0xc437,	0x01d1, 0xc437,		0x21, 0
	.dw 0x01d3, 0xc437,	0x01ff, 0xc437,		0x21, 0
	.dw 0x0201, 0xc437,	0x0201, 0xc437,		0x21, 0
	.dw 0x0203, 0xc437,	0x020f, 0xc437,		0x21, 0
	.dw 0x0211, 0xc437,	0x0211, 0xc437,		0x21, 0
	.dw 0x0213, 0xc437,	0x023f, 0xc437,		0x21, 0
	.dw 0x0241, 0xc437,	0x0241, 0xc437,		0x21, 0
	.dw 0x0243, 0xc437,	0x024f, 0xc437,		0x21, 0
	.dw 0x0251, 0xc437,	0x0251, 0xc437,		0x21, 0
	.dw 0x0253, 0xc437,	0x027f, 0xc437,		0x21, 0
	.dw 0x0281, 0xc437,	0x0281, 0xc437,		0x21, 0
	.dw 0x0283, 0xc437,	0x028f, 0xc437,		0x21, 0
	.dw 0x0291, 0xc437,	0x0291, 0xc437,		0x21, 0
	.dw 0x0293, 0xc437,	0x02bf, 0xc437,		0x21, 0
	.dw 0x02c1, 0xc437,	0x02c1, 0xc437,		0x21, 0
	.dw 0x02c3, 0xc437,	0x02cf, 0xc437,		0x21, 0
	.dw 0x02d1, 0xc437,	0x02d1, 0xc437,		0x21, 0
	.dw 0x02d3, 0xc437,	0x02ff, 0xc437,		0x21, 0
	.dw 0x0301, 0xc437,	0x0301, 0xc437,		0x21, 0
	.dw 0x0303, 0xc437,	0x030f, 0xc437,		0x21, 0
	.dw 0x0311, 0xc437,	0x0311, 0xc437,		0x21, 0
	.dw 0x0313, 0xc437,	0x033f, 0xc437,		0x21, 0
	.dw 0x0341, 0xc437,	0x0341, 0xc437,		0x21, 0
	.dw 0x0343, 0xc437,	0x034f, 0xc437,		0x21, 0
	.dw 0x0351, 0xc437,	0x0351, 0xc437,		0x21, 0
	.dw 0x0353, 0xc437,	0x037f, 0xc437,		0x21, 0
	.dw 0x0381, 0xc437,	0x0381, 0xc437,		0x21, 0
	.dw 0x0383, 0xc437,	0x038f, 0xc437,		0x21, 0
	.dw 0x0391, 0xc437,	0x0391, 0xc437,		0x21, 0
	.dw 0x0393, 0xc437,	0x03bf, 0xc437,		0x21, 0
	.dw 0x03c1, 0xc437,	0x03c1, 0xc437,		0x21, 0
	.dw 0x03c3, 0xc437,	0x03cf, 0xc437,		0x21, 0
	.dw 0x03d1, 0xc437,	0x03d1, 0xc437,		0x21, 0
	.dw 0x03d3, 0xc437,	0x03ff, 0xc437,		0x21, 0
	.dw 0x0401, 0xc437,	0x0401, 0xc437,		0x21, 0
	.dw 0x0403, 0xc437,	0x040f, 0xc437,		0x21, 0
	.dw 0x0411, 0xc437,	0x0411, 0xc437,		0x21, 0
	.dw 0x0413, 0xc437,	0x043f, 0xc437,		0x21, 0
	.dw 0x0441, 0xc437,	0x0441, 0xc437,		0x21, 0
	.dw 0x0443, 0xc437,	0x044f, 0xc437,		0x21, 0
	.dw 0x0451, 0xc437,	0x0451, 0xc437,		0x21, 0
	.dw 0x0453, 0xc437,	0x047f, 0xc437,		0x21, 0
	.dw 0x0481, 0xc437,	0x0481, 0xc437,		0x21, 0
	.dw 0x0483, 0xc437,	0x048f, 0xc437,		0x21, 0
	.dw 0x0491, 0xc437,	0x0491, 0xc437,		0x21, 0
	.dw 0x0493, 0xc437,	0x04bf, 0xc437,		0x21, 0
	.dw 0x04c1, 0xc437,	0x04c1, 0xc437,		0x21, 0
	.dw 0x04c3, 0xc437,	0x04cf, 0xc437,		0x21, 0
	.dw 0x04d1, 0xc437,	0x04d1, 0xc437,		0x21, 0
	.dw 0x04d3, 0xc437,	0x04ff, 0xc437,		0x21, 0
	.dw 0x0501, 0xc437,	0x0501, 0xc437,		0x21, 0
	.dw 0x0503, 0xc437,	0x050f, 0xc437,		0x21, 0
	.dw 0x0511, 0xc437,	0x0511, 0xc437,		0x21, 0
	.dw 0x0513, 0xc437,	0x053f, 0xc437,		0x21, 0
	.dw 0x0541, 0xc437,	0x0541, 0xc437,		0x21, 0
	.dw 0x0543, 0xc437,	0x054f, 0xc437,		0x21, 0
	.dw 0x0551, 0xc437,	0x0551, 0xc437,		0x21, 0
	.dw 0x0553, 0xc437,	0x057f, 0xc437,		0x21, 0
	.dw 0x0581, 0xc437,	0x0581, 0xc437,		0x21, 0
	.dw 0x0583, 0xc437,	0x058f, 0xc437,		0x21, 0
	.dw 0x0591, 0xc437,	0x0591, 0xc437,		0x21, 0
	.dw 0x0593, 0xc437,	0x05bf, 0xc437,		0x21, 0
	.dw 0x05c1, 0xc437,	0x05c1, 0xc437,		0x21, 0
	.dw 0x05c3, 0xc437,	0x05cf, 0xc437,		0x21, 0
	.dw 0x05d1, 0xc437,	0x05d1, 0xc437,		0x21, 0
	.dw 0x05d3, 0xc437,	0x05ff, 0xc437,		0x21, 0
	.dw 0x0601, 0xc437,	0x0601, 0xc437,		0x21, 0
	.dw 0x0603, 0xc437,	0x060f, 0xc437,		0x21, 0
	.dw 0x0611, 0xc437,	0x0611, 0xc437,		0x21, 0
	.dw 0x0613, 0xc437,	0x063f, 0xc437,		0x21, 0
	.dw 0x0641, 0xc437,	0x0641, 0xc437,		0x21, 0
	.dw 0x0643, 0xc437,	0x064f, 0xc437,		0x21, 0
	.dw 0x0651, 0xc437,	0x0651, 0xc437,		0x21, 0
	.dw 0x0653, 0xc437,	0x067f, 0xc437,		0x21, 0
	.dw 0x0681, 0xc437,	0x0681, 0xc437,		0x21, 0
	.dw 0x0683, 0xc437,	0x068f, 0xc437,		0x21, 0
	.dw 0x0691, 0xc437,	0x0691, 0xc437,		0x21, 0
	.dw 0x0693, 0xc437,	0x06bf, 0xc437,		0x21, 0
	.dw 0x06c1, 0xc437,	0x06c1, 0xc437,		0x21, 0
	.dw 0x06c3, 0xc437,	0x06cf, 0xc437,		0x21, 0
	.dw 0x06d1, 0xc437,	0x06d1, 0xc437,		0x21, 0
	.dw 0x06d3, 0xc437,	0x06ff, 0xc437,		0x21, 0
	.dw 0x0701, 0xc437,	0x0701, 0xc437,		0x21, 0
	.dw 0x0703, 0xc437,	0x070f, 0xc437,		0x21, 0
	.dw 0x0711, 0xc437,	0x0711, 0xc437,		0x21, 0
	.dw 0x0713, 0xc437,	0x073f, 0xc437,		0x21, 0
	.dw 0x0741, 0xc437,	0x0741, 0xc437,		0x21, 0
	.dw 0x0743, 0xc437,	0x074f, 0xc437,		0x21, 0
	.dw 0x0751, 0xc437,	0x0751, 0xc437,		0x21, 0
	.dw 0x0753, 0xc437,	0x077f, 0xc437,		0x21, 0
	.dw 0x0781, 0xc437,	0x0781, 0xc437,		0x21, 0
	.dw 0x0783, 0xc437,	0x078f, 0xc437,		0x21, 0
	.dw 0x0791, 0xc437,	0x0791, 0xc437,		0x21, 0
	.dw 0x0793, 0xc437,	0x07bf, 0xc437,		0x21, 0
	.dw 0x07c1, 0xc437,	0x07c1, 0xc437,		0x21, 0
	.dw 0x07c3, 0xc437,	0x07cf, 0xc437,		0x21, 0
	.dw 0x07d1, 0xc437,	0x07d1, 0xc437,		0x21, 0
	.dw 0x07d3, 0xc437,	0x07ff, 0xc437,		0x21, 0
	.dw 0x0801, 0xc437,	0x0801, 0xc437,		0x21, 0
	.dw 0x0803, 0xc437,	0x080f, 0xc437,		0x21, 0
	.dw 0x0811, 0xc437,	0x0811, 0xc437,		0x21, 0
	.dw 0x0813, 0xc437,	0x083f, 0xc437,		0x21, 0
	.dw 0x0841, 0xc437,	0x0841, 0xc437,		0x21, 0
	.dw 0x0843, 0xc437,	0x084f, 0xc437,		0x21, 0
	.dw 0x0851, 0xc437,	0x0851, 0xc437,		0x21, 0
	.dw 0x0853, 0xc437,	0x087f, 0xc437,		0x21, 0
	.dw 0x0881, 0xc437,	0x0881, 0xc437,		0x21, 0
	.dw 0x0883, 0xc437,	0x088f, 0xc437,		0x21, 0
	.dw 0x0891, 0xc437,	0x0891, 0xc437,		0x21, 0
	.dw 0x0893, 0xc437,	0x08bf, 0xc437,		0x21, 0
	.dw 0x08c1, 0xc437,	0x08c1, 0xc437,		0x21, 0
	.dw 0x08c3, 0xc437,	0x08cf, 0xc437,		0x21, 0
	.dw 0x08d1, 0xc437,	0x08d1, 0xc437,		0x21, 0
	.dw 0x08d3, 0xc437,	0x08ff, 0xc437,		0x21, 0
	.dw 0x0901, 0xc437,	0x0901, 0xc437,		0x21, 0
	.dw 0x0903, 0xc437,	0x090f, 0xc437,		0x21, 0
	.dw 0x0911, 0xc437,	0x0911, 0xc437,		0x21, 0
	.dw 0x0913, 0xc437,	0x093f, 0xc437,		0x21, 0
	.dw 0x0941, 0xc437,	0x0941, 0xc437,		0x21, 0
	.dw 0x0943, 0xc437,	0x094f, 0xc437,		0x21, 0
	.dw 0x0951, 0xc437,	0x0951, 0xc437,		0x21, 0
	.dw 0x0953, 0xc437,	0x097f, 0xc437,		0x21, 0
	.dw 0x0981, 0xc437,	0x0981, 0xc437,		0x21, 0
	.dw 0x0983, 0xc437,	0x098f, 0xc437,		0x21, 0
	.dw 0x0991, 0xc437,	0x0991, 0xc437,		0x21, 0
	.dw 0x0993, 0xc437,	0x09bf, 0xc437,		0x21, 0
	.dw 0x09c1, 0xc437,	0x09c1, 0xc437,		0x21, 0
	.dw 0x09c3, 0xc437,	0x09cf, 0xc437,		0x21, 0
	.dw 0x09d1, 0xc437,	0x09d1, 0xc437,		0x21, 0
	.dw 0x09d3, 0xc437,	0x09ff, 0xc437,		0x21, 0
	.dw 0x0a01, 0xc437,	0x0a01, 0xc437,		0x21, 0
	.dw 0x0a03, 0xc437,	0x0a0f, 0xc437,		0x21, 0
	.dw 0x0a11, 0xc437,	0x0a11, 0xc437,		0x21, 0
	.dw 0x0a13, 0xc437,	0x0a3f, 0xc437,		0x21, 0
	.dw 0x0a41, 0xc437,	0x0a41, 0xc437,		0x21, 0
	.dw 0x0a43, 0xc437,	0x0a4f, 0xc437,		0x21, 0
	.dw 0x0a51, 0xc437,	0x0a51, 0xc437,		0x21, 0
	.dw 0x0a53, 0xc437,	0x0a7f, 0xc437,		0x21, 0
	.dw 0x0a81, 0xc437,	0x0a81, 0xc437,		0x21, 0
	.dw 0x0a83, 0xc437,	0x0a8f, 0xc437,		0x21, 0
	.dw 0x0a91, 0xc437,	0x0a91, 0xc437,		0x21, 0
	.dw 0x0a93, 0xc437,	0x0abf, 0xc437,		0x21, 0
	.dw 0x0ac1, 0xc437,	0x0ac1, 0xc437,		0x21, 0
	.dw 0x0ac3, 0xc437,	0x0acf, 0xc437,		0x21, 0
	.dw 0x0ad1, 0xc437,	0x0ad1, 0xc437,		0x21, 0
	.dw 0x0ad3, 0xc437,	0x0aff, 0xc437,		0x21, 0
	.dw 0x0b01, 0xc437,	0x0b01, 0xc437,		0x21, 0
	.dw 0x0b03, 0xc437,	0x0b0f, 0xc437,		0x21, 0
	.dw 0x0b11, 0xc437,	0x0b11, 0xc437,		0x21, 0
	.dw 0x0b13, 0xc437,	0x0b3f, 0xc437,		0x21, 0
	.dw 0x0b41, 0xc437,	0x0b41, 0xc437,		0x21, 0
	.dw 0x0b43, 0xc437,	0x0b4f, 0xc437,		0x21, 0
	.dw 0x0b51, 0xc437,	0x0b51, 0xc437,		0x21, 0
	.dw 0x0b53, 0xc437,	0x0b7f, 0xc437,		0x21, 0
	.dw 0x0b81, 0xc437,	0x0b81, 0xc437,		0x21, 0
	.dw 0x0b83, 0xc437,	0x0b8f, 0xc437,		0x21, 0
	.dw 0x0b91, 0xc437,	0x0b91, 0xc437,		0x21, 0
	.dw 0x0b93, 0xc437,	0x0bbf, 0xc437,		0x21, 0
	.dw 0x0bc1, 0xc437,	0x0bc1, 0xc437,		0x21, 0
	.dw 0x0bc3, 0xc437,	0x0bcf, 0xc437,		0x21, 0
	.dw 0x0bd1, 0xc437,	0x0bd1, 0xc437,		0x21, 0
	.dw 0x0bd3, 0xc437,	0x0bff, 0xc437,		0x21, 0
	.dw 0x0c01, 0xc437,	0x0c01, 0xc437,		0x21, 0
	.dw 0x0c03, 0xc437,	0x0c0f, 0xc437,		0x21, 0
	.dw 0x0c11, 0xc437,	0x0c11, 0xc437,		0x21, 0
	.dw 0x0c13, 0xc437,	0x0c3f, 0xc437,		0x21, 0
	.dw 0x0c41, 0xc437,	0x0c41, 0xc437,		0x21, 0
	.dw 0x0c43, 0xc437,	0x0c4f, 0xc437,		0x21, 0
	.dw 0x0c51, 0xc437,	0x0c51, 0xc437,		0x21, 0
	.dw 0x0c53, 0xc437,	0x0c7f, 0xc437,		0x21, 0
	.dw 0x0c81, 0xc437,	0x0c81, 0xc437,		0x21, 0
	.dw 0x0c83, 0xc437,	0x0c8f, 0xc437,		0x21, 0
	.dw 0x0c91, 0xc437,	0x0c91, 0xc437,		0x21, 0
	.dw 0x0c93, 0xc437,	0x0cbf, 0xc437,		0x21, 0
	.dw 0x0cc1, 0xc437,	0x0cc1, 0xc437,		0x21, 0
	.dw 0x0cc3, 0xc437,	0x0ccf, 0xc437,		0x21, 0
	.dw 0x0cd1, 0xc437,	0x0cd1, 0xc437,		0x21, 0
	.dw 0x0cd3, 0xc437,	0x0cff, 0xc437,		0x21, 0
	.dw 0x0d01, 0xc437,	0x0d01, 0xc437,		0x21, 0
	.dw 0x0d03, 0xc437,	0x0d0f, 0xc437,		0x21, 0
	.dw 0x0d11, 0xc437,	0x0d11, 0xc437,		0x21, 0
	.dw 0x0d13, 0xc437,	0x0d3f, 0xc437,		0x21, 0
	.dw 0x0d41, 0xc437,	0x0d41, 0xc437,		0x21, 0
	.dw 0x0d43, 0xc437,	0x0d4f, 0xc437,		0x21, 0
	.dw 0x0d51, 0xc437,	0x0d51, 0xc437,		0x21, 0
	.dw 0x0d53, 0xc437,	0x0d7f, 0xc437,		0x21, 0
	.dw 0x0d81, 0xc437,	0x0d81, 0xc437,		0x21, 0
	.dw 0x0d83, 0xc437,	0x0d8f, 0xc437,		0x21, 0
	.dw 0x0d91, 0xc437,	0x0d91, 0xc437,		0x21, 0
	.dw 0x0d93, 0xc437,	0x0dbf, 0xc437,		0x21, 0
	.dw 0x0dc1, 0xc437,	0x0dc1, 0xc437,		0x21, 0
	.dw 0x0dc3, 0xc437,	0x0dcf, 0xc437,		0x21, 0
	.dw 0x0dd1, 0xc437,	0x0dd1, 0xc437,		0x21, 0
	.dw 0x0dd3, 0xc437,	0x0dff, 0xc437,		0x21, 0
	.dw 0x0e01, 0xc437,	0x0e01, 0xc437,		0x21, 0
	.dw 0x0e03, 0xc437,	0x0e0f, 0xc437,		0x21, 0
	.dw 0x0e11, 0xc437,	0x0e11, 0xc437,		0x21, 0
	.dw 0x0e13, 0xc437,	0x0e3f, 0xc437,		0x21, 0
	.dw 0x0e41, 0xc437,	0x0e41, 0xc437,		0x21, 0
	.dw 0x0e43, 0xc437,	0x0e4f, 0xc437,		0x21, 0
	.dw 0x0e51, 0xc437,	0x0e51, 0xc437,		0x21, 0
	.dw 0x0e53, 0xc437,	0x0e7f, 0xc437,		0x21, 0
	.dw 0x0e81, 0xc437,	0x0e81, 0xc437,		0x21, 0
	.dw 0x0e83, 0xc437,	0x0e8f, 0xc437,		0x21, 0
	.dw 0x0e91, 0xc437,	0x0e91, 0xc437,		0x21, 0
	.dw 0x0e93, 0xc437,	0x0ebf, 0xc437,		0x21, 0
	.dw 0x0ec1, 0xc437,	0x0ec1, 0xc437,		0x21, 0
	.dw 0x0ec3, 0xc437,	0x0ecf, 0xc437,		0x21, 0
	.dw 0x0ed1, 0xc437,	0x0ed1, 0xc437,		0x21, 0
	.dw 0x0ed3, 0xc437,	0x0eff, 0xc437,		0x21, 0
	.dw 0x0f01, 0xc437,	0x0f01, 0xc437,		0x21, 0
	.dw 0x0f03, 0xc437,	0x0f0f, 0xc437,		0x21, 0
	.dw 0x0f11, 0xc437,	0x0f11, 0xc437,		0x21, 0
	.dw 0x0f13, 0xc437,	0x0f3f, 0xc437,		0x21, 0
	.dw 0x0f41, 0xc437,	0x0f41, 0xc437,		0x21, 0
	.dw 0x0f43, 0xc437,	0x0f4f, 0xc437,		0x21, 0
	.dw 0x0f51, 0xc437,	0x0f51, 0xc437,		0x21, 0
	.dw 0x0f53, 0xc437,	0x0f7f, 0xc437,		0x21, 0
	.dw 0x0f81, 0xc437,	0x0f81, 0xc437,		0x21, 0
	.dw 0x0f83, 0xc437,	0x0f8f, 0xc437,		0x21, 0
	.dw 0x0f91, 0xc437,	0x0f91, 0xc437,		0x21, 0
	.dw 0x0f93, 0xc437,	0x0fbf, 0xc437,		0x21, 0
	.dw 0x0fc1, 0xc437,	0x0fc1, 0xc437,		0x21, 0
	.dw 0x0fc3, 0xc437,	0x0fcf, 0xc437,		0x21, 0
	.dw 0x0fd1, 0xc437,	0x0fd1, 0xc437,		0x21, 0
	.dw 0x0fd3, 0xc437,	0x1fff, 0xc437,		0x21, 0
	.dw 0x2001, 0xc437,	0x2001, 0xc437,		0x21, 0
	.dw 0x2003, 0xc437,	0x200f, 0xc437,		0x21, 0
	.dw 0x2011, 0xc437,	0x2011, 0xc437,		0x21, 0
	.dw 0x2013, 0xc437,	0x203f, 0xc437,		0x21, 0
	.dw 0x2041, 0xc437,	0x2041, 0xc437,		0x21, 0
	.dw 0x2043, 0xc437,	0x204f, 0xc437,		0x21, 0
	.dw 0x2051, 0xc437,	0x2051, 0xc437,		0x21, 0
	.dw 0x2053, 0xc437,	0x207f, 0xc437,		0x21, 0
	.dw 0x2081, 0xc437,	0x2081, 0xc437,		0x21, 0
	.dw 0x2083, 0xc437,	0x208f, 0xc437,		0x21, 0
	.dw 0x2091, 0xc437,	0x2091, 0xc437,		0x21, 0
	.dw 0x2093, 0xc437,	0x20bf, 0xc437,		0x21, 0
	.dw 0x20c1, 0xc437,	0x20c1, 0xc437,		0x21, 0
	.dw 0x20c3, 0xc437,	0x20cf, 0xc437,		0x21, 0
	.dw 0x20d1, 0xc437,	0x20d1, 0xc437,		0x21, 0
	.dw 0x20d3, 0xc437,	0x20ff, 0xc437,		0x21, 0
	.dw 0x2101, 0xc437,	0x2101, 0xc437,		0x21, 0
	.dw 0x2103, 0xc437,	0x210f, 0xc437,		0x21, 0
	.dw 0x2111, 0xc437,	0x2111, 0xc437,		0x21, 0
	.dw 0x2113, 0xc437,	0x213f, 0xc437,		0x21, 0
	.dw 0x2141, 0xc437,	0x2141, 0xc437,		0x21, 0
	.dw 0x2143, 0xc437,	0x214f, 0xc437,		0x21, 0
	.dw 0x2151, 0xc437,	0x2151, 0xc437,		0x21, 0
	.dw 0x2153, 0xc437,	0x217f, 0xc437,		0x21, 0
	.dw 0x2181, 0xc437,	0x2181, 0xc437,		0x21, 0
	.dw 0x2183, 0xc437,	0x218f, 0xc437,		0x21, 0
	.dw 0x2191, 0xc437,	0x2191, 0xc437,		0x21, 0
	.dw 0x2193, 0xc437,	0x21bf, 0xc437,		0x21, 0
	.dw 0x21c1, 0xc437,	0x21c1, 0xc437,		0x21, 0
	.dw 0x21c3, 0xc437,	0x21cf, 0xc437,		0x21, 0
	.dw 0x21d1, 0xc437,	0x21d1, 0xc437,		0x21, 0
	.dw 0x21d3, 0xc437,	0x21ff, 0xc437,		0x21, 0
	.dw 0x2201, 0xc437,	0x2201, 0xc437,		0x21, 0
	.dw 0x2203, 0xc437,	0x220f, 0xc437,		0x21, 0
	.dw 0x2211, 0xc437,	0x2211, 0xc437,		0x21, 0
	.dw 0x2213, 0xc437,	0x223f, 0xc437,		0x21, 0
	.dw 0x2241, 0xc437,	0x2241, 0xc437,		0x21, 0
	.dw 0x2243, 0xc437,	0x224f, 0xc437,		0x21, 0
	.dw 0x2251, 0xc437,	0x2251, 0xc437,		0x21, 0
	.dw 0x2253, 0xc437,	0x227f, 0xc437,		0x21, 0
	.dw 0x2281, 0xc437,	0x2281, 0xc437,		0x21, 0
	.dw 0x2283, 0xc437,	0x228f, 0xc437,		0x21, 0
	.dw 0x2291, 0xc437,	0x2291, 0xc437,		0x21, 0
	.dw 0x2293, 0xc437,	0x22bf, 0xc437,		0x21, 0
	.dw 0x22c1, 0xc437,	0x22c1, 0xc437,		0x21, 0
	.dw 0x22c3, 0xc437,	0x22cf, 0xc437,		0x21, 0
	.dw 0x22d1, 0xc437,	0x22d1, 0xc437,		0x21, 0
	.dw 0x22d3, 0xc437,	0x22ff, 0xc437,		0x21, 0
	.dw 0x2301, 0xc437,	0x2301, 0xc437,		0x21, 0
	.dw 0x2303, 0xc437,	0x230f, 0xc437,		0x21, 0
	.dw 0x2311, 0xc437,	0x2311, 0xc437,		0x21, 0
	.dw 0x2313, 0xc437,	0x233f, 0xc437,		0x21, 0
	.dw 0x2341, 0xc437,	0x2341, 0xc437,		0x21, 0
	.dw 0x2343, 0xc437,	0x234f, 0xc437,		0x21, 0
	.dw 0x2351, 0xc437,	0x2351, 0xc437,		0x21, 0
	.dw 0x2353, 0xc437,	0x237f, 0xc437,		0x21, 0
	.dw 0x2381, 0xc437,	0x2381, 0xc437,		0x21, 0
	.dw 0x2383, 0xc437,	0x238f, 0xc437,		0x21, 0
	.dw 0x2391, 0xc437,	0x2391, 0xc437,		0x21, 0
	.dw 0x2393, 0xc437,	0x23bf, 0xc437,		0x21, 0
	.dw 0x23c1, 0xc437,	0x23c1, 0xc437,		0x21, 0
	.dw 0x23c3, 0xc437,	0x23cf, 0xc437,		0x21, 0
	.dw 0x23d1, 0xc437,	0x23d1, 0xc437,		0x21, 0
	.dw 0x23d3, 0xc437,	0x23ff, 0xc437,		0x21, 0
	.dw 0x2401, 0xc437,	0x2401, 0xc437,		0x21, 0
	.dw 0x2403, 0xc437,	0x240f, 0xc437,		0x21, 0
	.dw 0x2411, 0xc437,	0x2411, 0xc437,		0x21, 0
	.dw 0x2413, 0xc437,	0x243f, 0xc437,		0x21, 0
	.dw 0x2441, 0xc437,	0x2441, 0xc437,		0x21, 0
	.dw 0x2443, 0xc437,	0x244f, 0xc437,		0x21, 0
	.dw 0x2451, 0xc437,	0x2451, 0xc437,		0x21, 0
	.dw 0x2453, 0xc437,	0x247f, 0xc437,		0x21, 0
	.dw 0x2481, 0xc437,	0x2481, 0xc437,		0x21, 0
	.dw 0x2483, 0xc437,	0x248f, 0xc437,		0x21, 0
	.dw 0x2491, 0xc437,	0x2491, 0xc437,		0x21, 0
	.dw 0x2493, 0xc437,	0x24bf, 0xc437,		0x21, 0
	.dw 0x24c1, 0xc437,	0x24c1, 0xc437,		0x21, 0
	.dw 0x24c3, 0xc437,	0x24cf, 0xc437,		0x21, 0
	.dw 0x24d1, 0xc437,	0x24d1, 0xc437,		0x21, 0
	.dw 0x24d3, 0xc437,	0x24ff, 0xc437,		0x21, 0
	.dw 0x2501, 0xc437,	0x2501, 0xc437,		0x21, 0
	.dw 0x2503, 0xc437,	0x250f, 0xc437,		0x21, 0
	.dw 0x2511, 0xc437,	0x2511, 0xc437,		0x21, 0
	.dw 0x2513, 0xc437,	0x253f, 0xc437,		0x21, 0
	.dw 0x2541, 0xc437,	0x2541, 0xc437,		0x21, 0
	.dw 0x2543, 0xc437,	0x254f, 0xc437,		0x21, 0
	.dw 0x2551, 0xc437,	0x2551, 0xc437,		0x21, 0
	.dw 0x2553, 0xc437,	0x257f, 0xc437,		0x21, 0
	.dw 0x2581, 0xc437,	0x2581, 0xc437,		0x21, 0
	.dw 0x2583, 0xc437,	0x258f, 0xc437,		0x21, 0
	.dw 0x2591, 0xc437,	0x2591, 0xc437,		0x21, 0
	.dw 0x2593, 0xc437,	0x25bf, 0xc437,		0x21, 0
	.dw 0x25c1, 0xc437,	0x25c1, 0xc437,		0x21, 0
	.dw 0x25c3, 0xc437,	0x25cf, 0xc437,		0x21, 0
	.dw 0x25d1, 0xc437,	0x25d1, 0xc437,		0x21, 0
	.dw 0x25d3, 0xc437,	0x25ff, 0xc437,		0x21, 0
	.dw 0x2601, 0xc437,	0x2601, 0xc437,		0x21, 0
	.dw 0x2603, 0xc437,	0x260f, 0xc437,		0x21, 0
	.dw 0x2611, 0xc437,	0x2611, 0xc437,		0x21, 0
	.dw 0x2613, 0xc437,	0x263f, 0xc437,		0x21, 0
	.dw 0x2641, 0xc437,	0x2641, 0xc437,		0x21, 0
	.dw 0x2643, 0xc437,	0x264f, 0xc437,		0x21, 0
	.dw 0x2651, 0xc437,	0x2651, 0xc437,		0x21, 0
	.dw 0x2653, 0xc437,	0x267f, 0xc437,		0x21, 0
	.dw 0x2681, 0xc437,	0x2681, 0xc437,		0x21, 0
	.dw 0x2683, 0xc437,	0x268f, 0xc437,		0x21, 0
	.dw 0x2691, 0xc437,	0x2691, 0xc437,		0x21, 0
	.dw 0x2693, 0xc437,	0x26bf, 0xc437,		0x21, 0
	.dw 0x26c1, 0xc437,	0x26c1, 0xc437,		0x21, 0
	.dw 0x26c3, 0xc437,	0x26cf, 0xc437,		0x21, 0
	.dw 0x26d1, 0xc437,	0x26d1, 0xc437,		0x21, 0
	.dw 0x26d3, 0xc437,	0x26ff, 0xc437,		0x21, 0
	.dw 0x2701, 0xc437,	0x2701, 0xc437,		0x21, 0
	.dw 0x2703, 0xc437,	0x270f, 0xc437,		0x21, 0
	.dw 0x2711, 0xc437,	0x2711, 0xc437,		0x21, 0
	.dw 0x2713, 0xc437,	0x273f, 0xc437,		0x21, 0
	.dw 0x2741, 0xc437,	0x2741, 0xc437,		0x21, 0
	.dw 0x2743, 0xc437,	0x274f, 0xc437,		0x21, 0
	.dw 0x2751, 0xc437,	0x2751, 0xc437,		0x21, 0
	.dw 0x2753, 0xc437,	0x277f, 0xc437,		0x21, 0
	.dw 0x2781, 0xc437,	0x2781, 0xc437,		0x21, 0
	.dw 0x2783, 0xc437,	0x278f, 0xc437,		0x21, 0
	.dw 0x2791, 0xc437,	0x2791, 0xc437,		0x21, 0
	.dw 0x2793, 0xc437,	0x27bf, 0xc437,		0x21, 0
	.dw 0x27c1, 0xc437,	0x27c1, 0xc437,		0x21, 0
	.dw 0x27c3, 0xc437,	0x27cf, 0xc437,		0x21, 0
	.dw 0x27d1, 0xc437,	0x27d1, 0xc437,		0x21, 0
	.dw 0x27d3, 0xc437,	0x27ff, 0xc437,		0x21, 0
	.dw 0x2801, 0xc437,	0x2801, 0xc437,		0x21, 0
	.dw 0x2803, 0xc437,	0x280f, 0xc437,		0x21, 0
	.dw 0x2811, 0xc437,	0x2811, 0xc437,		0x21, 0
	.dw 0x2813, 0xc437,	0x283f, 0xc437,		0x21, 0
	.dw 0x2841, 0xc437,	0x2841, 0xc437,		0x21, 0
	.dw 0x2843, 0xc437,	0x284f, 0xc437,		0x21, 0
	.dw 0x2851, 0xc437,	0x2851, 0xc437,		0x21, 0
	.dw 0x2853, 0xc437,	0x287f, 0xc437,		0x21, 0
	.dw 0x2881, 0xc437,	0x2881, 0xc437,		0x21, 0
	.dw 0x2883, 0xc437,	0x288f, 0xc437,		0x21, 0
	.dw 0x2891, 0xc437,	0x2891, 0xc437,		0x21, 0
	.dw 0x2893, 0xc437,	0x28bf, 0xc437,		0x21, 0
	.dw 0x28c1, 0xc437,	0x28c1, 0xc437,		0x21, 0
	.dw 0x28c3, 0xc437,	0x28cf, 0xc437,		0x21, 0
	.dw 0x28d1, 0xc437,	0x28d1, 0xc437,		0x21, 0
	.dw 0x28d3, 0xc437,	0x28ff, 0xc437,		0x21, 0
	.dw 0x2901, 0xc437,	0x2901, 0xc437,		0x21, 0
	.dw 0x2903, 0xc437,	0x290f, 0xc437,		0x21, 0
	.dw 0x2911, 0xc437,	0x2911, 0xc437,		0x21, 0
	.dw 0x2913, 0xc437,	0x293f, 0xc437,		0x21, 0
	.dw 0x2941, 0xc437,	0x2941, 0xc437,		0x21, 0
	.dw 0x2943, 0xc437,	0x294f, 0xc437,		0x21, 0
	.dw 0x2951, 0xc437,	0x2951, 0xc437,		0x21, 0
	.dw 0x2953, 0xc437,	0x297f, 0xc437,		0x21, 0
	.dw 0x2981, 0xc437,	0x2981, 0xc437,		0x21, 0
	.dw 0x2983, 0xc437,	0x298f, 0xc437,		0x21, 0
	.dw 0x2991, 0xc437,	0x2991, 0xc437,		0x21, 0
	.dw 0x2993, 0xc437,	0x29bf, 0xc437,		0x21, 0
	.dw 0x29c1, 0xc437,	0x29c1, 0xc437,		0x21, 0
	.dw 0x29c3, 0xc437,	0x29cf, 0xc437,		0x21, 0
	.dw 0x29d1, 0xc437,	0x29d1, 0xc437,		0x21, 0
	.dw 0x29d3, 0xc437,	0x29ff, 0xc437,		0x21, 0
	.dw 0x2a01, 0xc437,	0x2a01, 0xc437,		0x21, 0
	.dw 0x2a03, 0xc437,	0x2a0f, 0xc437,		0x21, 0
	.dw 0x2a11, 0xc437,	0x2a11, 0xc437,		0x21, 0
	.dw 0x2a13, 0xc437,	0x2a3f, 0xc437,		0x21, 0
	.dw 0x2a41, 0xc437,	0x2a41, 0xc437,		0x21, 0
	.dw 0x2a43, 0xc437,	0x2a4f, 0xc437,		0x21, 0
	.dw 0x2a51, 0xc437,	0x2a51, 0xc437,		0x21, 0
	.dw 0x2a53, 0xc437,	0x2a7f, 0xc437,		0x21, 0
	.dw 0x2a81, 0xc437,	0x2a81, 0xc437,		0x21, 0
	.dw 0x2a83, 0xc437,	0x2a8f, 0xc437,		0x21, 0
	.dw 0x2a91, 0xc437,	0x2a91, 0xc437,		0x21, 0
	.dw 0x2a93, 0xc437,	0x2abf, 0xc437,		0x21, 0
	.dw 0x2ac1, 0xc437,	0x2ac1, 0xc437,		0x21, 0
	.dw 0x2ac3, 0xc437,	0x2acf, 0xc437,		0x21, 0
	.dw 0x2ad1, 0xc437,	0x2ad1, 0xc437,		0x21, 0
	.dw 0x2ad3, 0xc437,	0x2aff, 0xc437,		0x21, 0
	.dw 0x2b01, 0xc437,	0x2b01, 0xc437,		0x21, 0
	.dw 0x2b03, 0xc437,	0x2b0f, 0xc437,		0x21, 0
	.dw 0x2b11, 0xc437,	0x2b11, 0xc437,		0x21, 0
	.dw 0x2b13, 0xc437,	0x2b3f, 0xc437,		0x21, 0
	.dw 0x2b41, 0xc437,	0x2b41, 0xc437,		0x21, 0
	.dw 0x2b43, 0xc437,	0x2b4f, 0xc437,		0x21, 0
	.dw 0x2b51, 0xc437,	0x2b51, 0xc437,		0x21, 0
	.dw 0x2b53, 0xc437,	0x2b7f, 0xc437,		0x21, 0
	.dw 0x2b81, 0xc437,	0x2b81, 0xc437,		0x21, 0
	.dw 0x2b83, 0xc437,	0x2b8f, 0xc437,		0x21, 0
	.dw 0x2b91, 0xc437,	0x2b91, 0xc437,		0x21, 0
	.dw 0x2b93, 0xc437,	0x2bbf, 0xc437,		0x21, 0
	.dw 0x2bc1, 0xc437,	0x2bc1, 0xc437,		0x21, 0
	.dw 0x2bc3, 0xc437,	0x2bcf, 0xc437,		0x21, 0
	.dw 0x2bd1, 0xc437,	0x2bd1, 0xc437,		0x21, 0
	.dw 0x2bd3, 0xc437,	0x2bff, 0xc437,		0x21, 0
	.dw 0x2c01, 0xc437,	0x2c01, 0xc437,		0x21, 0
	.dw 0x2c03, 0xc437,	0x2c0f, 0xc437,		0x21, 0
	.dw 0x2c11, 0xc437,	0x2c11, 0xc437,		0x21, 0
	.dw 0x2c13, 0xc437,	0x2c3f, 0xc437,		0x21, 0
	.dw 0x2c41, 0xc437,	0x2c41, 0xc437,		0x21, 0
	.dw 0x2c43, 0xc437,	0x2c4f, 0xc437,		0x21, 0
	.dw 0x2c51, 0xc437,	0x2c51, 0xc437,		0x21, 0
	.dw 0x2c53, 0xc437,	0x2c7f, 0xc437,		0x21, 0
	.dw 0x2c81, 0xc437,	0x2c81, 0xc437,		0x21, 0
	.dw 0x2c83, 0xc437,	0x2c8f, 0xc437,		0x21, 0
	.dw 0x2c91, 0xc437,	0x2c91, 0xc437,		0x21, 0
	.dw 0x2c93, 0xc437,	0x2cbf, 0xc437,		0x21, 0
	.dw 0x2cc1, 0xc437,	0x2cc1, 0xc437,		0x21, 0
	.dw 0x2cc3, 0xc437,	0x2ccf, 0xc437,		0x21, 0
	.dw 0x2cd1, 0xc437,	0x2cd1, 0xc437,		0x21, 0
	.dw 0x2cd3, 0xc437,	0x2cff, 0xc437,		0x21, 0
	.dw 0x2d01, 0xc437,	0x2d01, 0xc437,		0x21, 0
	.dw 0x2d03, 0xc437,	0x2d0f, 0xc437,		0x21, 0
	.dw 0x2d11, 0xc437,	0x2d11, 0xc437,		0x21, 0
	.dw 0x2d13, 0xc437,	0x2d3f, 0xc437,		0x21, 0
	.dw 0x2d41, 0xc437,	0x2d41, 0xc437,		0x21, 0
	.dw 0x2d43, 0xc437,	0x2d4f, 0xc437,		0x21, 0
	.dw 0x2d51, 0xc437,	0x2d51, 0xc437,		0x21, 0
	.dw 0x2d53, 0xc437,	0x2d7f, 0xc437,		0x21, 0
	.dw 0x2d81, 0xc437,	0x2d81, 0xc437,		0x21, 0
	.dw 0x2d83, 0xc437,	0x2d8f, 0xc437,		0x21, 0
	.dw 0x2d91, 0xc437,	0x2d91, 0xc437,		0x21, 0
	.dw 0x2d93, 0xc437,	0x2dbf, 0xc437,		0x21, 0
	.dw 0x2dc1, 0xc437,	0x2dc1, 0xc437,		0x21, 0
	.dw 0x2dc3, 0xc437,	0x2dcf, 0xc437,		0x21, 0
	.dw 0x2dd1, 0xc437,	0x2dd1, 0xc437,		0x21, 0
	.dw 0x2dd3, 0xc437,	0x2dff, 0xc437,		0x21, 0
	.dw 0x2e01, 0xc437,	0x2e01, 0xc437,		0x21, 0
	.dw 0x2e03, 0xc437,	0x2e0f, 0xc437,		0x21, 0
	.dw 0x2e11, 0xc437,	0x2e11, 0xc437,		0x21, 0
	.dw 0x2e13, 0xc437,	0x2e3f, 0xc437,		0x21, 0
	.dw 0x2e41, 0xc437,	0x2e41, 0xc437,		0x21, 0
	.dw 0x2e43, 0xc437,	0x2e4f, 0xc437,		0x21, 0
	.dw 0x2e51, 0xc437,	0x2e51, 0xc437,		0x21, 0
	.dw 0x2e53, 0xc437,	0x2e7f, 0xc437,		0x21, 0
	.dw 0x2e81, 0xc437,	0x2e81, 0xc437,		0x21, 0
	.dw 0x2e83, 0xc437,	0x2e8f, 0xc437,		0x21, 0
	.dw 0x2e91, 0xc437,	0x2e91, 0xc437,		0x21, 0
	.dw 0x2e93, 0xc437,	0x2ebf, 0xc437,		0x21, 0
	.dw 0x2ec1, 0xc437,	0x2ec1, 0xc437,		0x21, 0
	.dw 0x2ec3, 0xc437,	0x2ecf, 0xc437,		0x21, 0
	.dw 0x2ed1, 0xc437,	0x2ed1, 0xc437,		0x21, 0
	.dw 0x2ed3, 0xc437,	0x2eff, 0xc437,		0x21, 0
	.dw 0x2f01, 0xc437,	0x2f01, 0xc437,		0x21, 0
	.dw 0x2f03, 0xc437,	0x2f0f, 0xc437,		0x21, 0
	.dw 0x2f11, 0xc437,	0x2f11, 0xc437,		0x21, 0
	.dw 0x2f13, 0xc437,	0x2f3f, 0xc437,		0x21, 0
	.dw 0x2f41, 0xc437,	0x2f41, 0xc437,		0x21, 0
	.dw 0x2f43, 0xc437,	0x2f4f, 0xc437,		0x21, 0
	.dw 0x2f51, 0xc437,	0x2f51, 0xc437,		0x21, 0
	.dw 0x2f53, 0xc437,	0x2f7f, 0xc437,		0x21, 0
	.dw 0x2f81, 0xc437,	0x2f81, 0xc437,		0x21, 0
	.dw 0x2f83, 0xc437,	0x2f8f, 0xc437,		0x21, 0
	.dw 0x2f91, 0xc437,	0x2f91, 0xc437,		0x21, 0
	.dw 0x2f93, 0xc437,	0x2fbf, 0xc437,		0x21, 0
	.dw 0x2fc1, 0xc437,	0x2fc1, 0xc437,		0x21, 0
	.dw 0x2fc3, 0xc437,	0x2fcf, 0xc437,		0x21, 0
	.dw 0x2fd1, 0xc437,	0x2fd1, 0xc437,		0x21, 0
	.dw 0x2fd3, 0xc437,	0xffff, 0xc5ff,		0x21, 0
	.dw 0x0040, 0xc600,	0x01ff, 0xc600,		0x21, 0
	.dw 0x0240, 0xc600,	0x03ff, 0xc600,		0x21, 0
	.dw 0x0440, 0xc600,	0x05ff, 0xc600,		0x21, 0
	.dw 0x0640, 0xc600,	0x07ff, 0xc600,		0x21, 0
	.dw 0x0840, 0xc600,	0x09ff, 0xc600,		0x21, 0
	.dw 0x0a40, 0xc600,	0x0bff, 0xc600,		0x21, 0
	.dw 0x0c40, 0xc600,	0x0dff, 0xc600,		0x21, 0
	.dw 0x0e40, 0xc600,	0x0fff, 0xc600,		0x21, 0
	.dw 0x1040, 0xc600,	0x11ff, 0xc600,		0x21, 0
	.dw 0x1240, 0xc600,	0x13ff, 0xc600,		0x21, 0
	.dw 0x1440, 0xc600,	0x15ff, 0xc600,		0x21, 0
	.dw 0x1640, 0xc600,	0x17ff, 0xc600,		0x21, 0
	.dw 0x1840, 0xc600,	0x19ff, 0xc600,		0x21, 0
	.dw 0x1a40, 0xc600,	0x1bff, 0xc600,		0x21, 0
	.dw 0x1c40, 0xc600,	0x1dff, 0xc600,		0x21, 0
	.dw 0x1e40, 0xc600,	0x1fff, 0xc600,		0x21, 0
	.dw 0x2040, 0xc600,	0x21ff, 0xc600,		0x21, 0
	.dw 0x2240, 0xc600,	0x23ff, 0xc600,		0x21, 0
	.dw 0x2440, 0xc600,	0x25ff, 0xc600,		0x21, 0
	.dw 0x2640, 0xc600,	0x27ff, 0xc600,		0x21, 0
	.dw 0x2840, 0xc600,	0x29ff, 0xc600,		0x21, 0
	.dw 0x2a40, 0xc600,	0x2bff, 0xc600,		0x21, 0
	.dw 0x2c40, 0xc600,	0x2dff, 0xc600,		0x21, 0
	.dw 0x2e40, 0xc600,	0x2fff, 0xc600,		0x21, 0
	.dw 0x3040, 0xc600,	0x31ff, 0xc600,		0x21, 0
	.dw 0x3240, 0xc600,	0x33ff, 0xc600,		0x21, 0
	.dw 0x3440, 0xc600,	0x35ff, 0xc600,		0x21, 0
	.dw 0x3640, 0xc600,	0x37ff, 0xc600,		0x21, 0
	.dw 0x3840, 0xc600,	0x39ff, 0xc600,		0x21, 0
	.dw 0x3a40, 0xc600,	0x3bff, 0xc600,		0x21, 0
	.dw 0x3c40, 0xc600,	0x3dff, 0xc600,		0x21, 0
	.dw 0x3e40, 0xc600,	0x3fff, 0xc600,		0x21, 0
	.dw 0x4040, 0xc600,	0x41ff, 0xc600,		0x21, 0
	.dw 0x4240, 0xc600,	0x43ff, 0xc600,		0x21, 0
	.dw 0x4440, 0xc600,	0x45ff, 0xc600,		0x21, 0
	.dw 0x4640, 0xc600,	0x47ff, 0xc600,		0x21, 0
	.dw 0x4840, 0xc600,	0x49ff, 0xc600,		0x21, 0
	.dw 0x4a40, 0xc600,	0x4bff, 0xc600,		0x21, 0
	.dw 0x4c40, 0xc600,	0x4dff, 0xc600,		0x21, 0
	.dw 0x4e40, 0xc600,	0x4fff, 0xc600,		0x21, 0
	.dw 0x5040, 0xc600,	0x51ff, 0xc600,		0x21, 0
	.dw 0x5240, 0xc600,	0x53ff, 0xc600,		0x21, 0
	.dw 0x5440, 0xc600,	0x55ff, 0xc600,		0x21, 0
	.dw 0x5640, 0xc600,	0x57ff, 0xc600,		0x21, 0
	.dw 0x5840, 0xc600,	0x59ff, 0xc600,		0x21, 0
	.dw 0x5a40, 0xc600,	0x5bff, 0xc600,		0x21, 0
	.dw 0x5c40, 0xc600,	0x5dff, 0xc600,		0x21, 0
	.dw 0x5e40, 0xc600,	0x5fff, 0xc600,		0x21, 0
	.dw 0x6040, 0xc600,	0x61ff, 0xc600,		0x21, 0
	.dw 0x6240, 0xc600,	0x63ff, 0xc600,		0x21, 0
	.dw 0x6440, 0xc600,	0x65ff, 0xc600,		0x21, 0
	.dw 0x6640, 0xc600,	0x67ff, 0xc600,		0x21, 0
	.dw 0x6840, 0xc600,	0x69ff, 0xc600,		0x21, 0
	.dw 0x6a40, 0xc600,	0x6bff, 0xc600,		0x21, 0
	.dw 0x6c40, 0xc600,	0x6dff, 0xc600,		0x21, 0
	.dw 0x6e40, 0xc600,	0x6fff, 0xc600,		0x21, 0
	.dw 0x7040, 0xc600,	0x71ff, 0xc600,		0x21, 0
	.dw 0x7240, 0xc600,	0x73ff, 0xc600,		0x21, 0
	.dw 0x7440, 0xc600,	0x75ff, 0xc600,		0x21, 0
	.dw 0x7640, 0xc600,	0x77ff, 0xc600,		0x21, 0
	.dw 0x7840, 0xc600,	0x79ff, 0xc600,		0x21, 0
	.dw 0x7a40, 0xc600,	0x7bff, 0xc600,		0x21, 0
	.dw 0x7c40, 0xc600,	0x7dff, 0xc600,		0x21, 0
	.dw 0x7e40, 0xc600,	0x7fff, 0xc600,		0x21, 0
	.dw 0x8040, 0xc600,	0x81ff, 0xc600,		0x21, 0
	.dw 0x8240, 0xc600,	0x83ff, 0xc600,		0x21, 0
	.dw 0x8440, 0xc600,	0x85ff, 0xc600,		0x21, 0
	.dw 0x8640, 0xc600,	0x87ff, 0xc600,		0x21, 0
	.dw 0x8840, 0xc600,	0x89ff, 0xc600,		0x21, 0
	.dw 0x8a40, 0xc600,	0x8bff, 0xc600,		0x21, 0
	.dw 0x8c40, 0xc600,	0x8dff, 0xc600,		0x21, 0
	.dw 0x8e40, 0xc600,	0x8fff, 0xc600,		0x21, 0
	.dw 0x9040, 0xc600,	0x91ff, 0xc600,		0x21, 0
	.dw 0x9240, 0xc600,	0x93ff, 0xc600,		0x21, 0
	.dw 0x9440, 0xc600,	0x95ff, 0xc600,		0x21, 0
	.dw 0x9640, 0xc600,	0x97ff, 0xc600,		0x21, 0
	.dw 0x9840, 0xc600,	0x99ff, 0xc600,		0x21, 0
	.dw 0x9a40, 0xc600,	0x9bff, 0xc600,		0x21, 0
	.dw 0x9c40, 0xc600,	0x9dff, 0xc600,		0x21, 0
	.dw 0x9e40, 0xc600,	0x9fff, 0xc600,		0x21, 0
	.dw 0xa040, 0xc600,	0xa1ff, 0xc600,		0x21, 0
	.dw 0xa240, 0xc600,	0xa3ff, 0xc600,		0x21, 0
	.dw 0xa440, 0xc600,	0xa5ff, 0xc600,		0x21, 0
	.dw 0xa640, 0xc600,	0xa7ff, 0xc600,		0x21, 0
	.dw 0xa840, 0xc600,	0xa9ff, 0xc600,		0x21, 0
	.dw 0xaa40, 0xc600,	0xabff, 0xc600,		0x21, 0
	.dw 0xac40, 0xc600,	0xadff, 0xc600,		0x21, 0
	.dw 0xae40, 0xc600,	0xafff, 0xc600,		0x21, 0
	.dw 0xb040, 0xc600,	0xb1ff, 0xc600,		0x21, 0
	.dw 0xb240, 0xc600,	0xb3ff, 0xc600,		0x21, 0
	.dw 0xb440, 0xc600,	0xb5ff, 0xc600,		0x21, 0
	.dw 0xb640, 0xc600,	0xb7ff, 0xc600,		0x21, 0
	.dw 0xb840, 0xc600,	0xb9ff, 0xc600,		0x21, 0
	.dw 0xba40, 0xc600,	0xbbff, 0xc600,		0x21, 0
	.dw 0xbc40, 0xc600,	0xbdff, 0xc600,		0x21, 0
	.dw 0xbe40, 0xc600,	0xffff, 0xc600,		0x21, 0
	.dw 0x0040, 0xc601,	0x01ff, 0xc601,		0x21, 0
	.dw 0x0240, 0xc601,	0x03ff, 0xc601,		0x21, 0
	.dw 0x0440, 0xc601,	0x05ff, 0xc601,		0x21, 0
	.dw 0x0640, 0xc601,	0x07ff, 0xc601,		0x21, 0
	.dw 0x0840, 0xc601,	0x09ff, 0xc601,		0x21, 0
	.dw 0x0a40, 0xc601,	0x0bff, 0xc601,		0x21, 0
	.dw 0x0c40, 0xc601,	0x0dff, 0xc601,		0x21, 0
	.dw 0x0e40, 0xc601,	0x3fff, 0xc601,		0x21, 0
	.dw 0x4040, 0xc601,	0x41ff, 0xc601,		0x21, 0
	.dw 0x4240, 0xc601,	0x43ff, 0xc601,		0x21, 0
	.dw 0x4440, 0xc601,	0x45ff, 0xc601,		0x21, 0
	.dw 0x4640, 0xc601,	0x47ff, 0xc601,		0x21, 0
	.dw 0x4840, 0xc601,	0x49ff, 0xc601,		0x21, 0
	.dw 0x4a40, 0xc601,	0x4bff, 0xc601,		0x21, 0
	.dw 0x4c40, 0xc601,	0x4dff, 0xc601,		0x21, 0
	.dw 0x4e40, 0xc601,	0x7fff, 0xc601,		0x21, 0
	.dw 0x8040, 0xc601,	0x81ff, 0xc601,		0x21, 0
	.dw 0x8240, 0xc601,	0x83ff, 0xc601,		0x21, 0
	.dw 0x8440, 0xc601,	0x85ff, 0xc601,		0x21, 0
	.dw 0x8640, 0xc601,	0x87ff, 0xc601,		0x21, 0
	.dw 0x8840, 0xc601,	0x89ff, 0xc601,		0x21, 0
	.dw 0x8a40, 0xc601,	0x8bff, 0xc601,		0x21, 0
	.dw 0x8c40, 0xc601,	0x8dff, 0xc601,		0x21, 0
	.dw 0x8e40, 0xc601,	0xffff, 0xc601,		0x21, 0
	.dw 0x0040, 0xc602,	0x01ff, 0xc602,		0x21, 0
	.dw 0x0240, 0xc602,	0x03ff, 0xc602,		0x21, 0
	.dw 0x0440, 0xc602,	0x05ff, 0xc602,		0x21, 0
	.dw 0x0640, 0xc602,	0x07ff, 0xc602,		0x21, 0
	.dw 0x0840, 0xc602,	0x09ff, 0xc602,		0x21, 0
	.dw 0x0a40, 0xc602,	0x0bff, 0xc602,		0x21, 0
	.dw 0x0c40, 0xc602,	0x0dff, 0xc602,		0x21, 0
	.dw 0x0e40, 0xc602,	0x3fff, 0xc602,		0x21, 0
	.dw 0x4040, 0xc602,	0x41ff, 0xc602,		0x21, 0
	.dw 0x4240, 0xc602,	0x43ff, 0xc602,		0x21, 0
	.dw 0x4440, 0xc602,	0x45ff, 0xc602,		0x21, 0
	.dw 0x4640, 0xc602,	0x47ff, 0xc602,		0x21, 0
	.dw 0x4840, 0xc602,	0x49ff, 0xc602,		0x21, 0
	.dw 0x4a40, 0xc602,	0x4bff, 0xc602,		0x21, 0
	.dw 0x4c40, 0xc602,	0x4dff, 0xc602,		0x21, 0
	.dw 0x4e40, 0xc602,	0x7fff, 0xc602,		0x21, 0
	.dw 0x8040, 0xc602,	0x81ff, 0xc602,		0x21, 0
	.dw 0x8240, 0xc602,	0x83ff, 0xc602,		0x21, 0
	.dw 0x8440, 0xc602,	0x85ff, 0xc602,		0x21, 0
	.dw 0x8640, 0xc602,	0x87ff, 0xc602,		0x21, 0
	.dw 0x8840, 0xc602,	0x89ff, 0xc602,		0x21, 0
	.dw 0x8a40, 0xc602,	0x8bff, 0xc602,		0x21, 0
	.dw 0x8c40, 0xc602,	0x8dff, 0xc602,		0x21, 0
	.dw 0x8e40, 0xc602,	0xbfff, 0xc602,		0x21, 0
	.dw 0xc040, 0xc602,	0xc1ff, 0xc602,		0x21, 0
	.dw 0xc240, 0xc602,	0xc3ff, 0xc602,		0x21, 0
	.dw 0xc440, 0xc602,	0xc5ff, 0xc602,		0x21, 0
	.dw 0xc640, 0xc602,	0xc7ff, 0xc602,		0x21, 0
	.dw 0xc840, 0xc602,	0xc9ff, 0xc602,		0x21, 0
	.dw 0xca40, 0xc602,	0xcbff, 0xc602,		0x21, 0
	.dw 0xcc40, 0xc602,	0xcdff, 0xc602,		0x21, 0
	.dw 0xce40, 0xc602,	0xffff, 0xc602,		0x21, 0
	.dw 0x0040, 0xc603,	0x01ff, 0xc603,		0x21, 0
	.dw 0x0240, 0xc603,	0x03ff, 0xc603,		0x21, 0
	.dw 0x0440, 0xc603,	0x05ff, 0xc603,		0x21, 0
	.dw 0x0640, 0xc603,	0x07ff, 0xc603,		0x21, 0
	.dw 0x0840, 0xc603,	0x09ff, 0xc603,		0x21, 0
	.dw 0x0a40, 0xc603,	0x0bff, 0xc603,		0x21, 0
	.dw 0x0c40, 0xc603,	0x0dff, 0xc603,		0x21, 0
	.dw 0x0e40, 0xc603,	0x0fff, 0xc603,		0x21, 0
	.dw 0x1040, 0xc603,	0x11ff, 0xc603,		0x21, 0
	.dw 0x1240, 0xc603,	0x13ff, 0xc603,		0x21, 0
	.dw 0x1440, 0xc603,	0x15ff, 0xc603,		0x21, 0
	.dw 0x1640, 0xc603,	0x17ff, 0xc603,		0x21, 0
	.dw 0x1840, 0xc603,	0x19ff, 0xc603,		0x21, 0
	.dw 0x1a40, 0xc603,	0x1bff, 0xc603,		0x21, 0
	.dw 0x1c40, 0xc603,	0x1dff, 0xc603,		0x21, 0
	.dw 0x1e40, 0xc603,	0x3fff, 0xc603,		0x21, 0
	.dw 0x4040, 0xc603,	0x41ff, 0xc603,		0x21, 0
	.dw 0x4240, 0xc603,	0x43ff, 0xc603,		0x21, 0
	.dw 0x4440, 0xc603,	0x45ff, 0xc603,		0x21, 0
	.dw 0x4640, 0xc603,	0x47ff, 0xc603,		0x21, 0
	.dw 0x4840, 0xc603,	0x49ff, 0xc603,		0x21, 0
	.dw 0x4a40, 0xc603,	0x4bff, 0xc603,		0x21, 0
	.dw 0x4c40, 0xc603,	0x4dff, 0xc603,		0x21, 0
	.dw 0x4e40, 0xc603,	0x4fff, 0xc603,		0x21, 0
	.dw 0x5040, 0xc603,	0x51ff, 0xc603,		0x21, 0
	.dw 0x5240, 0xc603,	0x53ff, 0xc603,		0x21, 0
	.dw 0x5440, 0xc603,	0x55ff, 0xc603,		0x21, 0
	.dw 0x5640, 0xc603,	0x57ff, 0xc603,		0x21, 0
	.dw 0x5840, 0xc603,	0x59ff, 0xc603,		0x21, 0
	.dw 0x5a40, 0xc603,	0x5bff, 0xc603,		0x21, 0
	.dw 0x5c40, 0xc603,	0x5dff, 0xc603,		0x21, 0
	.dw 0x5e40, 0xc603,	0x7fff, 0xc603,		0x21, 0
	.dw 0x8040, 0xc603,	0x81ff, 0xc603,		0x21, 0
	.dw 0x8240, 0xc603,	0x83ff, 0xc603,		0x21, 0
	.dw 0x8440, 0xc603,	0x85ff, 0xc603,		0x21, 0
	.dw 0x8640, 0xc603,	0x87ff, 0xc603,		0x21, 0
	.dw 0x8840, 0xc603,	0x89ff, 0xc603,		0x21, 0
	.dw 0x8a40, 0xc603,	0x8bff, 0xc603,		0x21, 0
	.dw 0x8c40, 0xc603,	0x8dff, 0xc603,		0x21, 0
	.dw 0x8e40, 0xc603,	0x8fff, 0xc603,		0x21, 0
	.dw 0x9040, 0xc603,	0x91ff, 0xc603,		0x21, 0
	.dw 0x9240, 0xc603,	0x93ff, 0xc603,		0x21, 0
	.dw 0x9440, 0xc603,	0x95ff, 0xc603,		0x21, 0
	.dw 0x9640, 0xc603,	0x97ff, 0xc603,		0x21, 0
	.dw 0x9840, 0xc603,	0x99ff, 0xc603,		0x21, 0
	.dw 0x9a40, 0xc603,	0x9bff, 0xc603,		0x21, 0
	.dw 0x9c40, 0xc603,	0x9dff, 0xc603,		0x21, 0
	.dw 0x9e40, 0xc603,	0xffff, 0xc603,		0x21, 0
	.dw 0x0040, 0xc604,	0x01ff, 0xc604,		0x21, 0
	.dw 0x0240, 0xc604,	0x03ff, 0xc604,		0x21, 0
	.dw 0x0440, 0xc604,	0x05ff, 0xc604,		0x21, 0
	.dw 0x0640, 0xc604,	0x07ff, 0xc604,		0x21, 0
	.dw 0x0840, 0xc604,	0x09ff, 0xc604,		0x21, 0
	.dw 0x0a40, 0xc604,	0x0bff, 0xc604,		0x21, 0
	.dw 0x0c40, 0xc604,	0x0dff, 0xc604,		0x21, 0
	.dw 0x0e40, 0xc604,	0x3fff, 0xc604,		0x21, 0
	.dw 0x4040, 0xc604,	0x41ff, 0xc604,		0x21, 0
	.dw 0x4240, 0xc604,	0x43ff, 0xc604,		0x21, 0
	.dw 0x4440, 0xc604,	0x45ff, 0xc604,		0x21, 0
	.dw 0x4640, 0xc604,	0x47ff, 0xc604,		0x21, 0
	.dw 0x4840, 0xc604,	0x49ff, 0xc604,		0x21, 0
	.dw 0x4a40, 0xc604,	0x4bff, 0xc604,		0x21, 0
	.dw 0x4c40, 0xc604,	0x4dff, 0xc604,		0x21, 0
	.dw 0x4e40, 0xc604,	0x7fff, 0xc604,		0x21, 0
	.dw 0x8040, 0xc604,	0x81ff, 0xc604,		0x21, 0
	.dw 0x8240, 0xc604,	0x83ff, 0xc604,		0x21, 0
	.dw 0x8440, 0xc604,	0x85ff, 0xc604,		0x21, 0
	.dw 0x8640, 0xc604,	0x87ff, 0xc604,		0x21, 0
	.dw 0x8840, 0xc604,	0x89ff, 0xc604,		0x21, 0
	.dw 0x8a40, 0xc604,	0x8bff, 0xc604,		0x21, 0
	.dw 0x8c40, 0xc604,	0x8dff, 0xc604,		0x21, 0
	.dw 0x8e40, 0xc604,	0xbfff, 0xc604,		0x21, 0
	.dw 0xc040, 0xc604,	0xc1ff, 0xc604,		0x21, 0
	.dw 0xc240, 0xc604,	0xc3ff, 0xc604,		0x21, 0
	.dw 0xc440, 0xc604,	0xc5ff, 0xc604,		0x21, 0
	.dw 0xc640, 0xc604,	0xc7ff, 0xc604,		0x21, 0
	.dw 0xc840, 0xc604,	0xc9ff, 0xc604,		0x21, 0
	.dw 0xca40, 0xc604,	0xcbff, 0xc604,		0x21, 0
	.dw 0xcc40, 0xc604,	0xcdff, 0xc604,		0x21, 0
	.dw 0xce40, 0xc604,	0xffff, 0xc604,		0x21, 0
	.dw 0x0040, 0xc605,	0x01ff, 0xc605,		0x21, 0
	.dw 0x0240, 0xc605,	0x03ff, 0xc605,		0x21, 0
	.dw 0x0440, 0xc605,	0x05ff, 0xc605,		0x21, 0
	.dw 0x0640, 0xc605,	0x07ff, 0xc605,		0x21, 0
	.dw 0x0840, 0xc605,	0x09ff, 0xc605,		0x21, 0
	.dw 0x0a40, 0xc605,	0x0bff, 0xc605,		0x21, 0
	.dw 0x0c40, 0xc605,	0x0dff, 0xc605,		0x21, 0
	.dw 0x0e40, 0xc605,	0x3fff, 0xc605,		0x21, 0
	.dw 0x4040, 0xc605,	0x41ff, 0xc605,		0x21, 0
	.dw 0x4240, 0xc605,	0x43ff, 0xc605,		0x21, 0
	.dw 0x4440, 0xc605,	0x45ff, 0xc605,		0x21, 0
	.dw 0x4640, 0xc605,	0x47ff, 0xc605,		0x21, 0
	.dw 0x4840, 0xc605,	0x49ff, 0xc605,		0x21, 0
	.dw 0x4a40, 0xc605,	0x4bff, 0xc605,		0x21, 0
	.dw 0x4c40, 0xc605,	0x4dff, 0xc605,		0x21, 0
	.dw 0x4e40, 0xc605,	0x7fff, 0xc605,		0x21, 0
	.dw 0x8040, 0xc605,	0x81ff, 0xc605,		0x21, 0
	.dw 0x8240, 0xc605,	0x83ff, 0xc605,		0x21, 0
	.dw 0x8440, 0xc605,	0x85ff, 0xc605,		0x21, 0
	.dw 0x8640, 0xc605,	0x87ff, 0xc605,		0x21, 0
	.dw 0x8840, 0xc605,	0x89ff, 0xc605,		0x21, 0
	.dw 0x8a40, 0xc605,	0x8bff, 0xc605,		0x21, 0
	.dw 0x8c40, 0xc605,	0x8dff, 0xc605,		0x21, 0
	.dw 0x8e40, 0xc605,	0xffff, 0xc605,		0x21, 0
	.dw 0x0040, 0xc606,	0x01ff, 0xc606,		0x21, 0
	.dw 0x0240, 0xc606,	0x03ff, 0xc606,		0x21, 0
	.dw 0x0440, 0xc606,	0x05ff, 0xc606,		0x21, 0
	.dw 0x0640, 0xc606,	0x07ff, 0xc606,		0x21, 0
	.dw 0x0840, 0xc606,	0x09ff, 0xc606,		0x21, 0
	.dw 0x0a40, 0xc606,	0x0bff, 0xc606,		0x21, 0
	.dw 0x0c40, 0xc606,	0x0dff, 0xc606,		0x21, 0
	.dw 0x0e40, 0xc606,	0x3fff, 0xc606,		0x21, 0
	.dw 0x4040, 0xc606,	0x41ff, 0xc606,		0x21, 0
	.dw 0x4240, 0xc606,	0x43ff, 0xc606,		0x21, 0
	.dw 0x4440, 0xc606,	0x45ff, 0xc606,		0x21, 0
	.dw 0x4640, 0xc606,	0x47ff, 0xc606,		0x21, 0
	.dw 0x4840, 0xc606,	0x49ff, 0xc606,		0x21, 0
	.dw 0x4a40, 0xc606,	0x4bff, 0xc606,		0x21, 0
	.dw 0x4c40, 0xc606,	0x4dff, 0xc606,		0x21, 0
	.dw 0x4e40, 0xc606,	0xbfff, 0xc606,		0x21, 0
	.dw 0xc040, 0xc606,	0xc1ff, 0xc606,		0x21, 0
	.dw 0xc240, 0xc606,	0xc3ff, 0xc606,		0x21, 0
	.dw 0xc440, 0xc606,	0xc5ff, 0xc606,		0x21, 0
	.dw 0xc640, 0xc606,	0xc7ff, 0xc606,		0x21, 0
	.dw 0xc840, 0xc606,	0xc9ff, 0xc606,		0x21, 0
	.dw 0xca40, 0xc606,	0xcbff, 0xc606,		0x21, 0
	.dw 0xcc40, 0xc606,	0xcdff, 0xc606,		0x21, 0
	.dw 0xce40, 0xc606,	0xffff, 0xc606,		0x21, 0
	.dw 0x0040, 0xc607,	0x01ff, 0xc607,		0x21, 0
	.dw 0x0240, 0xc607,	0x03ff, 0xc607,		0x21, 0
	.dw 0x0440, 0xc607,	0x05ff, 0xc607,		0x21, 0
	.dw 0x0640, 0xc607,	0x07ff, 0xc607,		0x21, 0
	.dw 0x0840, 0xc607,	0x09ff, 0xc607,		0x21, 0
	.dw 0x0a40, 0xc607,	0x0bff, 0xc607,		0x21, 0
	.dw 0x0c40, 0xc607,	0x0dff, 0xc607,		0x21, 0
	.dw 0x0e40, 0xc607,	0x3fff, 0xc607,		0x21, 0
	.dw 0x4040, 0xc607,	0x41ff, 0xc607,		0x21, 0
	.dw 0x4240, 0xc607,	0x43ff, 0xc607,		0x21, 0
	.dw 0x4440, 0xc607,	0x45ff, 0xc607,		0x21, 0
	.dw 0x4640, 0xc607,	0x47ff, 0xc607,		0x21, 0
	.dw 0x4840, 0xc607,	0x49ff, 0xc607,		0x21, 0
	.dw 0x4a40, 0xc607,	0x4bff, 0xc607,		0x21, 0
	.dw 0x4c40, 0xc607,	0x4dff, 0xc607,		0x21, 0
	.dw 0x4e40, 0xc607,	0x7fff, 0xc607,		0x21, 0
	.dw 0x8040, 0xc607,	0x81ff, 0xc607,		0x21, 0
	.dw 0x8240, 0xc607,	0x83ff, 0xc607,		0x21, 0
	.dw 0x8440, 0xc607,	0x85ff, 0xc607,		0x21, 0
	.dw 0x8640, 0xc607,	0x87ff, 0xc607,		0x21, 0
	.dw 0x8840, 0xc607,	0x89ff, 0xc607,		0x21, 0
	.dw 0x8a40, 0xc607,	0x8bff, 0xc607,		0x21, 0
	.dw 0x8c40, 0xc607,	0x8dff, 0xc607,		0x21, 0
	.dw 0x8e40, 0xc607,	0xbfff, 0xc607,		0x21, 0
	.dw 0xc040, 0xc607,	0xc1ff, 0xc607,		0x21, 0
	.dw 0xc240, 0xc607,	0xc3ff, 0xc607,		0x21, 0
	.dw 0xc440, 0xc607,	0xc5ff, 0xc607,		0x21, 0
	.dw 0xc640, 0xc607,	0xc7ff, 0xc607,		0x21, 0
	.dw 0xc840, 0xc607,	0xc9ff, 0xc607,		0x21, 0
	.dw 0xca40, 0xc607,	0xcbff, 0xc607,		0x21, 0
	.dw 0xcc40, 0xc607,	0xcdff, 0xc607,		0x21, 0
	.dw 0xce40, 0xc607,	0xffff, 0xc607,		0x21, 0
	.dw 0x0000, 0xc608,	0x0000, 0xc608,		0x22, 0
	.dw 0x0009, 0xc608,	0x0009, 0xc608,		0x22, 0
	.dw 0x0012, 0xc608,	0x0012, 0xc608,		0x22, 0
	.dw 0x001b, 0xc608,	0x001b, 0xc608,		0x22, 0
	.dw 0x0024, 0xc608,	0x0024, 0xc608,		0x22, 0
	.dw 0x002d, 0xc608,	0x002d, 0xc608,		0x22, 0
	.dw 0x0036, 0xc608,	0x0036, 0xc608,		0x22, 0
	.dw 0x003f, 0xc608,	0x003f, 0xc608,		0x22, 0
	.dw 0x0040, 0xc608,	0x01ff, 0xc608,		0x21, 0
	.dw 0x0200, 0xc608,	0x0200, 0xc608,		0x22, 0
	.dw 0x0209, 0xc608,	0x0209, 0xc608,		0x22, 0
	.dw 0x0212, 0xc608,	0x0212, 0xc608,		0x22, 0
	.dw 0x021b, 0xc608,	0x021b, 0xc608,		0x22, 0
	.dw 0x0224, 0xc608,	0x0224, 0xc608,		0x22, 0
	.dw 0x022d, 0xc608,	0x022d, 0xc608,		0x22, 0
	.dw 0x0236, 0xc608,	0x0236, 0xc608,		0x22, 0
	.dw 0x023f, 0xc608,	0x023f, 0xc608,		0x22, 0
	.dw 0x0240, 0xc608,	0x03ff, 0xc608,		0x21, 0
	.dw 0x0400, 0xc608,	0x0400, 0xc608,		0x22, 0
	.dw 0x0409, 0xc608,	0x0409, 0xc608,		0x22, 0
	.dw 0x0412, 0xc608,	0x0412, 0xc608,		0x22, 0
	.dw 0x041b, 0xc608,	0x041b, 0xc608,		0x22, 0
	.dw 0x0424, 0xc608,	0x0424, 0xc608,		0x22, 0
	.dw 0x042d, 0xc608,	0x042d, 0xc608,		0x22, 0
	.dw 0x0436, 0xc608,	0x0436, 0xc608,		0x22, 0
	.dw 0x043f, 0xc608,	0x043f, 0xc608,		0x22, 0
	.dw 0x0440, 0xc608,	0x05ff, 0xc608,		0x21, 0
	.dw 0x0600, 0xc608,	0x0600, 0xc608,		0x22, 0
	.dw 0x0609, 0xc608,	0x0609, 0xc608,		0x22, 0
	.dw 0x0612, 0xc608,	0x0612, 0xc608,		0x22, 0
	.dw 0x061b, 0xc608,	0x061b, 0xc608,		0x22, 0
	.dw 0x0624, 0xc608,	0x0624, 0xc608,		0x22, 0
	.dw 0x062d, 0xc608,	0x062d, 0xc608,		0x22, 0
	.dw 0x0636, 0xc608,	0x0636, 0xc608,		0x22, 0
	.dw 0x063f, 0xc608,	0x063f, 0xc608,		0x22, 0
	.dw 0x0640, 0xc608,	0x07ff, 0xc608,		0x21, 0
	.dw 0x0800, 0xc608,	0x0800, 0xc608,		0x22, 0
	.dw 0x0809, 0xc608,	0x0809, 0xc608,		0x22, 0
	.dw 0x0812, 0xc608,	0x0812, 0xc608,		0x22, 0
	.dw 0x081b, 0xc608,	0x081b, 0xc608,		0x22, 0
	.dw 0x0824, 0xc608,	0x0824, 0xc608,		0x22, 0
	.dw 0x082d, 0xc608,	0x082d, 0xc608,		0x22, 0
	.dw 0x0836, 0xc608,	0x0836, 0xc608,		0x22, 0
	.dw 0x083f, 0xc608,	0x083f, 0xc608,		0x22, 0
	.dw 0x0840, 0xc608,	0x09ff, 0xc608,		0x21, 0
	.dw 0x0a00, 0xc608,	0x0a00, 0xc608,		0x22, 0
	.dw 0x0a09, 0xc608,	0x0a09, 0xc608,		0x22, 0
	.dw 0x0a12, 0xc608,	0x0a12, 0xc608,		0x22, 0
	.dw 0x0a1b, 0xc608,	0x0a1b, 0xc608,		0x22, 0
	.dw 0x0a24, 0xc608,	0x0a24, 0xc608,		0x22, 0
	.dw 0x0a2d, 0xc608,	0x0a2d, 0xc608,		0x22, 0
	.dw 0x0a36, 0xc608,	0x0a36, 0xc608,		0x22, 0
	.dw 0x0a3f, 0xc608,	0x0a3f, 0xc608,		0x22, 0
	.dw 0x0a40, 0xc608,	0x0bff, 0xc608,		0x21, 0
	.dw 0x0c00, 0xc608,	0x0c00, 0xc608,		0x22, 0
	.dw 0x0c09, 0xc608,	0x0c09, 0xc608,		0x22, 0
	.dw 0x0c12, 0xc608,	0x0c12, 0xc608,		0x22, 0
	.dw 0x0c1b, 0xc608,	0x0c1b, 0xc608,		0x22, 0
	.dw 0x0c24, 0xc608,	0x0c24, 0xc608,		0x22, 0
	.dw 0x0c2d, 0xc608,	0x0c2d, 0xc608,		0x22, 0
	.dw 0x0c36, 0xc608,	0x0c36, 0xc608,		0x22, 0
	.dw 0x0c3f, 0xc608,	0x0c3f, 0xc608,		0x22, 0
	.dw 0x0c40, 0xc608,	0x0dff, 0xc608,		0x21, 0
	.dw 0x0e00, 0xc608,	0x0e00, 0xc608,		0x22, 0
	.dw 0x0e09, 0xc608,	0x0e09, 0xc608,		0x22, 0
	.dw 0x0e12, 0xc608,	0x0e12, 0xc608,		0x22, 0
	.dw 0x0e1b, 0xc608,	0x0e1b, 0xc608,		0x22, 0
	.dw 0x0e24, 0xc608,	0x0e24, 0xc608,		0x22, 0
	.dw 0x0e2d, 0xc608,	0x0e2d, 0xc608,		0x22, 0
	.dw 0x0e36, 0xc608,	0x0e36, 0xc608,		0x22, 0
	.dw 0x0e3f, 0xc608,	0x0e3f, 0xc608,		0x22, 0
	.dw 0x0e40, 0xc608,	0x3fff, 0xc608,		0x21, 0
	.dw 0x4000, 0xc608,	0x4000, 0xc608,		0x22, 0
	.dw 0x4009, 0xc608,	0x4009, 0xc608,		0x22, 0
	.dw 0x4012, 0xc608,	0x4012, 0xc608,		0x22, 0
	.dw 0x401b, 0xc608,	0x401b, 0xc608,		0x22, 0
	.dw 0x4024, 0xc608,	0x4024, 0xc608,		0x22, 0
	.dw 0x402d, 0xc608,	0x402d, 0xc608,		0x22, 0
	.dw 0x4036, 0xc608,	0x4036, 0xc608,		0x22, 0
	.dw 0x403f, 0xc608,	0x403f, 0xc608,		0x22, 0
	.dw 0x4040, 0xc608,	0x41ff, 0xc608,		0x21, 0
	.dw 0x4200, 0xc608,	0x4200, 0xc608,		0x22, 0
	.dw 0x4209, 0xc608,	0x4209, 0xc608,		0x22, 0
	.dw 0x4212, 0xc608,	0x4212, 0xc608,		0x22, 0
	.dw 0x421b, 0xc608,	0x421b, 0xc608,		0x22, 0
	.dw 0x4224, 0xc608,	0x4224, 0xc608,		0x22, 0
	.dw 0x422d, 0xc608,	0x422d, 0xc608,		0x22, 0
	.dw 0x4236, 0xc608,	0x4236, 0xc608,		0x22, 0
	.dw 0x423f, 0xc608,	0x423f, 0xc608,		0x22, 0
	.dw 0x4240, 0xc608,	0x43ff, 0xc608,		0x21, 0
	.dw 0x4400, 0xc608,	0x4400, 0xc608,		0x22, 0
	.dw 0x4409, 0xc608,	0x4409, 0xc608,		0x22, 0
	.dw 0x4412, 0xc608,	0x4412, 0xc608,		0x22, 0
	.dw 0x441b, 0xc608,	0x441b, 0xc608,		0x22, 0
	.dw 0x4424, 0xc608,	0x4424, 0xc608,		0x22, 0
	.dw 0x442d, 0xc608,	0x442d, 0xc608,		0x22, 0
	.dw 0x4436, 0xc608,	0x4436, 0xc608,		0x22, 0
	.dw 0x443f, 0xc608,	0x443f, 0xc608,		0x22, 0
	.dw 0x4440, 0xc608,	0x45ff, 0xc608,		0x21, 0
	.dw 0x4600, 0xc608,	0x4600, 0xc608,		0x22, 0
	.dw 0x4609, 0xc608,	0x4609, 0xc608,		0x22, 0
	.dw 0x4612, 0xc608,	0x4612, 0xc608,		0x22, 0
	.dw 0x461b, 0xc608,	0x461b, 0xc608,		0x22, 0
	.dw 0x4624, 0xc608,	0x4624, 0xc608,		0x22, 0
	.dw 0x462d, 0xc608,	0x462d, 0xc608,		0x22, 0
	.dw 0x4636, 0xc608,	0x4636, 0xc608,		0x22, 0
	.dw 0x463f, 0xc608,	0x463f, 0xc608,		0x22, 0
	.dw 0x4640, 0xc608,	0x47ff, 0xc608,		0x21, 0
	.dw 0x4800, 0xc608,	0x4800, 0xc608,		0x22, 0
	.dw 0x4809, 0xc608,	0x4809, 0xc608,		0x22, 0
	.dw 0x4812, 0xc608,	0x4812, 0xc608,		0x22, 0
	.dw 0x481b, 0xc608,	0x481b, 0xc608,		0x22, 0
	.dw 0x4824, 0xc608,	0x4824, 0xc608,		0x22, 0
	.dw 0x482d, 0xc608,	0x482d, 0xc608,		0x22, 0
	.dw 0x4836, 0xc608,	0x4836, 0xc608,		0x22, 0
	.dw 0x483f, 0xc608,	0x483f, 0xc608,		0x22, 0
	.dw 0x4840, 0xc608,	0x49ff, 0xc608,		0x21, 0
	.dw 0x4a00, 0xc608,	0x4a00, 0xc608,		0x22, 0
	.dw 0x4a09, 0xc608,	0x4a09, 0xc608,		0x22, 0
	.dw 0x4a12, 0xc608,	0x4a12, 0xc608,		0x22, 0
	.dw 0x4a1b, 0xc608,	0x4a1b, 0xc608,		0x22, 0
	.dw 0x4a24, 0xc608,	0x4a24, 0xc608,		0x22, 0
	.dw 0x4a2d, 0xc608,	0x4a2d, 0xc608,		0x22, 0
	.dw 0x4a36, 0xc608,	0x4a36, 0xc608,		0x22, 0
	.dw 0x4a3f, 0xc608,	0x4a3f, 0xc608,		0x22, 0
	.dw 0x4a40, 0xc608,	0x4bff, 0xc608,		0x21, 0
	.dw 0x4c00, 0xc608,	0x4c00, 0xc608,		0x22, 0
	.dw 0x4c09, 0xc608,	0x4c09, 0xc608,		0x22, 0
	.dw 0x4c12, 0xc608,	0x4c12, 0xc608,		0x22, 0
	.dw 0x4c1b, 0xc608,	0x4c1b, 0xc608,		0x22, 0
	.dw 0x4c24, 0xc608,	0x4c24, 0xc608,		0x22, 0
	.dw 0x4c2d, 0xc608,	0x4c2d, 0xc608,		0x22, 0
	.dw 0x4c36, 0xc608,	0x4c36, 0xc608,		0x22, 0
	.dw 0x4c3f, 0xc608,	0x4c3f, 0xc608,		0x22, 0
	.dw 0x4c40, 0xc608,	0x4dff, 0xc608,		0x21, 0
	.dw 0x4e00, 0xc608,	0x4e00, 0xc608,		0x22, 0
	.dw 0x4e09, 0xc608,	0x4e09, 0xc608,		0x22, 0
	.dw 0x4e12, 0xc608,	0x4e12, 0xc608,		0x22, 0
	.dw 0x4e1b, 0xc608,	0x4e1b, 0xc608,		0x22, 0
	.dw 0x4e24, 0xc608,	0x4e24, 0xc608,		0x22, 0
	.dw 0x4e2d, 0xc608,	0x4e2d, 0xc608,		0x22, 0
	.dw 0x4e36, 0xc608,	0x4e36, 0xc608,		0x22, 0
	.dw 0x4e3f, 0xc608,	0x4e3f, 0xc608,		0x22, 0
	.dw 0x4e40, 0xc608,	0xffff, 0xc608,		0x21, 0
	.dw 0x0040, 0xc609,	0x01ff, 0xc609,		0x21, 0
	.dw 0x0240, 0xc609,	0x03ff, 0xc609,		0x21, 0
	.dw 0x0440, 0xc609,	0x05ff, 0xc609,		0x21, 0
	.dw 0x0640, 0xc609,	0x07ff, 0xc609,		0x21, 0
	.dw 0x0840, 0xc609,	0x09ff, 0xc609,		0x21, 0
	.dw 0x0a40, 0xc609,	0x0bff, 0xc609,		0x21, 0
	.dw 0x0c40, 0xc609,	0x0dff, 0xc609,		0x21, 0
	.dw 0x0e40, 0xc609,	0x3fff, 0xc609,		0x21, 0
	.dw 0x4040, 0xc609,	0x41ff, 0xc609,		0x21, 0
	.dw 0x4240, 0xc609,	0x43ff, 0xc609,		0x21, 0
	.dw 0x4440, 0xc609,	0x45ff, 0xc609,		0x21, 0
	.dw 0x4640, 0xc609,	0x47ff, 0xc609,		0x21, 0
	.dw 0x4840, 0xc609,	0x49ff, 0xc609,		0x21, 0
	.dw 0x4a40, 0xc609,	0x4bff, 0xc609,		0x21, 0
	.dw 0x4c40, 0xc609,	0x4dff, 0xc609,		0x21, 0
	.dw 0x4e40, 0xc609,	0x7fff, 0xc609,		0x21, 0
	.dw 0x8040, 0xc609,	0x81ff, 0xc609,		0x21, 0
	.dw 0x8240, 0xc609,	0x83ff, 0xc609,		0x21, 0
	.dw 0x8440, 0xc609,	0x85ff, 0xc609,		0x21, 0
	.dw 0x8640, 0xc609,	0x87ff, 0xc609,		0x21, 0
	.dw 0x8840, 0xc609,	0x89ff, 0xc609,		0x21, 0
	.dw 0x8a40, 0xc609,	0x8bff, 0xc609,		0x21, 0
	.dw 0x8c40, 0xc609,	0x8dff, 0xc609,		0x21, 0
	.dw 0x8e40, 0xc609,	0xbfff, 0xc609,		0x21, 0
	.dw 0xc040, 0xc609,	0xc1ff, 0xc609,		0x21, 0
	.dw 0xc240, 0xc609,	0xc3ff, 0xc609,		0x21, 0
	.dw 0xc440, 0xc609,	0xc5ff, 0xc609,		0x21, 0
	.dw 0xc640, 0xc609,	0xc7ff, 0xc609,		0x21, 0
	.dw 0xc840, 0xc609,	0xc9ff, 0xc609,		0x21, 0
	.dw 0xca40, 0xc609,	0xcbff, 0xc609,		0x21, 0
	.dw 0xcc40, 0xc609,	0xcdff, 0xc609,		0x21, 0
	.dw 0xce40, 0xc609,	0xffff, 0xc609,		0x21, 0
	.dw 0x0040, 0xc60a,	0x01ff, 0xc60a,		0x21, 0
	.dw 0x0240, 0xc60a,	0x03ff, 0xc60a,		0x21, 0
	.dw 0x0440, 0xc60a,	0x05ff, 0xc60a,		0x21, 0
	.dw 0x0640, 0xc60a,	0x07ff, 0xc60a,		0x21, 0
	.dw 0x0840, 0xc60a,	0x09ff, 0xc60a,		0x21, 0
	.dw 0x0a40, 0xc60a,	0x0bff, 0xc60a,		0x21, 0
	.dw 0x0c40, 0xc60a,	0x0dff, 0xc60a,		0x21, 0
	.dw 0x0e40, 0xc60a,	0x3fff, 0xc60a,		0x21, 0
	.dw 0x4040, 0xc60a,	0x41ff, 0xc60a,		0x21, 0
	.dw 0x4240, 0xc60a,	0x43ff, 0xc60a,		0x21, 0
	.dw 0x4440, 0xc60a,	0x45ff, 0xc60a,		0x21, 0
	.dw 0x4640, 0xc60a,	0x47ff, 0xc60a,		0x21, 0
	.dw 0x4840, 0xc60a,	0x49ff, 0xc60a,		0x21, 0
	.dw 0x4a40, 0xc60a,	0x4bff, 0xc60a,		0x21, 0
	.dw 0x4c40, 0xc60a,	0x4dff, 0xc60a,		0x21, 0
	.dw 0x4e40, 0xc60a,	0x7fff, 0xc60a,		0x21, 0
	.dw 0x8040, 0xc60a,	0x81ff, 0xc60a,		0x21, 0
	.dw 0x8240, 0xc60a,	0x83ff, 0xc60a,		0x21, 0
	.dw 0x8440, 0xc60a,	0x85ff, 0xc60a,		0x21, 0
	.dw 0x8640, 0xc60a,	0x87ff, 0xc60a,		0x21, 0
	.dw 0x8840, 0xc60a,	0x89ff, 0xc60a,		0x21, 0
	.dw 0x8a40, 0xc60a,	0x8bff, 0xc60a,		0x21, 0
	.dw 0x8c40, 0xc60a,	0x8dff, 0xc60a,		0x21, 0
	.dw 0x8e40, 0xc60a,	0xbfff, 0xc60a,		0x21, 0
	.dw 0xc040, 0xc60a,	0xc1ff, 0xc60a,		0x21, 0
	.dw 0xc240, 0xc60a,	0xc3ff, 0xc60a,		0x21, 0
	.dw 0xc440, 0xc60a,	0xc5ff, 0xc60a,		0x21, 0
	.dw 0xc640, 0xc60a,	0xc7ff, 0xc60a,		0x21, 0
	.dw 0xc840, 0xc60a,	0xc9ff, 0xc60a,		0x21, 0
	.dw 0xca40, 0xc60a,	0xcbff, 0xc60a,		0x21, 0
	.dw 0xcc40, 0xc60a,	0xcdff, 0xc60a,		0x21, 0
	.dw 0xce40, 0xc60a,	0xffff, 0xc60a,		0x21, 0
	.dw 0x0040, 0xc60b,	0x01ff, 0xc60b,		0x21, 0
	.dw 0x0240, 0xc60b,	0x03ff, 0xc60b,		0x21, 0
	.dw 0x0440, 0xc60b,	0x05ff, 0xc60b,		0x21, 0
	.dw 0x0640, 0xc60b,	0x07ff, 0xc60b,		0x21, 0
	.dw 0x0840, 0xc60b,	0x09ff, 0xc60b,		0x21, 0
	.dw 0x0a40, 0xc60b,	0x0bff, 0xc60b,		0x21, 0
	.dw 0x0c40, 0xc60b,	0x0dff, 0xc60b,		0x21, 0
	.dw 0x0e40, 0xc60b,	0x3fff, 0xc60b,		0x21, 0
	.dw 0x4040, 0xc60b,	0x41ff, 0xc60b,		0x21, 0
	.dw 0x4240, 0xc60b,	0x43ff, 0xc60b,		0x21, 0
	.dw 0x4440, 0xc60b,	0x45ff, 0xc60b,		0x21, 0
	.dw 0x4640, 0xc60b,	0x47ff, 0xc60b,		0x21, 0
	.dw 0x4840, 0xc60b,	0x49ff, 0xc60b,		0x21, 0
	.dw 0x4a40, 0xc60b,	0x4bff, 0xc60b,		0x21, 0
	.dw 0x4c40, 0xc60b,	0x4dff, 0xc60b,		0x21, 0
	.dw 0x4e40, 0xc60b,	0xffff, 0xc60b,		0x21, 0
	.dw 0x0040, 0xc60c,	0x01ff, 0xc60c,		0x21, 0
	.dw 0x0240, 0xc60c,	0x03ff, 0xc60c,		0x21, 0
	.dw 0x0440, 0xc60c,	0x05ff, 0xc60c,		0x21, 0
	.dw 0x0640, 0xc60c,	0x07ff, 0xc60c,		0x21, 0
	.dw 0x0840, 0xc60c,	0x09ff, 0xc60c,		0x21, 0
	.dw 0x0a40, 0xc60c,	0x0bff, 0xc60c,		0x21, 0
	.dw 0x0c40, 0xc60c,	0x0dff, 0xc60c,		0x21, 0
	.dw 0x0e40, 0xc60c,	0x3fff, 0xc60c,		0x21, 0
	.dw 0x4040, 0xc60c,	0x41ff, 0xc60c,		0x21, 0
	.dw 0x4240, 0xc60c,	0x43ff, 0xc60c,		0x21, 0
	.dw 0x4440, 0xc60c,	0x45ff, 0xc60c,		0x21, 0
	.dw 0x4640, 0xc60c,	0x47ff, 0xc60c,		0x21, 0
	.dw 0x4840, 0xc60c,	0x49ff, 0xc60c,		0x21, 0
	.dw 0x4a40, 0xc60c,	0x4bff, 0xc60c,		0x21, 0
	.dw 0x4c40, 0xc60c,	0x4dff, 0xc60c,		0x21, 0
	.dw 0x4e40, 0xc60c,	0xffff, 0xc60c,		0x21, 0
	.dw 0x0040, 0xc60d,	0x01ff, 0xc60d,		0x21, 0
	.dw 0x0240, 0xc60d,	0x03ff, 0xc60d,		0x21, 0
	.dw 0x0440, 0xc60d,	0x05ff, 0xc60d,		0x21, 0
	.dw 0x0640, 0xc60d,	0x07ff, 0xc60d,		0x21, 0
	.dw 0x0840, 0xc60d,	0x09ff, 0xc60d,		0x21, 0
	.dw 0x0a40, 0xc60d,	0x0bff, 0xc60d,		0x21, 0
	.dw 0x0c40, 0xc60d,	0x0dff, 0xc60d,		0x21, 0
	.dw 0x0e40, 0xc60d,	0x3fff, 0xc60d,		0x21, 0
	.dw 0x4040, 0xc60d,	0x41ff, 0xc60d,		0x21, 0
	.dw 0x4240, 0xc60d,	0x43ff, 0xc60d,		0x21, 0
	.dw 0x4440, 0xc60d,	0x45ff, 0xc60d,		0x21, 0
	.dw 0x4640, 0xc60d,	0x47ff, 0xc60d,		0x21, 0
	.dw 0x4840, 0xc60d,	0x49ff, 0xc60d,		0x21, 0
	.dw 0x4a40, 0xc60d,	0x4bff, 0xc60d,		0x21, 0
	.dw 0x4c40, 0xc60d,	0x4dff, 0xc60d,		0x21, 0
	.dw 0x4e40, 0xc60d,	0x7fff, 0xc60d,		0x21, 0
	.dw 0x8040, 0xc60d,	0x81ff, 0xc60d,		0x21, 0
	.dw 0x8240, 0xc60d,	0x83ff, 0xc60d,		0x21, 0
	.dw 0x8440, 0xc60d,	0x85ff, 0xc60d,		0x21, 0
	.dw 0x8640, 0xc60d,	0x87ff, 0xc60d,		0x21, 0
	.dw 0x8840, 0xc60d,	0x89ff, 0xc60d,		0x21, 0
	.dw 0x8a40, 0xc60d,	0x8bff, 0xc60d,		0x21, 0
	.dw 0x8c40, 0xc60d,	0x8dff, 0xc60d,		0x21, 0
	.dw 0x8e40, 0xc60d,	0xffff, 0xc67f,		0x21, 0
	.dw 0xc000, 0xc680,	0xffff, 0xc680,		0x21, 0
	.dw 0x1000, 0xc681,	0x3fff, 0xc681,		0x21, 0
	.dw 0x5000, 0xc681,	0x7fff, 0xc681,		0x21, 0
	.dw 0x9000, 0xc681,	0xffff, 0xc681,		0x21, 0
	.dw 0x1000, 0xc682,	0x3fff, 0xc682,		0x21, 0
	.dw 0x5000, 0xc682,	0x7fff, 0xc682,		0x21, 0
	.dw 0x9000, 0xc682,	0xbfff, 0xc682,		0x21, 0
	.dw 0xd000, 0xc682,	0xffff, 0xc682,		0x21, 0
	.dw 0x2000, 0xc683,	0x3fff, 0xc683,		0x21, 0
	.dw 0x6000, 0xc683,	0x7fff, 0xc683,		0x21, 0
	.dw 0xa000, 0xc683,	0xffff, 0xe07f,		0x21, 0
	.dw 0x0400, 0xe080,	0x0fff, 0xe080,		0x21, 0
	.dw 0x1400, 0xe080,	0x1fff, 0xe080,		0x21, 0
	.dw 0x2400, 0xe080,	0x2fff, 0xe080,		0x21, 0
	.dw 0x3400, 0xe080,	0x3fff, 0xe080,		0x21, 0
	.dw 0x4400, 0xe080,	0x4fff, 0xe080,		0x21, 0
	.dw 0x5400, 0xe080,	0x5fff, 0xe080,		0x21, 0
	.dw 0x6400, 0xe080,	0x6fff, 0xe080,		0x21, 0
	.dw 0x7400, 0xe080,	0xffff, 0xe080,		0x21, 0
	.dw 0x0400, 0xe081,	0x0fff, 0xe081,		0x21, 0
	.dw 0x1400, 0xe081,	0x1fff, 0xe081,		0x21, 0
	.dw 0x2400, 0xe081,	0x2fff, 0xe081,		0x21, 0
	.dw 0x3400, 0xe081,	0x3fff, 0xe081,		0x21, 0
	.dw 0x4400, 0xe081,	0x4fff, 0xe081,		0x21, 0
	.dw 0x5400, 0xe081,	0x5fff, 0xe081,		0x21, 0
	.dw 0x6400, 0xe081,	0x6fff, 0xe081,		0x21, 0
	.dw 0x7400, 0xe081,	0xffff, 0xe081,		0x21, 0
	.dw 0x0400, 0xe082,	0x0fff, 0xe082,		0x21, 0
	.dw 0x1400, 0xe082,	0x1fff, 0xe082,		0x21, 0
	.dw 0x2400, 0xe082,	0x2fff, 0xe082,		0x21, 0
	.dw 0x3400, 0xe082,	0x3fff, 0xe082,		0x21, 0
	.dw 0x4400, 0xe082,	0x4fff, 0xe082,		0x21, 0
	.dw 0x5400, 0xe082,	0x5fff, 0xe082,		0x21, 0
	.dw 0x6400, 0xe082,	0x6fff, 0xe082,		0x21, 0
	.dw 0x7400, 0xe082,	0xffff, 0xe082,		0x21, 0
	.dw 0x0400, 0xe083,	0x0fff, 0xe083,		0x21, 0
	.dw 0x1400, 0xe083,	0x1fff, 0xe083,		0x21, 0
	.dw 0x2400, 0xe083,	0x2fff, 0xe083,		0x21, 0
	.dw 0x3400, 0xe083,	0x3fff, 0xe083,		0x21, 0
	.dw 0x4400, 0xe083,	0x4fff, 0xe083,		0x21, 0
	.dw 0x5400, 0xe083,	0x5fff, 0xe083,		0x21, 0
	.dw 0x6400, 0xe083,	0x6fff, 0xe083,		0x21, 0
	.dw 0x7400, 0xe083,	0xffff, 0xe083,		0x21, 0
	.dw 0x0400, 0xe084,	0x0fff, 0xe084,		0x21, 0
	.dw 0x1400, 0xe084,	0x1fff, 0xe084,		0x21, 0
	.dw 0x2400, 0xe084,	0x2fff, 0xe084,		0x21, 0
	.dw 0x3400, 0xe084,	0x3fff, 0xe084,		0x21, 0
	.dw 0x4400, 0xe084,	0x4fff, 0xe084,		0x21, 0
	.dw 0x5400, 0xe084,	0x5fff, 0xe084,		0x21, 0
	.dw 0x6400, 0xe084,	0x6fff, 0xe084,		0x21, 0
	.dw 0x7400, 0xe084,	0xffff, 0xe084,		0x21, 0
	.dw 0x0400, 0xe085,	0x0fff, 0xe085,		0x21, 0
	.dw 0x1400, 0xe085,	0x1fff, 0xe085,		0x21, 0
	.dw 0x2400, 0xe085,	0x2fff, 0xe085,		0x21, 0
	.dw 0x3400, 0xe085,	0x3fff, 0xe085,		0x21, 0
	.dw 0x4400, 0xe085,	0x4fff, 0xe085,		0x21, 0
	.dw 0x5400, 0xe085,	0x5fff, 0xe085,		0x21, 0
	.dw 0x6400, 0xe085,	0x6fff, 0xe085,		0x21, 0
	.dw 0x7400, 0xe085,	0xffff, 0xe085,		0x21, 0
	.dw 0x0400, 0xe086,	0x0fff, 0xe086,		0x21, 0
	.dw 0x1400, 0xe086,	0x1fff, 0xe086,		0x21, 0
	.dw 0x2400, 0xe086,	0x2fff, 0xe086,		0x21, 0
	.dw 0x3400, 0xe086,	0x3fff, 0xe086,		0x21, 0
	.dw 0x4400, 0xe086,	0x4fff, 0xe086,		0x21, 0
	.dw 0x5400, 0xe086,	0x5fff, 0xe086,		0x21, 0
	.dw 0x6400, 0xe086,	0x6fff, 0xe086,		0x21, 0
	.dw 0x7400, 0xe086,	0xffff, 0xe086,		0x21, 0
	.dw 0x0400, 0xe087,	0x0fff, 0xe087,		0x21, 0
	.dw 0x1400, 0xe087,	0x1fff, 0xe087,		0x21, 0
	.dw 0x2400, 0xe087,	0x2fff, 0xe087,		0x21, 0
	.dw 0x3400, 0xe087,	0x3fff, 0xe087,		0x21, 0
	.dw 0x4400, 0xe087,	0x4fff, 0xe087,		0x21, 0
	.dw 0x5400, 0xe087,	0x5fff, 0xe087,		0x21, 0
	.dw 0x6400, 0xe087,	0x6fff, 0xe087,		0x21, 0
	.dw 0x7400, 0xe087,	0xffff, 0xe087,		0x21, 0
	.dw 0x0400, 0xe088,	0x0fff, 0xe088,		0x21, 0
	.dw 0x1400, 0xe088,	0x1fff, 0xe088,		0x21, 0
	.dw 0x2400, 0xe088,	0x2fff, 0xe088,		0x21, 0
	.dw 0x3400, 0xe088,	0x3fff, 0xe088,		0x21, 0
	.dw 0x4400, 0xe088,	0x4fff, 0xe088,		0x21, 0
	.dw 0x5400, 0xe088,	0x5fff, 0xe088,		0x21, 0
	.dw 0x6400, 0xe088,	0x6fff, 0xe088,		0x21, 0
	.dw 0x7400, 0xe088,	0xffff, 0xe088,		0x21, 0
	.dw 0x0400, 0xe089,	0x0fff, 0xe089,		0x21, 0
	.dw 0x1400, 0xe089,	0x1fff, 0xe089,		0x21, 0
	.dw 0x2400, 0xe089,	0x2fff, 0xe089,		0x21, 0
	.dw 0x3400, 0xe089,	0x3fff, 0xe089,		0x21, 0
	.dw 0x4400, 0xe089,	0x4fff, 0xe089,		0x21, 0
	.dw 0x5400, 0xe089,	0x5fff, 0xe089,		0x21, 0
	.dw 0x6400, 0xe089,	0x6fff, 0xe089,		0x21, 0
	.dw 0x7400, 0xe089,	0xffff, 0xe089,		0x21, 0
	.dw 0x0400, 0xe08a,	0x0fff, 0xe08a,		0x21, 0
	.dw 0x1400, 0xe08a,	0x1fff, 0xe08a,		0x21, 0
	.dw 0x2400, 0xe08a,	0x2fff, 0xe08a,		0x21, 0
	.dw 0x3400, 0xe08a,	0x3fff, 0xe08a,		0x21, 0
	.dw 0x4400, 0xe08a,	0x4fff, 0xe08a,		0x21, 0
	.dw 0x5400, 0xe08a,	0x5fff, 0xe08a,		0x21, 0
	.dw 0x6400, 0xe08a,	0x6fff, 0xe08a,		0x21, 0
	.dw 0x7400, 0xe08a,	0xffff, 0xe08a,		0x21, 0
	.dw 0x0400, 0xe08b,	0x0fff, 0xe08b,		0x21, 0
	.dw 0x1400, 0xe08b,	0x1fff, 0xe08b,		0x21, 0
	.dw 0x2400, 0xe08b,	0x2fff, 0xe08b,		0x21, 0
	.dw 0x3400, 0xe08b,	0x3fff, 0xe08b,		0x21, 0
	.dw 0x4400, 0xe08b,	0x4fff, 0xe08b,		0x21, 0
	.dw 0x5400, 0xe08b,	0x5fff, 0xe08b,		0x21, 0
	.dw 0x6400, 0xe08b,	0x6fff, 0xe08b,		0x21, 0
	.dw 0x7400, 0xe08b,	0xffff, 0xe08b,		0x21, 0
	.dw 0x0400, 0xe08c,	0x0fff, 0xe08c,		0x21, 0
	.dw 0x1400, 0xe08c,	0x1fff, 0xe08c,		0x21, 0
	.dw 0x2400, 0xe08c,	0x2fff, 0xe08c,		0x21, 0
	.dw 0x3400, 0xe08c,	0x3fff, 0xe08c,		0x21, 0
	.dw 0x4400, 0xe08c,	0x4fff, 0xe08c,		0x21, 0
	.dw 0x5400, 0xe08c,	0x5fff, 0xe08c,		0x21, 0
	.dw 0x6400, 0xe08c,	0x6fff, 0xe08c,		0x21, 0
	.dw 0x7400, 0xe08c,	0xffff, 0xe08c,		0x21, 0
	.dw 0x0400, 0xe08d,	0x0fff, 0xe08d,		0x21, 0
	.dw 0x1400, 0xe08d,	0x1fff, 0xe08d,		0x21, 0
	.dw 0x2400, 0xe08d,	0x2fff, 0xe08d,		0x21, 0
	.dw 0x3400, 0xe08d,	0x3fff, 0xe08d,		0x21, 0
	.dw 0x4400, 0xe08d,	0x4fff, 0xe08d,		0x21, 0
	.dw 0x5400, 0xe08d,	0x5fff, 0xe08d,		0x21, 0
	.dw 0x6400, 0xe08d,	0x6fff, 0xe08d,		0x21, 0
	.dw 0x7400, 0xe08d,	0xffff, 0xe08d,		0x21, 0
	.dw 0x0400, 0xe08e,	0x0fff, 0xe08e,		0x21, 0
	.dw 0x1400, 0xe08e,	0x1fff, 0xe08e,		0x21, 0
	.dw 0x2400, 0xe08e,	0x2fff, 0xe08e,		0x21, 0
	.dw 0x3400, 0xe08e,	0x3fff, 0xe08e,		0x21, 0
	.dw 0x4400, 0xe08e,	0x4fff, 0xe08e,		0x21, 0
	.dw 0x5400, 0xe08e,	0x5fff, 0xe08e,		0x21, 0
	.dw 0x6400, 0xe08e,	0x6fff, 0xe08e,		0x21, 0
	.dw 0x7400, 0xe08e,	0xffff, 0xe08e,		0x21, 0
	.dw 0x0400, 0xe08f,	0x0fff, 0xe08f,		0x21, 0
	.dw 0x1400, 0xe08f,	0x1fff, 0xe08f,		0x21, 0
	.dw 0x2400, 0xe08f,	0x2fff, 0xe08f,		0x21, 0
	.dw 0x3400, 0xe08f,	0x3fff, 0xe08f,		0x21, 0
	.dw 0x4400, 0xe08f,	0x4fff, 0xe08f,		0x21, 0
	.dw 0x5400, 0xe08f,	0x5fff, 0xe08f,		0x21, 0
	.dw 0x6400, 0xe08f,	0x6fff, 0xe08f,		0x21, 0
	.dw 0x7400, 0xe08f,	0xffff, 0xe08f,		0x21, 0
	.dw 0x0400, 0xe090,	0x0fff, 0xe090,		0x21, 0
	.dw 0x1400, 0xe090,	0x1fff, 0xe090,		0x21, 0
	.dw 0x2400, 0xe090,	0x2fff, 0xe090,		0x21, 0
	.dw 0x3400, 0xe090,	0x3fff, 0xe090,		0x21, 0
	.dw 0x4400, 0xe090,	0x4fff, 0xe090,		0x21, 0
	.dw 0x5400, 0xe090,	0x5fff, 0xe090,		0x21, 0
	.dw 0x6400, 0xe090,	0x6fff, 0xe090,		0x21, 0
	.dw 0x7400, 0xe090,	0xffff, 0xe090,		0x21, 0
	.dw 0x0400, 0xe091,	0x0fff, 0xe091,		0x21, 0
	.dw 0x1400, 0xe091,	0x1fff, 0xe091,		0x21, 0
	.dw 0x2400, 0xe091,	0x2fff, 0xe091,		0x21, 0
	.dw 0x3400, 0xe091,	0x3fff, 0xe091,		0x21, 0
	.dw 0x4400, 0xe091,	0x4fff, 0xe091,		0x21, 0
	.dw 0x5400, 0xe091,	0x5fff, 0xe091,		0x21, 0
	.dw 0x6400, 0xe091,	0x6fff, 0xe091,		0x21, 0
	.dw 0x7400, 0xe091,	0xffff, 0xe091,		0x21, 0
	.dw 0x0400, 0xe092,	0x0fff, 0xe092,		0x21, 0
	.dw 0x1400, 0xe092,	0x1fff, 0xe092,		0x21, 0
	.dw 0x2400, 0xe092,	0x2fff, 0xe092,		0x21, 0
	.dw 0x3400, 0xe092,	0x3fff, 0xe092,		0x21, 0
	.dw 0x4400, 0xe092,	0x4fff, 0xe092,		0x21, 0
	.dw 0x5400, 0xe092,	0x5fff, 0xe092,		0x21, 0
	.dw 0x6400, 0xe092,	0x6fff, 0xe092,		0x21, 0
	.dw 0x7400, 0xe092,	0xffff, 0xe092,		0x21, 0
	.dw 0x0400, 0xe093,	0x0fff, 0xe093,		0x21, 0
	.dw 0x1400, 0xe093,	0x1fff, 0xe093,		0x21, 0
	.dw 0x2400, 0xe093,	0x2fff, 0xe093,		0x21, 0
	.dw 0x3400, 0xe093,	0x3fff, 0xe093,		0x21, 0
	.dw 0x4400, 0xe093,	0x4fff, 0xe093,		0x21, 0
	.dw 0x5400, 0xe093,	0x5fff, 0xe093,		0x21, 0
	.dw 0x6400, 0xe093,	0x6fff, 0xe093,		0x21, 0
	.dw 0x7400, 0xe093,	0xffff, 0xe093,		0x21, 0
	.dw 0x0400, 0xe094,	0x0fff, 0xe094,		0x21, 0
	.dw 0x1400, 0xe094,	0x1fff, 0xe094,		0x21, 0
	.dw 0x2400, 0xe094,	0x2fff, 0xe094,		0x21, 0
	.dw 0x3400, 0xe094,	0x3fff, 0xe094,		0x21, 0
	.dw 0x4400, 0xe094,	0x4fff, 0xe094,		0x21, 0
	.dw 0x5400, 0xe094,	0x5fff, 0xe094,		0x21, 0
	.dw 0x6400, 0xe094,	0x6fff, 0xe094,		0x21, 0
	.dw 0x7400, 0xe094,	0xffff, 0xe094,		0x21, 0
	.dw 0x0400, 0xe095,	0x0fff, 0xe095,		0x21, 0
	.dw 0x1400, 0xe095,	0x1fff, 0xe095,		0x21, 0
	.dw 0x2400, 0xe095,	0x2fff, 0xe095,		0x21, 0
	.dw 0x3400, 0xe095,	0x3fff, 0xe095,		0x21, 0
	.dw 0x4400, 0xe095,	0x4fff, 0xe095,		0x21, 0
	.dw 0x5400, 0xe095,	0x5fff, 0xe095,		0x21, 0
	.dw 0x6400, 0xe095,	0x6fff, 0xe095,		0x21, 0
	.dw 0x7400, 0xe095,	0xffff, 0xe095,		0x21, 0
	.dw 0x0400, 0xe096,	0x0fff, 0xe096,		0x21, 0
	.dw 0x1400, 0xe096,	0x1fff, 0xe096,		0x21, 0
	.dw 0x2400, 0xe096,	0x2fff, 0xe096,		0x21, 0
	.dw 0x3400, 0xe096,	0x3fff, 0xe096,		0x21, 0
	.dw 0x4400, 0xe096,	0x4fff, 0xe096,		0x21, 0
	.dw 0x5400, 0xe096,	0x5fff, 0xe096,		0x21, 0
	.dw 0x6400, 0xe096,	0x6fff, 0xe096,		0x21, 0
	.dw 0x7400, 0xe096,	0xffff, 0xe096,		0x21, 0
	.dw 0x0400, 0xe097,	0x0fff, 0xe097,		0x21, 0
	.dw 0x1400, 0xe097,	0x1fff, 0xe097,		0x21, 0
	.dw 0x2400, 0xe097,	0x2fff, 0xe097,		0x21, 0
	.dw 0x3400, 0xe097,	0x3fff, 0xe097,		0x21, 0
	.dw 0x4400, 0xe097,	0x4fff, 0xe097,		0x21, 0
	.dw 0x5400, 0xe097,	0x5fff, 0xe097,		0x21, 0
	.dw 0x6400, 0xe097,	0x6fff, 0xe097,		0x21, 0
	.dw 0x7400, 0xe097,	0xffff, 0xe097,		0x21, 0
	.dw 0x0400, 0xe098,	0x0fff, 0xe098,		0x21, 0
	.dw 0x1400, 0xe098,	0x1fff, 0xe098,		0x21, 0
	.dw 0x2400, 0xe098,	0x2fff, 0xe098,		0x21, 0
	.dw 0x3400, 0xe098,	0x3fff, 0xe098,		0x21, 0
	.dw 0x4400, 0xe098,	0x4fff, 0xe098,		0x21, 0
	.dw 0x5400, 0xe098,	0x5fff, 0xe098,		0x21, 0
	.dw 0x6400, 0xe098,	0x6fff, 0xe098,		0x21, 0
	.dw 0x7400, 0xe098,	0xffff, 0xe098,		0x21, 0
	.dw 0x0400, 0xe099,	0x0fff, 0xe099,		0x21, 0
	.dw 0x1400, 0xe099,	0x1fff, 0xe099,		0x21, 0
	.dw 0x2400, 0xe099,	0x2fff, 0xe099,		0x21, 0
	.dw 0x3400, 0xe099,	0x3fff, 0xe099,		0x21, 0
	.dw 0x4400, 0xe099,	0x4fff, 0xe099,		0x21, 0
	.dw 0x5400, 0xe099,	0x5fff, 0xe099,		0x21, 0
	.dw 0x6400, 0xe099,	0x6fff, 0xe099,		0x21, 0
	.dw 0x7400, 0xe099,	0xffff, 0xe099,		0x21, 0
	.dw 0x0400, 0xe09a,	0x0fff, 0xe09a,		0x21, 0
	.dw 0x1400, 0xe09a,	0x1fff, 0xe09a,		0x21, 0
	.dw 0x2400, 0xe09a,	0x2fff, 0xe09a,		0x21, 0
	.dw 0x3400, 0xe09a,	0x3fff, 0xe09a,		0x21, 0
	.dw 0x4400, 0xe09a,	0x4fff, 0xe09a,		0x21, 0
	.dw 0x5400, 0xe09a,	0x5fff, 0xe09a,		0x21, 0
	.dw 0x6400, 0xe09a,	0x6fff, 0xe09a,		0x21, 0
	.dw 0x7400, 0xe09a,	0xffff, 0xe09a,		0x21, 0
	.dw 0x0400, 0xe09b,	0x0fff, 0xe09b,		0x21, 0
	.dw 0x1400, 0xe09b,	0x1fff, 0xe09b,		0x21, 0
	.dw 0x2400, 0xe09b,	0x2fff, 0xe09b,		0x21, 0
	.dw 0x3400, 0xe09b,	0x3fff, 0xe09b,		0x21, 0
	.dw 0x4400, 0xe09b,	0x4fff, 0xe09b,		0x21, 0
	.dw 0x5400, 0xe09b,	0x5fff, 0xe09b,		0x21, 0
	.dw 0x6400, 0xe09b,	0x6fff, 0xe09b,		0x21, 0
	.dw 0x7400, 0xe09b,	0xffff, 0xe09b,		0x21, 0
	.dw 0x0400, 0xe09c,	0x0fff, 0xe09c,		0x21, 0
	.dw 0x1400, 0xe09c,	0x1fff, 0xe09c,		0x21, 0
	.dw 0x2400, 0xe09c,	0x2fff, 0xe09c,		0x21, 0
	.dw 0x3400, 0xe09c,	0x3fff, 0xe09c,		0x21, 0
	.dw 0x4400, 0xe09c,	0x4fff, 0xe09c,		0x21, 0
	.dw 0x5400, 0xe09c,	0x5fff, 0xe09c,		0x21, 0
	.dw 0x6400, 0xe09c,	0x6fff, 0xe09c,		0x21, 0
	.dw 0x7400, 0xe09c,	0xffff, 0xe09c,		0x21, 0
	.dw 0x0400, 0xe09d,	0x0fff, 0xe09d,		0x21, 0
	.dw 0x1400, 0xe09d,	0x1fff, 0xe09d,		0x21, 0
	.dw 0x2400, 0xe09d,	0x2fff, 0xe09d,		0x21, 0
	.dw 0x3400, 0xe09d,	0x3fff, 0xe09d,		0x21, 0
	.dw 0x4400, 0xe09d,	0x4fff, 0xe09d,		0x21, 0
	.dw 0x5400, 0xe09d,	0x5fff, 0xe09d,		0x21, 0
	.dw 0x6400, 0xe09d,	0x6fff, 0xe09d,		0x21, 0
	.dw 0x7400, 0xe09d,	0xffff, 0xe09d,		0x21, 0
	.dw 0x0400, 0xe09e,	0x0fff, 0xe09e,		0x21, 0
	.dw 0x1400, 0xe09e,	0x1fff, 0xe09e,		0x21, 0
	.dw 0x2400, 0xe09e,	0x2fff, 0xe09e,		0x21, 0
	.dw 0x3400, 0xe09e,	0x3fff, 0xe09e,		0x21, 0
	.dw 0x4400, 0xe09e,	0x4fff, 0xe09e,		0x21, 0
	.dw 0x5400, 0xe09e,	0x5fff, 0xe09e,		0x21, 0
	.dw 0x6400, 0xe09e,	0x6fff, 0xe09e,		0x21, 0
	.dw 0x7400, 0xe09e,	0xffff, 0xe09e,		0x21, 0
	.dw 0x0400, 0xe09f,	0x0fff, 0xe09f,		0x21, 0
	.dw 0x1400, 0xe09f,	0x1fff, 0xe09f,		0x21, 0
	.dw 0x2400, 0xe09f,	0x2fff, 0xe09f,		0x21, 0
	.dw 0x3400, 0xe09f,	0x3fff, 0xe09f,		0x21, 0
	.dw 0x4400, 0xe09f,	0x4fff, 0xe09f,		0x21, 0
	.dw 0x5400, 0xe09f,	0x5fff, 0xe09f,		0x21, 0
	.dw 0x6400, 0xe09f,	0x6fff, 0xe09f,		0x21, 0
	.dw 0x7400, 0xe09f,	0xffff, 0xe09f,		0x21, 0
	.dw 0x0400, 0xe0a0,	0x0fff, 0xe0a0,		0x21, 0
	.dw 0x1400, 0xe0a0,	0x1fff, 0xe0a0,		0x21, 0
	.dw 0x2400, 0xe0a0,	0x2fff, 0xe0a0,		0x21, 0
	.dw 0x3400, 0xe0a0,	0x3fff, 0xe0a0,		0x21, 0
	.dw 0x4400, 0xe0a0,	0x4fff, 0xe0a0,		0x21, 0
	.dw 0x5400, 0xe0a0,	0x5fff, 0xe0a0,		0x21, 0
	.dw 0x6400, 0xe0a0,	0x6fff, 0xe0a0,		0x21, 0
	.dw 0x7400, 0xe0a0,	0xffff, 0xe0a0,		0x21, 0
	.dw 0x0400, 0xe0a1,	0x0fff, 0xe0a1,		0x21, 0
	.dw 0x1400, 0xe0a1,	0x1fff, 0xe0a1,		0x21, 0
	.dw 0x2400, 0xe0a1,	0x2fff, 0xe0a1,		0x21, 0
	.dw 0x3400, 0xe0a1,	0x3fff, 0xe0a1,		0x21, 0
	.dw 0x4400, 0xe0a1,	0x4fff, 0xe0a1,		0x21, 0
	.dw 0x5400, 0xe0a1,	0x5fff, 0xe0a1,		0x21, 0
	.dw 0x6400, 0xe0a1,	0x6fff, 0xe0a1,		0x21, 0
	.dw 0x7400, 0xe0a1,	0xffff, 0xe0a1,		0x21, 0
	.dw 0x0400, 0xe0a2,	0x0fff, 0xe0a2,		0x21, 0
	.dw 0x1400, 0xe0a2,	0x1fff, 0xe0a2,		0x21, 0
	.dw 0x2400, 0xe0a2,	0x2fff, 0xe0a2,		0x21, 0
	.dw 0x3400, 0xe0a2,	0x3fff, 0xe0a2,		0x21, 0
	.dw 0x4400, 0xe0a2,	0x4fff, 0xe0a2,		0x21, 0
	.dw 0x5400, 0xe0a2,	0x5fff, 0xe0a2,		0x21, 0
	.dw 0x6400, 0xe0a2,	0x6fff, 0xe0a2,		0x21, 0
	.dw 0x7400, 0xe0a2,	0xffff, 0xe0a2,		0x21, 0
	.dw 0x0400, 0xe0a3,	0x0fff, 0xe0a3,		0x21, 0
	.dw 0x1400, 0xe0a3,	0x1fff, 0xe0a3,		0x21, 0
	.dw 0x2400, 0xe0a3,	0x2fff, 0xe0a3,		0x21, 0
	.dw 0x3400, 0xe0a3,	0x3fff, 0xe0a3,		0x21, 0
	.dw 0x4400, 0xe0a3,	0x4fff, 0xe0a3,		0x21, 0
	.dw 0x5400, 0xe0a3,	0x5fff, 0xe0a3,		0x21, 0
	.dw 0x6400, 0xe0a3,	0x6fff, 0xe0a3,		0x21, 0
	.dw 0x7400, 0xe0a3,	0xffff, 0xe0a3,		0x21, 0
	.dw 0x0400, 0xe0a4,	0x0fff, 0xe0a4,		0x21, 0
	.dw 0x1400, 0xe0a4,	0x1fff, 0xe0a4,		0x21, 0
	.dw 0x2400, 0xe0a4,	0x2fff, 0xe0a4,		0x21, 0
	.dw 0x3400, 0xe0a4,	0x3fff, 0xe0a4,		0x21, 0
	.dw 0x4400, 0xe0a4,	0x4fff, 0xe0a4,		0x21, 0
	.dw 0x5400, 0xe0a4,	0x5fff, 0xe0a4,		0x21, 0
	.dw 0x6400, 0xe0a4,	0x6fff, 0xe0a4,		0x21, 0
	.dw 0x7400, 0xe0a4,	0xffff, 0xe0a4,		0x21, 0
	.dw 0x0400, 0xe0a5,	0x0fff, 0xe0a5,		0x21, 0
	.dw 0x1400, 0xe0a5,	0x1fff, 0xe0a5,		0x21, 0
	.dw 0x2400, 0xe0a5,	0x2fff, 0xe0a5,		0x21, 0
	.dw 0x3400, 0xe0a5,	0x3fff, 0xe0a5,		0x21, 0
	.dw 0x4400, 0xe0a5,	0x4fff, 0xe0a5,		0x21, 0
	.dw 0x5400, 0xe0a5,	0x5fff, 0xe0a5,		0x21, 0
	.dw 0x6400, 0xe0a5,	0x6fff, 0xe0a5,		0x21, 0
	.dw 0x7400, 0xe0a5,	0xffff, 0xe0a5,		0x21, 0
	.dw 0x0400, 0xe0a6,	0x0fff, 0xe0a6,		0x21, 0
	.dw 0x1400, 0xe0a6,	0x1fff, 0xe0a6,		0x21, 0
	.dw 0x2400, 0xe0a6,	0x2fff, 0xe0a6,		0x21, 0
	.dw 0x3400, 0xe0a6,	0x3fff, 0xe0a6,		0x21, 0
	.dw 0x4400, 0xe0a6,	0x4fff, 0xe0a6,		0x21, 0
	.dw 0x5400, 0xe0a6,	0x5fff, 0xe0a6,		0x21, 0
	.dw 0x6400, 0xe0a6,	0x6fff, 0xe0a6,		0x21, 0
	.dw 0x7400, 0xe0a6,	0xffff, 0xe0a6,		0x21, 0
	.dw 0x0400, 0xe0a7,	0x0fff, 0xe0a7,		0x21, 0
	.dw 0x1400, 0xe0a7,	0x1fff, 0xe0a7,		0x21, 0
	.dw 0x2400, 0xe0a7,	0x2fff, 0xe0a7,		0x21, 0
	.dw 0x3400, 0xe0a7,	0x3fff, 0xe0a7,		0x21, 0
	.dw 0x4400, 0xe0a7,	0x4fff, 0xe0a7,		0x21, 0
	.dw 0x5400, 0xe0a7,	0x5fff, 0xe0a7,		0x21, 0
	.dw 0x6400, 0xe0a7,	0x6fff, 0xe0a7,		0x21, 0
	.dw 0x7400, 0xe0a7,	0xffff, 0xe0a7,		0x21, 0
	.dw 0x0400, 0xe0a8,	0x0fff, 0xe0a8,		0x21, 0
	.dw 0x1400, 0xe0a8,	0x1fff, 0xe0a8,		0x21, 0
	.dw 0x2400, 0xe0a8,	0x2fff, 0xe0a8,		0x21, 0
	.dw 0x3400, 0xe0a8,	0x3fff, 0xe0a8,		0x21, 0
	.dw 0x4400, 0xe0a8,	0x4fff, 0xe0a8,		0x21, 0
	.dw 0x5400, 0xe0a8,	0x5fff, 0xe0a8,		0x21, 0
	.dw 0x6400, 0xe0a8,	0x6fff, 0xe0a8,		0x21, 0
	.dw 0x7400, 0xe0a8,	0xffff, 0xe0a8,		0x21, 0
	.dw 0x0400, 0xe0a9,	0x0fff, 0xe0a9,		0x21, 0
	.dw 0x1400, 0xe0a9,	0x1fff, 0xe0a9,		0x21, 0
	.dw 0x2400, 0xe0a9,	0x2fff, 0xe0a9,		0x21, 0
	.dw 0x3400, 0xe0a9,	0x3fff, 0xe0a9,		0x21, 0
	.dw 0x4400, 0xe0a9,	0x4fff, 0xe0a9,		0x21, 0
	.dw 0x5400, 0xe0a9,	0x5fff, 0xe0a9,		0x21, 0
	.dw 0x6400, 0xe0a9,	0x6fff, 0xe0a9,		0x21, 0
	.dw 0x7400, 0xe0a9,	0xffff, 0xe0a9,		0x21, 0
	.dw 0x0400, 0xe0aa,	0x0fff, 0xe0aa,		0x21, 0
	.dw 0x1400, 0xe0aa,	0x1fff, 0xe0aa,		0x21, 0
	.dw 0x2400, 0xe0aa,	0x2fff, 0xe0aa,		0x21, 0
	.dw 0x3400, 0xe0aa,	0x3fff, 0xe0aa,		0x21, 0
	.dw 0x4400, 0xe0aa,	0x4fff, 0xe0aa,		0x21, 0
	.dw 0x5400, 0xe0aa,	0x5fff, 0xe0aa,		0x21, 0
	.dw 0x6400, 0xe0aa,	0x6fff, 0xe0aa,		0x21, 0
	.dw 0x7400, 0xe0aa,	0xffff, 0xe0aa,		0x21, 0
	.dw 0x0400, 0xe0ab,	0x0fff, 0xe0ab,		0x21, 0
	.dw 0x1400, 0xe0ab,	0x1fff, 0xe0ab,		0x21, 0
	.dw 0x2400, 0xe0ab,	0x2fff, 0xe0ab,		0x21, 0
	.dw 0x3400, 0xe0ab,	0x3fff, 0xe0ab,		0x21, 0
	.dw 0x4400, 0xe0ab,	0x4fff, 0xe0ab,		0x21, 0
	.dw 0x5400, 0xe0ab,	0x5fff, 0xe0ab,		0x21, 0
	.dw 0x6400, 0xe0ab,	0x6fff, 0xe0ab,		0x21, 0
	.dw 0x7400, 0xe0ab,	0xffff, 0xe0ab,		0x21, 0
	.dw 0x0400, 0xe0ac,	0x0fff, 0xe0ac,		0x21, 0
	.dw 0x1400, 0xe0ac,	0x1fff, 0xe0ac,		0x21, 0
	.dw 0x2400, 0xe0ac,	0x2fff, 0xe0ac,		0x21, 0
	.dw 0x3400, 0xe0ac,	0x3fff, 0xe0ac,		0x21, 0
	.dw 0x4400, 0xe0ac,	0x4fff, 0xe0ac,		0x21, 0
	.dw 0x5400, 0xe0ac,	0x5fff, 0xe0ac,		0x21, 0
	.dw 0x6400, 0xe0ac,	0x6fff, 0xe0ac,		0x21, 0
	.dw 0x7400, 0xe0ac,	0xffff, 0xe0ac,		0x21, 0
	.dw 0x0400, 0xe0ad,	0x0fff, 0xe0ad,		0x21, 0
	.dw 0x1400, 0xe0ad,	0x1fff, 0xe0ad,		0x21, 0
	.dw 0x2400, 0xe0ad,	0x2fff, 0xe0ad,		0x21, 0
	.dw 0x3400, 0xe0ad,	0x3fff, 0xe0ad,		0x21, 0
	.dw 0x4400, 0xe0ad,	0x4fff, 0xe0ad,		0x21, 0
	.dw 0x5400, 0xe0ad,	0x5fff, 0xe0ad,		0x21, 0
	.dw 0x6400, 0xe0ad,	0x6fff, 0xe0ad,		0x21, 0
	.dw 0x7400, 0xe0ad,	0xffff, 0xe0ad,		0x21, 0
	.dw 0x0400, 0xe0ae,	0x0fff, 0xe0ae,		0x21, 0
	.dw 0x1400, 0xe0ae,	0x1fff, 0xe0ae,		0x21, 0
	.dw 0x2400, 0xe0ae,	0x2fff, 0xe0ae,		0x21, 0
	.dw 0x3400, 0xe0ae,	0x3fff, 0xe0ae,		0x21, 0
	.dw 0x4400, 0xe0ae,	0x4fff, 0xe0ae,		0x21, 0
	.dw 0x5400, 0xe0ae,	0x5fff, 0xe0ae,		0x21, 0
	.dw 0x6400, 0xe0ae,	0x6fff, 0xe0ae,		0x21, 0
	.dw 0x7400, 0xe0ae,	0xffff, 0xe0ae,		0x21, 0
	.dw 0x0400, 0xe0af,	0x0fff, 0xe0af,		0x21, 0
	.dw 0x1400, 0xe0af,	0x1fff, 0xe0af,		0x21, 0
	.dw 0x2400, 0xe0af,	0x2fff, 0xe0af,		0x21, 0
	.dw 0x3400, 0xe0af,	0x3fff, 0xe0af,		0x21, 0
	.dw 0x4400, 0xe0af,	0x4fff, 0xe0af,		0x21, 0
	.dw 0x5400, 0xe0af,	0x5fff, 0xe0af,		0x21, 0
	.dw 0x6400, 0xe0af,	0x6fff, 0xe0af,		0x21, 0
	.dw 0x7400, 0xe0af,	0xffff, 0xe0af,		0x21, 0
	.dw 0x0400, 0xe0b0,	0x0fff, 0xe0b0,		0x21, 0
	.dw 0x1400, 0xe0b0,	0x1fff, 0xe0b0,		0x21, 0
	.dw 0x2400, 0xe0b0,	0x2fff, 0xe0b0,		0x21, 0
	.dw 0x3400, 0xe0b0,	0x3fff, 0xe0b0,		0x21, 0
	.dw 0x4400, 0xe0b0,	0x4fff, 0xe0b0,		0x21, 0
	.dw 0x5400, 0xe0b0,	0x5fff, 0xe0b0,		0x21, 0
	.dw 0x6400, 0xe0b0,	0x6fff, 0xe0b0,		0x21, 0
	.dw 0x7400, 0xe0b0,	0xffff, 0xe0b0,		0x21, 0
	.dw 0x0400, 0xe0b1,	0x0fff, 0xe0b1,		0x21, 0
	.dw 0x1400, 0xe0b1,	0x1fff, 0xe0b1,		0x21, 0
	.dw 0x2400, 0xe0b1,	0x2fff, 0xe0b1,		0x21, 0
	.dw 0x3400, 0xe0b1,	0x3fff, 0xe0b1,		0x21, 0
	.dw 0x4400, 0xe0b1,	0x4fff, 0xe0b1,		0x21, 0
	.dw 0x5400, 0xe0b1,	0x5fff, 0xe0b1,		0x21, 0
	.dw 0x6400, 0xe0b1,	0x6fff, 0xe0b1,		0x21, 0
	.dw 0x7400, 0xe0b1,	0xffff, 0xe0b1,		0x21, 0
	.dw 0x0400, 0xe0b2,	0x0fff, 0xe0b2,		0x21, 0
	.dw 0x1400, 0xe0b2,	0x1fff, 0xe0b2,		0x21, 0
	.dw 0x2400, 0xe0b2,	0x2fff, 0xe0b2,		0x21, 0
	.dw 0x3400, 0xe0b2,	0x3fff, 0xe0b2,		0x21, 0
	.dw 0x4400, 0xe0b2,	0x4fff, 0xe0b2,		0x21, 0
	.dw 0x5400, 0xe0b2,	0x5fff, 0xe0b2,		0x21, 0
	.dw 0x6400, 0xe0b2,	0x6fff, 0xe0b2,		0x21, 0
	.dw 0x7400, 0xe0b2,	0xffff, 0xe0b2,		0x21, 0
	.dw 0x0400, 0xe0b3,	0x0fff, 0xe0b3,		0x21, 0
	.dw 0x1400, 0xe0b3,	0x1fff, 0xe0b3,		0x21, 0
	.dw 0x2400, 0xe0b3,	0x2fff, 0xe0b3,		0x21, 0
	.dw 0x3400, 0xe0b3,	0x3fff, 0xe0b3,		0x21, 0
	.dw 0x4400, 0xe0b3,	0x4fff, 0xe0b3,		0x21, 0
	.dw 0x5400, 0xe0b3,	0x5fff, 0xe0b3,		0x21, 0
	.dw 0x6400, 0xe0b3,	0x6fff, 0xe0b3,		0x21, 0
	.dw 0x7400, 0xe0b3,	0xffff, 0xe0b3,		0x21, 0
	.dw 0x0400, 0xe0b4,	0x0fff, 0xe0b4,		0x21, 0
	.dw 0x1400, 0xe0b4,	0x1fff, 0xe0b4,		0x21, 0
	.dw 0x2400, 0xe0b4,	0x2fff, 0xe0b4,		0x21, 0
	.dw 0x3400, 0xe0b4,	0x3fff, 0xe0b4,		0x21, 0
	.dw 0x4400, 0xe0b4,	0x4fff, 0xe0b4,		0x21, 0
	.dw 0x5400, 0xe0b4,	0x5fff, 0xe0b4,		0x21, 0
	.dw 0x6400, 0xe0b4,	0x6fff, 0xe0b4,		0x21, 0
	.dw 0x7400, 0xe0b4,	0xffff, 0xe0b4,		0x21, 0
	.dw 0x0400, 0xe0b5,	0x0fff, 0xe0b5,		0x21, 0
	.dw 0x1400, 0xe0b5,	0x1fff, 0xe0b5,		0x21, 0
	.dw 0x2400, 0xe0b5,	0x2fff, 0xe0b5,		0x21, 0
	.dw 0x3400, 0xe0b5,	0x3fff, 0xe0b5,		0x21, 0
	.dw 0x4400, 0xe0b5,	0x4fff, 0xe0b5,		0x21, 0
	.dw 0x5400, 0xe0b5,	0x5fff, 0xe0b5,		0x21, 0
	.dw 0x6400, 0xe0b5,	0x6fff, 0xe0b5,		0x21, 0
	.dw 0x7400, 0xe0b5,	0xffff, 0xe0b5,		0x21, 0
	.dw 0x0400, 0xe0b6,	0x0fff, 0xe0b6,		0x21, 0
	.dw 0x1400, 0xe0b6,	0x1fff, 0xe0b6,		0x21, 0
	.dw 0x2400, 0xe0b6,	0x2fff, 0xe0b6,		0x21, 0
	.dw 0x3400, 0xe0b6,	0x3fff, 0xe0b6,		0x21, 0
	.dw 0x4400, 0xe0b6,	0x4fff, 0xe0b6,		0x21, 0
	.dw 0x5400, 0xe0b6,	0x5fff, 0xe0b6,		0x21, 0
	.dw 0x6400, 0xe0b6,	0x6fff, 0xe0b6,		0x21, 0
	.dw 0x7400, 0xe0b6,	0xffff, 0xe0b6,		0x21, 0
	.dw 0x0400, 0xe0b7,	0x0fff, 0xe0b7,		0x21, 0
	.dw 0x1400, 0xe0b7,	0x1fff, 0xe0b7,		0x21, 0
	.dw 0x2400, 0xe0b7,	0x2fff, 0xe0b7,		0x21, 0
	.dw 0x3400, 0xe0b7,	0x3fff, 0xe0b7,		0x21, 0
	.dw 0x4400, 0xe0b7,	0x4fff, 0xe0b7,		0x21, 0
	.dw 0x5400, 0xe0b7,	0x5fff, 0xe0b7,		0x21, 0
	.dw 0x6400, 0xe0b7,	0x6fff, 0xe0b7,		0x21, 0
	.dw 0x7400, 0xe0b7,	0xffff, 0xe0b7,		0x21, 0
	.dw 0x0400, 0xe0b8,	0x0fff, 0xe0b8,		0x21, 0
	.dw 0x1400, 0xe0b8,	0x1fff, 0xe0b8,		0x21, 0
	.dw 0x2400, 0xe0b8,	0x2fff, 0xe0b8,		0x21, 0
	.dw 0x3400, 0xe0b8,	0x3fff, 0xe0b8,		0x21, 0
	.dw 0x4400, 0xe0b8,	0x4fff, 0xe0b8,		0x21, 0
	.dw 0x5400, 0xe0b8,	0x5fff, 0xe0b8,		0x21, 0
	.dw 0x6400, 0xe0b8,	0x6fff, 0xe0b8,		0x21, 0
	.dw 0x7400, 0xe0b8,	0xffff, 0xe0b8,		0x21, 0
	.dw 0x0400, 0xe0b9,	0x0fff, 0xe0b9,		0x21, 0
	.dw 0x1400, 0xe0b9,	0x1fff, 0xe0b9,		0x21, 0
	.dw 0x2400, 0xe0b9,	0x2fff, 0xe0b9,		0x21, 0
	.dw 0x3400, 0xe0b9,	0x3fff, 0xe0b9,		0x21, 0
	.dw 0x4400, 0xe0b9,	0x4fff, 0xe0b9,		0x21, 0
	.dw 0x5400, 0xe0b9,	0x5fff, 0xe0b9,		0x21, 0
	.dw 0x6400, 0xe0b9,	0x6fff, 0xe0b9,		0x21, 0
	.dw 0x7400, 0xe0b9,	0xffff, 0xe0b9,		0x21, 0
	.dw 0x0400, 0xe0ba,	0x0fff, 0xe0ba,		0x21, 0
	.dw 0x1400, 0xe0ba,	0x1fff, 0xe0ba,		0x21, 0
	.dw 0x2400, 0xe0ba,	0x2fff, 0xe0ba,		0x21, 0
	.dw 0x3400, 0xe0ba,	0x3fff, 0xe0ba,		0x21, 0
	.dw 0x4400, 0xe0ba,	0x4fff, 0xe0ba,		0x21, 0
	.dw 0x5400, 0xe0ba,	0x5fff, 0xe0ba,		0x21, 0
	.dw 0x6400, 0xe0ba,	0x6fff, 0xe0ba,		0x21, 0
	.dw 0x7400, 0xe0ba,	0xffff, 0xe0ba,		0x21, 0
	.dw 0x0400, 0xe0bb,	0x0fff, 0xe0bb,		0x21, 0
	.dw 0x1400, 0xe0bb,	0x1fff, 0xe0bb,		0x21, 0
	.dw 0x2400, 0xe0bb,	0x2fff, 0xe0bb,		0x21, 0
	.dw 0x3400, 0xe0bb,	0x3fff, 0xe0bb,		0x21, 0
	.dw 0x4400, 0xe0bb,	0x4fff, 0xe0bb,		0x21, 0
	.dw 0x5400, 0xe0bb,	0x5fff, 0xe0bb,		0x21, 0
	.dw 0x6400, 0xe0bb,	0x6fff, 0xe0bb,		0x21, 0
	.dw 0x7400, 0xe0bb,	0xffff, 0xe0bb,		0x21, 0
	.dw 0x0400, 0xe0bc,	0x0fff, 0xe0bc,		0x21, 0
	.dw 0x1400, 0xe0bc,	0x1fff, 0xe0bc,		0x21, 0
	.dw 0x2400, 0xe0bc,	0x2fff, 0xe0bc,		0x21, 0
	.dw 0x3400, 0xe0bc,	0x3fff, 0xe0bc,		0x21, 0
	.dw 0x4400, 0xe0bc,	0x4fff, 0xe0bc,		0x21, 0
	.dw 0x5400, 0xe0bc,	0x5fff, 0xe0bc,		0x21, 0
	.dw 0x6400, 0xe0bc,	0x6fff, 0xe0bc,		0x21, 0
	.dw 0x7400, 0xe0bc,	0xffff, 0xe0bc,		0x21, 0
	.dw 0x0400, 0xe0bd,	0x0fff, 0xe0bd,		0x21, 0
	.dw 0x1400, 0xe0bd,	0x1fff, 0xe0bd,		0x21, 0
	.dw 0x2400, 0xe0bd,	0x2fff, 0xe0bd,		0x21, 0
	.dw 0x3400, 0xe0bd,	0x3fff, 0xe0bd,		0x21, 0
	.dw 0x4400, 0xe0bd,	0x4fff, 0xe0bd,		0x21, 0
	.dw 0x5400, 0xe0bd,	0x5fff, 0xe0bd,		0x21, 0
	.dw 0x6400, 0xe0bd,	0x6fff, 0xe0bd,		0x21, 0
	.dw 0x7400, 0xe0bd,	0xffff, 0xe0bd,		0x21, 0
	.dw 0x0400, 0xe0be,	0x0fff, 0xe0be,		0x21, 0
	.dw 0x1400, 0xe0be,	0x1fff, 0xe0be,		0x21, 0
	.dw 0x2400, 0xe0be,	0x2fff, 0xe0be,		0x21, 0
	.dw 0x3400, 0xe0be,	0x3fff, 0xe0be,		0x21, 0
	.dw 0x4400, 0xe0be,	0x4fff, 0xe0be,		0x21, 0
	.dw 0x5400, 0xe0be,	0x5fff, 0xe0be,		0x21, 0
	.dw 0x6400, 0xe0be,	0x6fff, 0xe0be,		0x21, 0
	.dw 0x7400, 0xe0be,	0xffff, 0xe0be,		0x21, 0
	.dw 0x0400, 0xe0bf,	0x0fff, 0xe0bf,		0x21, 0
	.dw 0x1400, 0xe0bf,	0x1fff, 0xe0bf,		0x21, 0
	.dw 0x2400, 0xe0bf,	0x2fff, 0xe0bf,		0x21, 0
	.dw 0x3400, 0xe0bf,	0x3fff, 0xe0bf,		0x21, 0
	.dw 0x4400, 0xe0bf,	0x4fff, 0xe0bf,		0x21, 0
	.dw 0x5400, 0xe0bf,	0x5fff, 0xe0bf,		0x21, 0
	.dw 0x6400, 0xe0bf,	0x6fff, 0xe0bf,		0x21, 0
	.dw 0x7400, 0xe0bf,	0xffff, 0xe0df,		0x21, 0
	.dw 0x0400, 0xe0e0,	0x0fff, 0xe0e0,		0x21, 0
	.dw 0x1400, 0xe0e0,	0x1fff, 0xe0e0,		0x21, 0
	.dw 0x2400, 0xe0e0,	0x2fff, 0xe0e0,		0x21, 0
	.dw 0x3400, 0xe0e0,	0x3fff, 0xe0e0,		0x21, 0
	.dw 0x4400, 0xe0e0,	0x4fff, 0xe0e0,		0x21, 0
	.dw 0x5400, 0xe0e0,	0x5fff, 0xe0e0,		0x21, 0
	.dw 0x6400, 0xe0e0,	0x6fff, 0xe0e0,		0x21, 0
	.dw 0x7400, 0xe0e0,	0xffff, 0xe0e0,		0x21, 0
	.dw 0x0400, 0xe0e1,	0x0fff, 0xe0e1,		0x21, 0
	.dw 0x1400, 0xe0e1,	0x1fff, 0xe0e1,		0x21, 0
	.dw 0x2400, 0xe0e1,	0x2fff, 0xe0e1,		0x21, 0
	.dw 0x3400, 0xe0e1,	0x3fff, 0xe0e1,		0x21, 0
	.dw 0x4400, 0xe0e1,	0x4fff, 0xe0e1,		0x21, 0
	.dw 0x5400, 0xe0e1,	0x5fff, 0xe0e1,		0x21, 0
	.dw 0x6400, 0xe0e1,	0x6fff, 0xe0e1,		0x21, 0
	.dw 0x7400, 0xe0e1,	0xffff, 0xe0e1,		0x21, 0
	.dw 0x0400, 0xe0e2,	0x0fff, 0xe0e2,		0x21, 0
	.dw 0x1400, 0xe0e2,	0x1fff, 0xe0e2,		0x21, 0
	.dw 0x2400, 0xe0e2,	0x2fff, 0xe0e2,		0x21, 0
	.dw 0x3400, 0xe0e2,	0x3fff, 0xe0e2,		0x21, 0
	.dw 0x4400, 0xe0e2,	0x4fff, 0xe0e2,		0x21, 0
	.dw 0x5400, 0xe0e2,	0x5fff, 0xe0e2,		0x21, 0
	.dw 0x6400, 0xe0e2,	0x6fff, 0xe0e2,		0x21, 0
	.dw 0x7400, 0xe0e2,	0xffff, 0xe0e2,		0x21, 0
	.dw 0x0400, 0xe0e3,	0x0fff, 0xe0e3,		0x21, 0
	.dw 0x1400, 0xe0e3,	0x1fff, 0xe0e3,		0x21, 0
	.dw 0x2400, 0xe0e3,	0x2fff, 0xe0e3,		0x21, 0
	.dw 0x3400, 0xe0e3,	0x3fff, 0xe0e3,		0x21, 0
	.dw 0x4400, 0xe0e3,	0x4fff, 0xe0e3,		0x21, 0
	.dw 0x5400, 0xe0e3,	0x5fff, 0xe0e3,		0x21, 0
	.dw 0x6400, 0xe0e3,	0x6fff, 0xe0e3,		0x21, 0
	.dw 0x7400, 0xe0e3,	0xffff, 0xe0e3,		0x21, 0
	.dw 0x0400, 0xe0e4,	0x0fff, 0xe0e4,		0x21, 0
	.dw 0x1400, 0xe0e4,	0x1fff, 0xe0e4,		0x21, 0
	.dw 0x2400, 0xe0e4,	0x2fff, 0xe0e4,		0x21, 0
	.dw 0x3400, 0xe0e4,	0x3fff, 0xe0e4,		0x21, 0
	.dw 0x4400, 0xe0e4,	0x4fff, 0xe0e4,		0x21, 0
	.dw 0x5400, 0xe0e4,	0x5fff, 0xe0e4,		0x21, 0
	.dw 0x6400, 0xe0e4,	0x6fff, 0xe0e4,		0x21, 0
	.dw 0x7400, 0xe0e4,	0xffff, 0xe0e4,		0x21, 0
	.dw 0x0400, 0xe0e5,	0x0fff, 0xe0e5,		0x21, 0
	.dw 0x1400, 0xe0e5,	0x1fff, 0xe0e5,		0x21, 0
	.dw 0x2400, 0xe0e5,	0x2fff, 0xe0e5,		0x21, 0
	.dw 0x3400, 0xe0e5,	0x3fff, 0xe0e5,		0x21, 0
	.dw 0x4400, 0xe0e5,	0x4fff, 0xe0e5,		0x21, 0
	.dw 0x5400, 0xe0e5,	0x5fff, 0xe0e5,		0x21, 0
	.dw 0x6400, 0xe0e5,	0x6fff, 0xe0e5,		0x21, 0
	.dw 0x7400, 0xe0e5,	0xffff, 0xe0e5,		0x21, 0
	.dw 0x0400, 0xe0e6,	0x0fff, 0xe0e6,		0x21, 0
	.dw 0x1400, 0xe0e6,	0x1fff, 0xe0e6,		0x21, 0
	.dw 0x2400, 0xe0e6,	0x2fff, 0xe0e6,		0x21, 0
	.dw 0x3400, 0xe0e6,	0x3fff, 0xe0e6,		0x21, 0
	.dw 0x4400, 0xe0e6,	0x4fff, 0xe0e6,		0x21, 0
	.dw 0x5400, 0xe0e6,	0x5fff, 0xe0e6,		0x21, 0
	.dw 0x6400, 0xe0e6,	0x6fff, 0xe0e6,		0x21, 0
	.dw 0x7400, 0xe0e6,	0xffff, 0xe0e6,		0x21, 0
	.dw 0x0400, 0xe0e7,	0x0fff, 0xe0e7,		0x21, 0
	.dw 0x1400, 0xe0e7,	0x1fff, 0xe0e7,		0x21, 0
	.dw 0x2400, 0xe0e7,	0x2fff, 0xe0e7,		0x21, 0
	.dw 0x3400, 0xe0e7,	0x3fff, 0xe0e7,		0x21, 0
	.dw 0x4400, 0xe0e7,	0x4fff, 0xe0e7,		0x21, 0
	.dw 0x5400, 0xe0e7,	0x5fff, 0xe0e7,		0x21, 0
	.dw 0x6400, 0xe0e7,	0x6fff, 0xe0e7,		0x21, 0
	.dw 0x7400, 0xe0e7,	0xffff, 0xe0e7,		0x21, 0
	.dw 0x0400, 0xe0e8,	0x0fff, 0xe0e8,		0x21, 0
	.dw 0x1400, 0xe0e8,	0x1fff, 0xe0e8,		0x21, 0
	.dw 0x2400, 0xe0e8,	0x2fff, 0xe0e8,		0x21, 0
	.dw 0x3400, 0xe0e8,	0x3fff, 0xe0e8,		0x21, 0
	.dw 0x4400, 0xe0e8,	0x4fff, 0xe0e8,		0x21, 0
	.dw 0x5400, 0xe0e8,	0x5fff, 0xe0e8,		0x21, 0
	.dw 0x6400, 0xe0e8,	0x6fff, 0xe0e8,		0x21, 0
	.dw 0x7400, 0xe0e8,	0xffff, 0xe0e8,		0x21, 0
	.dw 0x0400, 0xe0e9,	0x0fff, 0xe0e9,		0x21, 0
	.dw 0x1400, 0xe0e9,	0x1fff, 0xe0e9,		0x21, 0
	.dw 0x2400, 0xe0e9,	0x2fff, 0xe0e9,		0x21, 0
	.dw 0x3400, 0xe0e9,	0x3fff, 0xe0e9,		0x21, 0
	.dw 0x4400, 0xe0e9,	0x4fff, 0xe0e9,		0x21, 0
	.dw 0x5400, 0xe0e9,	0x5fff, 0xe0e9,		0x21, 0
	.dw 0x6400, 0xe0e9,	0x6fff, 0xe0e9,		0x21, 0
	.dw 0x7400, 0xe0e9,	0xffff, 0xe0e9,		0x21, 0
	.dw 0x0400, 0xe0ea,	0x0fff, 0xe0ea,		0x21, 0
	.dw 0x1400, 0xe0ea,	0x1fff, 0xe0ea,		0x21, 0
	.dw 0x2400, 0xe0ea,	0x2fff, 0xe0ea,		0x21, 0
	.dw 0x3400, 0xe0ea,	0x3fff, 0xe0ea,		0x21, 0
	.dw 0x4400, 0xe0ea,	0x4fff, 0xe0ea,		0x21, 0
	.dw 0x5400, 0xe0ea,	0x5fff, 0xe0ea,		0x21, 0
	.dw 0x6400, 0xe0ea,	0x6fff, 0xe0ea,		0x21, 0
	.dw 0x7400, 0xe0ea,	0xffff, 0xe0ea,		0x21, 0
	.dw 0x0400, 0xe0eb,	0x0fff, 0xe0eb,		0x21, 0
	.dw 0x1400, 0xe0eb,	0x1fff, 0xe0eb,		0x21, 0
	.dw 0x2400, 0xe0eb,	0x2fff, 0xe0eb,		0x21, 0
	.dw 0x3400, 0xe0eb,	0x3fff, 0xe0eb,		0x21, 0
	.dw 0x4400, 0xe0eb,	0x4fff, 0xe0eb,		0x21, 0
	.dw 0x5400, 0xe0eb,	0x5fff, 0xe0eb,		0x21, 0
	.dw 0x6400, 0xe0eb,	0x6fff, 0xe0eb,		0x21, 0
	.dw 0x7400, 0xe0eb,	0xffff, 0xe0eb,		0x21, 0
	.dw 0x0400, 0xe0ec,	0x0fff, 0xe0ec,		0x21, 0
	.dw 0x1400, 0xe0ec,	0x1fff, 0xe0ec,		0x21, 0
	.dw 0x2400, 0xe0ec,	0x2fff, 0xe0ec,		0x21, 0
	.dw 0x3400, 0xe0ec,	0x3fff, 0xe0ec,		0x21, 0
	.dw 0x4400, 0xe0ec,	0x4fff, 0xe0ec,		0x21, 0
	.dw 0x5400, 0xe0ec,	0x5fff, 0xe0ec,		0x21, 0
	.dw 0x6400, 0xe0ec,	0x6fff, 0xe0ec,		0x21, 0
	.dw 0x7400, 0xe0ec,	0xffff, 0xe0ec,		0x21, 0
	.dw 0x0400, 0xe0ed,	0x0fff, 0xe0ed,		0x21, 0
	.dw 0x1400, 0xe0ed,	0x1fff, 0xe0ed,		0x21, 0
	.dw 0x2400, 0xe0ed,	0x2fff, 0xe0ed,		0x21, 0
	.dw 0x3400, 0xe0ed,	0x3fff, 0xe0ed,		0x21, 0
	.dw 0x4400, 0xe0ed,	0x4fff, 0xe0ed,		0x21, 0
	.dw 0x5400, 0xe0ed,	0x5fff, 0xe0ed,		0x21, 0
	.dw 0x6400, 0xe0ed,	0x6fff, 0xe0ed,		0x21, 0
	.dw 0x7400, 0xe0ed,	0xffff, 0xe0ed,		0x21, 0
	.dw 0x0400, 0xe0ee,	0x0fff, 0xe0ee,		0x21, 0
	.dw 0x1400, 0xe0ee,	0x1fff, 0xe0ee,		0x21, 0
	.dw 0x2400, 0xe0ee,	0x2fff, 0xe0ee,		0x21, 0
	.dw 0x3400, 0xe0ee,	0x3fff, 0xe0ee,		0x21, 0
	.dw 0x4400, 0xe0ee,	0x4fff, 0xe0ee,		0x21, 0
	.dw 0x5400, 0xe0ee,	0x5fff, 0xe0ee,		0x21, 0
	.dw 0x6400, 0xe0ee,	0x6fff, 0xe0ee,		0x21, 0
	.dw 0x7400, 0xe0ee,	0xffff, 0xe0ee,		0x21, 0
	.dw 0x0400, 0xe0ef,	0x0fff, 0xe0ef,		0x21, 0
	.dw 0x1400, 0xe0ef,	0x1fff, 0xe0ef,		0x21, 0
	.dw 0x2400, 0xe0ef,	0x2fff, 0xe0ef,		0x21, 0
	.dw 0x3400, 0xe0ef,	0x3fff, 0xe0ef,		0x21, 0
	.dw 0x4400, 0xe0ef,	0x4fff, 0xe0ef,		0x21, 0
	.dw 0x5400, 0xe0ef,	0x5fff, 0xe0ef,		0x21, 0
	.dw 0x6400, 0xe0ef,	0x6fff, 0xe0ef,		0x21, 0
	.dw 0x7400, 0xe0ef,	0xffff, 0xe0ef,		0x21, 0
	.dw 0x0400, 0xe0f0,	0x0fff, 0xe0f0,		0x21, 0
	.dw 0x1400, 0xe0f0,	0x1fff, 0xe0f0,		0x21, 0
	.dw 0x2400, 0xe0f0,	0x2fff, 0xe0f0,		0x21, 0
	.dw 0x3400, 0xe0f0,	0x3fff, 0xe0f0,		0x21, 0
	.dw 0x4400, 0xe0f0,	0x4fff, 0xe0f0,		0x21, 0
	.dw 0x5400, 0xe0f0,	0x5fff, 0xe0f0,		0x21, 0
	.dw 0x6400, 0xe0f0,	0x6fff, 0xe0f0,		0x21, 0
	.dw 0x7400, 0xe0f0,	0xffff, 0xe0f0,		0x21, 0
	.dw 0x0400, 0xe0f1,	0x0fff, 0xe0f1,		0x21, 0
	.dw 0x1400, 0xe0f1,	0x1fff, 0xe0f1,		0x21, 0
	.dw 0x2400, 0xe0f1,	0x2fff, 0xe0f1,		0x21, 0
	.dw 0x3400, 0xe0f1,	0x3fff, 0xe0f1,		0x21, 0
	.dw 0x4400, 0xe0f1,	0x4fff, 0xe0f1,		0x21, 0
	.dw 0x5400, 0xe0f1,	0x5fff, 0xe0f1,		0x21, 0
	.dw 0x6400, 0xe0f1,	0x6fff, 0xe0f1,		0x21, 0
	.dw 0x7400, 0xe0f1,	0xffff, 0xe0f1,		0x21, 0
	.dw 0x0400, 0xe0f2,	0x0fff, 0xe0f2,		0x21, 0
	.dw 0x1400, 0xe0f2,	0x1fff, 0xe0f2,		0x21, 0
	.dw 0x2400, 0xe0f2,	0x2fff, 0xe0f2,		0x21, 0
	.dw 0x3400, 0xe0f2,	0x3fff, 0xe0f2,		0x21, 0
	.dw 0x4400, 0xe0f2,	0x4fff, 0xe0f2,		0x21, 0
	.dw 0x5400, 0xe0f2,	0x5fff, 0xe0f2,		0x21, 0
	.dw 0x6400, 0xe0f2,	0x6fff, 0xe0f2,		0x21, 0
	.dw 0x7400, 0xe0f2,	0xffff, 0xe0f2,		0x21, 0
	.dw 0x0400, 0xe0f3,	0x0fff, 0xe0f3,		0x21, 0
	.dw 0x1400, 0xe0f3,	0x1fff, 0xe0f3,		0x21, 0
	.dw 0x2400, 0xe0f3,	0x2fff, 0xe0f3,		0x21, 0
	.dw 0x3400, 0xe0f3,	0x3fff, 0xe0f3,		0x21, 0
	.dw 0x4400, 0xe0f3,	0x4fff, 0xe0f3,		0x21, 0
	.dw 0x5400, 0xe0f3,	0x5fff, 0xe0f3,		0x21, 0
	.dw 0x6400, 0xe0f3,	0x6fff, 0xe0f3,		0x21, 0
	.dw 0x7400, 0xe0f3,	0xffff, 0xe0f3,		0x21, 0
	.dw 0x0400, 0xe0f4,	0x0fff, 0xe0f4,		0x21, 0
	.dw 0x1400, 0xe0f4,	0x1fff, 0xe0f4,		0x21, 0
	.dw 0x2400, 0xe0f4,	0x2fff, 0xe0f4,		0x21, 0
	.dw 0x3400, 0xe0f4,	0x3fff, 0xe0f4,		0x21, 0
	.dw 0x4400, 0xe0f4,	0x4fff, 0xe0f4,		0x21, 0
	.dw 0x5400, 0xe0f4,	0x5fff, 0xe0f4,		0x21, 0
	.dw 0x6400, 0xe0f4,	0x6fff, 0xe0f4,		0x21, 0
	.dw 0x7400, 0xe0f4,	0xffff, 0xe0f4,		0x21, 0
	.dw 0x0400, 0xe0f5,	0x0fff, 0xe0f5,		0x21, 0
	.dw 0x1400, 0xe0f5,	0x1fff, 0xe0f5,		0x21, 0
	.dw 0x2400, 0xe0f5,	0x2fff, 0xe0f5,		0x21, 0
	.dw 0x3400, 0xe0f5,	0x3fff, 0xe0f5,		0x21, 0
	.dw 0x4400, 0xe0f5,	0x4fff, 0xe0f5,		0x21, 0
	.dw 0x5400, 0xe0f5,	0x5fff, 0xe0f5,		0x21, 0
	.dw 0x6400, 0xe0f5,	0x6fff, 0xe0f5,		0x21, 0
	.dw 0x7400, 0xe0f5,	0xffff, 0xe0f5,		0x21, 0
	.dw 0x0400, 0xe0f6,	0x0fff, 0xe0f6,		0x21, 0
	.dw 0x1400, 0xe0f6,	0x1fff, 0xe0f6,		0x21, 0
	.dw 0x2400, 0xe0f6,	0x2fff, 0xe0f6,		0x21, 0
	.dw 0x3400, 0xe0f6,	0x3fff, 0xe0f6,		0x21, 0
	.dw 0x4400, 0xe0f6,	0x4fff, 0xe0f6,		0x21, 0
	.dw 0x5400, 0xe0f6,	0x5fff, 0xe0f6,		0x21, 0
	.dw 0x6400, 0xe0f6,	0x6fff, 0xe0f6,		0x21, 0
	.dw 0x7400, 0xe0f6,	0xffff, 0xe0f6,		0x21, 0
	.dw 0x0400, 0xe0f7,	0x0fff, 0xe0f7,		0x21, 0
	.dw 0x1400, 0xe0f7,	0x1fff, 0xe0f7,		0x21, 0
	.dw 0x2400, 0xe0f7,	0x2fff, 0xe0f7,		0x21, 0
	.dw 0x3400, 0xe0f7,	0x3fff, 0xe0f7,		0x21, 0
	.dw 0x4400, 0xe0f7,	0x4fff, 0xe0f7,		0x21, 0
	.dw 0x5400, 0xe0f7,	0x5fff, 0xe0f7,		0x21, 0
	.dw 0x6400, 0xe0f7,	0x6fff, 0xe0f7,		0x21, 0
	.dw 0x7400, 0xe0f7,	0xffff, 0xe0f7,		0x21, 0
	.dw 0x0400, 0xe0f8,	0x0fff, 0xe0f8,		0x21, 0
	.dw 0x1400, 0xe0f8,	0x1fff, 0xe0f8,		0x21, 0
	.dw 0x2400, 0xe0f8,	0x2fff, 0xe0f8,		0x21, 0
	.dw 0x3400, 0xe0f8,	0x3fff, 0xe0f8,		0x21, 0
	.dw 0x4400, 0xe0f8,	0x4fff, 0xe0f8,		0x21, 0
	.dw 0x5400, 0xe0f8,	0x5fff, 0xe0f8,		0x21, 0
	.dw 0x6400, 0xe0f8,	0x6fff, 0xe0f8,		0x21, 0
	.dw 0x7400, 0xe0f8,	0xffff, 0xe0f8,		0x21, 0
	.dw 0x0400, 0xe0f9,	0x0fff, 0xe0f9,		0x21, 0
	.dw 0x1400, 0xe0f9,	0x1fff, 0xe0f9,		0x21, 0
	.dw 0x2400, 0xe0f9,	0x2fff, 0xe0f9,		0x21, 0
	.dw 0x3400, 0xe0f9,	0x3fff, 0xe0f9,		0x21, 0
	.dw 0x4400, 0xe0f9,	0x4fff, 0xe0f9,		0x21, 0
	.dw 0x5400, 0xe0f9,	0x5fff, 0xe0f9,		0x21, 0
	.dw 0x6400, 0xe0f9,	0x6fff, 0xe0f9,		0x21, 0
	.dw 0x7400, 0xe0f9,	0xffff, 0xe0f9,		0x21, 0
	.dw 0x0400, 0xe0fa,	0x0fff, 0xe0fa,		0x21, 0
	.dw 0x1400, 0xe0fa,	0x1fff, 0xe0fa,		0x21, 0
	.dw 0x2400, 0xe0fa,	0x2fff, 0xe0fa,		0x21, 0
	.dw 0x3400, 0xe0fa,	0x3fff, 0xe0fa,		0x21, 0
	.dw 0x4400, 0xe0fa,	0x4fff, 0xe0fa,		0x21, 0
	.dw 0x5400, 0xe0fa,	0x5fff, 0xe0fa,		0x21, 0
	.dw 0x6400, 0xe0fa,	0x6fff, 0xe0fa,		0x21, 0
	.dw 0x7400, 0xe0fa,	0xffff, 0xe0fa,		0x21, 0
	.dw 0x0400, 0xe0fb,	0x0fff, 0xe0fb,		0x21, 0
	.dw 0x1400, 0xe0fb,	0x1fff, 0xe0fb,		0x21, 0
	.dw 0x2400, 0xe0fb,	0x2fff, 0xe0fb,		0x21, 0
	.dw 0x3400, 0xe0fb,	0x3fff, 0xe0fb,		0x21, 0
	.dw 0x4400, 0xe0fb,	0x4fff, 0xe0fb,		0x21, 0
	.dw 0x5400, 0xe0fb,	0x5fff, 0xe0fb,		0x21, 0
	.dw 0x6400, 0xe0fb,	0x6fff, 0xe0fb,		0x21, 0
	.dw 0x7400, 0xe0fb,	0xffff, 0xe0fb,		0x21, 0
	.dw 0x0400, 0xe0fc,	0x0fff, 0xe0fc,		0x21, 0
	.dw 0x1400, 0xe0fc,	0x1fff, 0xe0fc,		0x21, 0
	.dw 0x2400, 0xe0fc,	0x2fff, 0xe0fc,		0x21, 0
	.dw 0x3400, 0xe0fc,	0x3fff, 0xe0fc,		0x21, 0
	.dw 0x4400, 0xe0fc,	0x4fff, 0xe0fc,		0x21, 0
	.dw 0x5400, 0xe0fc,	0x5fff, 0xe0fc,		0x21, 0
	.dw 0x6400, 0xe0fc,	0x6fff, 0xe0fc,		0x21, 0
	.dw 0x7400, 0xe0fc,	0xffff, 0xe0fc,		0x21, 0
	.dw 0x0400, 0xe0fd,	0x0fff, 0xe0fd,		0x21, 0
	.dw 0x1400, 0xe0fd,	0x1fff, 0xe0fd,		0x21, 0
	.dw 0x2400, 0xe0fd,	0x2fff, 0xe0fd,		0x21, 0
	.dw 0x3400, 0xe0fd,	0x3fff, 0xe0fd,		0x21, 0
	.dw 0x4400, 0xe0fd,	0x4fff, 0xe0fd,		0x21, 0
	.dw 0x5400, 0xe0fd,	0x5fff, 0xe0fd,		0x21, 0
	.dw 0x6400, 0xe0fd,	0x6fff, 0xe0fd,		0x21, 0
	.dw 0x7400, 0xe0fd,	0xffff, 0xe0fd,		0x21, 0
	.dw 0x0400, 0xe0fe,	0x0fff, 0xe0fe,		0x21, 0
	.dw 0x1400, 0xe0fe,	0x1fff, 0xe0fe,		0x21, 0
	.dw 0x2400, 0xe0fe,	0x2fff, 0xe0fe,		0x21, 0
	.dw 0x3400, 0xe0fe,	0x3fff, 0xe0fe,		0x21, 0
	.dw 0x4400, 0xe0fe,	0x4fff, 0xe0fe,		0x21, 0
	.dw 0x5400, 0xe0fe,	0x5fff, 0xe0fe,		0x21, 0
	.dw 0x6400, 0xe0fe,	0x6fff, 0xe0fe,		0x21, 0
	.dw 0x7400, 0xe0fe,	0xffff, 0xe0fe,		0x21, 0
	.dw 0x0400, 0xe0ff,	0x0fff, 0xe0ff,		0x21, 0
	.dw 0x1400, 0xe0ff,	0x1fff, 0xe0ff,		0x21, 0
	.dw 0x2400, 0xe0ff,	0x2fff, 0xe0ff,		0x21, 0
	.dw 0x3400, 0xe0ff,	0x3fff, 0xe0ff,		0x21, 0
	.dw 0x4400, 0xe0ff,	0x4fff, 0xe0ff,		0x21, 0
	.dw 0x5400, 0xe0ff,	0x5fff, 0xe0ff,		0x21, 0
	.dw 0x6400, 0xe0ff,	0x6fff, 0xe0ff,		0x21, 0
	.dw 0x7400, 0xe0ff,	0xffff, 0xe0ff,		0x21, 0
	.dw 0x0000, 0xe160,	0xffff, 0xe17f,		0x21, 0
	.dw 0x0000, 0xe1a0,	0xffff, 0xe1ff,		0x21, 0
	.dw 0x0000, 0xe4c0,	0xffff, 0xe4ff,		0x21, 0
	.dw 0x0000, 0xe5c0,	0xffff, 0xe5ff,		0x21, 0
	.dw 0x0000, 0xe6c0,	0xffff, 0xe6ff,		0x21, 0
	.dw 0x0000, 0xe740,	0xffff, 0xe7ff,		0x21, 0
	.dw 0x0000, 0xf001,	0xffff, 0xffff,		0x21, 0
	.dw 0x0000, 0x0000,	0x0000, 0x0000,		0x00, 0
.endm

	se_all_test
